/*
=====================
EE-CPTCITY 0.0.2
=====================

---------------------------------------------------------------------------------
cptcity color Palettes for the Google Earth Engine JavaScript API (Code Editor)
---------------------------------------------------------------------------------

===========
MIT License
===========

Copyright (c) 2022 Antony Marcos Barja Ingaruca

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

=================
GitHub Repository
=================

ee-cptcity module: https://github.com/ambarja/ee-cptcity
*/

/*
Original function is based in pokepalletes of David Montero
link: https://github.com/davemlz/ee-pokepalettes
*/

/**
 * Creates a color bar panel.
 *
 * @param {string} title - Title of the colorbar.
 * @param {numeric} minValue - Min label value.
 * @param {numeric} maxValue - Max label value.
 * @param {Array} palette - Palette to use.
 *
 */

exports.colorbar = function (title, minValue, maxValue, palette) {
  function makeColorBarParams(palette) {
    return {
      bbox: [0, 0, 1, 0.1],
      dimensions: '100x10',
      format: 'png',
      min: 0,
      max: 1,
      palette: palette,
    };
  }

  function makeColorBar(palette) {
    return ui.Thumbnail({
      image: ee.Image.pixelLonLat().select(0),
      params: makeColorBarParams(palette),
      style: { stretch: 'horizontal', margin: '0px 8px', maxHeight: '24px' },
    });
  }

  function makeLabels(min, max) {
    return ui.Panel({
      widgets: [
        ui.Label(min, { margin: '4px 8px' }),
        ui.Label(
          (max / 2),
          { margin: '4px 8px', textAlign: 'center', stretch: 'horizontal' }),
        ui.Label(max, { margin: '4px 8px' })
      ],
      layout: ui.Panel.Layout.flow('horizontal')
    });
  }

  var legendTitle = ui.Label({
    value: title,
    style: { fontWeight: 'bold' }
  });

  return ui.Panel([
    legendTitle,
    makeColorBar(palette),
    makeLabels(minValue, maxValue)
  ]);

};

/**
* Returns the cptcity color palettes.
*/
exports.pal = { "arendal_arctic": ["#2C3563", "#2E3664", "#303867", "#323B6A", "#343C6B", "#363D6D", "#383F6F", "#394171", "#3C4474", "#3E4676", "#404878", "#424A7A", "#444B7C", "#464E7E", "#495181", "#4C5484", "#4D5585", "#505888", "#525A8A", "#565E8E", "#586090", "#5A6392", "#5C6594", "#5F6897", "#626B9A", "#666F9D", "#6972A0", "#6B75A2", "#7079A5", "#757DA7", "#7C83AA", "#8287AD", "#868BAF", "#8B8FB1", "#8F93B4", "#9498B5", "#9B9EB9", "#9FA1BB", "#A3A5BD", "#A6A8BF", "#AAACC1", "#AFB0C3", "#B4B5C5", "#B6B7C7", "#B9BAC8", "#BBBCCA", "#BEBFCB", "#C1C1CC", "#C2C3CD", "#C4C5CE", "#C5C5CE", "#96D283", "#9BD984", "#9EDA85", "#A2DC86", "#A5DC86", "#A8DD86", "#AADE87", "#AEDF87", "#B1E087", "#B5E288", "#B8E389", "#BAE389", "#BDE489", "#BFE58A", "#C3E68A", "#C7E78B", "#CAE88B", "#CDE98C", "#CFEA8D", "#D2EB8D", "#D6EC8E", "#DAED8E", "#DCEE8F", "#DEEF8F", "#E0EE8E", "#E1EB8B", "#E0ED8D", "#E1EB8B", "#E2E989", "#E3E584", "#E4E382", "#E5E17F", "#E5DF7D", "#E6DD7B", "#E7DB78", "#E8D977", "#E8D674", "#EAD270", "#EBD06E", "#ECCE6B", "#ECCC69", "#EDCA68", "#EEC866", "#EFC664", "#EFC462", "#F0C15F", "#F1BD5B", "#F0BB5A", "#EBB95A", "#E7B759", "#E2B559", "#DEB359", "#DAB159", "#D2AD59", "#CCAB59", "#C8A959", "#C4A759", "#BFA559", "#BBA359", "#B7A259", "#B3A059", "#AE9E59"], "arendal_temperature": ["#1E5CB3", "#1E5CB3", "#176FC1", "#176FC1", "#0B8ED8", "#0B8ED8", "#04A1E6", "#04A1E6", "#19B5F1", "#19B5F1", "#33BCCF", "#33BCCF", "#66CCCE", "#66CCCE", "#99DBB8", "#99DBB8", "#C0E588", "#C0E588", "#CCE64B", "#CCE64B", "#F3F01D", "#F3F01D", "#FEDE27", "#FEDE27", "#FCC707", "#FCC707", "#F89D0E", "#F89D0E", "#F57215", "#F57215", "#F1471C", "#F1471C", "#DB1E26", "#DB1E26", "#A4262C", "#A4262C"], "arendal_zambezi_focus": ["#98CB4E", "#98CB4E", "#DCE164", "#DCE164", "#FDEE8E", "#FDEE8E", "#F1C55E", "#F1C55E", "#B87F3F", "#B87F3F", "#9C6A3E", "#9C6A3E", "#FFFFFF", "#FFFFFF"], "cividis": ["#00204D", "#002455", "#00275E", "#002B68", "#002E6F", "#00326F", "#01366E", "#14396D", "#213D6D", "#2A406C", "#31446B", "#38486B", "#3E4B6B", "#434F6B", "#49526B", "#4F576C", "#545A6C", "#595E6D", "#5D616E", "#62656F", "#666970", "#6B6C71", "#6F7073", "#737475", "#787777", "#7D7C78", "#828079", "#868379", "#8B8779", "#908B79", "#958F78", "#9A9377", "#9F9777", "#A49B76", "#AA9F75", "#B0A473", "#B5A971", "#BAAD70", "#C0B16E", "#C5B56C", "#CBBA69", "#D0BE67", "#D6C364", "#DBC761", "#E1CC5D", "#E7D259", "#EDD654", "#F3DB4F", "#F9E04A", "#FFE544", "#FFEA46"], "cmocean_algae": ["#D7F9D0", "#D7F9D0", "#D6F8CE", "#D6F8CE", "#D4F7CD", "#D4F7CD", "#D3F6CB", "#D3F6CB", "#D2F5CA", "#D2F5CA", "#D1F4C8", "#D1F4C8", "#CFF4C7", "#CFF4C7", "#CEF3C5", "#CEF3C5", "#CDF2C4", "#CDF2C4", "#CCF1C3", "#CCF1C3", "#CAF0C1", "#CAF0C1", "#C9EFC0", "#C9EFC0", "#C8EEBE", "#C8EEBE", "#C7EDBD", "#C7EDBD", "#C5ECBB", "#C5ECBB", "#C4EBBA", "#C4EBBA", "#C3EBB9", "#C3EBB9", "#C2EAB7", "#C2EAB7", "#C0E9B6", "#C0E9B6", "#BFE8B4", "#BFE8B4", "#BEE7B3", "#BEE7B3", "#BDE6B1", "#BDE6B1", "#BBE5B0", "#BBE5B0", "#BAE4AF", "#BAE4AF", "#B9E4AD", "#B9E4AD", "#B8E3AC", "#B8E3AC", "#B6E2AB", "#B6E2AB", "#B5E1A9", "#B5E1A9", "#B4E0A8", "#B4E0A8", "#B2DFA6", "#B2DFA6", "#B1DEA5", "#B1DEA5", "#B0DEA4", "#B0DEA4", "#AFDDA2", "#AFDDA2", "#ADDCA1", "#ADDCA1", "#ACDBA0", "#ACDBA0", "#ABDA9E", "#ABDA9E", "#AADA9D", "#AADA9D", "#A8D99C", "#A8D99C", "#A7D89A", "#A7D89A", "#A6D799", "#A6D799", "#A4D698", "#A4D698", "#A3D596", "#A3D596", "#A2D595", "#A2D595", "#A0D494", "#A0D494", "#9FD392", "#9FD392", "#9ED291", "#9ED291", "#9DD190", "#9DD190", "#9BD18F", "#9BD18F", "#9AD08D", "#9AD08D", "#99CF8C", "#99CF8C", "#97CE8B", "#97CE8B", "#96CD8A", "#96CD8A", "#95CD88", "#95CD88", "#93CC87", "#93CC87", "#92CB86", "#92CB86", "#91CA85", "#91CA85", "#8FCA83", "#8FCA83", "#8EC982", "#8EC982", "#8CC881", "#8CC881", "#8BC780", "#8BC780", "#8AC77E", "#8AC77E", "#88C67D", "#88C67D", "#87C57C", "#87C57C", "#85C47B", "#85C47B", "#84C47A", "#84C47A", "#83C379", "#83C379", "#81C277", "#81C277", "#80C176", "#80C176", "#7EC175", "#7EC175", "#7DC074", "#7DC074", "#7BBF73", "#7BBF73", "#7ABE72", "#7ABE72", "#78BE71", "#78BE71", "#77BD6F", "#77BD6F", "#75BC6E", "#75BC6E", "#74BB6D", "#74BB6D", "#72BB6C", "#72BB6C", "#71BA6B", "#71BA6B", "#6FB96A", "#6FB96A", "#6EB969", "#6EB969", "#6CB868", "#6CB868", "#6BB767", "#6BB767", "#69B666", "#69B666", "#67B665", "#67B665", "#66B564", "#66B564", "#64B463", "#64B463", "#62B462", "#62B462", "#61B361", "#61B361", "#5FB260", "#5FB260", "#5DB25F", "#5DB25F", "#5BB15E", "#5BB15E", "#5AB05D", "#5AB05D", "#58AF5D", "#58AF5D", "#56AF5C", "#56AF5C", "#54AE5B", "#54AE5B", "#52AD5A", "#52AD5A", "#50AD59", "#50AD59", "#4EAC59", "#4EAC59", "#4CAB58", "#4CAB58", "#4AAB57", "#4AAB57", "#48AA57", "#48AA57", "#46A956", "#46A956", "#44A855", "#44A855", "#42A855", "#42A855", "#3FA754", "#3FA754", "#3DA654", "#3DA654", "#3BA654", "#3BA654", "#39A553", "#39A553", "#37A453", "#37A453", "#34A353", "#34A353", "#32A352", "#32A352", "#30A252", "#30A252", "#2EA152", "#2EA152", "#2CA052", "#2CA052", "#2AA052", "#2AA052", "#289F51", "#289F51", "#269E51", "#269E51", "#249D51", "#249D51", "#229C51", "#229C51", "#209C51", "#209C51", "#1E9B51", "#1E9B51", "#1C9A51", "#1C9A51", "#1B9951", "#1B9951", "#199851", "#199851", "#189750", "#189750", "#169650", "#169650", "#159650", "#159650", "#139550", "#139550", "#129450", "#129450", "#109350", "#109350", "#0F9250", "#0F9250", "#0E9150", "#0E9150", "#0D904F", "#0D904F", "#0C8F4F", "#0C8F4F", "#0B8F4F", "#0B8F4F", "#0A8E4F", "#0A8E4F", "#098D4F", "#098D4F", "#098C4F", "#098C4F", "#088B4E", "#088B4E", "#088A4E", "#088A4E", "#07894E", "#07894E", "#07884E", "#07884E", "#07874D", "#07874D", "#07864D", "#07864D", "#07864D", "#07854D", "#07854D", "#07844D", "#07844D", "#07834C", "#07834C", "#07824C", "#07824C", "#08814C", "#08814C", "#08804B", "#08804B", "#087F4B", "#087F4B", "#097E4B", "#097E4B", "#097D4B", "#097D4B", "#0A7C4A", "#0A7C4A", "#0A7C4A", "#0B7B4A", "#0B7B4A", "#0B7A49", "#0B7A49", "#0C7949", "#0C7949", "#0C7849", "#0C7849", "#0D7748", "#0D7748", "#0D7648", "#0D7648", "#0E7548", "#0E7548", "#0E7447", "#0E7447", "#0F7347", "#0F7347", "#0F7347", "#107246", "#107246", "#107146", "#107146", "#117045", "#117045", "#116F45", "#116F45", "#126E45", "#126E45", "#126D44", "#126D44", "#126C44", "#126C44", "#136B43", "#136B43", "#136A43", "#136A43", "#146A43", "#146A43", "#146942", "#146942", "#146842", "#146842", "#156741", "#156741", "#156641", "#156641", "#156540", "#156540", "#166440", "#166440", "#166340", "#166340", "#16623F", "#16623F", "#17623F", "#17623F", "#17613E", "#17613E", "#17603E", "#17603E", "#175F3D", "#175F3D", "#185E3D", "#185E3D", "#185D3C", "#185D3C", "#185C3C", "#185C3C", "#185B3B", "#185B3B", "#185B3B", "#195A3A", "#195A3A", "#19593A", "#19593A", "#195839", "#195839", "#195739", "#195739", "#195638", "#195638", "#195538", "#195538", "#195437", "#195437", "#195437", "#1A5336", "#1A5336", "#1A5235", "#1A5235", "#1A5135", "#1A5135", "#1A5034", "#1A5034", "#1A4F34", "#1A4F34", "#1A4E33", "#1A4E33", "#1A4D33", "#1A4D33", "#1A4D32", "#1A4D32", "#1A4C32", "#1A4C32", "#1A4B31", "#1A4B31", "#1A4A30", "#1A4A30", "#1A4930", "#1A4930", "#1A482F", "#1A482F", "#1A472F", "#1A472F", "#1A472E", "#1A472E", "#1A462E", "#1A462E", "#1A452D", "#1A452D", "#1A442C", "#1A442C", "#1A432C", "#1A432C", "#19422B", "#19422B", "#19412B", "#19412B", "#19402A", "#19402A", "#194029", "#194029", "#193F29", "#193F29", "#193E28", "#193E28", "#193D27", "#193D27", "#193C27", "#193C27", "#183B26", "#183B26", "#183B26", "#183A25", "#183A25", "#183924", "#183924", "#183824", "#183824", "#183723", "#183723", "#173622", "#173622", "#173522", "#173522", "#173521", "#173521", "#173420", "#173420", "#173320", "#173320", "#16321F", "#16321F", "#16311E", "#16311E", "#16301E", "#16301E", "#162F1D", "#162F1D", "#152F1C", "#152F1C", "#152E1C", "#152E1C", "#152D1B", "#152D1B", "#142C1A", "#142C1A", "#142B1A", "#142B1A", "#142A19", "#142A19", "#142918", "#142918", "#132918", "#132918", "#132817", "#132817", "#132716", "#132716", "#122616", "#122616", "#122515", "#122515", "#122414", "#122414"], "cmocean_amp": ["#F1EDEC", "#F1EDEC", "#F1ECEB", "#F1ECEB", "#F0EBE9", "#F0EBE9", "#EFE9E8", "#EFE9E8", "#EFE8E7", "#EFE8E7", "#EEE7E5", "#EEE7E5", "#EEE6E4", "#EEE6E4", "#EDE5E3", "#EDE5E3", "#EDE3E1", "#EDE3E1", "#ECE2E0", "#ECE2E0", "#ECE1DE", "#ECE1DE", "#EBE0DD", "#EBE0DD", "#EBDFDC", "#EBDFDC", "#EADDDA", "#EADDDA", "#EADCD9", "#EADCD9", "#E9DBD7", "#E9DBD7", "#E9DAD6", "#E9DAD6", "#E9D9D4", "#E9D9D4", "#E8D8D3", "#E8D8D3", "#E8D6D2", "#E8D6D2", "#E7D5D0", "#E7D5D0", "#E7D4CF", "#E7D4CF", "#E6D3CD", "#E6D3CD", "#E6D2CC", "#E6D2CC", "#E6D1CA", "#E6D1CA", "#E5CFC9", "#E5CFC9", "#E5CEC8", "#E5CEC8", "#E4CDC6", "#E4CDC6", "#E4CCC5", "#E4CCC5", "#E4CBC3", "#E4CBC3", "#E3C9C2", "#E3C9C2", "#E3C8C0", "#E3C8C0", "#E2C7BF", "#E2C7BF", "#E2C6BD", "#E2C6BD", "#E2C5BC", "#E2C5BC", "#E1C4BB", "#E1C4BB", "#E1C3B9", "#E1C3B9", "#E1C1B8", "#E1C1B8", "#E0C0B6", "#E0C0B6", "#E0BFB5", "#E0BFB5", "#DFBEB3", "#DFBEB3", "#DFBDB2", "#DFBDB2", "#DFBCB0", "#DFBCB0", "#DEBAAF", "#DEBAAF", "#DEB9AE", "#DEB9AE", "#DEB8AC", "#DEB8AC", "#DDB7AB", "#DDB7AB", "#DDB6A9", "#DDB6A9", "#DDB5A8", "#DDB5A8", "#DCB4A6", "#DCB4A6", "#DCB2A5", "#DCB2A5", "#DCB1A3", "#DCB1A3", "#DBB0A2", "#DBB0A2", "#DBAFA1", "#DBAFA1", "#DBAE9F", "#DBAE9F", "#DAAD9E", "#DAAD9E", "#DAAC9C", "#DAAC9C", "#D9AA9B", "#D9AA9B", "#D9A999", "#D9A999", "#D9A898", "#D9A898", "#D8A796", "#D8A796", "#D8A695", "#D8A695", "#D8A594", "#D8A594", "#D7A492", "#D7A492", "#D7A291", "#D7A291", "#D7A18F", "#D7A18F", "#D6A08E", "#D6A08E", "#D69F8C", "#D69F8C", "#D69E8B", "#D69E8B", "#D59D89", "#D59D89", "#D59C88", "#D59C88", "#D59A87", "#D59A87", "#D49985", "#D49985", "#D49884", "#D49884", "#D49782", "#D49782", "#D39681", "#D39681", "#D3957F", "#D3957F", "#D3947E", "#D3947E", "#D2927D", "#D2927D", "#D2917B", "#D2917B", "#D2907A", "#D2907A", "#D18F78", "#D18F78", "#D18E77", "#D18E77", "#D18D76", "#D18D76", "#D08C74", "#D08C74", "#D08B73", "#D08B73", "#D08971", "#D08971", "#CF8870", "#CF8870", "#CF876F", "#CF876F", "#CF866D", "#CF866D", "#CE856C", "#CE856C", "#CE846A", "#CE846A", "#CD8369", "#CD8369", "#CD8168", "#CD8168", "#CD8066", "#CD8066", "#CC7F65", "#CC7F65", "#CC7E64", "#CC7E64", "#CC7D62", "#CC7D62", "#CB7C61", "#CB7C61", "#CB7A60", "#CB7A60", "#CB795E", "#CB795E", "#CA785D", "#CA785D", "#CA775B", "#CA775B", "#C9765A", "#C9765A", "#C97559", "#C97559", "#C97457", "#C97457", "#C87256", "#C87256", "#C87155", "#C87155", "#C87054", "#C87054", "#C76F52", "#C76F52", "#C76E51", "#C76E51", "#C66D50", "#C66D50", "#C66B4E", "#C66B4E", "#C66A4D", "#C66A4D", "#C5694C", "#C5694C", "#C5684A", "#C5684A", "#C56749", "#C56749", "#C46548", "#C46548", "#C46447", "#C46447", "#C36346", "#C36346", "#C36244", "#C36244", "#C36143", "#C36143", "#C25F42", "#C25F42", "#C25E41", "#C25E41", "#C15D3F", "#C15D3F", "#C15C3E", "#C15C3E", "#C05B3D", "#C05B3D", "#C0593C", "#C0593C", "#C0583B", "#C0583B", "#BF573A", "#BF573A", "#BF5639", "#BF5639", "#BE5438", "#BE5438", "#BE5336", "#BE5336", "#BD5235", "#BD5235", "#BD5134", "#BD5134", "#BD4F33", "#BD4F33", "#BC4E32", "#BC4E32", "#BC4D31", "#BC4D31", "#BB4C30", "#BB4C30", "#BB4A30", "#BB4A30", "#BA492F", "#BA492F", "#BA482E", "#BA482E", "#B9462D", "#B9462D", "#B9452C", "#B9452C", "#B8442B", "#B8442B", "#B8422B", "#B8422B", "#B7412A", "#B7412A", "#B74029", "#B74029", "#B63F29", "#B63F29", "#B53D28", "#B53D28", "#B53C27", "#B53C27", "#B43B27", "#B43B27", "#B43926", "#B43926", "#B33826", "#B33826", "#B23726", "#B23726", "#B23525", "#B23525", "#B13425", "#B13425", "#B03325", "#B03325", "#B03125", "#B03125", "#AF3024", "#AF3024", "#AE2F24", "#AE2F24", "#AE2D24", "#AE2D24", "#AD2C24", "#AD2C24", "#AC2B24", "#AC2B24", "#AB2A24", "#AB2A24", "#AA2824", "#AA2824", "#AA2724", "#AA2724", "#A92624", "#A92624", "#A82524", "#A82524", "#A72424", "#A72424", "#A62225", "#A62225", "#A52125", "#A52125", "#A42025", "#A42025", "#A31F25", "#A31F25", "#A21E25", "#A21E25", "#A11D25", "#A11D25", "#A01C26", "#A01C26", "#9F1B26", "#9F1B26", "#9E1A26", "#9E1A26", "#9D1926", "#9D1926", "#9C1827", "#9C1827", "#9B1727", "#9B1727", "#9A1627", "#9A1627", "#991527", "#991527", "#981527", "#981527", "#971428", "#971428", "#951328", "#951328", "#941328", "#941328", "#931228", "#931228", "#921128", "#921128", "#911129", "#911129", "#901029", "#901029", "#8E1029", "#8E1029", "#8D1029", "#8D1029", "#8C0F29", "#8C0F29", "#8B0F29", "#8B0F29", "#890F29", "#890F29", "#880F29", "#880F29", "#870E29", "#870E29", "#850E29", "#850E29", "#840E29", "#840E29", "#830E29", "#830E29", "#810E29", "#810E29", "#800E29", "#800E29", "#7F0E29", "#7F0E29", "#7D0E29", "#7D0E29", "#7C0E29", "#7C0E29", "#7B0E29", "#7B0E29", "#790E29", "#790E29", "#780E28", "#780E28", "#770E28", "#770E28", "#750E28", "#750E28", "#740E28", "#740E28", "#730E27", "#730E27", "#710E27", "#710E27", "#700E27", "#700E27", "#6F0E26", "#6F0E26", "#6D0E26", "#6D0E26", "#6C0F26", "#6C0F26", "#6B0F25", "#6B0F25", "#690F25", "#690F25", "#680F25", "#680F25", "#670F24", "#670F24", "#650F24", "#650F24", "#640E23", "#640E23", "#630E23", "#630E23", "#610E22", "#610E22", "#600E22", "#600E22", "#5F0E21", "#5F0E21", "#5D0E21", "#5D0E21", "#5C0E21", "#5C0E21", "#5B0E20", "#5B0E20", "#5A0E1F", "#5A0E1F", "#580E1F", "#580E1F", "#570E1E", "#570E1E", "#560E1E", "#560E1E", "#540D1D", "#540D1D", "#530D1D", "#530D1D", "#520D1C", "#520D1C", "#510D1C", "#510D1C", "#4F0D1B", "#4F0D1B", "#4E0D1A", "#4E0D1A", "#4D0C1A", "#4D0C1A", "#4B0C19", "#4B0C19", "#4A0C19", "#4A0C19", "#490C18", "#490C18", "#480B17", "#480B17", "#460B17", "#460B17", "#450B16", "#450B16", "#440B16", "#440B16", "#430A15", "#430A15", "#410A14", "#410A14", "#400A14", "#400A14", "#3F0A13", "#3F0A13", "#3D0912", "#3D0912", "#3C0912", "#3C0912"], "cmocean_balance": ["#181C43", "#181C43", "#191E46", "#191E46", "#1A1F49", "#1A1F49", "#1B214C", "#1B214C", "#1C224F", "#1C224F", "#1D2352", "#1D2352", "#1E2555", "#1E2555", "#1F2658", "#1F2658", "#20275B", "#20275B", "#21295F", "#21295F", "#212A62", "#212A62", "#222B65", "#222B65", "#232D69", "#232D69", "#242E6C", "#242E6C", "#252F6F", "#252F6F", "#253073", "#253073", "#263276", "#263276", "#27337A", "#27337A", "#27347D", "#27347D", "#283681", "#283681", "#283784", "#283784", "#293888", "#293888", "#293A8C", "#293A8C", "#293B8F", "#293B8F", "#293C93", "#293C93", "#293E97", "#293E97", "#293F9A", "#293F9A", "#29409E", "#29409E", "#2942A2", "#2942A2", "#2843A5", "#2843A5", "#2745A9", "#2745A9", "#2647AC", "#2647AC", "#2548B0", "#2548B0", "#234AB3", "#234AB3", "#214CB6", "#214CB6", "#1F4EB8", "#1F4EB8", "#1C50BA", "#1C50BA", "#1952BC", "#1952BC", "#1655BD", "#1655BD", "#1357BE", "#1357BE", "#1059BE", "#1059BE", "#0D5BBE", "#0D5BBE", "#0C5EBE", "#0C5EBE", "#0A60BE", "#0A60BE", "#0A62BE", "#0A62BE", "#0A64BE", "#0A64BE", "#0B66BD", "#0B66BD", "#0D68BD", "#0D68BD", "#0F6ABD", "#0F6ABD", "#116CBC", "#116CBC", "#136EBC", "#136EBC", "#1670BC", "#1670BC", "#1972BB", "#1972BB", "#1B74BB", "#1B74BB", "#1E76BB", "#1E76BB", "#2178BB", "#2178BB", "#237ABA", "#237ABA", "#267BBA", "#267BBA", "#297DBA", "#297DBA", "#2B7FBA", "#2B7FBA", "#2E81BA", "#2E81BA", "#3083BA", "#3083BA", "#3384BA", "#3384BA", "#3686BA", "#3686BA", "#3888BA", "#3888BA", "#3B89BA", "#3B89BA", "#3E8BBA", "#3E8BBA", "#408DBA", "#408DBA", "#438FBA", "#438FBA", "#4690BA", "#4690BA", "#4892BA", "#4892BA", "#4B94BA", "#4B94BA", "#4E95BA", "#4E95BA", "#5197BA", "#5197BA", "#5399BA", "#5399BA", "#569ABB", "#569ABB", "#599CBB", "#599CBB", "#5C9DBB", "#5C9DBB", "#5F9FBB", "#5F9FBB", "#62A0BB", "#62A0BB", "#65A2BC", "#65A2BC", "#68A4BC", "#68A4BC", "#6BA5BC", "#6BA5BC", "#6EA7BD", "#6EA7BD", "#71A8BD", "#71A8BD", "#75AABE", "#75AABE", "#78ABBE", "#78ABBE", "#7BACBF", "#7BACBF", "#7EAEBF", "#7EAEBF", "#81AFC0", "#81AFC0", "#85B1C0", "#85B1C0", "#88B2C1", "#88B2C1", "#8BB4C2", "#8BB4C2", "#8EB5C3", "#8EB5C3", "#91B7C3", "#91B7C3", "#94B8C4", "#94B8C4", "#98BAC5", "#98BAC5", "#9BBBC6", "#9BBBC6", "#9EBCC7", "#9EBCC7", "#A1BEC8", "#A1BEC8", "#A4BFC9", "#A4BFC9", "#A7C1CA", "#A7C1CA", "#AAC2CB", "#AAC2CB", "#ADC4CC", "#ADC4CC", "#B0C5CD", "#B0C5CD", "#B3C7CE", "#B3C7CE", "#B6C9CF", "#B6C9CF", "#B9CAD0", "#B9CAD0", "#BCCCD2", "#BCCCD2", "#BFCDD3", "#BFCDD3", "#C1CFD4", "#C1CFD4", "#C4D0D5", "#C4D0D5", "#C7D2D7", "#C7D2D7", "#CAD4D8", "#CAD4D8", "#CDD5D9", "#CDD5D9", "#D0D7DA", "#D0D7DA", "#D3D9DC", "#D3D9DC", "#D5DADD", "#D5DADD", "#D8DCDE", "#D8DCDE", "#DBDEE0", "#DBDEE0", "#DEE0E1", "#DEE0E1", "#E1E1E3", "#E1E1E3", "#E3E3E4", "#E3E3E4", "#E6E5E6", "#E6E5E6", "#E9E7E7", "#E9E7E7", "#EBE9E9", "#EBE9E9", "#EEEAEA", "#EEEAEA", "#F1ECEC", "#F1ECEC", "#F1ECEB", "#F1ECEB", "#F0EAE9", "#F0EAE9", "#EFE8E6", "#EFE8E6", "#EEE5E3", "#EEE5E3", "#EDE3E0", "#EDE3E0", "#ECE0DE", "#ECE0DE", "#EBDEDB", "#EBDEDB", "#EADCD8", "#EADCD8", "#E9D9D5", "#E9D9D5", "#E8D7D2", "#E8D7D2", "#E7D5CF", "#E7D5CF", "#E6D2CD", "#E6D2CD", "#E5D0CA", "#E5D0CA", "#E5CEC7", "#E5CEC7", "#E4CBC4", "#E4CBC4", "#E3C9C1", "#E3C9C1", "#E2C7BE", "#E2C7BE", "#E1C4BB", "#E1C4BB", "#E1C2B8", "#E1C2B8", "#E0C0B5", "#E0C0B5", "#DFBDB2", "#DFBDB2", "#DFBBB0", "#DFBBB0", "#DEB9AD", "#DEB9AD", "#DDB6AA", "#DDB6AA", "#DCB4A7", "#DCB4A7", "#DCB2A4", "#DCB2A4", "#DBAFA1", "#DBAFA1", "#DAAD9E", "#DAAD9E", "#DAAB9B", "#DAAB9B", "#D9A998", "#D9A998", "#D8A696", "#D8A696", "#D8A493", "#D8A493", "#D7A290", "#D7A290", "#D69F8D", "#D69F8D", "#D69D8A", "#D69D8A", "#D59B87", "#D59B87", "#D49984", "#D49984", "#D39681", "#D39681", "#D3947F", "#D3947F", "#D2927C", "#D2927C", "#D18F79", "#D18F79", "#D18D76", "#D18D76", "#D08B73", "#D08B73", "#CF8970", "#CF8970", "#CF866E", "#CF866E", "#CE846B", "#CE846B", "#CD8268", "#CD8268", "#CD7F65", "#CD7F65", "#CC7D63", "#CC7D63", "#CB7B60", "#CB7B60", "#CA795D", "#CA795D", "#CA765B", "#CA765B", "#C97458", "#C97458", "#C87255", "#C87255", "#C76F53", "#C76F53", "#C76D50", "#C76D50", "#C66B4D", "#C66B4D", "#C5684B", "#C5684B", "#C46648", "#C46648", "#C36346", "#C36346", "#C36143", "#C36143", "#C25F41", "#C25F41", "#C15C3F", "#C15C3F", "#C05A3C", "#C05A3C", "#BF573A", "#BF573A", "#BE5538", "#BE5538", "#BE5236", "#BE5236", "#BD5034", "#BD5034", "#BC4D32", "#BC4D32", "#BB4B30", "#BB4B30", "#BA482E", "#BA482E", "#B9452C", "#B9452C", "#B8432B", "#B8432B", "#B74029", "#B74029", "#B63D28", "#B63D28", "#B43B27", "#B43B27", "#B33826", "#B33826", "#B23525", "#B23525", "#B13325", "#B13325", "#AF3024", "#AF3024", "#AE2E24", "#AE2E24", "#AC2B24", "#AC2B24", "#AB2924", "#AB2924", "#A92624", "#A92624", "#A72424", "#A72424", "#A52125", "#A52125", "#A31F25", "#A31F25", "#A11D25", "#A11D25", "#9F1B26", "#9F1B26", "#9D1926", "#9D1926", "#9B1727", "#9B1727", "#991627", "#991627", "#971428", "#971428", "#941328", "#941328", "#921228", "#921228", "#901029", "#901029", "#8D1029", "#8D1029", "#8B0F29", "#8B0F29", "#880F29", "#880F29", "#860E29", "#860E29", "#830E29", "#830E29", "#800E29", "#800E29", "#7E0E29", "#7E0E29", "#7B0E29", "#7B0E29", "#780E28", "#780E28", "#760E28", "#760E28", "#730E27", "#730E27", "#700E27", "#700E27", "#6D0E26", "#6D0E26", "#6B0F25", "#6B0F25", "#680F25", "#680F25", "#650F24", "#650F24", "#630E23", "#630E23", "#600E22", "#600E22", "#5E0E21", "#5E0E21", "#5B0E20", "#5B0E20", "#580E1F", "#580E1F", "#560E1E", "#560E1E", "#530D1D", "#530D1D", "#510D1C", "#510D1C", "#4E0D1B", "#4E0D1B", "#4B0C19", "#4B0C19", "#490C18", "#490C18", "#460B17", "#460B17", "#440B16", "#440B16", "#410A14", "#410A14", "#3F0A13", "#3F0A13", "#3C0912", "#3C0912"], "cmocean_curl": ["#151D44", "#151D44", "#151F45", "#151F45", "#162146", "#162146", "#162347", "#162347", "#172548", "#172548", "#172749", "#172749", "#18294A", "#18294A", "#182B4B", "#182B4B", "#182D4C", "#182D4C", "#192F4D", "#192F4D", "#19314F", "#19314F", "#1A3350", "#1A3350", "#1A3551", "#1A3551", "#1A3752", "#1A3752", "#1B3853", "#1B3853", "#1B3A54", "#1B3A54", "#1B3C56", "#1B3C56", "#1B3E57", "#1B3E57", "#1C4058", "#1C4058", "#1C4259", "#1C4259", "#1C435A", "#1C435A", "#1C455B", "#1C455B", "#1C475D", "#1C475D", "#1C495E", "#1C495E", "#1C4B5F", "#1C4B5F", "#1C4D60", "#1C4D60", "#1C4E61", "#1C4E61", "#1C5062", "#1C5062", "#1C5264", "#1C5264", "#1C5465", "#1C5465", "#1B5666", "#1B5666", "#1B5867", "#1B5867", "#1B5968", "#1B5968", "#1A5B69", "#1A5B69", "#1A5D6A", "#1A5D6A", "#1A5F6B", "#1A5F6B", "#19616C", "#19616C", "#18636D", "#18636D", "#18656E", "#18656E", "#17676F", "#17676F", "#176870", "#176870", "#166A71", "#166A71", "#156C72", "#156C72", "#146E73", "#146E73", "#147074", "#147074", "#137275", "#137275", "#127476", "#127476", "#127676", "#127676", "#117877", "#117877", "#117978", "#117978", "#117B79", "#117B79", "#117D79", "#117D79", "#117F7A", "#117F7A", "#12817B", "#12817B", "#13837B", "#13837B", "#14857C", "#14857C", "#16877C", "#16877C", "#18887D", "#18887D", "#1A8A7D", "#1A8A7D", "#1D8C7E", "#1D8C7E", "#1F8E7E", "#1F8E7E", "#228F7E", "#228F7E", "#26917F", "#26917F", "#29937F", "#29937F", "#2D9580", "#2D9580", "#309680", "#309680", "#349880", "#349880", "#389981", "#389981", "#3C9B81", "#3C9B81", "#409C82", "#409C82", "#449E82", "#449E82", "#489F83", "#489F83", "#4CA183", "#4CA183", "#50A284", "#50A284", "#54A484", "#54A484", "#58A585", "#58A585", "#5CA786", "#5CA786", "#60A887", "#60A887", "#64A988", "#64A988", "#68AB89", "#68AB89", "#6CAC8A", "#6CAC8A", "#6FAE8B", "#6FAE8B", "#73AF8C", "#73AF8C", "#77B08D", "#77B08D", "#7AB28F", "#7AB28F", "#7EB390", "#7EB390", "#82B491", "#82B491", "#85B693", "#85B693", "#89B794", "#89B794", "#8CB896", "#8CB896", "#90BA98", "#90BA98", "#93BB99", "#93BB99", "#96BD9B", "#96BD9B", "#9ABE9D", "#9ABE9D", "#9DBF9F", "#9DBF9F", "#A0C1A1", "#A0C1A1", "#A3C2A3", "#A3C2A3", "#A7C4A5", "#A7C4A5", "#AAC5A7", "#AAC5A7", "#ADC6A9", "#ADC6A9", "#B0C8AB", "#B0C8AB", "#B3C9AD", "#B3C9AD", "#B6CBB0", "#B6CBB0", "#B9CCB2", "#B9CCB2", "#BCCEB4", "#BCCEB4", "#C0CFB7", "#C0CFB7", "#C3D1B9", "#C3D1B9", "#C5D2BC", "#C5D2BC", "#C8D4BE", "#C8D4BE", "#CBD6C1", "#CBD6C1", "#CED7C3", "#CED7C3", "#D1D9C6", "#D1D9C6", "#D4DAC8", "#D4DAC8", "#D7DCCB", "#D7DCCB", "#DADECE", "#DADECE", "#DDDFD1", "#DDDFD1", "#E0E1D3", "#E0E1D3", "#E2E3D6", "#E2E3D6", "#E5E5D9", "#E5E5D9", "#E8E6DC", "#E8E6DC", "#EBE8DF", "#EBE8DF", "#EEEAE1", "#EEEAE1", "#F0ECE4", "#F0ECE4", "#F3EEE7", "#F3EEE7", "#F6EFEA", "#F6EFEA", "#F9F1ED", "#F9F1ED", "#FBF3F0", "#FBF3F0", "#FEF5F3", "#FEF5F3", "#FDF5F4", "#FDF5F4", "#FCF3F0", "#FCF3F0", "#FBF0ED", "#FBF0ED", "#FAEEEA", "#FAEEEA", "#F8ECE6", "#F8ECE6", "#F7E9E3", "#F7E9E3", "#F6E7E0", "#F6E7E0", "#F5E4DC", "#F5E4DC", "#F4E2D9", "#F4E2D9", "#F3DFD6", "#F3DFD6", "#F2DDD2", "#F2DDD2", "#F1DACF", "#F1DACF", "#F0D8CC", "#F0D8CC", "#EFD5C8", "#EFD5C8", "#EFD3C5", "#EFD3C5", "#EED0C2", "#EED0C2", "#EDCEBE", "#EDCEBE", "#ECCBBB", "#ECCBBB", "#EBC9B8", "#EBC9B8", "#EBC6B5", "#EBC6B5", "#EAC4B2", "#EAC4B2", "#E9C1AF", "#E9C1AF", "#E8BFAB", "#E8BFAB", "#E8BDA8", "#E8BDA8", "#E7BAA5", "#E7BAA5", "#E6B8A2", "#E6B8A2", "#E6B59F", "#E6B59F", "#E5B39C", "#E5B39C", "#E4B09A", "#E4B09A", "#E4AE97", "#E4AE97", "#E3AB94", "#E3AB94", "#E3A991", "#E3A991", "#E2A68E", "#E2A68E", "#E1A48C", "#E1A48C", "#E1A189", "#E1A189", "#E09E87", "#E09E87", "#DF9C84", "#DF9C84", "#DF9982", "#DF9982", "#DE9780", "#DE9780", "#DD947D", "#DD947D", "#DD927B", "#DD927B", "#DC8F79", "#DC8F79", "#DB8D77", "#DB8D77", "#DA8A75", "#DA8A75", "#DA8874", "#DA8874", "#D98572", "#D98572", "#D88370", "#D88370", "#D7806F", "#D7806F", "#D67E6D", "#D67E6D", "#D57B6C", "#D57B6C", "#D4796B", "#D4796B", "#D37669", "#D37669", "#D27468", "#D27468", "#D17267", "#D17267", "#D06F66", "#D06F66", "#CF6D66", "#CF6D66", "#CE6A65", "#CE6A65", "#CC6864", "#CC6864", "#CB6664", "#CB6664", "#CA6363", "#CA6363", "#C86162", "#C86162", "#C75F62", "#C75F62", "#C65D62", "#C65D62", "#C45A61", "#C45A61", "#C35861", "#C35861", "#C15661", "#C15661", "#C05461", "#C05461", "#BE5260", "#BE5260", "#BC5060", "#BC5060", "#BB4E60", "#BB4E60", "#B94C60", "#B94C60", "#B74A60", "#B74A60", "#B54860", "#B54860", "#B44660", "#B44660", "#B24460", "#B24460", "#B04260", "#B04260", "#AE4060", "#AE4060", "#AC3E60", "#AC3E60", "#AA3C60", "#AA3C60", "#A83A60", "#A83A60", "#A63860", "#A63860", "#A43760", "#A43760", "#A23560", "#A23560", "#A03360", "#A03360", "#9E3160", "#9E3160", "#9C3060", "#9C3060", "#9A2E60", "#9A2E60", "#982C61", "#982C61", "#962B61", "#962B61", "#942961", "#942961", "#912860", "#912860", "#8F2660", "#8F2660", "#8D2560", "#8D2560", "#8B2360", "#8B2360", "#882260", "#882260", "#862160", "#862160", "#841F60", "#841F60", "#811E5F", "#811E5F", "#7F1D5F", "#7F1D5F", "#7C1C5F", "#7C1C5F", "#7A1B5E", "#7A1B5E", "#771A5E", "#771A5E", "#75195D", "#75195D", "#72185C", "#72185C", "#70185C", "#70185C", "#6D175B", "#6D175B", "#6A165A", "#6A165A", "#681659", "#681659", "#651558", "#651558", "#631557", "#631557", "#601455", "#601455", "#5D1454", "#5D1454", "#5B1452", "#5B1452", "#581351", "#581351", "#55134F", "#55134F", "#53134E", "#53134E", "#50124C", "#50124C", "#4D124A", "#4D124A", "#4B1248", "#4B1248", "#481146", "#481146", "#461144", "#461144", "#431042", "#431042", "#401040", "#401040", "#3E0F3E", "#3E0F3E", "#3B0F3C", "#3B0F3C", "#390E3A", "#390E3A", "#360E37", "#360E37", "#340D35", "#340D35"], "cmocean_deep": ["#FDFECC", "#FDFECC", "#FBFDCB", "#FBFDCB", "#F9FCCA", "#F9FCCA", "#F7FBC8", "#F7FBC8", "#F5FAC7", "#F5FAC7", "#F3FAC6", "#F3FAC6", "#F1F9C5", "#F1F9C5", "#EFF8C4", "#EFF8C4", "#EDF7C3", "#EDF7C3", "#EBF7C1", "#EBF7C1", "#E9F6C0", "#E9F6C0", "#E7F5BF", "#E7F5BF", "#E5F4BE", "#E5F4BE", "#E3F4BD", "#E3F4BD", "#E1F3BC", "#E1F3BC", "#DFF2BB", "#DFF2BB", "#DDF2BA", "#DDF2BA", "#DBF1B9", "#DBF1B9", "#D9F0B8", "#D9F0B8", "#D7EFB7", "#D7EFB7", "#D4EFB6", "#D4EFB6", "#D2EEB5", "#D2EEB5", "#D0EDB4", "#D0EDB4", "#CEECB3", "#CEECB3", "#CCECB3", "#CCECB3", "#CAEBB2", "#CAEBB2", "#C8EAB1", "#C8EAB1", "#C6EAB0", "#C6EAB0", "#C4E9AF", "#C4E9AF", "#C1E8AF", "#C1E8AF", "#BFE7AE", "#BFE7AE", "#BDE7AD", "#BDE7AD", "#BBE6AC", "#BBE6AC", "#B9E5AC", "#B9E5AC", "#B7E5AB", "#B7E5AB", "#B5E4AA", "#B5E4AA", "#B2E3AA", "#B2E3AA", "#B0E2A9", "#B0E2A9", "#AEE2A9", "#AEE2A9", "#ACE1A8", "#ACE1A8", "#AAE0A8", "#AAE0A8", "#A7E0A7", "#A7E0A7", "#A5DFA7", "#A5DFA7", "#A3DEA6", "#A3DEA6", "#A1DDA6", "#A1DDA6", "#9FDDA5", "#9FDDA5", "#9CDCA5", "#9CDCA5", "#9ADBA5", "#9ADBA5", "#98DAA4", "#98DAA4", "#96DAA4", "#96DAA4", "#94D9A4", "#94D9A4", "#92D8A4", "#92D8A4", "#90D7A4", "#90D7A4", "#8DD7A3", "#8DD7A3", "#8BD6A3", "#8BD6A3", "#89D5A3", "#89D5A3", "#87D4A3", "#87D4A3", "#85D3A3", "#85D3A3", "#83D3A3", "#83D3A3", "#81D2A3", "#81D2A3", "#7FD1A3", "#7FD1A3", "#7DD0A3", "#7DD0A3", "#7CCFA3", "#7CCFA3", "#7ACEA3", "#7ACEA3", "#78CEA3", "#78CEA3", "#76CDA3", "#76CDA3", "#75CCA3", "#75CCA3", "#73CBA3", "#73CBA3", "#71CAA3", "#71CAA3", "#70C9A3", "#70C9A3", "#6EC8A3", "#6EC8A3", "#6DC7A3", "#6DC7A3", "#6BC6A3", "#6BC6A3", "#6AC5A4", "#6AC5A4", "#69C4A4", "#69C4A4", "#67C3A4", "#67C3A4", "#66C2A4", "#66C2A4", "#65C2A4", "#65C2A4", "#64C1A4", "#64C1A4", "#63C0A4", "#63C0A4", "#62BFA4", "#62BFA4", "#61BEA4", "#61BEA4", "#60BDA4", "#60BDA4", "#5FBCA4", "#5FBCA4", "#5EBBA4", "#5EBBA4", "#5DBAA4", "#5DBAA4", "#5CB9A4", "#5CB9A4", "#5BB8A4", "#5BB8A4", "#5AB7A4", "#5AB7A4", "#5AB6A4", "#5AB6A4", "#59B4A4", "#59B4A4", "#58B3A4", "#58B3A4", "#58B2A4", "#58B2A4", "#57B1A4", "#57B1A4", "#56B0A4", "#56B0A4", "#56AFA4", "#56AFA4", "#55AEA3", "#55AEA3", "#55ADA3", "#55ADA3", "#54ACA3", "#54ACA3", "#53ABA3", "#53ABA3", "#53AAA3", "#53AAA3", "#52A9A3", "#52A9A3", "#52A8A3", "#52A8A3", "#51A7A3", "#51A7A3", "#51A6A2", "#51A6A2", "#51A5A2", "#51A5A2", "#50A4A2", "#50A4A2", "#50A3A2", "#50A3A2", "#4FA2A2", "#4FA2A2", "#4FA1A2", "#4FA1A2", "#4FA0A2", "#4FA0A2", "#4E9FA1", "#4E9FA1", "#4E9EA1", "#4E9EA1", "#4D9DA1", "#4D9DA1", "#4D9CA1", "#4D9CA1", "#4D9BA1", "#4D9BA1", "#4C9AA0", "#4C9AA0", "#4C99A0", "#4C99A0", "#4B98A0", "#4B98A0", "#4B97A0", "#4B97A0", "#4B96A0", "#4B96A0", "#4A959F", "#4A959F", "#4A949F", "#4A949F", "#4A939F", "#4A939F", "#49929F", "#49929F", "#49919E", "#49919E", "#49909E", "#49909E", "#488F9E", "#488F9E", "#488E9E", "#488E9E", "#488D9D", "#488D9D", "#478C9D", "#478C9D", "#478B9D", "#478B9D", "#478A9D", "#478A9D", "#46899D", "#46899D", "#46889C", "#46889C", "#46879C", "#46879C", "#45869C", "#45869C", "#45859C", "#45859C", "#45849B", "#45849B", "#44839B", "#44839B", "#44829B", "#44829B", "#44819B", "#44819B", "#44809B", "#44809B", "#437F9A", "#437F9A", "#437E9A", "#437E9A", "#437D9A", "#437D9A", "#427C9A", "#427C9A", "#427B99", "#427B99", "#427A99", "#427A99", "#427999", "#427999", "#417899", "#417899", "#417799", "#417799", "#417698", "#417698", "#407598", "#407598", "#407498", "#407498", "#407398", "#407398", "#407298", "#407298", "#407197", "#407197", "#3F7097", "#3F7097", "#3F6F97", "#3F6F97", "#3F6E97", "#3F6E97", "#3F6D97", "#3F6D97", "#3F6C96", "#3F6C96", "#3E6B96", "#3E6B96", "#3E6A96", "#3E6A96", "#3E6996", "#3E6996", "#3E6896", "#3E6896", "#3E6795", "#3E6795", "#3E6695", "#3E6695", "#3E6595", "#3E6595", "#3E6495", "#3E6495", "#3E6394", "#3E6394", "#3E6294", "#3E6294", "#3E6194", "#3E6194", "#3E6094", "#3E6094", "#3E5F93", "#3E5F93", "#3E5E93", "#3E5E93", "#3E5C93", "#3E5C93", "#3E5B93", "#3E5B93", "#3E5A92", "#3E5A92", "#3E5992", "#3E5992", "#3E5892", "#3E5892", "#3E5791", "#3E5791", "#3E5691", "#3E5691", "#3F5590", "#3F5590", "#3F5490", "#3F5490", "#3F538F", "#3F538F", "#3F528F", "#3F528F", "#3F508E", "#3F508E", "#404F8D", "#404F8D", "#404E8D", "#404E8D", "#404D8C", "#404D8C", "#404C8B", "#404C8B", "#414B8A", "#414B8A", "#414A89", "#414A89", "#414988", "#414988", "#414887", "#414887", "#414785", "#414785", "#414684", "#414684", "#414583", "#414583", "#414481", "#414481", "#424380", "#424380", "#41427E", "#41427E", "#41417D", "#41417D", "#41407B", "#41407B", "#41407A", "#41407A", "#413F78", "#413F78", "#413E76", "#413E76", "#413D75", "#413D75", "#403C73", "#403C73", "#403C71", "#403C71", "#403B70", "#403B70", "#403A6E", "#403A6E", "#3F396C", "#3F396C", "#3F386B", "#3F386B", "#3F3869", "#3F3869", "#3E3767", "#3E3767", "#3E3666", "#3E3666", "#3D3564", "#3D3564", "#3D3562", "#3D3562", "#3D3461", "#3D3461", "#3C335F", "#3C335F", "#3C325D", "#3C325D", "#3B325C", "#3B325C", "#3B315A", "#3B315A", "#3A3058", "#3A3058", "#3A3057", "#3A3057", "#392F55", "#392F55", "#392E54", "#392E54", "#382D52", "#382D52", "#382D51", "#382D51", "#372C4F", "#372C4F", "#362B4D", "#362B4D", "#362A4C", "#362A4C", "#352A4A", "#352A4A", "#352949", "#352949", "#342847", "#342847", "#342846", "#342846", "#332744", "#332744", "#322643", "#322643", "#322541", "#322541", "#312540", "#312540", "#30243E", "#30243E", "#30233D", "#30233D", "#2F223B", "#2F223B", "#2F223A", "#2F223A", "#2E2139", "#2E2139", "#2D2037", "#2D2037", "#2D1F36", "#2D1F36", "#2C1F34", "#2C1F34", "#2B1E33", "#2B1E33", "#2B1D32", "#2B1D32", "#2A1C30", "#2A1C30", "#291C2F", "#291C2F", "#281B2D", "#281B2D", "#281A2C", "#281A2C"], "cmocean_delta": ["#112040", "#112040", "#122143", "#122143", "#142246", "#142246", "#152449", "#152449", "#16254C", "#16254C", "#172750", "#172750", "#192853", "#192853", "#1A2956", "#1A2956", "#1B2A5A", "#1B2A5A", "#1C2C5D", "#1C2C5D", "#1E2D60", "#1E2D60", "#1F2E64", "#1F2E64", "#203067", "#203067", "#21316B", "#21316B", "#22326F", "#22326F", "#233372", "#233372", "#243576", "#243576", "#25367A", "#25367A", "#25377E", "#25377E", "#263882", "#263882", "#263A86", "#263A86", "#273B8A", "#273B8A", "#273D8D", "#273D8D", "#263E91", "#263E91", "#254094", "#254094", "#244297", "#244297", "#234498", "#234498", "#21479A", "#21479A", "#20499B", "#20499B", "#1F4B9B", "#1F4B9B", "#1E4D9C", "#1E4D9C", "#1D509C", "#1D509C", "#1C529D", "#1C529D", "#1C549D", "#1C549D", "#1B569D", "#1B569D", "#1B589E", "#1B589E", "#1B5A9E", "#1B5A9E", "#1B5C9E", "#1B5C9E", "#1B5E9F", "#1B5E9F", "#1B609F", "#1B609F", "#1B639F", "#1B639F", "#1B659F", "#1B659F", "#1C67A0", "#1C67A0", "#1C69A0", "#1C69A0", "#1D6AA0", "#1D6AA0", "#1E6CA1", "#1E6CA1", "#1E6EA1", "#1E6EA1", "#1F70A2", "#1F70A2", "#2072A2", "#2072A2", "#2174A2", "#2174A2", "#2276A3", "#2276A3", "#2378A3", "#2378A3", "#247AA4", "#247AA4", "#257CA4", "#257CA4", "#267EA5", "#267EA5", "#2780A5", "#2780A5", "#2882A6", "#2882A6", "#2A84A6", "#2A84A6", "#2B85A6", "#2B85A6", "#2C87A7", "#2C87A7", "#2E89A7", "#2E89A7", "#2F8BA8", "#2F8BA8", "#308DA8", "#308DA8", "#328FA9", "#328FA9", "#3391A9", "#3391A9", "#3593AA", "#3593AA", "#3795AA", "#3795AA", "#3897AB", "#3897AB", "#3A98AB", "#3A98AB", "#3C9AAC", "#3C9AAC", "#3E9CAC", "#3E9CAC", "#409EAD", "#409EAD", "#42A0AD", "#42A0AD", "#45A2AE", "#45A2AE", "#47A3AE", "#47A3AE", "#4AA5AE", "#4AA5AE", "#4DA7AF", "#4DA7AF", "#50A9AF", "#50A9AF", "#53AAB0", "#53AAB0", "#56ACB0", "#56ACB0", "#5AAEB0", "#5AAEB0", "#5DAFB1", "#5DAFB1", "#61B1B1", "#61B1B1", "#65B3B2", "#65B3B2", "#69B4B3", "#69B4B3", "#6DB6B3", "#6DB6B3", "#71B7B4", "#71B7B4", "#75B8B5", "#75B8B5", "#79BAB5", "#79BAB5", "#7DBBB6", "#7DBBB6", "#81BDB7", "#81BDB7", "#84BEB8", "#84BEB8", "#88C0B9", "#88C0B9", "#8CC1BA", "#8CC1BA", "#90C3BC", "#90C3BC", "#94C4BD", "#94C4BD", "#97C5BE", "#97C5BE", "#9BC7BF", "#9BC7BF", "#9EC8C1", "#9EC8C1", "#A2CAC2", "#A2CAC2", "#A6CBC3", "#A6CBC3", "#A9CDC4", "#A9CDC4", "#ACCEC6", "#ACCEC6", "#B0D0C7", "#B0D0C7", "#B3D2C9", "#B3D2C9", "#B7D3CA", "#B7D3CA", "#BAD5CC", "#BAD5CC", "#BDD6CD", "#BDD6CD", "#C1D8CE", "#C1D8CE", "#C4DAD0", "#C4DAD0", "#C7DBD1", "#C7DBD1", "#CADDD3", "#CADDD3", "#CDDFD4", "#CDDFD4", "#D1E0D6", "#D1E0D6", "#D4E2D7", "#D4E2D7", "#D7E4D9", "#D7E4D9", "#DAE6DA", "#DAE6DA", "#DDE7DB", "#DDE7DB", "#E0E9DD", "#E0E9DD", "#E3EBDE", "#E3EBDE", "#E6EDDF", "#E6EDDF", "#EAEFE0", "#EAEFE0", "#EDF1E2", "#EDF1E2", "#F0F3E3", "#F0F3E3", "#F3F5E3", "#F3F5E3", "#F6F7E4", "#F6F7E4", "#FAF8E5", "#FAF8E5", "#FDFAE6", "#FDFAE6", "#FFFCCC", "#FFFCCC", "#FDFAC8", "#FDFAC8", "#FCF7C4", "#FCF7C4", "#FAF5BF", "#FAF5BF", "#F9F3BB", "#F9F3BB", "#F8F0B7", "#F8F0B7", "#F6EEB2", "#F6EEB2", "#F5EBAE", "#F5EBAE", "#F4E9AA", "#F4E9AA", "#F2E7A6", "#F2E7A6", "#F1E4A1", "#F1E4A1", "#F0E29D", "#F0E29D", "#EEE099", "#EEE099", "#EDDE94", "#EDDE94", "#EBDC90", "#EBDC90", "#EAD98C", "#EAD98C", "#E8D787", "#E8D787", "#E7D583", "#E7D583", "#E5D37F", "#E5D37F", "#E4D17A", "#E4D17A", "#E2CF76", "#E2CF76", "#E0CD71", "#E0CD71", "#DFCB6D", "#DFCB6D", "#DDC969", "#DDC969", "#DBC764", "#DBC764", "#D9C560", "#D9C560", "#D7C45C", "#D7C45C", "#D5C258", "#D5C258", "#D2C053", "#D2C053", "#D0BE4F", "#D0BE4F", "#CEBD4B", "#CEBD4B", "#CBBB47", "#CBBB47", "#C8BA43", "#C8BA43", "#C6B83F", "#C6B83F", "#C3B73C", "#C3B73C", "#C0B538", "#C0B538", "#BDB434", "#BDB434", "#BAB331", "#BAB331", "#B7B12E", "#B7B12E", "#B4B02A", "#B4B02A", "#B1AF27", "#B1AF27", "#AEAD24", "#AEAD24", "#ABAC21", "#ABAC21", "#A8AB1E", "#A8AB1E", "#A4AA1B", "#A4AA1B", "#A1A818", "#A1A818", "#9EA716", "#9EA716", "#9AA613", "#9AA613", "#97A511", "#97A511", "#93A40E", "#93A40E", "#90A20C", "#90A20C", "#8CA10A", "#8CA10A", "#89A009", "#89A009", "#859F07", "#859F07", "#829E06", "#829E06", "#7E9C06", "#7E9C06", "#7B9B06", "#7B9B06", "#779A06", "#779A06", "#749906", "#749906", "#709807", "#709807", "#6C9607", "#6C9607", "#699508", "#699508", "#65940A", "#65940A", "#61920B", "#61920B", "#5E910D", "#5E910D", "#5A900E", "#5A900E", "#578F10", "#578F10", "#538D11", "#538D11", "#4F8C13", "#4F8C13", "#4C8B15", "#4C8B15", "#488916", "#488916", "#448818", "#448818", "#418619", "#418619", "#3D851B", "#3D851B", "#3A831C", "#3A831C", "#36821D", "#36821D", "#33801F", "#33801F", "#2F7F20", "#2F7F20", "#2C7D21", "#2C7D21", "#297C22", "#297C22", "#267A24", "#267A24", "#227925", "#227925", "#1F7726", "#1F7726", "#1D7527", "#1D7527", "#1A7427", "#1A7427", "#177228", "#177228", "#157029", "#157029", "#136E2A", "#136E2A", "#116D2A", "#116D2A", "#0F6B2B", "#0F6B2B", "#0D692B", "#0D692B", "#0C672C", "#0C672C", "#0B652C", "#0B652C", "#0B642C", "#0B642C", "#0B622D", "#0B622D", "#0B602D", "#0B602D", "#0B5E2D", "#0B5E2D", "#0C5C2D", "#0C5C2D", "#0D5A2D", "#0D5A2D", "#0E582D", "#0E582D", "#0F562C", "#0F562C", "#0F552C", "#0F552C", "#10532C", "#10532C", "#11512C", "#11512C", "#124F2B", "#124F2B", "#134D2B", "#134D2B", "#144B2A", "#144B2A", "#15492A", "#15492A", "#164729", "#164729", "#164528", "#164528", "#174327", "#174327", "#174127", "#174127", "#184026", "#184026", "#183E25", "#183E25", "#193C24", "#193C24", "#193A23", "#193A23", "#193822", "#193822", "#193621", "#193621", "#19341F", "#19341F", "#19321E", "#19321E", "#19301D", "#19301D", "#192E1C", "#192E1C", "#192C1A", "#192C1A", "#192B19", "#192B19", "#182917", "#182917", "#182716", "#182716", "#182514", "#182514", "#172313", "#172313"], "cmocean_dense": ["#E6F1F1", "#E6F1F1", "#E4F0F0", "#E4F0F0", "#E3EFEF", "#E3EFEF", "#E1EEEF", "#E1EEEF", "#DFEDEE", "#DFEDEE", "#DDEDED", "#DDEDED", "#DCECED", "#DCECED", "#DAEBEC", "#DAEBEC", "#D8EAEC", "#D8EAEC", "#D7E9EB", "#D7E9EB", "#D5E9EB", "#D5E9EB", "#D3E8EA", "#D3E8EA", "#D1E7EA", "#D1E7EA", "#D0E6E9", "#D0E6E9", "#CEE5E9", "#CEE5E9", "#CCE4E8", "#CCE4E8", "#CBE4E8", "#CBE4E8", "#C9E3E8", "#C9E3E8", "#C7E2E7", "#C7E2E7", "#C6E1E7", "#C6E1E7", "#C4E0E6", "#C4E0E6", "#C2DFE6", "#C2DFE6", "#C1DFE6", "#C1DFE6", "#BFDEE6", "#BFDEE6", "#BEDDE5", "#BEDDE5", "#BCDCE5", "#BCDCE5", "#BADBE5", "#BADBE5", "#B9DAE4", "#B9DAE4", "#B7DAE4", "#B7DAE4", "#B6D9E4", "#B6D9E4", "#B4D8E4", "#B4D8E4", "#B2D7E4", "#B2D7E4", "#B1D6E3", "#B1D6E3", "#AFD5E3", "#AFD5E3", "#AED4E3", "#AED4E3", "#ACD4E3", "#ACD4E3", "#ABD3E3", "#ABD3E3", "#A9D2E3", "#A9D2E3", "#A8D1E3", "#A8D1E3", "#A6D0E3", "#A6D0E3", "#A5CFE2", "#A5CFE2", "#A3CEE2", "#A3CEE2", "#A2CEE2", "#A2CEE2", "#A0CDE2", "#A0CDE2", "#9FCCE2", "#9FCCE2", "#9ECBE2", "#9ECBE2", "#9CCAE2", "#9CCAE2", "#9BC9E2", "#9BC9E2", "#9AC8E2", "#9AC8E2", "#98C7E2", "#98C7E2", "#97C6E2", "#97C6E2", "#96C5E2", "#96C5E2", "#94C5E2", "#94C5E2", "#93C4E2", "#93C4E2", "#92C3E2", "#92C3E2", "#90C2E2", "#90C2E2", "#8FC1E2", "#8FC1E2", "#8EC0E2", "#8EC0E2", "#8DBFE2", "#8DBFE2", "#8CBEE2", "#8CBEE2", "#8ABDE3", "#8ABDE3", "#89BCE3", "#89BCE3", "#88BBE3", "#88BBE3", "#87BAE3", "#87BAE3", "#86B9E3", "#86B9E3", "#85B8E3", "#85B8E3", "#84B7E3", "#84B7E3", "#83B6E3", "#83B6E3", "#82B5E3", "#82B5E3", "#81B4E3", "#81B4E3", "#80B3E3", "#80B3E3", "#7FB2E3", "#7FB2E3", "#7FB1E4", "#7FB1E4", "#7EB0E4", "#7EB0E4", "#7DAFE4", "#7DAFE4", "#7CAEE4", "#7CAEE4", "#7BADE4", "#7BADE4", "#7BACE4", "#7BACE4", "#7AABE4", "#7AABE4", "#79AAE4", "#79AAE4", "#79A9E4", "#79A9E4", "#78A8E4", "#78A8E4", "#78A7E4", "#78A7E4", "#77A6E4", "#77A6E4", "#77A5E4", "#77A5E4", "#76A4E5", "#76A4E5", "#76A3E5", "#76A3E5", "#75A1E5", "#75A1E5", "#75A0E5", "#75A0E5", "#759FE5", "#759FE5", "#759EE5", "#759EE5", "#749DE5", "#749DE5", "#749CE4", "#749CE4", "#749BE4", "#749BE4", "#749AE4", "#749AE4", "#7498E4", "#7498E4", "#7397E4", "#7397E4", "#7396E4", "#7396E4", "#7395E4", "#7395E4", "#7394E4", "#7394E4", "#7393E3", "#7393E3", "#7391E3", "#7391E3", "#7390E3", "#7390E3", "#738FE3", "#738FE3", "#738EE2", "#738EE2", "#748DE2", "#748DE2", "#748BE2", "#748BE2", "#748AE2", "#748AE2", "#7489E1", "#7489E1", "#7488E1", "#7488E1", "#7487E0", "#7487E0", "#7485E0", "#7485E0", "#7584DF", "#7584DF", "#7583DF", "#7583DF", "#7582DE", "#7582DE", "#7581DE", "#7581DE", "#757FDD", "#757FDD", "#757EDD", "#757EDD", "#767DDC", "#767DDC", "#767CDC", "#767CDC", "#767BDB", "#767BDB", "#7679DA", "#7679DA", "#7678DA", "#7678DA", "#7777D9", "#7777D9", "#7776D8", "#7776D8", "#7775D7", "#7775D7", "#7773D7", "#7773D7", "#7772D6", "#7772D6", "#7871D5", "#7871D5", "#7870D4", "#7870D4", "#786FD3", "#786FD3", "#786ED2", "#786ED2", "#786CD2", "#786CD2", "#786BD1", "#786BD1", "#786AD0", "#786AD0", "#7969CF", "#7969CF", "#7968CE", "#7968CE", "#7966CD", "#7966CD", "#7965CC", "#7965CC", "#7964CB", "#7964CB", "#7963CA", "#7963CA", "#7962C9", "#7962C9", "#7961C8", "#7961C8", "#7960C7", "#7960C7", "#795EC5", "#795EC5", "#795DC4", "#795DC4", "#795CC3", "#795CC3", "#795BC2", "#795BC2", "#795AC1", "#795AC1", "#7959C0", "#7959C0", "#7958BF", "#7958BF", "#7957BD", "#7957BD", "#7956BC", "#7956BC", "#7954BB", "#7954BB", "#7953BA", "#7953BA", "#7952B8", "#7952B8", "#7951B7", "#7951B7", "#7950B6", "#7950B6", "#794FB5", "#794FB5", "#784EB3", "#784EB3", "#784DB2", "#784DB2", "#784CB1", "#784CB1", "#784BAF", "#784BAF", "#784AAE", "#784AAE", "#7849AD", "#7849AD", "#7748AB", "#7748AB", "#7747AA", "#7747AA", "#7746A9", "#7746A9", "#7745A7", "#7745A7", "#7743A6", "#7743A6", "#7642A5", "#7642A5", "#7641A3", "#7641A3", "#7640A2", "#7640A2", "#763FA0", "#763FA0", "#753E9F", "#753E9F", "#753D9D", "#753D9D", "#753C9C", "#753C9C", "#743B9B", "#743B9B", "#743B99", "#743B99", "#743A98", "#743A98", "#733996", "#733996", "#733895", "#733895", "#733793", "#733793", "#723692", "#723692", "#723590", "#723590", "#72348F", "#72348F", "#71338D", "#71338D", "#71328C", "#71328C", "#70318A", "#70318A", "#703088", "#703088", "#6F2F87", "#6F2F87", "#6F2E85", "#6F2E85", "#6E2D84", "#6E2D84", "#6E2D82", "#6E2D82", "#6D2C81", "#6D2C81", "#6D2B7F", "#6D2B7F", "#6C2A7E", "#6C2A7E", "#6C297C", "#6C297C", "#6B287A", "#6B287A", "#6B2879", "#6B2879", "#6A2777", "#6A2777", "#6A2675", "#6A2675", "#692574", "#692574", "#682472", "#682472", "#682471", "#682471", "#67236F", "#67236F", "#67226D", "#67226D", "#66216C", "#66216C", "#65216A", "#65216A", "#652068", "#652068", "#641F67", "#641F67", "#631F65", "#631F65", "#621E63", "#621E63", "#621D62", "#621D62", "#611D60", "#611D60", "#601C5E", "#601C5E", "#5F1B5D", "#5F1B5D", "#5F1B5B", "#5F1B5B", "#5E1A59", "#5E1A59", "#5D1A58", "#5D1A58", "#5C1956", "#5C1956", "#5B1954", "#5B1954", "#5A1853", "#5A1853", "#5A1851", "#5A1851", "#591750", "#591750", "#58174E", "#58174E", "#57164C", "#57164C", "#56164B", "#56164B", "#551649", "#551649", "#541548", "#541548", "#531546", "#531546", "#521544", "#521544", "#511443", "#511443", "#501441", "#501441", "#4F1440", "#4F1440", "#4E133E", "#4E133E", "#4D133D", "#4D133D", "#4B133B", "#4B133B", "#4A133A", "#4A133A", "#491238", "#491238", "#481237", "#481237", "#471236", "#471236", "#461234", "#461234", "#451133", "#451133", "#441132", "#441132", "#421130", "#421130", "#41112F", "#41112F", "#40102E", "#40102E", "#3F102D", "#3F102D", "#3E102B", "#3E102B", "#3C102A", "#3C102A", "#3B0F29", "#3B0F29", "#3A0F28", "#3A0F28", "#390F27", "#390F27", "#380F25", "#380F25", "#360E24", "#360E24"], "cmocean_diff": ["#082340", "#082340", "#092542", "#092542", "#0A2644", "#0A2644", "#0B2845", "#0B2845", "#0C2A47", "#0C2A47", "#0C2C49", "#0C2C49", "#0D2D4B", "#0D2D4B", "#0E2F4D", "#0E2F4D", "#0F314F", "#0F314F", "#103251", "#103251", "#113453", "#113453", "#113655", "#113655", "#123756", "#123756", "#133958", "#133958", "#143B5A", "#143B5A", "#143D5C", "#143D5C", "#153E5E", "#153E5E", "#16405F", "#16405F", "#174261", "#174261", "#184363", "#184363", "#194564", "#194564", "#1A4766", "#1A4766", "#1B4867", "#1B4867", "#1D4A68", "#1D4A68", "#1F4C69", "#1F4C69", "#214D6A", "#214D6A", "#244F6B", "#244F6B", "#26506C", "#26506C", "#28526D", "#28526D", "#2B536E", "#2B536E", "#2D556F", "#2D556F", "#2F5670", "#2F5670", "#315871", "#315871", "#345973", "#345973", "#365B74", "#365B74", "#385C75", "#385C75", "#3A5E76", "#3A5E76", "#3C5F77", "#3C5F77", "#3E6178", "#3E6178", "#416279", "#416279", "#43647A", "#43647A", "#45657B", "#45657B", "#47677D", "#47677D", "#49687E", "#49687E", "#4B6A7F", "#4B6A7F", "#4D6B80", "#4D6B80", "#4F6D81", "#4F6D81", "#516E82", "#516E82", "#537084", "#537084", "#557185", "#557185", "#587386", "#587386", "#5A7487", "#5A7487", "#5C7688", "#5C7688", "#5E788A", "#5E788A", "#60798B", "#60798B", "#627B8C", "#627B8C", "#647C8D", "#647C8D", "#667E8E", "#667E8E", "#687F90", "#687F90", "#6A8191", "#6A8191", "#6C8292", "#6C8292", "#6E8494", "#6E8494", "#708695", "#708695", "#728796", "#728796", "#748997", "#748997", "#768A99", "#768A99", "#788C9A", "#788C9A", "#7B8D9B", "#7B8D9B", "#7D8F9D", "#7D8F9D", "#7F919E", "#7F919E", "#81929F", "#81929F", "#8394A1", "#8394A1", "#8596A2", "#8596A2", "#8797A3", "#8797A3", "#8999A5", "#8999A5", "#8B9AA6", "#8B9AA6", "#8D9CA7", "#8D9CA7", "#8F9EA9", "#8F9EA9", "#929FAA", "#929FAA", "#94A1AC", "#94A1AC", "#96A3AD", "#96A3AD", "#98A5AF", "#98A5AF", "#9AA6B0", "#9AA6B0", "#9CA8B1", "#9CA8B1", "#9EAAB3", "#9EAAB3", "#A0ABB4", "#A0ABB4", "#A3ADB6", "#A3ADB6", "#A5AFB7", "#A5AFB7", "#A7B1B9", "#A7B1B9", "#A9B2BA", "#A9B2BA", "#ABB4BC", "#ABB4BC", "#AEB6BD", "#AEB6BD", "#B0B8BF", "#B0B8BF", "#B2BAC0", "#B2BAC0", "#B4BBC2", "#B4BBC2", "#B6BDC4", "#B6BDC4", "#B9BFC5", "#B9BFC5", "#BBC1C7", "#BBC1C7", "#BDC3C8", "#BDC3C8", "#BFC5CA", "#BFC5CA", "#C2C6CC", "#C2C6CC", "#C4C8CD", "#C4C8CD", "#C6CACF", "#C6CACF", "#C8CCD1", "#C8CCD1", "#CBCED2", "#CBCED2", "#CDD0D4", "#CDD0D4", "#CFD2D6", "#CFD2D6", "#D2D4D7", "#D2D4D7", "#D4D6D9", "#D4D6D9", "#D6D8DB", "#D6D8DB", "#D9DADD", "#D9DADD", "#DBDCDE", "#DBDCDE", "#DDDEE0", "#DDDEE0", "#E0E0E2", "#E0E0E2", "#E2E2E3", "#E2E2E3", "#E4E3E5", "#E4E3E5", "#E6E5E7", "#E6E5E7", "#E8E7E8", "#E8E7E8", "#EBE9EA", "#EBE9EA", "#ECEAEB", "#ECEAEB", "#EEECEC", "#EEECEC", "#F0EDEE", "#F0EDEE", "#F1EEEF", "#F1EEEF", "#F3EFEF", "#F3EFEF", "#F4F0F0", "#F4F0F0", "#F5F1F0", "#F5F1F0", "#F5F1F0", "#F6F1F0", "#F6F1F0", "#F6F1F0", "#F5F1EF", "#F5F1EF", "#F5F0EE", "#F5F0EE", "#F4EFED", "#F4EFED", "#F3EEEB", "#F3EEEB", "#F2EDE9", "#F2EDE9", "#F1EBE8", "#F1EBE8", "#EFEAE5", "#EFEAE5", "#EEE8E3", "#EEE8E3", "#ECE6E1", "#ECE6E1", "#EAE5DF", "#EAE5DF", "#E8E3DC", "#E8E3DC", "#E7E1DA", "#E7E1DA", "#E5DFD7", "#E5DFD7", "#E3DDD4", "#E3DDD4", "#E1DBD2", "#E1DBD2", "#DFD9CF", "#DFD9CF", "#DDD7CD", "#DDD7CD", "#DBD5CA", "#DBD5CA", "#D9D3C7", "#D9D3C7", "#D7D1C5", "#D7D1C5", "#D5CFC2", "#D5CFC2", "#D3CDC0", "#D3CDC0", "#D2CBBD", "#D2CBBD", "#D0C9BB", "#D0C9BB", "#CEC7B8", "#CEC7B8", "#CCC5B5", "#CCC5B5", "#CAC3B3", "#CAC3B3", "#C8C1B0", "#C8C1B0", "#C7BFAE", "#C7BFAE", "#C5BDAB", "#C5BDAB", "#C3BBA9", "#C3BBA9", "#C1B9A6", "#C1B9A6", "#BFB7A4", "#BFB7A4", "#BEB5A1", "#BEB5A1", "#BCB39F", "#BCB39F", "#BAB19D", "#BAB19D", "#B9B09A", "#B9B09A", "#B7AE98", "#B7AE98", "#B5AC95", "#B5AC95", "#B3AA93", "#B3AA93", "#B2A890", "#B2A890", "#B0A68E", "#B0A68E", "#AEA58C", "#AEA58C", "#ADA389", "#ADA389", "#ABA187", "#ABA187", "#A99F85", "#A99F85", "#A89D82", "#A89D82", "#A69C80", "#A69C80", "#A49A7D", "#A49A7D", "#A3987B", "#A3987B", "#A19679", "#A19679", "#A09576", "#A09576", "#9E9374", "#9E9374", "#9C9172", "#9C9172", "#9B8F70", "#9B8F70", "#998E6D", "#998E6D", "#988C6B", "#988C6B", "#968A69", "#968A69", "#958967", "#958967", "#938764", "#938764", "#918562", "#918562", "#908460", "#908460", "#8E825E", "#8E825E", "#8D805B", "#8D805B", "#8B7F59", "#8B7F59", "#8A7D57", "#8A7D57", "#887B55", "#887B55", "#877A53", "#877A53", "#857850", "#857850", "#83764E", "#83764E", "#82754C", "#82754C", "#80734A", "#80734A", "#7F7248", "#7F7248", "#7D7046", "#7D7046", "#7C6E43", "#7C6E43", "#7A6D41", "#7A6D41", "#796B3F", "#796B3F", "#776A3D", "#776A3D", "#76683B", "#76683B", "#746639", "#746639", "#726537", "#726537", "#716335", "#716335", "#6F6233", "#6F6233", "#6E6030", "#6E6030", "#6C5F2E", "#6C5F2E", "#6A5D2C", "#6A5D2C", "#685C2B", "#685C2B", "#675A29", "#675A29", "#655927", "#655927", "#635826", "#635826", "#615625", "#615625", "#5F5524", "#5F5524", "#5D5423", "#5D5423", "#5B5222", "#5B5222", "#595121", "#595121", "#574F20", "#574F20", "#554E20", "#554E20", "#534D1F", "#534D1F", "#514B1E", "#514B1E", "#4F4A1D", "#4F4A1D", "#4D481D", "#4D481D", "#4B471C", "#4B471C", "#49451B", "#49451B", "#47441A", "#47441A", "#45431A", "#45431A", "#434119", "#434119", "#424018", "#424018", "#403E17", "#403E17", "#3E3D16", "#3E3D16", "#3C3B16", "#3C3B16", "#3A3A15", "#3A3A15", "#383914", "#383914", "#363713", "#363713", "#343612", "#343612", "#333412", "#333412", "#313311", "#313311", "#2F3110", "#2F3110", "#2D300F", "#2D300F", "#2B2E0E", "#2B2E0E", "#292D0D", "#292D0D", "#272B0C", "#272B0C", "#262A0B", "#262A0B", "#24280A", "#24280A", "#222709", "#222709", "#202509", "#202509", "#1E2408", "#1E2408", "#1C2207", "#1C2207"], "cmocean_gray": ["#000000", "#000000", "#000000", "#000000", "#000000", "#010101", "#010101", "#010101", "#020202", "#020202", "#020202", "#030303", "#030303", "#030303", "#040404", "#040404", "#050505", "#050505", "#050505", "#060606", "#060606", "#070707", "#070707", "#080808", "#080808", "#090909", "#090909", "#0A0A0A", "#0A0A0A", "#0B0B0B", "#0B0B0B", "#0C0C0C", "#0C0C0C", "#0D0D0D", "#0D0D0D", "#0F0E0E", "#0F0E0E", "#100F0F", "#100F0F", "#111010", "#111010", "#121111", "#121111", "#131212", "#131212", "#141313", "#141313", "#151414", "#151414", "#161515", "#161515", "#171616", "#171616", "#181717", "#181717", "#191818", "#191818", "#1A1919", "#1A1919", "#1B1A1A", "#1B1A1A", "#1C1B1B", "#1C1B1B", "#1D1C1C", "#1D1C1C", "#1D1D1D", "#1D1D1D", "#1E1E1E", "#1E1E1E", "#1F1F1F", "#1F1F1F", "#202020", "#202020", "#212121", "#212121", "#222222", "#222222", "#232323", "#232323", "#242424", "#242424", "#252524", "#252524", "#262625", "#262625", "#272626", "#272626", "#282727", "#282727", "#292828", "#292828", "#2A2929", "#2A2929", "#2B2A2A", "#2B2A2A", "#2B2B2B", "#2B2B2B", "#2C2C2C", "#2C2C2C", "#2D2D2D", "#2D2D2D", "#2E2E2E", "#2E2E2E", "#2F2F2E", "#2F2F2E", "#30302F", "#30302F", "#313030", "#313030", "#323131", "#323131", "#333232", "#333232", "#343333", "#343333", "#353434", "#353434", "#353535", "#353535", "#363636", "#363636", "#373737", "#373737", "#383837", "#383837", "#393938", "#393938", "#3A3939", "#3A3939", "#3B3A3A", "#3B3A3A", "#3C3B3B", "#3C3B3B", "#3D3C3C", "#3D3C3C", "#3E3D3D", "#3E3D3D", "#3E3E3E", "#3E3E3E", "#3F3F3F", "#3F3F3F", "#404040", "#404040", "#414140", "#414140", "#424241", "#424241", "#434242", "#434242", "#444343", "#444343", "#454444", "#454444", "#464545", "#464545", "#474646", "#474646", "#474747", "#474747", "#484848", "#484848", "#494948", "#494948", "#4A4A49", "#4A4A49", "#4B4B4A", "#4B4B4A", "#4C4B4B", "#4C4B4B", "#4D4C4C", "#4D4C4C", "#4E4D4D", "#4E4D4D", "#4F4E4E", "#4F4E4E", "#504F4F", "#504F4F", "#505050", "#505050", "#515150", "#515150", "#525251", "#525251", "#535352", "#535352", "#545453", "#545453", "#555454", "#555454", "#565555", "#565555", "#575656", "#575656", "#585757", "#585757", "#595858", "#595858", "#5A5959", "#5A5959", "#5A5A5A", "#5A5A5A", "#5B5B5A", "#5B5B5A", "#5C5C5B", "#5C5C5B", "#5D5D5C", "#5D5D5C", "#5E5E5D", "#5E5E5D", "#5F5E5E", "#5F5E5E", "#605F5F", "#605F5F", "#616060", "#616060", "#626161", "#626161", "#636262", "#636262", "#646363", "#646363", "#656464", "#656464", "#656564", "#656564", "#666665", "#666665", "#676766", "#676766", "#686867", "#686867", "#696968", "#696968", "#6A6A69", "#6A6A69", "#6B6B6A", "#6B6B6A", "#6C6B6B", "#6C6B6B", "#6D6C6C", "#6D6C6C", "#6E6D6D", "#6E6D6D", "#6F6E6E", "#6F6E6E", "#706F6F", "#706F6F", "#717070", "#717070", "#727171", "#727171", "#737271", "#737271", "#737372", "#737372", "#747473", "#747473", "#757574", "#757574", "#767675", "#767675", "#777776", "#777776", "#787877", "#787877", "#797978", "#797978", "#7A7A79", "#7A7A79", "#7B7B7A", "#7B7B7A", "#7C7C7B", "#7C7C7B", "#7D7D7C", "#7D7D7C", "#7E7D7D", "#7E7D7D", "#7F7E7E", "#7F7E7E", "#807F7F", "#807F7F", "#818080", "#818080", "#828181", "#828181", "#838282", "#838282", "#848383", "#848383", "#858484", "#858484", "#868585", "#868585", "#878686", "#878686", "#888787", "#888787", "#898888", "#898888", "#8A8989", "#8A8989", "#8B8A8A", "#8B8A8A", "#8C8B8B", "#8C8B8B", "#8D8C8C", "#8D8C8C", "#8E8D8D", "#8E8D8D", "#8F8E8E", "#8F8E8E", "#908F8F", "#908F8F", "#919090", "#919090", "#929191", "#929191", "#939292", "#939292", "#949393", "#949393", "#959494", "#959494", "#969595", "#969595", "#979696", "#979696", "#989797", "#989797", "#999898", "#999898", "#9A9999", "#9A9999", "#9B9A9A", "#9B9A9A", "#9C9B9B", "#9C9B9B", "#9D9D9C", "#9D9D9C", "#9E9E9D", "#9E9E9D", "#9F9F9E", "#9F9F9E", "#A0A09F", "#A0A09F", "#A1A1A0", "#A1A1A0", "#A2A2A1", "#A2A2A1", "#A3A3A2", "#A3A3A2", "#A4A4A3", "#A4A4A3", "#A5A5A4", "#A5A5A4", "#A6A6A5", "#A6A6A5", "#A7A7A6", "#A7A7A6", "#A8A8A7", "#A8A8A7", "#AAA9A8", "#AAA9A8", "#ABAAA9", "#ABAAA9", "#ACABAA", "#ACABAA", "#ADACAC", "#ADACAC", "#AEADAD", "#AEADAD", "#AFAFAE", "#AFAFAE", "#B0B0AF", "#B0B0AF", "#B1B1B0", "#B1B1B0", "#B2B2B1", "#B2B2B1", "#B3B3B2", "#B3B3B2", "#B4B4B3", "#B4B4B3", "#B6B5B4", "#B6B5B4", "#B7B6B5", "#B7B6B5", "#B8B7B6", "#B8B7B6", "#B9B9B8", "#B9B9B8", "#BABAB9", "#BABAB9", "#BBBBBA", "#BBBBBA", "#BCBCBB", "#BCBCBB", "#BDBDBC", "#BDBDBC", "#BEBEBD", "#BEBEBD", "#C0BFBE", "#C0BFBE", "#C1C0BF", "#C1C0BF", "#C2C2C1", "#C2C2C1", "#C3C3C2", "#C3C3C2", "#C4C4C3", "#C4C4C3", "#C5C5C4", "#C5C5C4", "#C6C6C5", "#C6C6C5", "#C8C7C6", "#C8C7C6", "#C9C8C7", "#C9C8C7", "#CACAC9", "#CACAC9", "#CBCBCA", "#CBCBCA", "#CCCCCB", "#CCCCCB", "#CDCDCC", "#CDCDCC", "#CFCECD", "#CFCECD", "#D0D0CE", "#D0D0CE", "#D1D1D0", "#D1D1D0", "#D2D2D1", "#D2D2D1", "#D3D3D2", "#D3D3D2", "#D5D4D3", "#D5D4D3", "#D6D6D4", "#D6D6D4", "#D7D7D6", "#D7D7D6", "#D8D8D7", "#D8D8D7", "#D9D9D8", "#D9D9D8", "#DBDAD9", "#DBDAD9", "#DCDCDB", "#DCDCDB", "#DDDDDC", "#DDDDDC", "#DEDEDD", "#DEDEDD", "#E0DFDE", "#E0DFDE", "#E1E1DF", "#E1E1DF", "#E2E2E1", "#E2E2E1", "#E3E3E2", "#E3E3E2", "#E5E4E3", "#E5E4E3", "#E6E6E4", "#E6E6E4", "#E7E7E6", "#E7E7E6", "#E8E8E7", "#E8E8E7", "#EAEAE8", "#EAEAE8", "#EBEBEA", "#EBEBEA", "#ECECEB", "#ECECEB", "#EEEDEC", "#EEEDEC", "#EFEFED", "#EFEFED", "#F0F0EF", "#F0F0EF", "#F2F1F0", "#F2F1F0", "#F3F3F1", "#F3F3F1", "#F4F4F3", "#F4F4F3", "#F5F5F4", "#F5F5F4", "#F7F7F5", "#F7F7F5", "#F8F8F7", "#F8F8F7", "#F9F9F8", "#F9F9F8", "#FBFBF9", "#FBFBF9", "#FCFCFB", "#FCFCFB", "#FEFDFC", "#FEFDFC", "#FFFFFD", "#FFFFFD"], "cmocean_haline": ["#2A186C", "#2A186C", "#2A196E", "#2A196E", "#2A1971", "#2A1971", "#2B1973", "#2B1973", "#2B1975", "#2B1975", "#2C1A78", "#2C1A78", "#2C1A7A", "#2C1A7A", "#2D1A7D", "#2D1A7D", "#2D1A7F", "#2D1A7F", "#2D1B82", "#2D1B82", "#2E1B84", "#2E1B84", "#2E1B87", "#2E1B87", "#2E1C89", "#2E1C89", "#2E1C8C", "#2E1C8C", "#2E1C8E", "#2E1C8E", "#2E1D91", "#2E1D91", "#2E1D93", "#2E1D93", "#2E1E95", "#2E1E95", "#2E1E98", "#2E1E98", "#2E1F9A", "#2E1F9A", "#2D209C", "#2D209C", "#2D219D", "#2D219D", "#2C229F", "#2C229F", "#2B24A0", "#2B24A0", "#2A25A1", "#2A25A1", "#2927A2", "#2927A2", "#2829A3", "#2829A3", "#262BA3", "#262BA3", "#252DA3", "#252DA3", "#242EA3", "#242EA3", "#2230A3", "#2230A3", "#2132A2", "#2132A2", "#2034A2", "#2034A2", "#1E35A1", "#1E35A1", "#1D37A1", "#1D37A1", "#1C39A0", "#1C39A0", "#1B3AA0", "#1B3AA0", "#193C9F", "#193C9F", "#183D9E", "#183D9E", "#173F9E", "#173F9E", "#16409D", "#16409D", "#15419C", "#15419C", "#14439C", "#14439C", "#13449B", "#13449B", "#12459B", "#12459B", "#11479A", "#11479A", "#104899", "#104899", "#0F4999", "#0F4999", "#0F4A98", "#0F4A98", "#0E4C97", "#0E4C97", "#0D4D97", "#0D4D97", "#0D4E96", "#0D4E96", "#0D4F96", "#0D4F96", "#0C5095", "#0C5095", "#0C5195", "#0C5195", "#0C5294", "#0C5294", "#0C5394", "#0C5394", "#0C5493", "#0C5493", "#0D5593", "#0D5593", "#0D5692", "#0D5692", "#0D5792", "#0D5792", "#0E5891", "#0E5891", "#0E5991", "#0E5991", "#0F5A91", "#0F5A91", "#0F5B90", "#0F5B90", "#105C90", "#105C90", "#115D8F", "#115D8F", "#115E8F", "#115E8F", "#125F8F", "#125F8F", "#13608E", "#13608E", "#14618E", "#14618E", "#14628E", "#14628E", "#15638E", "#15638E", "#16638D", "#16638D", "#17648D", "#17648D", "#18658D", "#18658D", "#18668C", "#18668C", "#19678C", "#19678C", "#1A688C", "#1A688C", "#1B698C", "#1B698C", "#1C6A8C", "#1C6A8C", "#1D6B8B", "#1D6B8B", "#1D6B8B", "#1E6C8B", "#1E6C8B", "#1F6D8B", "#1F6D8B", "#206E8B", "#206E8B", "#216F8B", "#216F8B", "#22708A", "#22708A", "#22718A", "#22718A", "#23718A", "#23718A", "#24728A", "#24728A", "#25738A", "#25738A", "#26748A", "#26748A", "#26758A", "#26758A", "#27768A", "#27768A", "#287689", "#287689", "#297789", "#297789", "#297889", "#297889", "#2A7989", "#2A7989", "#2B7A89", "#2B7A89", "#2B7B89", "#2B7B89", "#2C7C89", "#2C7C89", "#2D7C89", "#2D7C89", "#2D7D89", "#2D7D89", "#2E7E89", "#2E7E89", "#2F7F89", "#2F7F89", "#2F8089", "#2F8089", "#308189", "#308189", "#318289", "#318289", "#318288", "#318288", "#328388", "#328388", "#338488", "#338488", "#338588", "#338588", "#348688", "#348688", "#348788", "#348788", "#358888", "#358888", "#358988", "#358988", "#368988", "#368988", "#378A88", "#378A88", "#378B88", "#378B88", "#388C88", "#388C88", "#388D88", "#388D88", "#398E88", "#398E88", "#398F88", "#398F88", "#3A9087", "#3A9087", "#3A9087", "#3B9187", "#3B9187", "#3B9287", "#3B9287", "#3C9387", "#3C9387", "#3C9487", "#3C9487", "#3D9587", "#3D9587", "#3D9687", "#3D9687", "#3E9787", "#3E9787", "#3E9886", "#3E9886", "#3F9986", "#3F9986", "#3F9986", "#409A86", "#409A86", "#419B86", "#419B86", "#419C85", "#419C85", "#429D85", "#429D85", "#429E85", "#429E85", "#439F85", "#439F85", "#43A084", "#43A084", "#44A184", "#44A184", "#44A284", "#44A284", "#45A384", "#45A384", "#46A483", "#46A483", "#46A483", "#47A583", "#47A583", "#48A682", "#48A682", "#48A782", "#48A782", "#49A882", "#49A882", "#4AA981", "#4AA981", "#4AAA81", "#4AAA81", "#4BAB81", "#4BAB81", "#4CAC80", "#4CAC80", "#4CAD80", "#4CAD80", "#4DAE7F", "#4DAE7F", "#4EAE7F", "#4EAE7F", "#4FAF7E", "#4FAF7E", "#50B07E", "#50B07E", "#51B17D", "#51B17D", "#51B27D", "#51B27D", "#52B37C", "#52B37C", "#53B47C", "#53B47C", "#54B57B", "#54B57B", "#55B67B", "#55B67B", "#56B77A", "#56B77A", "#57B879", "#57B879", "#58B879", "#58B879", "#5AB978", "#5AB978", "#5BBA77", "#5BBA77", "#5CBB77", "#5CBB77", "#5DBC76", "#5DBC76", "#5EBD75", "#5EBD75", "#5FBE75", "#5FBE75", "#61BF74", "#61BF74", "#62BF73", "#62BF73", "#63C072", "#63C072", "#65C172", "#65C172", "#66C271", "#66C271", "#68C370", "#68C370", "#69C46F", "#69C46F", "#6BC46E", "#6BC46E", "#6CC56E", "#6CC56E", "#6EC66D", "#6EC66D", "#70C76C", "#70C76C", "#71C86B", "#71C86B", "#73C86A", "#73C86A", "#75C969", "#75C969", "#77CA68", "#77CA68", "#78CB68", "#78CB68", "#7ACB67", "#7ACB67", "#7CCC66", "#7CCC66", "#7ECD65", "#7ECD65", "#80CE64", "#80CE64", "#82CE63", "#82CE63", "#84CF62", "#84CF62", "#86D062", "#86D062", "#89D061", "#89D061", "#8BD160", "#8BD160", "#8DD25F", "#8DD25F", "#8FD25F", "#8FD25F", "#92D35E", "#92D35E", "#94D35D", "#94D35D", "#97D45D", "#97D45D", "#99D45D", "#99D45D", "#9BD55C", "#9BD55C", "#9ED65C", "#9ED65C", "#A0D65C", "#A0D65C", "#A3D75C", "#A3D75C", "#A5D75C", "#A5D75C", "#A8D85C", "#A8D85C", "#AAD85C", "#AAD85C", "#ADD85C", "#ADD85C", "#AFD95D", "#AFD95D", "#B1D95D", "#B1D95D", "#B4DA5E", "#B4DA5E", "#B6DA5F", "#B6DA5F", "#B8DB60", "#B8DB60", "#BBDB61", "#BBDB61", "#BDDC62", "#BDDC62", "#BFDC63", "#BFDC63", "#C1DD64", "#C1DD64", "#C4DD65", "#C4DD65", "#C6DE66", "#C6DE66", "#C8DE67", "#C8DE67", "#CADF69", "#CADF69", "#CCDF6A", "#CCDF6A", "#CEE06C", "#CEE06C", "#D0E06D", "#D0E06D", "#D2E16F", "#D2E16F", "#D4E170", "#D4E170", "#D6E272", "#D6E272", "#D8E273", "#D8E273", "#DAE375", "#DAE375", "#DCE377", "#DCE377", "#DEE479", "#DEE479", "#E0E57A", "#E0E57A", "#E1E57C", "#E1E57C", "#E3E67E", "#E3E67E", "#E5E680", "#E5E680", "#E7E781", "#E7E781", "#E9E783", "#E9E783", "#EBE885", "#EBE885", "#ECE987", "#ECE987", "#EEE989", "#EEE989", "#F0EA8A", "#F0EA8A", "#F2EA8C", "#F2EA8C", "#F3EB8E", "#F3EB8E", "#F5EC90", "#F5EC90", "#F7EC92", "#F7EC92", "#F8ED94", "#F8ED94", "#FAEE96", "#FAEE96", "#FCEE98", "#FCEE98", "#FDEF9A", "#FDEF9A"], "cmocean_ice": ["#040613", "#040613", "#050614", "#050614", "#050715", "#050715", "#060817", "#060817", "#070918", "#070918", "#080A1A", "#080A1A", "#090B1B", "#090B1B", "#0A0C1D", "#0A0C1D", "#0B0D1E", "#0B0D1E", "#0C0D1F", "#0C0D1F", "#0D0E21", "#0D0E21", "#0E0F22", "#0E0F22", "#0F1024", "#0F1024", "#101125", "#101125", "#111227", "#111227", "#121328", "#121328", "#13132A", "#13132A", "#14142B", "#14142B", "#15152C", "#15152C", "#16162E", "#16162E", "#17172F", "#17172F", "#171831", "#171831", "#181832", "#181832", "#191934", "#191934", "#1A1A35", "#1A1A35", "#1B1B37", "#1B1B37", "#1C1C38", "#1C1C38", "#1D1C3A", "#1D1C3A", "#1E1D3B", "#1E1D3B", "#1F1E3D", "#1F1E3D", "#1F1F3E", "#1F1F3E", "#201F40", "#201F40", "#212041", "#212041", "#222143", "#222143", "#232244", "#232244", "#242246", "#242246", "#252347", "#252347", "#252449", "#252449", "#26254A", "#26254A", "#27254C", "#27254C", "#28264E", "#28264E", "#29274F", "#29274F", "#292851", "#292851", "#2A2852", "#2A2852", "#2B2954", "#2B2954", "#2C2A55", "#2C2A55", "#2C2B57", "#2C2B57", "#2D2B59", "#2D2B59", "#2E2C5A", "#2E2C5A", "#2F2D5C", "#2F2D5C", "#2F2E5E", "#2F2E5E", "#302F5F", "#302F5F", "#312F61", "#312F61", "#313062", "#313062", "#323164", "#323164", "#333266", "#333266", "#333267", "#333267", "#343369", "#343369", "#35346B", "#35346B", "#35356C", "#35356C", "#36356E", "#36356E", "#363670", "#363670", "#373771", "#373771", "#383873", "#383873", "#383975", "#383975", "#393976", "#393976", "#393A78", "#393A78", "#3A3B7A", "#3A3B7A", "#3A3C7B", "#3A3C7B", "#3A3D7D", "#3A3D7D", "#3B3E7F", "#3B3E7F", "#3B3E80", "#3B3E80", "#3C3F82", "#3C3F82", "#3C4084", "#3C4084", "#3C4185", "#3C4185", "#3D4287", "#3D4287", "#3D4389", "#3D4389", "#3D448A", "#3D448A", "#3E458C", "#3E458C", "#3E468D", "#3E468D", "#3E478F", "#3E478F", "#3E4890", "#3E4890", "#3E4992", "#3E4992", "#3E4993", "#3E4993", "#3F4A95", "#3F4A95", "#3F4B96", "#3F4B96", "#3F4C97", "#3F4C97", "#3F4E99", "#3F4E99", "#3F4F9A", "#3F4F9A", "#3F509B", "#3F509B", "#3F519D", "#3F519D", "#3F529E", "#3F529E", "#3F539F", "#3F539F", "#3F54A0", "#3F54A0", "#3F55A1", "#3F55A1", "#3F56A2", "#3F56A2", "#3F57A3", "#3F57A3", "#3F58A4", "#3F58A4", "#3F59A5", "#3F59A5", "#3E5AA6", "#3E5AA6", "#3E5CA7", "#3E5CA7", "#3E5DA8", "#3E5DA8", "#3E5EA9", "#3E5EA9", "#3E5FAA", "#3E5FAA", "#3E60AB", "#3E60AB", "#3E61AB", "#3E61AB", "#3E62AC", "#3E62AC", "#3E63AD", "#3E63AD", "#3E65AD", "#3E65AD", "#3E66AE", "#3E66AE", "#3E67AF", "#3E67AF", "#3E68AF", "#3E68AF", "#3E69B0", "#3E69B0", "#3E6AB0", "#3E6AB0", "#3F6BB1", "#3F6BB1", "#3F6CB2", "#3F6CB2", "#3F6EB2", "#3F6EB2", "#3F6FB3", "#3F6FB3", "#3F70B3", "#3F70B3", "#3F71B4", "#3F71B4", "#4072B4", "#4072B4", "#4073B4", "#4073B4", "#4074B5", "#4074B5", "#4075B5", "#4075B5", "#4176B6", "#4176B6", "#4178B6", "#4178B6", "#4279B7", "#4279B7", "#427AB7", "#427AB7", "#427BB7", "#427BB7", "#437CB8", "#437CB8", "#437DB8", "#437DB8", "#447EB9", "#447EB9", "#447FB9", "#447FB9", "#4580B9", "#4580B9", "#4581BA", "#4581BA", "#4682BA", "#4682BA", "#4684BB", "#4684BB", "#4785BB", "#4785BB", "#4786BB", "#4786BB", "#4887BC", "#4887BC", "#4988BC", "#4988BC", "#4989BC", "#4989BC", "#4A8ABD", "#4A8ABD", "#4B8BBD", "#4B8BBD", "#4B8CBD", "#4B8CBD", "#4C8DBE", "#4C8DBE", "#4D8EBE", "#4D8EBE", "#4E8FBF", "#4E8FBF", "#4E90BF", "#4E90BF", "#4F91BF", "#4F91BF", "#5092C0", "#5092C0", "#5194C0", "#5194C0", "#5195C0", "#5195C0", "#5296C1", "#5296C1", "#5397C1", "#5397C1", "#5498C2", "#5498C2", "#5599C2", "#5599C2", "#559AC2", "#559AC2", "#569BC3", "#569BC3", "#579CC3", "#579CC3", "#589DC3", "#589DC3", "#599EC4", "#599EC4", "#5A9FC4", "#5A9FC4", "#5BA0C5", "#5BA0C5", "#5CA1C5", "#5CA1C5", "#5DA2C5", "#5DA2C5", "#5EA3C6", "#5EA3C6", "#5FA4C6", "#5FA4C6", "#5FA6C7", "#5FA6C7", "#60A7C7", "#60A7C7", "#61A8C7", "#61A8C7", "#62A9C8", "#62A9C8", "#63AAC8", "#63AAC8", "#64ABC9", "#64ABC9", "#65ACC9", "#65ACC9", "#67ADC9", "#67ADC9", "#68AECA", "#68AECA", "#69AFCA", "#69AFCA", "#6AB0CB", "#6AB0CB", "#6BB1CB", "#6BB1CB", "#6CB2CB", "#6CB2CB", "#6DB3CC", "#6DB3CC", "#6EB4CC", "#6EB4CC", "#6FB5CD", "#6FB5CD", "#71B6CD", "#71B6CD", "#72B8CE", "#72B8CE", "#73B9CE", "#73B9CE", "#74BACE", "#74BACE", "#75BBCF", "#75BBCF", "#77BCCF", "#77BCCF", "#78BDD0", "#78BDD0", "#79BED0", "#79BED0", "#7BBFD0", "#7BBFD0", "#7CC0D1", "#7CC0D1", "#7DC1D1", "#7DC1D1", "#7FC2D2", "#7FC2D2", "#80C3D2", "#80C3D2", "#82C4D3", "#82C4D3", "#83C5D3", "#83C5D3", "#85C6D3", "#85C6D3", "#86C7D4", "#86C7D4", "#88C8D4", "#88C8D4", "#89C9D5", "#89C9D5", "#8BCAD5", "#8BCAD5", "#8CCBD6", "#8CCBD6", "#8ECCD6", "#8ECCD6", "#90CDD7", "#90CDD7", "#92CED7", "#92CED7", "#93CFD8", "#93CFD8", "#95D0D8", "#95D0D8", "#97D1D9", "#97D1D9", "#99D2D9", "#99D2D9", "#9AD3DA", "#9AD3DA", "#9CD4DA", "#9CD4DA", "#9ED5DB", "#9ED5DB", "#A0D6DC", "#A0D6DC", "#A2D6DC", "#A2D6DC", "#A4D7DD", "#A4D7DD", "#A6D8DE", "#A6D8DE", "#A8D9DE", "#A8D9DE", "#A9DADF", "#A9DADF", "#ABDBE0", "#ABDBE0", "#ADDCE0", "#ADDCE0", "#AFDDE1", "#AFDDE1", "#B1DEE2", "#B1DEE2", "#B3DFE3", "#B3DFE3", "#B5E0E3", "#B5E0E3", "#B7E1E4", "#B7E1E4", "#B9E2E5", "#B9E2E5", "#BAE3E6", "#BAE3E6", "#BCE4E7", "#BCE4E7", "#BEE5E7", "#BEE5E7", "#C0E6E8", "#C0E6E8", "#C2E6E9", "#C2E6E9", "#C4E7EA", "#C4E7EA", "#C6E8EB", "#C6E8EB", "#C8E9EC", "#C8E9EC", "#C9EAED", "#C9EAED", "#CBEBEE", "#CBEBEE", "#CDECEF", "#CDECEF", "#CFEDEF", "#CFEDEF", "#D1EEF0", "#D1EEF0", "#D3EFF1", "#D3EFF1", "#D5F0F2", "#D5F0F2", "#D6F1F3", "#D6F1F3", "#D8F2F4", "#D8F2F4", "#DAF3F5", "#DAF3F5", "#DCF4F6", "#DCF4F6", "#DEF5F7", "#DEF5F7", "#E0F6F8", "#E0F6F8", "#E1F7F9", "#E1F7F9", "#E3F9FA", "#E3F9FA", "#E5FAFB", "#E5FAFB", "#E7FBFB", "#E7FBFB", "#E8FCFC", "#E8FCFC", "#EAFDFD", "#EAFDFD"], "cmocean_matter": ["#FEEDB0", "#FEEDB0", "#FDECAF", "#FDECAF", "#FDEAAD", "#FDEAAD", "#FDE9AC", "#FDE9AC", "#FDE8AB", "#FDE8AB", "#FDE6A9", "#FDE6A9", "#FDE5A8", "#FDE5A8", "#FDE3A7", "#FDE3A7", "#FDE2A5", "#FDE2A5", "#FCE1A4", "#FCE1A4", "#FCDFA3", "#FCDFA3", "#FCDEA1", "#FCDEA1", "#FCDCA0", "#FCDCA0", "#FCDB9F", "#FCDB9F", "#FCDA9D", "#FCDA9D", "#FCD89C", "#FCD89C", "#FBD79B", "#FBD79B", "#FBD59A", "#FBD59A", "#FBD498", "#FBD498", "#FBD397", "#FBD397", "#FBD196", "#FBD196", "#FBD094", "#FBD094", "#FBCF93", "#FBCF93", "#FACD92", "#FACD92", "#FACC91", "#FACC91", "#FACA90", "#FACA90", "#FAC98E", "#FAC98E", "#FAC88D", "#FAC88D", "#FAC68C", "#FAC68C", "#FAC58B", "#FAC58B", "#F9C38A", "#F9C38A", "#F9C288", "#F9C288", "#F9C187", "#F9C187", "#F9BF86", "#F9BF86", "#F9BE85", "#F9BE85", "#F9BD84", "#F9BD84", "#F8BB83", "#F8BB83", "#F8BA82", "#F8BA82", "#F8B880", "#F8B880", "#F8B77F", "#F8B77F", "#F8B67E", "#F8B67E", "#F7B47D", "#F7B47D", "#F7B37C", "#F7B37C", "#F7B27B", "#F7B27B", "#F7B07A", "#F7B07A", "#F7AF79", "#F7AF79", "#F6AE78", "#F6AE78", "#F6AC77", "#F6AC77", "#F6AB76", "#F6AB76", "#F6A975", "#F6A975", "#F5A874", "#F5A874", "#F5A773", "#F5A773", "#F5A572", "#F5A572", "#F5A471", "#F5A471", "#F5A370", "#F5A370", "#F4A16F", "#F4A16F", "#F4A06E", "#F4A06E", "#F49F6D", "#F49F6D", "#F49D6C", "#F49D6C", "#F39C6B", "#F39C6B", "#F39A6A", "#F39A6A", "#F39969", "#F39969", "#F29868", "#F29868", "#F29668", "#F29668", "#F29567", "#F29567", "#F29466", "#F29466", "#F19265", "#F19265", "#F19164", "#F19164", "#F18F63", "#F18F63", "#F08E63", "#F08E63", "#F08D62", "#F08D62", "#F08B61", "#F08B61", "#EF8A60", "#EF8A60", "#EF8960", "#EF8960", "#EF875F", "#EF875F", "#EE865E", "#EE865E", "#EE855E", "#EE855E", "#EE835D", "#EE835D", "#ED825C", "#ED825C", "#ED815C", "#ED815C", "#ED7F5B", "#ED7F5B", "#EC7E5A", "#EC7E5A", "#EC7C5A", "#EC7C5A", "#EC7B59", "#EC7B59", "#EB7A59", "#EB7A59", "#EB7858", "#EB7858", "#EA7758", "#EA7758", "#EA7657", "#EA7657", "#E97457", "#E97457", "#E97356", "#E97356", "#E97256", "#E97256", "#E87056", "#E87056", "#E86F55", "#E86F55", "#E76E55", "#E76E55", "#E76C55", "#E76C55", "#E66B54", "#E66B54", "#E66A54", "#E66A54", "#E56854", "#E56854", "#E56754", "#E56754", "#E46653", "#E46653", "#E36453", "#E36453", "#E36353", "#E36353", "#E26253", "#E26253", "#E26053", "#E26053", "#E15F53", "#E15F53", "#E05E53", "#E05E53", "#E05D53", "#E05D53", "#DF5B53", "#DF5B53", "#DF5A53", "#DF5A53", "#DE5953", "#DE5953", "#DD5853", "#DD5853", "#DC5653", "#DC5653", "#DC5553", "#DC5553", "#DB5453", "#DB5453", "#DA5353", "#DA5353", "#D95153", "#D95153", "#D95053", "#D95053", "#D84F54", "#D84F54", "#D74E54", "#D74E54", "#D64D54", "#D64D54", "#D54C54", "#D54C54", "#D54B54", "#D54B54", "#D44A55", "#D44A55", "#D34855", "#D34855", "#D24755", "#D24755", "#D14656", "#D14656", "#D04556", "#D04556", "#CF4456", "#CF4456", "#CE4356", "#CE4356", "#CD4257", "#CD4257", "#CC4157", "#CC4157", "#CB4057", "#CB4057", "#CA3F58", "#CA3F58", "#C93E58", "#C93E58", "#C83D58", "#C83D58", "#C73D59", "#C73D59", "#C63C59", "#C63C59", "#C53B59", "#C53B59", "#C43A5A", "#C43A5A", "#C3395A", "#C3395A", "#C2385A", "#C2385A", "#C1375B", "#C1375B", "#C0365B", "#C0365B", "#BF365B", "#BF365B", "#BE355C", "#BE355C", "#BD345C", "#BD345C", "#BB335C", "#BB335C", "#BA325D", "#BA325D", "#B9325D", "#B9325D", "#B8315D", "#B8315D", "#B7305E", "#B7305E", "#B62F5E", "#B62F5E", "#B52F5E", "#B52F5E", "#B32E5F", "#B32E5F", "#B22D5F", "#B22D5F", "#B12D5F", "#B12D5F", "#B02C5F", "#B02C5F", "#AF2B60", "#AF2B60", "#AE2B60", "#AE2B60", "#AC2A60", "#AC2A60", "#AB2960", "#AB2960", "#AA2961", "#AA2961", "#A92861", "#A92861", "#A72861", "#A72861", "#A62761", "#A62761", "#A52662", "#A52662", "#A42662", "#A42662", "#A32562", "#A32562", "#A12562", "#A12562", "#A02462", "#A02462", "#9F2462", "#9F2462", "#9E2363", "#9E2363", "#9C2363", "#9C2363", "#9B2263", "#9B2263", "#9A2263", "#9A2263", "#992263", "#992263", "#972163", "#972163", "#962163", "#962163", "#952063", "#952063", "#932063", "#932063", "#921F63", "#921F63", "#911F63", "#911F63", "#901F63", "#901F63", "#8E1E63", "#8E1E63", "#8D1E63", "#8D1E63", "#8C1E63", "#8C1E63", "#8A1D63", "#8A1D63", "#891D63", "#891D63", "#881D63", "#881D63", "#861D63", "#861D63", "#851C63", "#851C63", "#841C63", "#841C63", "#821C63", "#821C63", "#811C63", "#811C63", "#801B62", "#801B62", "#7E1B62", "#7E1B62", "#7D1B62", "#7D1B62", "#7C1B62", "#7C1B62", "#7A1B62", "#7A1B62", "#791A61", "#791A61", "#781A61", "#781A61", "#761A61", "#761A61", "#751A61", "#751A61", "#741A60", "#741A60", "#721A60", "#721A60", "#711960", "#711960", "#70195F", "#70195F", "#6E195F", "#6E195F", "#6D195E", "#6D195E", "#6B195E", "#6B195E", "#6A195E", "#6A195E", "#69195D", "#69195D", "#67195D", "#67195D", "#66185C", "#66185C", "#65185C", "#65185C", "#63185B", "#63185B", "#62185B", "#62185B", "#61185A", "#61185A", "#5F185A", "#5F185A", "#5E1859", "#5E1859", "#5D1758", "#5D1758", "#5B1758", "#5B1758", "#5A1757", "#5A1757", "#591757", "#591757", "#571756", "#571756", "#561755", "#561755", "#551755", "#551755", "#531654", "#531654", "#521653", "#521653", "#511653", "#511653", "#4F1652", "#4F1652", "#4E1651", "#4E1651", "#4D1551", "#4D1551", "#4B1550", "#4B1550", "#4A154F", "#4A154F", "#49154E", "#49154E", "#47154E", "#47154E", "#46144D", "#46144D", "#45144C", "#45144C", "#44144B", "#44144B", "#42144B", "#42144B", "#41134A", "#41134A", "#401349", "#401349", "#3E1348", "#3E1348", "#3D1347", "#3D1347", "#3C1247", "#3C1247", "#3B1246", "#3B1246", "#391245", "#391245", "#381144", "#381144", "#371143", "#371143", "#361142", "#361142", "#341141", "#341141", "#331041", "#331041", "#321040", "#321040", "#300F3F", "#300F3F", "#2F0F3E", "#2F0F3E"], "cmocean_oxy": ["#400505", "#400505", "#420505", "#420505", "#430606", "#430606", "#450606", "#450606", "#470607", "#470607", "#480607", "#480607", "#4A0608", "#4A0608", "#4C0608", "#4C0608", "#4D0708", "#4D0708", "#4F0709", "#4F0709", "#510709", "#510709", "#52070A", "#52070A", "#54070A", "#54070A", "#56070B", "#56070B", "#57070B", "#57070B", "#59070B", "#59070B", "#5B070C", "#5B070C", "#5C070C", "#5C070C", "#5E070D", "#5E070D", "#60070D", "#60070D", "#62070D", "#62070D", "#63070E", "#63070E", "#65070E", "#65070E", "#67070E", "#67070E", "#68070E", "#68070E", "#6A060F", "#6A060F", "#6C060F", "#6C060F", "#6E060F", "#6E060F", "#6F060F", "#6F060F", "#71060F", "#71060F", "#73050F", "#73050F", "#75050F", "#75050F", "#76050F", "#76050F", "#78050F", "#78050F", "#7A050F", "#7A050F", "#7B050E", "#7B050E", "#7D050E", "#7D050E", "#7F050E", "#7F050E", "#80060D", "#80060D", "#82070D", "#82070D", "#83080C", "#83080C", "#84090C", "#84090C", "#860B0B", "#860B0B", "#870D0A", "#870D0A", "#880E0A", "#880E0A", "#8A1009", "#8A1009", "#8B1209", "#8B1209", "#8C1409", "#8C1409", "#8D1608", "#8D1608", "#8E1708", "#8E1708", "#8F1907", "#8F1907", "#5C4441", "#5C4441", "#505050", "#505050", "#515151", "#515151", "#525251", "#525251", "#535352", "#535352", "#545453", "#545453", "#555554", "#555554", "#565655", "#565655", "#575656", "#575656", "#585757", "#585757", "#595858", "#595858", "#5A5959", "#5A5959", "#5B5A5A", "#5B5A5A", "#5C5B5B", "#5C5B5B", "#5D5C5C", "#5D5C5C", "#5E5D5D", "#5E5D5D", "#5E5E5E", "#5E5E5E", "#5F5F5E", "#5F5F5E", "#60605F", "#60605F", "#616160", "#616160", "#626261", "#626261", "#636362", "#636362", "#646463", "#646463", "#656564", "#656564", "#666665", "#666665", "#676666", "#676666", "#686767", "#686767", "#696868", "#696868", "#6A6969", "#6A6969", "#6B6A6A", "#6B6A6A", "#6C6B6B", "#6C6B6B", "#6D6C6C", "#6D6C6C", "#6E6D6D", "#6E6D6D", "#6F6E6E", "#6F6E6E", "#706F6F", "#706F6F", "#717070", "#717070", "#727170", "#727170", "#727271", "#727271", "#737372", "#737372", "#747473", "#747473", "#757574", "#757574", "#767675", "#767675", "#777776", "#777776", "#787877", "#787877", "#797978", "#797978", "#7A7A79", "#7A7A79", "#7B7B7A", "#7B7B7A", "#7C7C7B", "#7C7C7B", "#7D7D7C", "#7D7D7C", "#7E7E7D", "#7E7E7D", "#7F7F7E", "#7F7F7E", "#80807F", "#80807F", "#818180", "#818180", "#828281", "#828281", "#838382", "#838382", "#848483", "#848483", "#858584", "#858584", "#868685", "#868685", "#878786", "#878786", "#888887", "#888887", "#898988", "#898988", "#8A8A89", "#8A8A89", "#8B8B8A", "#8B8B8A", "#8C8C8B", "#8C8C8B", "#8D8D8C", "#8D8D8C", "#8E8E8D", "#8E8E8D", "#8F8F8E", "#8F8F8E", "#90908F", "#90908F", "#929190", "#929190", "#939291", "#939291", "#949392", "#949392", "#959493", "#959493", "#969595", "#969595", "#979696", "#979696", "#989797", "#989797", "#999898", "#999898", "#9A9999", "#9A9999", "#9B9B9A", "#9B9B9A", "#9C9C9B", "#9C9C9B", "#9D9D9C", "#9D9D9C", "#9E9E9D", "#9E9E9D", "#9F9F9E", "#9F9F9E", "#A0A09F", "#A0A09F", "#A1A1A0", "#A1A1A0", "#A2A2A1", "#A2A2A1", "#A4A3A2", "#A4A3A2", "#A5A4A3", "#A5A4A3", "#A6A5A4", "#A6A5A4", "#A7A6A6", "#A7A6A6", "#A8A7A7", "#A8A7A7", "#A9A9A8", "#A9A9A8", "#AAAAA9", "#AAAAA9", "#ABABAA", "#ABABAA", "#ACACAB", "#ACACAB", "#ADADAC", "#ADADAC", "#AEAEAD", "#AEAEAD", "#B0AFAE", "#B0AFAE", "#B1B0AF", "#B1B0AF", "#B2B1B1", "#B2B1B1", "#B3B3B2", "#B3B3B2", "#B4B4B3", "#B4B4B3", "#B5B5B4", "#B5B5B4", "#B6B6B5", "#B6B6B5", "#B8B7B6", "#B8B7B6", "#B9B8B7", "#B9B8B7", "#BAB9B8", "#BAB9B8", "#BBBBBA", "#BBBBBA", "#BCBCBB", "#BCBCBB", "#BDBDBC", "#BDBDBC", "#BEBEBD", "#BEBEBD", "#C0BFBE", "#C0BFBE", "#C1C0BF", "#C1C0BF", "#C2C2C1", "#C2C2C1", "#C3C3C2", "#C3C3C2", "#C4C4C3", "#C4C4C3", "#C5C5C4", "#C5C5C4", "#C7C6C5", "#C7C6C5", "#C8C8C6", "#C8C8C6", "#C9C9C8", "#C9C9C8", "#CACAC9", "#CACAC9", "#CBCBCA", "#CBCBCA", "#CDCCCB", "#CDCCCB", "#CECECC", "#CECECC", "#CFCFCE", "#CFCFCE", "#D0D0CF", "#D0D0CF", "#D2D1D0", "#D2D1D0", "#D3D2D1", "#D3D2D1", "#D4D4D3", "#D4D4D3", "#D5D5D4", "#D5D5D4", "#D6D6D5", "#D6D6D5", "#D8D7D6", "#D8D7D6", "#D9D9D8", "#D9D9D8", "#DADAD9", "#DADAD9", "#DBDBDA", "#DBDBDA", "#DDDCDB", "#DDDCDB", "#DEDEDD", "#DEDEDD", "#DFDFDE", "#DFDFDE", "#E1E0DF", "#E1E0DF", "#E2E2E0", "#E2E2E0", "#E3E3E2", "#E3E3E2", "#E4E4E3", "#E4E4E3", "#E6E5E4", "#E6E5E4", "#E7E7E6", "#E7E7E6", "#E8E8E7", "#E8E8E7", "#EAE9E8", "#EAE9E8", "#EBEBE9", "#EBEBE9", "#ECECEB", "#ECECEB", "#EEEDEC", "#EEEDEC", "#EFEFED", "#EFEFED", "#F0F0EF", "#F0F0EF", "#F2F1F0", "#F2F1F0", "#F3F3F1", "#F3F3F1", "#F4F4F3", "#F4F4F3", "#F6F7D8", "#F6F7D8", "#F7FE68", "#F7FE68", "#F5FD65", "#F5FD65", "#F4FC62", "#F4FC62", "#F2FA5F", "#F2FA5F", "#F0F95B", "#F0F95B", "#EFF858", "#EFF858", "#EEF755", "#EEF755", "#ECF551", "#ECF551", "#EBF44D", "#EBF44D", "#EBF249", "#EBF249", "#EAF145", "#EAF145", "#EAEF42", "#EAEF42", "#EAED3F", "#EAED3F", "#EAEC3D", "#EAEC3D", "#EAEA3B", "#EAEA3B", "#EAE839", "#EAE839", "#E9E638", "#E9E638", "#E9E536", "#E9E536", "#E9E335", "#E9E335", "#E9E133", "#E9E133", "#E9DF32", "#E9DF32", "#E8DE31", "#E8DE31", "#E8DC30", "#E8DC30", "#E8DA2E", "#E8DA2E", "#E7D92D", "#E7D92D", "#E7D72C", "#E7D72C", "#E7D52B", "#E7D52B", "#E7D42A", "#E7D42A", "#E6D22A", "#E6D22A", "#E6D029", "#E6D029", "#E5CF28", "#E5CF28", "#E5CD27", "#E5CD27", "#E5CB26", "#E5CB26", "#E4CA25", "#E4CA25", "#E4C825", "#E4C825", "#E3C724", "#E3C724", "#E3C523", "#E3C523", "#E3C322", "#E3C322", "#E2C222", "#E2C222", "#E2C021", "#E2C021", "#E1BF20", "#E1BF20", "#E1BD1F", "#E1BD1F", "#E0BB1F", "#E0BB1F", "#E0BA1E", "#E0BA1E", "#DFB81D", "#DFB81D", "#DFB71D", "#DFB71D", "#DFB51C", "#DFB51C", "#DEB41B", "#DEB41B", "#DEB21B", "#DEB21B", "#DDB01A", "#DDB01A", "#DDAF19", "#DDAF19"], "cmocean_phase": ["#A8780D", "#A8780D", "#A9770F", "#A9770F", "#AB7611", "#AB7611", "#AC7513", "#AC7513", "#AE7414", "#AE7414", "#AF7316", "#AF7316", "#B17218", "#B17218", "#B27119", "#B27119", "#B3701B", "#B3701B", "#B56F1D", "#B56F1D", "#B66E1E", "#B66E1E", "#B76D20", "#B76D20", "#B96C22", "#B96C22", "#BA6B23", "#BA6B23", "#BB6A25", "#BB6A25", "#BD6926", "#BD6926", "#BE6828", "#BE6828", "#BF672A", "#BF672A", "#C0662B", "#C0662B", "#C1652D", "#C1652D", "#C2642E", "#C2642E", "#C46230", "#C46230", "#C56132", "#C56132", "#C66033", "#C66033", "#C75F35", "#C75F35", "#C85E37", "#C85E37", "#C95D38", "#C95D38", "#CA5C3A", "#CA5C3A", "#CB5A3C", "#CB5A3C", "#CC593E", "#CC593E", "#CD583F", "#CD583F", "#CE5741", "#CE5741", "#CF5643", "#CF5643", "#D05445", "#D05445", "#D05347", "#D05347", "#D15249", "#D15249", "#D2514B", "#D2514B", "#D34F4D", "#D34F4D", "#D44E4F", "#D44E4F", "#D54D51", "#D54D51", "#D54B53", "#D54B53", "#D64A55", "#D64A55", "#D74957", "#D74957", "#D8475A", "#D8475A", "#D8465C", "#D8465C", "#D9455E", "#D9455E", "#D94361", "#D94361", "#DA4263", "#DA4263", "#DB4066", "#DB4066", "#DB3F68", "#DB3F68", "#DC3D6B", "#DC3D6B", "#DC3C6D", "#DC3C6D", "#DD3A70", "#DD3A70", "#DD3973", "#DD3973", "#DD3876", "#DD3876", "#DE3678", "#DE3678", "#DE357B", "#DE357B", "#DE337E", "#DE337E", "#DE3281", "#DE3281", "#DF3184", "#DF3184", "#DF2F87", "#DF2F87", "#DF2E8A", "#DF2E8A", "#DF2D8D", "#DF2D8D", "#DF2B90", "#DF2B90", "#DF2A93", "#DF2A93", "#DE2997", "#DE2997", "#DE289A", "#DE289A", "#DE289D", "#DE289D", "#DE27A0", "#DE27A0", "#DD26A3", "#DD26A3", "#DD26A6", "#DD26A6", "#DC25A9", "#DC25A9", "#DC25AD", "#DC25AD", "#DB25B0", "#DB25B0", "#DA25B3", "#DA25B3", "#DA26B6", "#DA26B6", "#D926B9", "#D926B9", "#D827BC", "#D827BC", "#D727BE", "#D727BE", "#D628C1", "#D628C1", "#D529C4", "#D529C4", "#D42AC7", "#D42AC7", "#D32BC9", "#D32BC9", "#D22DCC", "#D22DCC", "#D12ECE", "#D12ECE", "#D02FD0", "#D02FD0", "#CF31D3", "#CF31D3", "#CD32D5", "#CD32D5", "#CC34D7", "#CC34D7", "#CB35D9", "#CB35D9", "#C937DB", "#C937DB", "#C839DD", "#C839DD", "#C63ADF", "#C63ADF", "#C53CE1", "#C53CE1", "#C33EE2", "#C33EE2", "#C23FE4", "#C23FE4", "#C041E5", "#C041E5", "#BE43E7", "#BE43E7", "#BD45E8", "#BD45E8", "#BB46E9", "#BB46E9", "#B948EB", "#B948EB", "#B84AEC", "#B84AEC", "#B64BED", "#B64BED", "#B44DEE", "#B44DEE", "#B24FEF", "#B24FEF", "#B050EF", "#B050EF", "#AE52F0", "#AE52F0", "#AC54F1", "#AC54F1", "#AA55F1", "#AA55F1", "#A957F2", "#A957F2", "#A759F3", "#A759F3", "#A45AF3", "#A45AF3", "#A25CF3", "#A25CF3", "#A05DF4", "#A05DF4", "#9E5FF4", "#9E5FF4", "#9C60F4", "#9C60F4", "#9A62F4", "#9A62F4", "#9863F4", "#9863F4", "#9565F4", "#9565F4", "#9366F4", "#9366F4", "#9168F4", "#9168F4", "#8F69F4", "#8F69F4", "#8C6BF3", "#8C6BF3", "#8A6CF3", "#8A6CF3", "#876DF3", "#876DF3", "#856FF2", "#856FF2", "#8270F1", "#8270F1", "#8071F1", "#8071F1", "#7D73F0", "#7D73F0", "#7B74EF", "#7B74EF", "#7875EF", "#7875EF", "#7677EE", "#7677EE", "#7378ED", "#7378ED", "#7079EC", "#7079EC", "#6E7AEB", "#6E7AEB", "#6B7BE9", "#6B7BE9", "#687CE8", "#687CE8", "#667EE7", "#667EE7", "#637FE6", "#637FE6", "#6080E4", "#6080E4", "#5D81E3", "#5D81E3", "#5A82E1", "#5A82E1", "#5883DF", "#5883DF", "#5584DE", "#5584DE", "#5285DC", "#5285DC", "#4F86DA", "#4F86DA", "#4D87D8", "#4D87D8", "#4A87D7", "#4A87D7", "#4788D5", "#4788D5", "#4589D3", "#4589D3", "#428AD1", "#428AD1", "#408ACF", "#408ACF", "#3D8BCD", "#3D8BCD", "#3B8CCB", "#3B8CCB", "#388CC9", "#388CC9", "#368DC7", "#368DC7", "#348EC4", "#348EC4", "#328EC2", "#328EC2", "#308FC0", "#308FC0", "#2E8FBE", "#2E8FBE", "#2C90BC", "#2C90BC", "#2A90BA", "#2A90BA", "#2891B8", "#2891B8", "#2791B6", "#2791B6", "#2591B4", "#2591B4", "#2492B2", "#2492B2", "#2392B0", "#2392B0", "#2192AE", "#2192AE", "#2093AC", "#2093AC", "#1F93AA", "#1F93AA", "#1E93A8", "#1E93A8", "#1D94A6", "#1D94A6", "#1C94A4", "#1C94A4", "#1B94A2", "#1B94A2", "#1A94A0", "#1A94A0", "#19959E", "#19959E", "#19959C", "#19959C", "#18959A", "#18959A", "#179598", "#179598", "#169696", "#169696", "#159694", "#159694", "#149692", "#149692", "#149690", "#149690", "#13978E", "#13978E", "#12978C", "#12978C", "#11978A", "#11978A", "#109788", "#109788", "#0F9786", "#0F9786", "#0E9884", "#0E9884", "#0D9882", "#0D9882", "#0D9880", "#0D9880", "#0C987E", "#0C987E", "#0C987C", "#0C987C", "#0B9979", "#0B9979", "#0B9977", "#0B9977", "#0B9975", "#0B9975", "#0C9973", "#0C9973", "#0D9970", "#0D9970", "#0E996E", "#0E996E", "#0F9A6B", "#0F9A6B", "#119A69", "#119A69", "#139A66", "#139A66", "#159A63", "#159A63", "#179A61", "#179A61", "#199A5E", "#199A5E", "#1C9A5B", "#1C9A5B", "#1F9A58", "#1F9A58", "#219A55", "#219A55", "#249A52", "#249A52", "#279A4F", "#279A4F", "#2B9A4C", "#2B9A4C", "#2E9A49", "#2E9A49", "#319946", "#319946", "#359943", "#359943", "#389940", "#389940", "#3C993C", "#3C993C", "#409839", "#409839", "#439836", "#439836", "#479732", "#479732", "#4B972F", "#4B972F", "#4F962C", "#4F962C", "#539629", "#539629", "#569526", "#569526", "#5A9423", "#5A9423", "#5E9420", "#5E9420", "#61931E", "#61931E", "#65921B", "#65921B", "#689119", "#689119", "#6B9017", "#6B9017", "#6F9016", "#6F9016", "#728F14", "#728F14", "#748E13", "#748E13", "#778D12", "#778D12", "#7A8C11", "#7A8C11", "#7D8B10", "#7D8B10", "#7F8B0F", "#7F8B0F", "#828A0F", "#828A0F", "#84890E", "#84890E", "#86880E", "#86880E", "#88870E", "#88870E", "#8B860D", "#8B860D", "#8D850D", "#8D850D", "#8F840D", "#8F840D", "#91830D", "#91830D", "#93830D", "#93830D", "#95820D", "#95820D", "#97810D", "#97810D", "#99800D", "#99800D", "#9B7F0D", "#9B7F0D", "#9D7E0D", "#9D7E0D", "#9F7D0D", "#9F7D0D", "#A17C0D", "#A17C0D", "#A27B0D", "#A27B0D", "#A47A0D", "#A47A0D", "#A6790D", "#A6790D", "#A8780D", "#A8780D"], "cmocean_rain": ["#EEEDF3", "#EEEDF3", "#EEECF1", "#EEECF1", "#EDEBF0", "#EDEBF0", "#ECEAEE", "#ECEAEE", "#EBE9EC", "#EBE9EC", "#EBE8EB", "#EBE8EB", "#EAE7E9", "#EAE7E9", "#E9E6E8", "#E9E6E8", "#E8E5E6", "#E8E5E6", "#E8E4E5", "#E8E4E5", "#E7E3E3", "#E7E3E3", "#E6E2E2", "#E6E2E2", "#E5E1E0", "#E5E1E0", "#E4DFDF", "#E4DFDF", "#E4DEDD", "#E4DEDD", "#E3DDDC", "#E3DDDC", "#E3DCDA", "#E3DCDA", "#E2DBD8", "#E2DBD8", "#E2DAD6", "#E2DAD6", "#E1D9D4", "#E1D9D4", "#E0D8D3", "#E0D8D3", "#E0D7D1", "#E0D7D1", "#DFD6CF", "#DFD6CF", "#DFD5CD", "#DFD5CD", "#DED4CB", "#DED4CB", "#DED3C9", "#DED3C9", "#DDD1C7", "#DDD1C7", "#DDD0C5", "#DDD0C5", "#DCCFC3", "#DCCFC3", "#DCCEC1", "#DCCEC1", "#DBCDBF", "#DBCDBF", "#DBCCBE", "#DBCCBE", "#DBCBBC", "#DBCBBC", "#DACABA", "#DACABA", "#DAC9B8", "#DAC9B8", "#D9C8B6", "#D9C8B6", "#D8C7B4", "#D8C7B4", "#D8C6B2", "#D8C6B2", "#D7C5B0", "#D7C5B0", "#D7C4AE", "#D7C4AE", "#D6C3AC", "#D6C3AC", "#D5C2AA", "#D5C2AA", "#D5C1A8", "#D5C1A8", "#D4C0A6", "#D4C0A6", "#D3BFA4", "#D3BFA4", "#D2BFA2", "#D2BFA2", "#D1BEA0", "#D1BEA0", "#D0BD9E", "#D0BD9E", "#CFBC9C", "#CFBC9C", "#CDBC9B", "#CDBC9B", "#CCBB99", "#CCBB99", "#CBBA98", "#CBBA98", "#C9BA96", "#C9BA96", "#C8B995", "#C8B995", "#C6B994", "#C6B994", "#C4B892", "#C4B892", "#C3B791", "#C3B791", "#C1B790", "#C1B790", "#C0B68F", "#C0B68F", "#BEB68E", "#BEB68E", "#BCB58D", "#BCB58D", "#BAB58D", "#BAB58D", "#B9B48C", "#B9B48C", "#B7B38B", "#B7B38B", "#B5B38A", "#B5B38A", "#B4B289", "#B4B289", "#B2B289", "#B2B289", "#B0B188", "#B0B188", "#AEB187", "#AEB187", "#ADB087", "#ADB087", "#ABB086", "#ABB086", "#A9AF85", "#A9AF85", "#A8AE85", "#A8AE85", "#A6AE84", "#A6AE84", "#A4AD84", "#A4AD84", "#A2AD83", "#A2AD83", "#A1AC82", "#A1AC82", "#9FAC82", "#9FAC82", "#9DAB81", "#9DAB81", "#9CAA81", "#9CAA81", "#9AAA80", "#9AAA80", "#98A980", "#98A980", "#96A97F", "#96A97F", "#95A87E", "#95A87E", "#93A87E", "#93A87E", "#91A77D", "#91A77D", "#90A77D", "#90A77D", "#8EA67C", "#8EA67C", "#8CA57C", "#8CA57C", "#8AA57B", "#8AA57B", "#89A47B", "#89A47B", "#87A47A", "#87A47A", "#85A37A", "#85A37A", "#83A379", "#83A379", "#82A278", "#82A278", "#80A178", "#80A178", "#7EA177", "#7EA177", "#7CA077", "#7CA077", "#7AA076", "#7AA076", "#799F76", "#799F76", "#779F75", "#779F75", "#759E75", "#759E75", "#739D75", "#739D75", "#719D74", "#719D74", "#6F9C74", "#6F9C74", "#6D9C73", "#6D9C73", "#6B9B73", "#6B9B73", "#699B72", "#699B72", "#679A72", "#679A72", "#659A72", "#659A72", "#649971", "#649971", "#619871", "#619871", "#5F9871", "#5F9871", "#5D9770", "#5D9770", "#5B9770", "#5B9770", "#599670", "#599670", "#57956F", "#57956F", "#55956F", "#55956F", "#53946F", "#53946F", "#51946F", "#51946F", "#4F936E", "#4F936E", "#4C936E", "#4C936E", "#4A926E", "#4A926E", "#48916E", "#48916E", "#46916E", "#46916E", "#43906E", "#43906E", "#418F6E", "#418F6E", "#3F8F6E", "#3F8F6E", "#3D8E6E", "#3D8E6E", "#3A8D6D", "#3A8D6D", "#388D6D", "#388D6D", "#368C6D", "#368C6D", "#348B6D", "#348B6D", "#318B6E", "#318B6E", "#2F8A6E", "#2F8A6E", "#2D896E", "#2D896E", "#2B896E", "#2B896E", "#29886E", "#29886E", "#26876E", "#26876E", "#24866E", "#24866E", "#22866E", "#22866E", "#20856E", "#20856E", "#1E846E", "#1E846E", "#1C836E", "#1C836E", "#1B826E", "#1B826E", "#19816E", "#19816E", "#17816E", "#17816E", "#15806E", "#15806E", "#147F6E", "#147F6E", "#127E6E", "#127E6E", "#117D6E", "#117D6E", "#0F7C6E", "#0F7C6E", "#0E7C6E", "#0E7C6E", "#0C7B6E", "#0C7B6E", "#0B7A6E", "#0B7A6E", "#0A796E", "#0A796E", "#09786E", "#09786E", "#08776E", "#08776E", "#07766E", "#07766E", "#06756E", "#06756E", "#06746E", "#06746E", "#05746E", "#05746E", "#05736E", "#05736E", "#04726E", "#04726E", "#04716E", "#04716E", "#04706D", "#04706D", "#036F6D", "#036F6D", "#036E6D", "#036E6D", "#036D6D", "#036D6D", "#036C6D", "#036C6D", "#046B6D", "#046B6D", "#046B6D", "#046A6C", "#046A6C", "#04696C", "#04696C", "#05686C", "#05686C", "#05676C", "#05676C", "#06666C", "#06666C", "#07656B", "#07656B", "#07646B", "#07646B", "#08636B", "#08636B", "#09626B", "#09626B", "#0A616A", "#0A616A", "#0B606A", "#0B606A", "#0C5F6A", "#0C5F6A", "#0D5F69", "#0D5F69", "#0E5E69", "#0E5E69", "#0F5D69", "#0F5D69", "#105C68", "#105C68", "#115B68", "#115B68", "#125A67", "#125A67", "#135967", "#135967", "#145867", "#145867", "#155766", "#155766", "#165666", "#165666", "#165565", "#165565", "#175465", "#175465", "#185364", "#185364", "#195264", "#195264", "#1A5163", "#1A5163", "#1A5063", "#1A5063", "#1B4F62", "#1B4F62", "#1C4E61", "#1C4E61", "#1C4D61", "#1C4D61", "#1D4C60", "#1D4C60", "#1E4B5F", "#1E4B5F", "#1E4A5F", "#1E4A5F", "#1F495E", "#1F495E", "#1F485D", "#1F485D", "#20485D", "#20485D", "#21475C", "#21475C", "#21465B", "#21465B", "#21455A", "#21455A", "#22445A", "#22445A", "#224359", "#224359", "#234258", "#234258", "#234157", "#234157", "#234056", "#234056", "#243F56", "#243F56", "#243E55", "#243E55", "#243D54", "#243D54", "#243C53", "#243C53", "#243B52", "#243B52", "#253A51", "#253A51", "#253951", "#253951", "#253850", "#253850", "#25374F", "#25374F", "#25374E", "#25374E", "#25364D", "#25364D", "#25354C", "#25354C", "#25344C", "#25344C", "#25334B", "#25334B", "#25324A", "#25324A", "#253149", "#253149", "#253048", "#253048", "#252F48", "#252F48", "#252E47", "#252E47", "#252D46", "#252D46", "#252C45", "#252C45", "#252B45", "#252B45", "#252A44", "#252A44", "#242943", "#242943", "#242842", "#242842", "#242742", "#242742", "#242741", "#242741", "#242640", "#242640", "#24253F", "#24253F", "#23243F", "#23243F", "#23233E", "#23233E", "#23223D", "#23223D", "#23213D", "#23213D", "#23203C", "#23203C", "#221F3B", "#221F3B", "#221E3A", "#221E3A", "#221D3A", "#221D3A", "#221C39", "#221C39", "#221B38", "#221B38"], "cmocean_solar": ["#331418", "#331418", "#351418", "#351418", "#361519", "#361519", "#371519", "#371519", "#38151A", "#38151A", "#3A161A", "#3A161A", "#3B161B", "#3B161B", "#3C171B", "#3C171B", "#3D171C", "#3D171C", "#3E181C", "#3E181C", "#40181D", "#40181D", "#41181D", "#41181D", "#42191D", "#42191D", "#43191E", "#43191E", "#451A1E", "#451A1E", "#461A1F", "#461A1F", "#471A1F", "#471A1F", "#481B1F", "#481B1F", "#4A1B20", "#4A1B20", "#4B1B20", "#4B1B20", "#4C1C20", "#4C1C20", "#4D1C21", "#4D1C21", "#4F1C21", "#4F1C21", "#501D21", "#501D21", "#511D22", "#511D22", "#521E22", "#521E22", "#541E22", "#541E22", "#551E22", "#551E22", "#561F23", "#561F23", "#571F23", "#571F23", "#591F23", "#591F23", "#5A2023", "#5A2023", "#5B2023", "#5B2023", "#5C2024", "#5C2024", "#5E2124", "#5E2124", "#5F2124", "#5F2124", "#602124", "#602124", "#612224", "#612224", "#632224", "#632224", "#642224", "#642224", "#652324", "#652324", "#662325", "#662325", "#682325", "#682325", "#692425", "#692425", "#6A2425", "#6A2425", "#6B2425", "#6B2425", "#6D2525", "#6D2525", "#6E2525", "#6E2525", "#6F2525", "#6F2525", "#702625", "#702625", "#722625", "#722625", "#732724", "#732724", "#742724", "#742724", "#752724", "#752724", "#772824", "#772824", "#782824", "#782824", "#792924", "#792924", "#7A2924", "#7A2924", "#7B2A24", "#7B2A24", "#7C2A23", "#7C2A23", "#7E2B23", "#7E2B23", "#7F2B23", "#7F2B23", "#802C23", "#802C23", "#812C22", "#812C22", "#822D22", "#822D22", "#832D22", "#832D22", "#842E22", "#842E22", "#852E21", "#852E21", "#872F21", "#872F21", "#883021", "#883021", "#893021", "#893021", "#8A3120", "#8A3120", "#8B3120", "#8B3120", "#8C3220", "#8C3220", "#8D331F", "#8D331F", "#8E341F", "#8E341F", "#8F341F", "#8F341F", "#90351E", "#90351E", "#91361E", "#91361E", "#92361E", "#92361E", "#93371D", "#93371D", "#93381D", "#93381D", "#94391D", "#94391D", "#953A1D", "#953A1D", "#963A1C", "#963A1C", "#973B1C", "#973B1C", "#983C1C", "#983C1C", "#993D1B", "#993D1B", "#9A3E1B", "#9A3E1B", "#9A3F1B", "#9A3F1B", "#9B401A", "#9B401A", "#9C401A", "#9C401A", "#9D411A", "#9D411A", "#9E421A", "#9E421A", "#9F4319", "#9F4319", "#9F4419", "#9F4419", "#A04519", "#A04519", "#A14619", "#A14619", "#A24718", "#A24718", "#A34818", "#A34818", "#A34918", "#A34918", "#A44A18", "#A44A18", "#A54A17", "#A54A17", "#A64B17", "#A64B17", "#A64C17", "#A64C17", "#A74D17", "#A74D17", "#A84E16", "#A84E16", "#A84F16", "#A84F16", "#A95016", "#A95016", "#AA5116", "#AA5116", "#AB5216", "#AB5216", "#AB5315", "#AB5315", "#AC5415", "#AC5415", "#AD5515", "#AD5515", "#AD5615", "#AD5615", "#AE5715", "#AE5715", "#AF5814", "#AF5814", "#AF5914", "#AF5914", "#B05A14", "#B05A14", "#B15B14", "#B15B14", "#B15C14", "#B15C14", "#B25D14", "#B25D14", "#B25E14", "#B25E14", "#B35F14", "#B35F14", "#B46013", "#B46013", "#B46113", "#B46113", "#B56213", "#B56213", "#B66313", "#B66313", "#B66413", "#B66413", "#B76513", "#B76513", "#B76613", "#B76613", "#B86813", "#B86813", "#B86913", "#B86913", "#B96A13", "#B96A13", "#BA6B13", "#BA6B13", "#BA6C13", "#BA6C13", "#BB6D13", "#BB6D13", "#BB6E13", "#BB6E13", "#BC6F13", "#BC6F13", "#BC7013", "#BC7013", "#BD7113", "#BD7113", "#BE7213", "#BE7213", "#BE7313", "#BE7313", "#BF7413", "#BF7413", "#BF7513", "#BF7513", "#C07613", "#C07613", "#C07714", "#C07714", "#C17914", "#C17914", "#C17A14", "#C17A14", "#C27B14", "#C27B14", "#C27C14", "#C27C14", "#C37D14", "#C37D14", "#C37E15", "#C37E15", "#C47F15", "#C47F15", "#C48015", "#C48015", "#C58115", "#C58115", "#C58215", "#C58215", "#C68416", "#C68416", "#C68516", "#C68516", "#C78616", "#C78616", "#C78716", "#C78716", "#C78817", "#C78817", "#C88917", "#C88917", "#C88A17", "#C88A17", "#C98B18", "#C98B18", "#C98C18", "#C98C18", "#CA8E18", "#CA8E18", "#CA8F19", "#CA8F19", "#CB9019", "#CB9019", "#CB9119", "#CB9119", "#CB921A", "#CB921A", "#CC931A", "#CC931A", "#CC941A", "#CC941A", "#CD961B", "#CD961B", "#CD971B", "#CD971B", "#CE981C", "#CE981C", "#CE991C", "#CE991C", "#CE9A1C", "#CE9A1C", "#CF9B1D", "#CF9B1D", "#CF9C1D", "#CF9C1D", "#D09E1E", "#D09E1E", "#D09F1E", "#D09F1E", "#D0A01F", "#D0A01F", "#D1A11F", "#D1A11F", "#D1A220", "#D1A220", "#D1A420", "#D1A420", "#D2A520", "#D2A520", "#D2A621", "#D2A621", "#D3A721", "#D3A721", "#D3A822", "#D3A822", "#D3A922", "#D3A922", "#D4AB23", "#D4AB23", "#D4AC24", "#D4AC24", "#D4AD24", "#D4AD24", "#D5AE25", "#D5AE25", "#D5AF25", "#D5AF25", "#D5B126", "#D5B126", "#D6B226", "#D6B226", "#D6B327", "#D6B327", "#D6B427", "#D6B427", "#D7B528", "#D7B528", "#D7B728", "#D7B728", "#D7B829", "#D7B829", "#D7B92A", "#D7B92A", "#D8BA2A", "#D8BA2A", "#D8BC2B", "#D8BC2B", "#D8BD2B", "#D8BD2B", "#D9BE2C", "#D9BE2C", "#D9BF2C", "#D9BF2C", "#D9C12D", "#D9C12D", "#D9C22E", "#D9C22E", "#DAC32E", "#DAC32E", "#DAC42F", "#DAC42F", "#DAC62F", "#DAC62F", "#DAC730", "#DAC730", "#DBC831", "#DBC831", "#DBC931", "#DBC931", "#DBCB32", "#DBCB32", "#DBCC32", "#DBCC32", "#DCCD33", "#DCCD33", "#DCCE34", "#DCCE34", "#DCD034", "#DCD034", "#DCD135", "#DCD135", "#DDD236", "#DDD236", "#DDD436", "#DDD436", "#DDD537", "#DDD537", "#DDD637", "#DDD637", "#DDD738", "#DDD738", "#DED939", "#DED939", "#DEDA39", "#DEDA39", "#DEDB3A", "#DEDB3A", "#DEDD3B", "#DEDD3B", "#DEDE3B", "#DEDE3B", "#DEDF3C", "#DEDF3C", "#DFE13D", "#DFE13D", "#DFE23D", "#DFE23D", "#DFE33E", "#DFE33E", "#DFE53F", "#DFE53F", "#DFE63F", "#DFE63F", "#DFE740", "#DFE740", "#DFE941", "#DFE941", "#E0EA41", "#E0EA41", "#E0EB42", "#E0EB42", "#E0ED43", "#E0ED43", "#E0EE43", "#E0EE43", "#E0F044", "#E0F044", "#E0F145", "#E0F145", "#E0F245", "#E0F245", "#E0F446", "#E0F446", "#E0F547", "#E0F547", "#E0F647", "#E0F647", "#E0F848", "#E0F848", "#E0F949", "#E0F949", "#E0FB49", "#E0FB49", "#E1FC4A", "#E1FC4A", "#E1FD4B", "#E1FD4B"], "cmocean_speed": ["#FFFDCD", "#FFFDCD", "#FEFCCB", "#FEFCCB", "#FEFAC9", "#FEFAC9", "#FDF9C7", "#FDF9C7", "#FCF8C5", "#FCF8C5", "#FCF7C2", "#FCF7C2", "#FBF6C0", "#FBF6C0", "#FAF4BE", "#FAF4BE", "#F9F3BC", "#F9F3BC", "#F9F2BA", "#F9F2BA", "#F8F1B8", "#F8F1B8", "#F7F0B6", "#F7F0B6", "#F7EEB4", "#F7EEB4", "#F6EDB1", "#F6EDB1", "#F6ECAF", "#F6ECAF", "#F5EBAD", "#F5EBAD", "#F4EAAB", "#F4EAAB", "#F3E9A9", "#F3E9A9", "#F3E7A7", "#F3E7A7", "#F2E6A5", "#F2E6A5", "#F1E5A2", "#F1E5A2", "#F1E4A0", "#F1E4A0", "#F0E39E", "#F0E39E", "#EFE29C", "#EFE29C", "#EFE19A", "#EFE19A", "#EEDF98", "#EEDF98", "#EDDE96", "#EDDE96", "#EDDD93", "#EDDD93", "#ECDC91", "#ECDC91", "#EBDB8F", "#EBDB8F", "#EADA8D", "#EADA8D", "#EAD98B", "#EAD98B", "#E9D889", "#E9D889", "#E8D786", "#E8D786", "#E7D684", "#E7D684", "#E7D582", "#E7D582", "#E6D480", "#E6D480", "#E5D37E", "#E5D37E", "#E4D27B", "#E4D27B", "#E3D079", "#E3D079", "#E3CF77", "#E3CF77", "#E2CE75", "#E2CE75", "#E1CD73", "#E1CD73", "#E0CD71", "#E0CD71", "#DFCC6E", "#DFCC6E", "#DECB6C", "#DECB6C", "#DDCA6A", "#DDCA6A", "#DCC968", "#DCC968", "#DBC866", "#DBC866", "#DAC764", "#DAC764", "#D9C661", "#D9C661", "#D8C55F", "#D8C55F", "#D7C45D", "#D7C45D", "#D6C35B", "#D6C35B", "#D5C259", "#D5C259", "#D4C157", "#D4C157", "#D3C155", "#D3C155", "#D2C053", "#D2C053", "#D1BF51", "#D1BF51", "#D0BE4F", "#D0BE4F", "#CEBD4C", "#CEBD4C", "#CDBD4A", "#CDBD4A", "#CCBC48", "#CCBC48", "#CBBB46", "#CBBB46", "#C9BA45", "#C9BA45", "#C8B943", "#C8B943", "#C7B941", "#C7B941", "#C5B83F", "#C5B83F", "#C4B73D", "#C4B73D", "#C3B73B", "#C3B73B", "#C1B639", "#C1B639", "#C0B537", "#C0B537", "#BEB436", "#BEB436", "#BDB434", "#BDB434", "#BBB332", "#BBB332", "#BAB230", "#BAB230", "#B8B22F", "#B8B22F", "#B7B12D", "#B7B12D", "#B5B02B", "#B5B02B", "#B4B02A", "#B4B02A", "#B2AF28", "#B2AF28", "#B1AE27", "#B1AE27", "#AFAE25", "#AFAE25", "#ADAD23", "#ADAD23", "#ACAD22", "#ACAD22", "#AAAC20", "#AAAC20", "#A9AB1F", "#A9AB1F", "#A7AB1E", "#A7AB1E", "#A5AA1C", "#A5AA1C", "#A4A91B", "#A4A91B", "#A2A919", "#A2A919", "#A0A818", "#A0A818", "#9FA817", "#9FA817", "#9DA715", "#9DA715", "#9BA614", "#9BA614", "#9AA613", "#9AA613", "#98A512", "#98A512", "#96A510", "#96A510", "#95A40F", "#95A40F", "#93A30E", "#93A30E", "#91A30D", "#91A30D", "#8FA20C", "#8FA20C", "#8EA20B", "#8EA20B", "#8CA10A", "#8CA10A", "#8AA009", "#8AA009", "#88A008", "#88A008", "#879F08", "#879F08", "#859F07", "#859F07", "#839E07", "#839E07", "#819D06", "#819D06", "#809D06", "#809D06", "#7E9C06", "#7E9C06", "#7C9C06", "#7C9C06", "#7A9B06", "#7A9B06", "#799A06", "#799A06", "#779A06", "#779A06", "#759906", "#759906", "#739906", "#739906", "#719806", "#719806", "#709707", "#709707", "#6E9707", "#6E9707", "#6C9607", "#6C9607", "#6A9508", "#6A9508", "#689509", "#689509", "#669409", "#669409", "#65940A", "#65940A", "#63930B", "#63930B", "#61920B", "#61920B", "#5F920C", "#5F920C", "#5D910D", "#5D910D", "#5C900E", "#5C900E", "#5A900F", "#5A900F", "#588F0F", "#588F0F", "#568E10", "#568E10", "#548E11", "#548E11", "#528D12", "#528D12", "#518C12", "#518C12", "#4F8C13", "#4F8C13", "#4D8B14", "#4D8B14", "#4B8A15", "#4B8A15", "#498A16", "#498A16", "#488916", "#488916", "#468817", "#468817", "#448818", "#448818", "#428719", "#428719", "#408619", "#408619", "#3F851A", "#3F851A", "#3D851B", "#3D851B", "#3B841C", "#3B841C", "#39831C", "#39831C", "#38831D", "#38831D", "#36821E", "#36821E", "#34811E", "#34811E", "#32801F", "#32801F", "#317F20", "#317F20", "#2F7F20", "#2F7F20", "#2D7E21", "#2D7E21", "#2C7D21", "#2C7D21", "#2A7C22", "#2A7C22", "#287C23", "#287C23", "#277B23", "#277B23", "#257A24", "#257A24", "#247924", "#247924", "#227825", "#227825", "#217825", "#217825", "#1F7726", "#1F7726", "#1E7626", "#1E7626", "#1C7527", "#1C7527", "#1B7427", "#1B7427", "#1A7327", "#1A7327", "#187328", "#187328", "#177228", "#177228", "#167129", "#167129", "#157029", "#157029", "#136F29", "#136F29", "#126E2A", "#126E2A", "#116D2A", "#116D2A", "#106C2A", "#106C2A", "#0F6C2B", "#0F6C2B", "#0F6B2B", "#0F6B2B", "#0E6A2B", "#0E6A2B", "#0D692B", "#0D692B", "#0D682B", "#0D682B", "#0C672C", "#0C672C", "#0C662C", "#0C662C", "#0B652C", "#0B652C", "#0B642C", "#0B642C", "#0B632C", "#0B632C", "#0B632C", "#0B622D", "#0B622D", "#0B612D", "#0B612D", "#0B602D", "#0B602D", "#0B5F2D", "#0B5F2D", "#0B5E2D", "#0B5E2D", "#0C5D2D", "#0C5D2D", "#0C5C2D", "#0C5C2D", "#0C5B2D", "#0C5B2D", "#0D5A2D", "#0D5A2D", "#0D592D", "#0D592D", "#0E582D", "#0E582D", "#0E572D", "#0E572D", "#0F562C", "#0F562C", "#0F552C", "#0F552C", "#10542C", "#10542C", "#10542C", "#10532C", "#10532C", "#11522C", "#11522C", "#11512C", "#11512C", "#12502B", "#12502B", "#124F2B", "#124F2B", "#134E2B", "#134E2B", "#134D2B", "#134D2B", "#144C2A", "#144C2A", "#144B2A", "#144B2A", "#144A2A", "#144A2A", "#15492A", "#15492A", "#154829", "#154829", "#164729", "#164729", "#164629", "#164629", "#164528", "#164528", "#174428", "#174428", "#174327", "#174327", "#174227", "#174227", "#174127", "#174127", "#184026", "#184026", "#183F26", "#183F26", "#183F25", "#183F25", "#183E25", "#183E25", "#193D24", "#193D24", "#193C24", "#193C24", "#193B23", "#193B23", "#193A23", "#193A23", "#193922", "#193922", "#193822", "#193822", "#193721", "#193721", "#193621", "#193621", "#193520", "#193520", "#19341F", "#19341F", "#19331F", "#19331F", "#19321E", "#19321E", "#19311E", "#19311E", "#19301D", "#19301D", "#192F1C", "#192F1C", "#192E1C", "#192E1C", "#192D1B", "#192D1B", "#192C1A", "#192C1A", "#192C19", "#192C19", "#192B19", "#192B19", "#192A18", "#192A18", "#182917", "#182917", "#182817", "#182817", "#182716", "#182716", "#182615", "#182615", "#182514", "#182514", "#172413", "#172413", "#172313", "#172313"], "cmocean_tarn": ["#17230E", "#17230E", "#18250E", "#18250E", "#19270E", "#19270E", "#1B290F", "#1B290F", "#1C2A0F", "#1C2A0F", "#1D2C0F", "#1D2C0F", "#1F2E10", "#1F2E10", "#203010", "#203010", "#213110", "#213110", "#223310", "#223310", "#233510", "#233510", "#253710", "#253710", "#263810", "#263810", "#273A10", "#273A10", "#283C10", "#283C10", "#2A3D10", "#2A3D10", "#2B3F0F", "#2B3F0F", "#2C410F", "#2C410F", "#2E420F", "#2E420F", "#2F440E", "#2F440E", "#30460E", "#30460E", "#32470D", "#32470D", "#34490C", "#34490C", "#364A0C", "#364A0C", "#394B0C", "#394B0C", "#3C4D0D", "#3C4D0D", "#3F4E0E", "#3F4E0E", "#424F0F", "#424F0F", "#445010", "#445010", "#475111", "#475111", "#4A5312", "#4A5312", "#4D5413", "#4D5413", "#4F5514", "#4F5514", "#525615", "#525615", "#555716", "#555716", "#575817", "#575817", "#5A5918", "#5A5918", "#5D5B19", "#5D5B19", "#605C1A", "#605C1A", "#625D1A", "#625D1A", "#655E1B", "#655E1B", "#685F1C", "#685F1C", "#6B601D", "#6B601D", "#6D611E", "#6D611E", "#70621F", "#70621F", "#736320", "#736320", "#766421", "#766421", "#786621", "#786621", "#7B6722", "#7B6722", "#7E6823", "#7E6823", "#816924", "#816924", "#846A25", "#846A25", "#866B26", "#866B26", "#896C27", "#896C27", "#8C6D27", "#8C6D27", "#8F6E28", "#8F6E28", "#926F29", "#926F29", "#95702A", "#95702A", "#98712B", "#98712B", "#9B722C", "#9B722C", "#9E732D", "#9E732D", "#A0742E", "#A0742E", "#A3752F", "#A3752F", "#A67630", "#A67630", "#A97731", "#A97731", "#AC7832", "#AC7832", "#AF7933", "#AF7933", "#B27A35", "#B27A35", "#B57B36", "#B57B36", "#B87C37", "#B87C37", "#BB7D39", "#BB7D39", "#BE7E3A", "#BE7E3A", "#C17F3C", "#C17F3C", "#C4803E", "#C4803E", "#C68141", "#C68141", "#C98244", "#C98244", "#CB8448", "#CB8448", "#CC864C", "#CC864C", "#CD884F", "#CD884F", "#CE8A53", "#CE8A53", "#CF8C57", "#CF8C57", "#D08F5A", "#D08F5A", "#D1915D", "#D1915D", "#D29361", "#D29361", "#D29664", "#D29664", "#D39868", "#D39868", "#D49A6B", "#D49A6B", "#D59C6F", "#D59C6F", "#D69F72", "#D69F72", "#D7A175", "#D7A175", "#D8A379", "#D8A379", "#D9A67C", "#D9A67C", "#DAA880", "#DAA880", "#DBAA83", "#DBAA83", "#DBAD87", "#DBAD87", "#DCAF8A", "#DCAF8A", "#DDB18E", "#DDB18E", "#DEB391", "#DEB391", "#DFB695", "#DFB695", "#E0B898", "#E0B898", "#E1BA9C", "#E1BA9C", "#E2BD9F", "#E2BD9F", "#E3BFA3", "#E3BFA3", "#E4C1A6", "#E4C1A6", "#E5C4AA", "#E5C4AA", "#E6C6AD", "#E6C6AD", "#E7C8B1", "#E7C8B1", "#E8CBB4", "#E8CBB4", "#E9CDB8", "#E9CDB8", "#EAD0BB", "#EAD0BB", "#EBD2BF", "#EBD2BF", "#ECD4C2", "#ECD4C2", "#EDD7C6", "#EDD7C6", "#EFD9C9", "#EFD9C9", "#F0DBCD", "#F0DBCD", "#F1DED1", "#F1DED1", "#F2E0D4", "#F2E0D4", "#F3E3D8", "#F3E3D8", "#F4E5DB", "#F4E5DB", "#F6E8DF", "#F6E8DF", "#F7EAE2", "#F7EAE2", "#F8ECE5", "#F8ECE5", "#F9EFE9", "#F9EFE9", "#FAF1EC", "#FAF1EC", "#FBF3EF", "#FBF3EF", "#FCF5F2", "#FCF5F2", "#FCF6F4", "#FCF6F4", "#FCF7F6", "#FCF7F6", "#FCF7F6", "#FCF7F5", "#FCF7F5", "#FBF6F3", "#FBF6F3", "#FBF5F0", "#FBF5F0", "#F9F4ED", "#F9F4ED", "#F8F2EA", "#F8F2EA", "#F6F0E7", "#F6F0E7", "#F4EEE3", "#F4EEE3", "#F2ECE0", "#F2ECE0", "#F0EADC", "#F0EADC", "#EFE8D8", "#EFE8D8", "#EDE6D5", "#EDE6D5", "#EBE4D1", "#EBE4D1", "#E9E2CD", "#E9E2CD", "#E7DFCA", "#E7DFCA", "#E5DDC6", "#E5DDC6", "#E3DBC2", "#E3DBC2", "#E1D9BF", "#E1D9BF", "#DFD7BB", "#DFD7BB", "#DDD6B8", "#DDD6B8", "#DAD4B4", "#DAD4B4", "#D7D2B2", "#D7D2B2", "#D4D1AF", "#D4D1AF", "#D1CFAD", "#D1CFAD", "#CECEAB", "#CECEAB", "#CBCCAA", "#CBCCAA", "#C7CBA8", "#C7CBA8", "#C4C9A7", "#C4C9A7", "#C1C8A6", "#C1C8A6", "#BEC6A5", "#BEC6A5", "#BAC4A4", "#BAC4A4", "#B7C3A3", "#B7C3A3", "#B4C1A2", "#B4C1A2", "#B1C0A1", "#B1C0A1", "#AEBEA0", "#AEBEA0", "#ABBD9F", "#ABBD9F", "#A8BB9E", "#A8BB9E", "#A5B99D", "#A5B99D", "#A2B89C", "#A2B89C", "#9FB69B", "#9FB69B", "#9CB59A", "#9CB59A", "#99B399", "#99B399", "#97B298", "#97B298", "#94B097", "#94B097", "#91AE96", "#91AE96", "#8EAD95", "#8EAD95", "#8BAB94", "#8BAB94", "#88AA93", "#88AA93", "#85A892", "#85A892", "#82A792", "#82A792", "#7FA591", "#7FA591", "#7CA490", "#7CA490", "#79A28F", "#79A28F", "#76A18E", "#76A18E", "#739F8D", "#739F8D", "#709E8C", "#709E8C", "#6D9C8B", "#6D9C8B", "#6A9B8A", "#6A9B8A", "#679A89", "#679A89", "#649889", "#649889", "#619788", "#619788", "#5E9587", "#5E9587", "#5A9486", "#5A9486", "#579285", "#579285", "#549185", "#549185", "#518F84", "#518F84", "#4E8E83", "#4E8E83", "#4A8C83", "#4A8C83", "#478B82", "#478B82", "#448982", "#448982", "#418881", "#418881", "#3D8680", "#3D8680", "#3A8580", "#3A8580", "#37837F", "#37837F", "#34817F", "#34817F", "#31807E", "#31807E", "#2E7E7E", "#2E7E7E", "#2C7C7D", "#2C7C7D", "#2A7B7D", "#2A7B7D", "#27797C", "#27797C", "#25777C", "#25777C", "#24757B", "#24757B", "#22747A", "#22747A", "#21727A", "#21727A", "#207079", "#207079", "#206E78", "#206E78", "#1F6C77", "#1F6C77", "#1F6A76", "#1F6A76", "#1E6976", "#1E6976", "#1E6775", "#1E6775", "#1D6574", "#1D6574", "#1D6373", "#1D6373", "#1C6172", "#1C6172", "#1C5F71", "#1C5F71", "#1B5D70", "#1B5D70", "#1A5C6F", "#1A5C6F", "#1A5A6F", "#1A5A6F", "#19586E", "#19586E", "#18566D", "#18566D", "#18546C", "#18546C", "#17536B", "#17536B", "#16516B", "#16516B", "#154F6A", "#154F6A", "#144D69", "#144D69", "#134B68", "#134B68", "#124968", "#124968", "#114867", "#114867", "#104666", "#104666", "#104465", "#104465", "#0F4265", "#0F4265", "#0E4064", "#0E4064", "#0D3E63", "#0D3E63", "#0C3C63", "#0C3C63", "#0B3B62", "#0B3B62", "#0A3962", "#0A3962", "#093761", "#093761", "#093560", "#093560", "#093360", "#093360", "#09315F", "#09315F", "#0A2F5E", "#0A2F5E", "#0B2D5D", "#0B2D5D", "#0C2A5B", "#0C2A5B", "#0D2859", "#0D2859", "#0E2658", "#0E2658", "#0E2456", "#0E2456", "#0F2254", "#0F2254", "#0F2052", "#0F2052", "#101E4F", "#101E4F"], "cmocean_tempo": ["#FFF6F4", "#FFF6F4", "#FDF5F3", "#FDF5F3", "#FCF4F1", "#FCF4F1", "#FBF3F0", "#FBF3F0", "#F9F2EE", "#F9F2EE", "#F8F1ED", "#F8F1ED", "#F7F0EB", "#F7F0EB", "#F5EFEA", "#F5EFEA", "#F4EEE8", "#F4EEE8", "#F2EDE7", "#F2EDE7", "#F1ECE5", "#F1ECE5", "#F0EBE4", "#F0EBE4", "#EEEAE2", "#EEEAE2", "#EDEAE1", "#EDEAE1", "#EBE9DF", "#EBE9DF", "#EAE8DE", "#EAE8DE", "#E9E7DD", "#E9E7DD", "#E7E6DB", "#E7E6DB", "#E6E5DA", "#E6E5DA", "#E4E4D8", "#E4E4D8", "#E3E3D7", "#E3E3D7", "#E2E2D6", "#E2E2D6", "#E0E2D4", "#E0E2D4", "#DFE1D3", "#DFE1D3", "#DDE0D1", "#DDE0D1", "#DCDFD0", "#DCDFD0", "#DBDECF", "#DBDECF", "#D9DDCD", "#D9DDCD", "#D8DDCC", "#D8DDCC", "#D6DCCB", "#D6DCCB", "#D5DBC9", "#D5DBC9", "#D3DAC8", "#D3DAC8", "#D2D9C7", "#D2D9C7", "#D1D8C5", "#D1D8C5", "#CFD8C4", "#CFD8C4", "#CED7C3", "#CED7C3", "#CCD6C1", "#CCD6C1", "#CBD5C0", "#CBD5C0", "#C9D4BF", "#C9D4BF", "#C8D4BE", "#C8D4BE", "#C6D3BC", "#C6D3BC", "#C5D2BB", "#C5D2BB", "#C3D1BA", "#C3D1BA", "#C2D1B9", "#C2D1B9", "#C0D0B7", "#C0D0B7", "#BFCFB6", "#BFCFB6", "#BDCEB5", "#BDCEB5", "#BCCEB4", "#BCCEB4", "#BACDB3", "#BACDB3", "#B9CCB2", "#B9CCB2", "#B7CBB0", "#B7CBB0", "#B6CBAF", "#B6CBAF", "#B4CAAE", "#B4CAAE", "#B3C9AD", "#B3C9AD", "#B1C8AC", "#B1C8AC", "#B0C8AB", "#B0C8AB", "#AEC7AA", "#AEC7AA", "#ACC6A9", "#ACC6A9", "#ABC5A8", "#ABC5A8", "#A9C5A6", "#A9C5A6", "#A8C4A5", "#A8C4A5", "#A6C3A4", "#A6C3A4", "#A4C3A3", "#A4C3A3", "#A3C2A2", "#A3C2A2", "#A1C1A1", "#A1C1A1", "#A0C0A0", "#A0C0A0", "#9EC09F", "#9EC09F", "#9CBF9F", "#9CBF9F", "#9BBE9E", "#9BBE9E", "#99BE9D", "#99BE9D", "#97BD9C", "#97BD9C", "#96BC9B", "#96BC9B", "#94BC9A", "#94BC9A", "#92BB99", "#92BB99", "#91BA98", "#91BA98", "#8FBA97", "#8FBA97", "#8DB997", "#8DB997", "#8BB896", "#8BB896", "#8AB795", "#8AB795", "#88B794", "#88B794", "#86B693", "#86B693", "#85B593", "#85B593", "#83B592", "#83B592", "#81B491", "#81B491", "#7FB390", "#7FB390", "#7DB390", "#7DB390", "#7CB28F", "#7CB28F", "#7AB18E", "#7AB18E", "#78B18E", "#78B18E", "#76B08D", "#76B08D", "#74AF8D", "#74AF8D", "#72AF8C", "#72AF8C", "#71AE8B", "#71AE8B", "#6FAD8B", "#6FAD8B", "#6DAD8A", "#6DAD8A", "#6BAC8A", "#6BAC8A", "#69AB89", "#69AB89", "#67AB89", "#67AB89", "#65AA88", "#65AA88", "#63A988", "#63A988", "#61A987", "#61A987", "#5FA887", "#5FA887", "#5DA786", "#5DA786", "#5BA686", "#5BA686", "#59A685", "#59A685", "#57A585", "#57A585", "#56A485", "#56A485", "#54A484", "#54A484", "#52A384", "#52A384", "#50A284", "#50A284", "#4EA183", "#4EA183", "#4BA183", "#4BA183", "#49A083", "#49A083", "#479F82", "#479F82", "#459F82", "#459F82", "#439E82", "#439E82", "#419D82", "#419D82", "#3F9C81", "#3F9C81", "#3D9C81", "#3D9C81", "#3B9B81", "#3B9B81", "#3A9A81", "#3A9A81", "#389981", "#389981", "#369880", "#369880", "#349880", "#349880", "#329780", "#329780", "#309680", "#309680", "#2E9580", "#2E9580", "#2C947F", "#2C947F", "#2A937F", "#2A937F", "#29937F", "#29937F", "#27927F", "#27927F", "#25917F", "#25917F", "#24907F", "#24907F", "#228F7E", "#228F7E", "#218E7E", "#218E7E", "#1F8D7E", "#1F8D7E", "#1E8D7E", "#1E8D7E", "#1C8C7E", "#1C8C7E", "#1B8B7D", "#1B8B7D", "#1A8A7D", "#1A8A7D", "#19897D", "#19897D", "#17887D", "#17887D", "#16877C", "#16877C", "#16867C", "#16867C", "#15857C", "#15857C", "#14847C", "#14847C", "#13847B", "#13847B", "#13837B", "#13837B", "#12827B", "#12827B", "#12817B", "#12817B", "#11807A", "#11807A", "#117F7A", "#117F7A", "#117E7A", "#117E7A", "#117D79", "#117D79", "#117C79", "#117C79", "#117B79", "#117B79", "#117A78", "#117A78", "#117978", "#117978", "#117878", "#117878", "#117777", "#117777", "#117677", "#117677", "#127676", "#127676", "#127576", "#127576", "#127476", "#127476", "#137375", "#137375", "#137275", "#137275", "#137174", "#137174", "#147074", "#147074", "#146F73", "#146F73", "#146E73", "#146E73", "#156D73", "#156D73", "#156C72", "#156C72", "#166B72", "#166B72", "#166A71", "#166A71", "#166971", "#166971", "#176870", "#176870", "#176770", "#176770", "#17666F", "#17666F", "#18656F", "#18656F", "#18656E", "#18656E", "#18646E", "#18646E", "#19636D", "#19636D", "#19626D", "#19626D", "#19616C", "#19616C", "#19606C", "#19606C", "#1A5F6B", "#1A5F6B", "#1A5E6B", "#1A5E6B", "#1A5D6A", "#1A5D6A", "#1A5C6A", "#1A5C6A", "#1A5B69", "#1A5B69", "#1B5A68", "#1B5A68", "#1B5968", "#1B5968", "#1B5867", "#1B5867", "#1B5867", "#1B5766", "#1B5766", "#1B5666", "#1B5666", "#1C5565", "#1C5565", "#1C5465", "#1C5465", "#1C5364", "#1C5364", "#1C5263", "#1C5263", "#1C5163", "#1C5163", "#1C5062", "#1C5062", "#1C4F62", "#1C4F62", "#1C4E61", "#1C4E61", "#1C4D61", "#1C4D61", "#1C4C60", "#1C4C60", "#1C4C5F", "#1C4C5F", "#1C4B5F", "#1C4B5F", "#1C4A5E", "#1C4A5E", "#1C495E", "#1C495E", "#1C485D", "#1C485D", "#1C475D", "#1C475D", "#1C465C", "#1C465C", "#1C455B", "#1C455B", "#1C445B", "#1C445B", "#1C435A", "#1C435A", "#1C425A", "#1C425A", "#1C4259", "#1C4259", "#1C4158", "#1C4158", "#1C4058", "#1C4058", "#1B3F57", "#1B3F57", "#1B3E57", "#1B3E57", "#1B3D56", "#1B3D56", "#1B3C56", "#1B3C56", "#1B3B55", "#1B3B55", "#1B3A54", "#1B3A54", "#1B3954", "#1B3954", "#1B3853", "#1B3853", "#1A3753", "#1A3753", "#1A3652", "#1A3652", "#1A3651", "#1A3651", "#1A3551", "#1A3551", "#1A3450", "#1A3450", "#1A3350", "#1A3350", "#19324F", "#19324F", "#19314F", "#19314F", "#19304E", "#19304E", "#192F4D", "#192F4D", "#192E4D", "#192E4D", "#182D4C", "#182D4C", "#182C4C", "#182C4C", "#182B4B", "#182B4B", "#182A4B", "#182A4B", "#18294A", "#18294A", "#17284A", "#17284A", "#172749", "#172749", "#172648", "#172648", "#172548", "#172548", "#172447", "#172447", "#162347", "#162347", "#162246", "#162246", "#162146", "#162146", "#162045", "#162045", "#151F45", "#151F45", "#151E44", "#151E44", "#151D44", "#151D44"], "cmocean_thermal": ["#042333", "#042333", "#042435", "#042435", "#042537", "#042537", "#042539", "#042539", "#05263B", "#05263B", "#05273D", "#05273D", "#05273F", "#05273F", "#052841", "#052841", "#052943", "#052943", "#062945", "#062945", "#062A47", "#062A47", "#062B49", "#062B49", "#072B4B", "#072B4B", "#072C4D", "#072C4D", "#072C50", "#072C50", "#082D52", "#082D52", "#082E54", "#082E54", "#092E56", "#092E56", "#092F59", "#092F59", "#0A2F5B", "#0A2F5B", "#0B305D", "#0B305D", "#0C3060", "#0C3060", "#0C3062", "#0C3062", "#0D3165", "#0D3165", "#0E3167", "#0E3167", "#0F326A", "#0F326A", "#10326C", "#10326C", "#12326F", "#12326F", "#133372", "#133372", "#143374", "#143374", "#163377", "#163377", "#17337A", "#17337A", "#19337C", "#19337C", "#1A347F", "#1A347F", "#1C3482", "#1C3482", "#1E3484", "#1E3484", "#1F3487", "#1F3487", "#21348A", "#21348A", "#23348C", "#23348C", "#25348F", "#25348F", "#273491", "#273491", "#2A3393", "#2A3393", "#2C3395", "#2C3395", "#2E3397", "#2E3397", "#303399", "#303399", "#33339B", "#33339B", "#35339C", "#35339C", "#37339D", "#37339D", "#39339E", "#39339E", "#3C339F", "#3C339F", "#3E349F", "#3E349F", "#40349F", "#40349F", "#4234A0", "#4234A0", "#4435A0", "#4435A0", "#4635A0", "#4635A0", "#4736A0", "#4736A0", "#49369F", "#49369F", "#4B379F", "#4B379F", "#4D379F", "#4D379F", "#4E389E", "#4E389E", "#50399E", "#50399E", "#52399D", "#52399D", "#533A9D", "#533A9D", "#553B9D", "#553B9D", "#563B9C", "#563B9C", "#583C9C", "#583C9C", "#593D9B", "#593D9B", "#5B3D9B", "#5B3D9B", "#5C3E9A", "#5C3E9A", "#5E3F9A", "#5E3F9A", "#5F3F99", "#5F3F99", "#604099", "#604099", "#624198", "#624198", "#634198", "#634198", "#654297", "#654297", "#664397", "#664397", "#674396", "#674396", "#694496", "#694496", "#6A4595", "#6A4595", "#6C4595", "#6C4595", "#6D4694", "#6D4694", "#6E4794", "#6E4794", "#704794", "#704794", "#714893", "#714893", "#724893", "#724893", "#744992", "#744992", "#754A92", "#754A92", "#764A92", "#764A92", "#784B91", "#784B91", "#794B91", "#794B91", "#7A4C91", "#7A4C91", "#7C4D90", "#7C4D90", "#7D4D90", "#7D4D90", "#7E4E90", "#7E4E90", "#804E8F", "#804E8F", "#814F8F", "#814F8F", "#83508F", "#83508F", "#84508E", "#84508E", "#85518E", "#85518E", "#87518E", "#87518E", "#88528D", "#88528D", "#89528D", "#89528D", "#8B538D", "#8B538D", "#8C538C", "#8C538C", "#8E548C", "#8E548C", "#8F548C", "#8F548C", "#90558B", "#90558B", "#92558B", "#92558B", "#93568B", "#93568B", "#95568A", "#95568A", "#96578A", "#96578A", "#97578A", "#97578A", "#995889", "#995889", "#9A5889", "#9A5889", "#9C5989", "#9C5989", "#9D5988", "#9D5988", "#9F5A88", "#9F5A88", "#A05A87", "#A05A87", "#A25B87", "#A25B87", "#A35B86", "#A35B86", "#A55C86", "#A55C86", "#A65C86", "#A65C86", "#A85D85", "#A85D85", "#A95D84", "#A95D84", "#AB5D84", "#AB5D84", "#AC5E83", "#AC5E83", "#AE5E83", "#AE5E83", "#AF5F82", "#AF5F82", "#B15F82", "#B15F82", "#B26081", "#B26081", "#B46080", "#B46080", "#B56180", "#B56180", "#B7617F", "#B7617F", "#B8627E", "#B8627E", "#BA627E", "#BA627E", "#BB627D", "#BB627D", "#BD637C", "#BD637C", "#BE637B", "#BE637B", "#C0647B", "#C0647B", "#C1647A", "#C1647A", "#C36579", "#C36579", "#C46578", "#C46578", "#C66677", "#C66677", "#C76676", "#C76676", "#C96775", "#C96775", "#CA6774", "#CA6774", "#CC6873", "#CC6873", "#CD6872", "#CD6872", "#CE6971", "#CE6971", "#D06970", "#D06970", "#D16A6F", "#D16A6F", "#D36A6E", "#D36A6E", "#D46B6D", "#D46B6D", "#D66C6C", "#D66C6C", "#D76C6B", "#D76C6B", "#D86D6A", "#D86D6A", "#DA6E69", "#DA6E69", "#DB6E68", "#DB6E68", "#DC6F66", "#DC6F66", "#DE7065", "#DE7065", "#DF7064", "#DF7064", "#E07163", "#E07163", "#E17262", "#E17262", "#E37260", "#E37260", "#E4735F", "#E4735F", "#E5745E", "#E5745E", "#E6755D", "#E6755D", "#E7765B", "#E7765B", "#E8775A", "#E8775A", "#EA7859", "#EA7859", "#EB7958", "#EB7958", "#EC7956", "#EC7956", "#ED7A55", "#ED7A55", "#EE7B54", "#EE7B54", "#EE7D53", "#EE7D53", "#EF7E52", "#EF7E52", "#F07F50", "#F07F50", "#F1804F", "#F1804F", "#F2814E", "#F2814E", "#F3824D", "#F3824D", "#F3834C", "#F3834C", "#F4854B", "#F4854B", "#F5864A", "#F5864A", "#F58749", "#F58749", "#F68848", "#F68848", "#F68A47", "#F68A47", "#F78B46", "#F78B46", "#F78C45", "#F78C45", "#F88E44", "#F88E44", "#F88F43", "#F88F43", "#F99143", "#F99143", "#F99242", "#F99242", "#F99341", "#F99341", "#FA9541", "#FA9541", "#FA9640", "#FA9640", "#FA983F", "#FA983F", "#FB993F", "#FB993F", "#FB9B3E", "#FB9B3E", "#FB9C3E", "#FB9C3E", "#FB9E3E", "#FB9E3E", "#FB9F3D", "#FB9F3D", "#FBA13D", "#FBA13D", "#FCA33D", "#FCA33D", "#FCA43D", "#FCA43D", "#FCA63C", "#FCA63C", "#FCA73C", "#FCA73C", "#FCA93C", "#FCA93C", "#FCAA3C", "#FCAA3C", "#FCAC3C", "#FCAC3C", "#FCAE3C", "#FCAE3C", "#FCAF3C", "#FCAF3C", "#FCB13C", "#FCB13C", "#FBB23D", "#FBB23D", "#FBB43D", "#FBB43D", "#FBB63D", "#FBB63D", "#FBB73D", "#FBB73D", "#FBB93E", "#FBB93E", "#FBBB3E", "#FBBB3E", "#FBBC3E", "#FBBC3E", "#FABE3F", "#FABE3F", "#FABF3F", "#FABF3F", "#FAC140", "#FAC140", "#FAC340", "#FAC340", "#F9C441", "#F9C441", "#F9C641", "#F9C641", "#F9C842", "#F9C842", "#F8C943", "#F8C943", "#F8CB43", "#F8CB43", "#F8CD44", "#F8CD44", "#F7CE45", "#F7CE45", "#F7D045", "#F7D045", "#F7D246", "#F7D246", "#F6D347", "#F6D347", "#F6D547", "#F6D547", "#F5D748", "#F5D748", "#F5D849", "#F5D849", "#F4DA4A", "#F4DA4A", "#F4DC4B", "#F4DC4B", "#F3DD4B", "#F3DD4B", "#F3DF4C", "#F3DF4C", "#F2E14D", "#F2E14D", "#F2E24E", "#F2E24E", "#F1E44F", "#F1E44F", "#F1E650", "#F1E650", "#F0E851", "#F0E851", "#EFE951", "#EFE951", "#EFEB52", "#EFEB52", "#EEED53", "#EEED53", "#EDEE54", "#EDEE54", "#EDF055", "#EDF055", "#ECF256", "#ECF256", "#EBF457", "#EBF457", "#EAF558", "#EAF558", "#EAF759", "#EAF759", "#E9F95A", "#E9F95A", "#E8FA5B", "#E8FA5B"], "cmocean_topo": ["#281A2C", "#281A2C", "#291C2F", "#291C2F", "#2B1D32", "#2B1D32", "#2C1F34", "#2C1F34", "#2D2037", "#2D2037", "#2F223A", "#2F223A", "#30233D", "#30233D", "#312540", "#312540", "#322643", "#322643", "#342846", "#342846", "#352949", "#352949", "#362A4C", "#362A4C", "#372C4F", "#372C4F", "#382D52", "#382D52", "#392F55", "#392F55", "#3A3058", "#3A3058", "#3B325C", "#3B325C", "#3C335F", "#3C335F", "#3D3562", "#3D3562", "#3E3666", "#3E3666", "#3F3869", "#3F3869", "#3F396C", "#3F396C", "#403B70", "#403B70", "#403C73", "#403C73", "#413E76", "#413E76", "#41407A", "#41407A", "#41417D", "#41417D", "#424380", "#424380", "#414583", "#414583", "#414785", "#414785", "#414988", "#414988", "#414B8A", "#414B8A", "#404D8C", "#404D8C", "#404F8D", "#404F8D", "#3F528F", "#3F528F", "#3F5490", "#3F5490", "#3E5691", "#3E5691", "#3E5892", "#3E5892", "#3E5A92", "#3E5A92", "#3E5C93", "#3E5C93", "#3E5F93", "#3E5F93", "#3E6194", "#3E6194", "#3E6394", "#3E6394", "#3E6595", "#3E6595", "#3E6795", "#3E6795", "#3E6996", "#3E6996", "#3E6B96", "#3E6B96", "#3F6D97", "#3F6D97", "#3F6F97", "#3F6F97", "#407197", "#407197", "#407398", "#407398", "#407598", "#407598", "#417799", "#417799", "#427999", "#427999", "#427B99", "#427B99", "#437D9A", "#437D9A", "#437F9A", "#437F9A", "#44819B", "#44819B", "#44839B", "#44839B", "#45859C", "#45859C", "#46879C", "#46879C", "#46899D", "#46899D", "#478B9D", "#478B9D", "#488D9D", "#488D9D", "#488F9E", "#488F9E", "#49919E", "#49919E", "#4A939F", "#4A939F", "#4A959F", "#4A959F", "#4B97A0", "#4B97A0", "#4C99A0", "#4C99A0", "#4D9BA1", "#4D9BA1", "#4D9DA1", "#4D9DA1", "#4E9FA1", "#4E9FA1", "#4FA1A2", "#4FA1A2", "#50A3A2", "#50A3A2", "#51A5A2", "#51A5A2", "#51A7A3", "#51A7A3", "#52A9A3", "#52A9A3", "#53ABA3", "#53ABA3", "#55ADA3", "#55ADA3", "#56AFA4", "#56AFA4", "#57B1A4", "#57B1A4", "#58B3A4", "#58B3A4", "#5AB6A4", "#5AB6A4", "#5BB8A4", "#5BB8A4", "#5DBAA4", "#5DBAA4", "#5FBCA4", "#5FBCA4", "#61BEA4", "#61BEA4", "#63C0A4", "#63C0A4", "#65C2A4", "#65C2A4", "#67C3A4", "#67C3A4", "#6AC5A4", "#6AC5A4", "#6DC7A3", "#6DC7A3", "#70C9A3", "#70C9A3", "#73CBA3", "#73CBA3", "#76CDA3", "#76CDA3", "#7ACEA3", "#7ACEA3", "#7DD0A3", "#7DD0A3", "#81D2A3", "#81D2A3", "#85D3A3", "#85D3A3", "#89D5A3", "#89D5A3", "#8DD7A3", "#8DD7A3", "#92D8A4", "#92D8A4", "#96DAA4", "#96DAA4", "#9ADBA5", "#9ADBA5", "#9FDDA5", "#9FDDA5", "#A3DEA6", "#A3DEA6", "#A7E0A7", "#A7E0A7", "#ACE1A8", "#ACE1A8", "#B0E2A9", "#B0E2A9", "#B5E4AA", "#B5E4AA", "#B9E5AC", "#B9E5AC", "#BDE7AD", "#BDE7AD", "#C1E8AF", "#C1E8AF", "#C6EAB0", "#C6EAB0", "#CAEBB2", "#CAEBB2", "#CEECB3", "#CEECB3", "#D2EEB5", "#D2EEB5", "#D7EFB7", "#D7EFB7", "#DBF1B9", "#DBF1B9", "#DFF2BB", "#DFF2BB", "#E3F4BD", "#E3F4BD", "#E7F5BF", "#E7F5BF", "#EBF7C1", "#EBF7C1", "#EFF8C4", "#EFF8C4", "#F3FAC6", "#F3FAC6", "#F7FBC8", "#F7FBC8", "#FBFDCB", "#FBFDCB", "#0D2514", "#0D2514", "#0E2715", "#0E2715", "#0F2915", "#0F2915", "#102A16", "#102A16", "#112C17", "#112C17", "#122E17", "#122E17", "#133018", "#133018", "#143218", "#143218", "#153319", "#153319", "#16351A", "#16351A", "#17371A", "#17371A", "#17391B", "#17391B", "#183A1B", "#183A1B", "#193C1C", "#193C1C", "#1A3E1C", "#1A3E1C", "#1B401C", "#1B401C", "#1B411D", "#1B411D", "#1C431D", "#1C431D", "#1D451D", "#1D451D", "#1E471E", "#1E471E", "#1F481E", "#1F481E", "#204A1E", "#204A1E", "#214C1E", "#214C1E", "#234E1E", "#234E1E", "#254F1E", "#254F1E", "#27511E", "#27511E", "#2A521E", "#2A521E", "#2D531F", "#2D531F", "#305520", "#305520", "#335622", "#335622", "#365723", "#365723", "#395825", "#395825", "#3C5A26", "#3C5A26", "#3F5B28", "#3F5B28", "#415C2A", "#415C2A", "#445D2B", "#445D2B", "#475F2D", "#475F2D", "#49602F", "#49602F", "#4C6130", "#4C6130", "#4E6231", "#4E6231", "#516333", "#516333", "#546534", "#546534", "#566635", "#566635", "#596736", "#596736", "#5C6837", "#5C6837", "#5E6A38", "#5E6A38", "#616B39", "#616B39", "#646C3A", "#646C3A", "#666D3A", "#666D3A", "#696F3B", "#696F3B", "#6B703C", "#6B703C", "#6E713C", "#6E713C", "#71723D", "#71723D", "#73743D", "#73743D", "#76753E", "#76753E", "#79763E", "#79763E", "#7B773E", "#7B773E", "#7E793F", "#7E793F", "#817A3F", "#817A3F", "#837B3F", "#837B3F", "#867C3F", "#867C3F", "#897E40", "#897E40", "#8C7F40", "#8C7F40", "#8E8040", "#8E8040", "#918140", "#918140", "#948340", "#948340", "#968440", "#968440", "#998540", "#998540", "#9C8640", "#9C8640", "#9F8840", "#9F8840", "#A18940", "#A18940", "#A48A3F", "#A48A3F", "#A78C3F", "#A78C3F", "#AA8D3F", "#AA8D3F", "#AD8E3F", "#AD8E3F", "#B08F3F", "#B08F3F", "#B3913F", "#B3913F", "#B6923F", "#B6923F", "#B9933E", "#B9933E", "#BC943E", "#BC943E", "#BF953F", "#BF953F", "#C19741", "#C19741", "#C39945", "#C39945", "#C49B48", "#C49B48", "#C59D4C", "#C59D4C", "#C69F50", "#C69F50", "#C7A153", "#C7A153", "#C8A357", "#C8A357", "#CAA55A", "#CAA55A", "#CBA75E", "#CBA75E", "#CCA961", "#CCA961", "#CDAB65", "#CDAB65", "#CEAD68", "#CEAD68", "#CFB06C", "#CFB06C", "#D0B26F", "#D0B26F", "#D1B473", "#D1B473", "#D2B676", "#D2B676", "#D3B87A", "#D3B87A", "#D4BB7D", "#D4BB7D", "#D5BD81", "#D5BD81", "#D6BF84", "#D6BF84", "#D7C188", "#D7C188", "#D8C38B", "#D8C38B", "#DAC68F", "#DAC68F", "#DBC892", "#DBC892", "#DCCA96", "#DCCA96", "#DDCC99", "#DDCC99", "#DECF9D", "#DECF9D", "#DFD1A0", "#DFD1A0", "#E0D3A4", "#E0D3A4", "#E2D5A7", "#E2D5A7", "#E3D8AB", "#E3D8AB", "#E4DAAE", "#E4DAAE", "#E5DCB2", "#E5DCB2", "#E6DFB6", "#E6DFB6", "#E8E1B9", "#E8E1B9", "#E9E3BD", "#E9E3BD", "#EAE6C0", "#EAE6C0", "#ECE8C4", "#ECE8C4", "#EDEAC7", "#EDEAC7", "#EEEDCB", "#EEEDCB", "#F0EFCF", "#F0EFCF", "#F1F1D2", "#F1F1D2", "#F2F4D6", "#F2F4D6", "#F4F6D9", "#F4F6D9", "#F5F9DD", "#F5F9DD", "#F7FBE1", "#F7FBE1", "#F9FDE4", "#F9FDE4"], "cmocean_turbid": ["#E9F6AB", "#E9F6AB", "#E8F5AA", "#E8F5AA", "#E8F3A8", "#E8F3A8", "#E7F2A7", "#E7F2A7", "#E6F1A5", "#E6F1A5", "#E6F0A4", "#E6F0A4", "#E5EFA2", "#E5EFA2", "#E5EEA1", "#E5EEA1", "#E4EC9F", "#E4EC9F", "#E4EB9E", "#E4EB9E", "#E3EA9C", "#E3EA9C", "#E3E99B", "#E3E99B", "#E2E89A", "#E2E89A", "#E2E798", "#E2E798", "#E1E597", "#E1E597", "#E0E495", "#E0E495", "#E0E394", "#E0E394", "#DFE292", "#DFE292", "#DFE191", "#DFE191", "#DEE08F", "#DEE08F", "#DEDF8E", "#DEDF8E", "#DDDD8D", "#DDDD8D", "#DDDC8B", "#DDDC8B", "#DCDB8A", "#DCDB8A", "#DCDA88", "#DCDA88", "#DBD987", "#DBD987", "#DBD886", "#DBD886", "#DAD784", "#DAD784", "#DAD583", "#DAD583", "#D9D482", "#D9D482", "#D9D380", "#D9D380", "#D9D27F", "#D9D27F", "#D8D17E", "#D8D17E", "#D8D07C", "#D8D07C", "#D7CF7B", "#D7CF7B", "#D7CE7A", "#D7CE7A", "#D6CC78", "#D6CC78", "#D6CB77", "#D6CB77", "#D5CA76", "#D5CA76", "#D5C974", "#D5C974", "#D4C873", "#D4C873", "#D4C772", "#D4C772", "#D3C671", "#D3C671", "#D3C56F", "#D3C56F", "#D3C36E", "#D3C36E", "#D2C26D", "#D2C26D", "#D2C16C", "#D2C16C", "#D1C06B", "#D1C06B", "#D1BF69", "#D1BF69", "#D0BE68", "#D0BE68", "#D0BD67", "#D0BD67", "#CFBC66", "#CFBC66", "#CFBB65", "#CFBB65", "#CFBA64", "#CFBA64", "#CEB862", "#CEB862", "#CEB761", "#CEB761", "#CDB660", "#CDB660", "#CDB55F", "#CDB55F", "#CCB45E", "#CCB45E", "#CCB35D", "#CCB35D", "#CBB25C", "#CBB25C", "#CBB15B", "#CBB15B", "#CAB05A", "#CAB05A", "#CAAF59", "#CAAF59", "#CAAE58", "#CAAE58", "#C9AC57", "#C9AC57", "#C9AB56", "#C9AB56", "#C8AA55", "#C8AA55", "#C8A954", "#C8A954", "#C7A853", "#C7A853", "#C7A752", "#C7A752", "#C6A651", "#C6A651", "#C6A551", "#C6A551", "#C5A450", "#C5A450", "#C5A34F", "#C5A34F", "#C4A24E", "#C4A24E", "#C4A14D", "#C4A14D", "#C3A04D", "#C3A04D", "#C39F4C", "#C39F4C", "#C29E4B", "#C29E4B", "#C29C4A", "#C29C4A", "#C19B4A", "#C19B4A", "#C19A49", "#C19A49", "#C09948", "#C09948", "#C09848", "#C09848", "#BF9747", "#BF9747", "#BF9647", "#BF9647", "#BE9546", "#BE9546", "#BD9445", "#BD9445", "#BD9345", "#BD9345", "#BC9244", "#BC9244", "#BC9144", "#BC9144", "#BB9043", "#BB9043", "#BB8F43", "#BB8F43", "#BA8E42", "#BA8E42", "#B98D42", "#B98D42", "#B98C42", "#B98C42", "#B88B41", "#B88B41", "#B78A41", "#B78A41", "#B78940", "#B78940", "#B68940", "#B68940", "#B68840", "#B68840", "#B58740", "#B58740", "#B4863F", "#B4863F", "#B3853F", "#B3853F", "#B3843F", "#B3843F", "#B2833E", "#B2833E", "#B1823E", "#B1823E", "#B1813E", "#B1813E", "#B0803E", "#B0803E", "#AF7F3D", "#AF7F3D", "#AF7E3D", "#AF7E3D", "#AE7D3D", "#AE7D3D", "#AD7D3D", "#AD7D3D", "#AC7C3D", "#AC7C3D", "#AC7B3D", "#AC7B3D", "#AB7A3C", "#AB7A3C", "#AA793C", "#AA793C", "#A9783C", "#A9783C", "#A8773C", "#A8773C", "#A8773C", "#A7763C", "#A7763C", "#A6753C", "#A6753C", "#A5743C", "#A5743C", "#A4733B", "#A4733B", "#A4723B", "#A4723B", "#A3723B", "#A3723B", "#A2713B", "#A2713B", "#A1703B", "#A1703B", "#A06F3B", "#A06F3B", "#9F6E3B", "#9F6E3B", "#9E6E3B", "#9E6E3B", "#9E6D3B", "#9E6D3B", "#9D6C3B", "#9D6C3B", "#9C6B3B", "#9C6B3B", "#9B6B3B", "#9B6B3B", "#9A6A3B", "#9A6A3B", "#99693B", "#99693B", "#98683B", "#98683B", "#97683A", "#97683A", "#96673A", "#96673A", "#96663A", "#96663A", "#95653A", "#95653A", "#94653A", "#94653A", "#93643A", "#93643A", "#92633A", "#92633A", "#91623A", "#91623A", "#90623A", "#90623A", "#8F613A", "#8F613A", "#8E603A", "#8E603A", "#8D603A", "#8D603A", "#8C5F3A", "#8C5F3A", "#8B5E3A", "#8B5E3A", "#8A5E3A", "#8A5E3A", "#895D3A", "#895D3A", "#885C3A", "#885C3A", "#875C39", "#875C39", "#865B39", "#865B39", "#855A39", "#855A39", "#845A39", "#845A39", "#835939", "#835939", "#825839", "#825839", "#815839", "#815839", "#805739", "#805739", "#7F5639", "#7F5639", "#7E5639", "#7E5639", "#7D5538", "#7D5538", "#7C5438", "#7C5438", "#7B5438", "#7B5438", "#7A5338", "#7A5338", "#795338", "#795338", "#785238", "#785238", "#775138", "#775138", "#765138", "#765138", "#755037", "#755037", "#744F37", "#744F37", "#734F37", "#734F37", "#724E37", "#724E37", "#714E37", "#714E37", "#704D37", "#704D37", "#6F4C36", "#6F4C36", "#6E4C36", "#6E4C36", "#6D4B36", "#6D4B36", "#6C4B36", "#6C4B36", "#6B4A35", "#6B4A35", "#6A4935", "#6A4935", "#694935", "#694935", "#674835", "#674835", "#664835", "#664835", "#654734", "#654734", "#644634", "#644634", "#634634", "#634634", "#624534", "#624534", "#614533", "#614533", "#604433", "#604433", "#5F4333", "#5F4333", "#5E4333", "#5E4333", "#5D4232", "#5D4232", "#5C4232", "#5C4232", "#5B4132", "#5B4132", "#5A4131", "#5A4131", "#594031", "#594031", "#583F31", "#583F31", "#573F30", "#573F30", "#563E30", "#563E30", "#553E30", "#553E30", "#543D30", "#543D30", "#533C2F", "#533C2F", "#523C2F", "#523C2F", "#513B2F", "#513B2F", "#503B2E", "#503B2E", "#4F3A2E", "#4F3A2E", "#4E392E", "#4E392E", "#4D392D", "#4D392D", "#4B382D", "#4B382D", "#4A382C", "#4A382C", "#49372C", "#49372C", "#48362C", "#48362C", "#47362B", "#47362B", "#46352B", "#46352B", "#45352B", "#45352B", "#44342A", "#44342A", "#43332A", "#43332A", "#423329", "#423329", "#413229", "#413229", "#403229", "#403229", "#3F3128", "#3F3128", "#3E3028", "#3E3028", "#3D3027", "#3D3027", "#3C2F27", "#3C2F27", "#3B2F27", "#3B2F27", "#3A2E26", "#3A2E26", "#392D26", "#392D26", "#382D25", "#382D25", "#372C25", "#372C25", "#362B24", "#362B24", "#352B24", "#352B24", "#342A24", "#342A24", "#332A23", "#332A23", "#322923", "#322923", "#312822", "#312822", "#302822", "#302822", "#2F2721", "#2F2721", "#2E2621", "#2E2621", "#2D2620", "#2D2620", "#2C2520", "#2C2520", "#2B241F", "#2B241F", "#2A241F", "#2A241F", "#29231F", "#29231F", "#28231E", "#28231E", "#27221E", "#27221E", "#26211D", "#26211D", "#25211D", "#25211D", "#24201C", "#24201C", "#231F1C", "#231F1C", "#221F1B", "#221F1B"], "em_NZ_blue": ["#0000FF", "#0005FF", "#0005FF", "#0005FF", "#0005FF", "#000AFF", "#0014FF", "#001EFF", "#0032FF", "#0050FF", "#006EFF", "#0087FF", "#009BFF", "#00A5FF", "#00AFFF", "#00BEFF", "#00C8FF", "#00D2FF", "#00EBFF", "#FAFFFF", "#00FF00", "#00FC00", "#05FC00", "#05F800", "#0AF800", "#0AF000", "#0FF000", "#0FE600", "#14E600", "#14DC00", "#19DC00", "#19D200", "#1ED200", "#1EC800", "#1EC700", "#1EBE00", "#1EB900", "#1EB400", "#1EAF00", "#1EAA00", "#1EA500", "#1EA000", "#1E9B00", "#1E9600", "#1E9500", "#1E9400", "#1E9300", "#1E9200", "#1E9100", "#1E9000", "#1E8F00", "#1E8E00", "#1E8D00", "#1E8C00", "#1E8B00", "#1E8A00", "#1E8900", "#1E8800", "#1E8700", "#1E8600", "#1E8400", "#1E8500", "#1E8300", "#1E8400", "#1E8200", "#1E8300", "#1E8100", "#1E8200", "#1E8000", "#1E7F00", "#598A3B", "#598A3B", "#598A3B", "#598A3B", "#598A3B", "#598A3B", "#598A3B", "#598A3B", "#598A3B", "#598A3B", "#598A3B", "#598A3B", "#598A3B", "#598A3B", "#598A3B", "#598A3B", "#598A3B", "#598A3B", "#598A3B", "#598A3B", "#598A3B", "#7A9547", "#7A9547", "#7A9547", "#7A9547", "#7A9547", "#7A9547", "#7A9547", "#7A9547", "#7A9547", "#7A9547", "#9CA153", "#9CA153", "#9CA153", "#9CA153", "#9CA153", "#9CA153", "#9CA153", "#9CA153", "#9CA153", "#9CA153", "#9CA153", "#BBAD61", "#BBAD61", "#BBAD61", "#BBAD61", "#BBAD61", "#BBAD61", "#BBAD61", "#BBAD61", "#BBAD61", "#D9BB7D", "#D9BB7D", "#D9BB7D", "#D9BB7D", "#D9BB7D", "#D9BB7D", "#D9BB7D", "#D9BB7D", "#D9BB7D", "#D9BB7D", "#D9BB7D", "#FFBB78", "#FFBB78", "#FFBB78", "#FFBB78", "#FFBA77", "#FFBA77", "#FFBA77", "#FFBA77", "#FFBA77", "#FFBA77", "#FFBA77", "#FFBA77", "#FFB977", "#FFB977", "#FFB977", "#FFB977", "#FFB976", "#FFB976", "#FFB976", "#FFB976", "#FFB876", "#FFB876", "#FFB876", "#FFB876", "#FFB876", "#FFB876", "#FFB876", "#FFB876", "#FFB775", "#FFB775", "#FFB775", "#FFB775", "#FFB775", "#FFB775", "#FFB775", "#FFB775", "#FFB675", "#FFB675", "#FFB675", "#FFB675", "#FFB674", "#FFB674", "#FFB674", "#FFB574", "#FFB574", "#FFB574", "#FFB574", "#FFB574", "#FFB574", "#FFB574", "#FFB574", "#FFB474", "#FFB474", "#FFB473", "#FFB473", "#FFB473", "#FFB473", "#FFB473", "#FFB473", "#FFB373", "#FFB373", "#FFB373", "#FFB373", "#FFB373", "#FFB373", "#FFB372", "#FFB372", "#FFB272", "#FFB272", "#FFB272", "#FFB272", "#FFB272", "#FFB272", "#FFB272", "#FFB172", "#FFB172", "#FFB172", "#FFB171", "#FFB171", "#FFB171", "#FFB171", "#FFB171", "#FFB071", "#FFB071", "#FFB071", "#FFB071", "#FFB071", "#FFB071", "#FFB071", "#FFB071", "#FFAF70", "#FFAF70", "#FFAF70", "#FFAF70", "#FFAF70", "#FFAF70", "#FFAF70", "#FFAF70", "#FFAE70", "#FFAE70", "#FFAE70", "#FFAE70", "#FFAE6F", "#FFAE6F", "#FFAE6F", "#FFAE6F", "#FFAD6F", "#FFAD6F", "#FFAD6F", "#FFAD6F", "#FFAD6F", "#FFAD6F", "#FFAD6F", "#FFAC6F", "#FFAC6E", "#FFAC6E", "#FFAC6E", "#FFAC6E", "#FFAC6E", "#FFAC6E", "#FFAC6E", "#FFAB6E", "#FFAB6E", "#FFAB6E", "#FFAB6E", "#FFAB6E", "#FFAB6D", "#FFAB6D", "#FFAB6D", "#FFAA6D", "#FFAA6D", "#FFAA6D", "#FFAA6D", "#FFAA6D", "#FFAA6D", "#FFAA6D", "#FFAA6D", "#FFAC6C", "#FFAC6C", "#FFAC6C", "#FFAC6C", "#FFAC6C", "#FFAC6C", "#FFAC6C", "#FFAC6C", "#FFAC6C", "#FFAC6C", "#FFAC6C", "#FFAD6D", "#FFAD6D", "#FFAD6D", "#FFAD6D", "#FFAD6D", "#FFAD6D", "#FFAD6D", "#FFAF6F", "#FFAF6F", "#FFAF6F", "#FFAF6F", "#FFAF6F", "#FFAF6F", "#FFAF6F", "#FFAF6F", "#FFB373", "#FFB373", "#FFB373", "#FFB373", "#FFB373", "#FFB373", "#FFB373", "#FFB373", "#FFB373", "#FFB978", "#FFB978", "#FFB978", "#FFB978", "#FFB978", "#FFB978", "#FFB978", "#FFB978", "#FFB978", "#FFC382", "#FFC382", "#FFC382", "#FFC382", "#FFC382", "#FFC382", "#FFC382", "#FFD796", "#FFD796", "#FFD796", "#FFD796", "#FFDCAA", "#FFDCAA", "#FFDCAA", "#FFEBC3", "#FFEBC3", "#FFEBC3", "#FFF0DC", "#FFF0DC", "#FFF0DC", "#FFF0DC", "#FFF0DC", "#FFF0DC", "#FFF0DC", "#FFF0DC", "#FFF0DC", "#FFF0DC", "#FFFAFF", "#FFFAFF", "#FFFAFF", "#FFFAFF", "#FFFAFF", "#FFFAFF", "#FFFAFF", "#FFFAFF", "#FFFAFF", "#FFFAFF", "#FFFAFF", "#FFFAFF", "#FFFFFF", "#FFFFFF"], "esri_effects_park_boundary_1": ["#458A6F", "#458A6F", "#468C71", "#468C71", "#499175", "#499175", "#4A9478", "#4A9478", "#4D997C", "#4D997C", "#4F9E80", "#4F9E80", "#50A183", "#50A183", "#53A687", "#53A687", "#55AB8C", "#55AB8C", "#57AD8E", "#57AD8E", "#59B392", "#59B392", "#5CB897", "#5CB897", "#5EBD9C", "#5EBD9C", "#60BF9E", "#60BF9E", "#62C4A2", "#62C4A2", "#65C9A6", "#65C9A6", "#68CCA6", "#68CCA6", "#70CF9F", "#70CF9F", "#76CF98", "#76CF98", "#7DD192", "#7DD192", "#83D48F", "#83D48F", "#8BD68C", "#8BD68C", "#9AD993", "#9AD993", "#A9DB9C", "#A9DB9C", "#B6DEA2", "#B6DEA2", "#C1DEA9", "#C1DEA9", "#CCE0B1", "#CCE0B1", "#D5E3B8", "#D5E3B8", "#DFE6C1", "#DFE6C1", "#E6E8CA", "#E6E8CA", "#EBE9D3", "#EBE9D3", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA", "#EDEADA"], "esri_effects_park_gradation_1": ["#458A6F", "#458A6F", "#458A6F", "#458A6F", "#468C71", "#468C71", "#478F73", "#478F73", "#499175", "#499175", "#499175", "#499175", "#4A9479", "#4A9479", "#4B967B", "#4B967B", "#4D997D", "#4D997D", "#4D997D", "#4D997D", "#4E9C7F", "#4E9C7F", "#4F9E82", "#4F9E82", "#50A185", "#50A185", "#52A387", "#52A387", "#52A387", "#52A387", "#53A689", "#53A689", "#54A88C", "#54A88C", "#55AB8E", "#55AB8E", "#57AD91", "#57AD91", "#58B093", "#58B093", "#59B395", "#59B395", "#5BB597", "#5BB597", "#5CB899", "#5CB899", "#5DBA9B", "#5DBA9B", "#5EBD9D", "#5EBD9D", "#5EBD9D", "#5EBD9D", "#60BF9F", "#60BF9F", "#61C2A2", "#61C2A2", "#62C4A4", "#62C4A4", "#63C7A6", "#63C7A6", "#65C9A8", "#65C9A8", "#66CCAA", "#66CCAA", "#6ACCA6", "#6ACCA6", "#6DCFA3", "#6DCFA3", "#73D1A2", "#73D1A2", "#79D4A2", "#79D4A2", "#7CD6A0", "#7CD6A0", "#82D99F", "#82D99F", "#86DB9E", "#86DB9E", "#8CDE9F", "#8CDE9F", "#90E09E", "#90E09E", "#94E09E", "#94E09E", "#98E39D", "#98E39D", "#9EE6A0", "#9EE6A0", "#A7E8A5", "#A7E8A5", "#AEEBA9", "#AEEBA9", "#B9EDAF", "#B9EDAF", "#BCF0B1", "#BCF0B1", "#BCF0B1", "#BCF0B1", "#BCF0B1", "#BCF0B1", "#BCF0B1", "#BCF0B1", "#BCF0B1", "#BCF0B1", "#BCF0B1", "#BCF0B1", "#BCF0B1", "#BCF0B1", "#BCF0B1", "#BCF0B1", "#BCF0B1", "#BCF0B1", "#BCF0B1", "#BCF0B1", "#BCF0B1", "#BCF0B1", "#BCF0B1", "#BCF0B1", "#BCF0B1", "#BCF0B1", "#BCF0B1", "#BCF0B1", "#BCF0B1", "#BCF0B1", "#BCF0B1", "#BCF0B1", "#BCF0B1"], "esri_events_current_dir_3": ["#73B2FF", "#73B2FF", "#7EB7F7", "#7EB7F7", "#8BBCF0", "#8BBCF0", "#97C0E6", "#97C0E6", "#A2C5DE", "#A2C5DE", "#ABCAD4", "#ABCAD4", "#B6CFCC", "#B6CFCC", "#BED4C2", "#BED4C2", "#C5D6B8", "#C5D6B8", "#CDDBAF", "#CDDBAF", "#D8E3A8", "#D8E3A8", "#DDE69C", "#DDE69C", "#E7ED95", "#E7ED95", "#EFF28D", "#EFF28D", "#F5F781", "#F5F781", "#FCFC77", "#FCFC77", "#FFFF73", "#FFFF73", "#FFFA75", "#FFFA75", "#FFF875", "#FFF875", "#FFF675", "#FFF675", "#FFF178", "#FFF178", "#FFEF78", "#FFEF78", "#FFED78", "#FFED78", "#FFE97A", "#FFE97A", "#FFE77A", "#FFE77A", "#FFE47A", "#FFE47A", "#FFE17D", "#FFE17D", "#FFDE7D", "#FFDE7D", "#FFDA7D", "#FFDA7D", "#FFD87D", "#FFD87D", "#FFD580", "#FFD580", "#FFD280", "#FFD280", "#FCD483", "#FCD483", "#FAD787", "#FAD787", "#F7DA8B", "#F7DA8B", "#F5DD8E", "#F5DD8E", "#F2DF91", "#F2DF91", "#F0E297", "#F0E297", "#EDE59A", "#EDE59A", "#EBE89D", "#EBE89D", "#E9EDA4", "#E9EDA4", "#E6F0A8", "#E6F0A8", "#E3F2AC", "#E3F2AC", "#DFF5B0", "#DFF5B0", "#DCF7B5", "#DCF7B5", "#D8FAB9", "#D8FAB9", "#D4FCBD", "#D4FCBD", "#D1FFBF", "#D1FFBF", "#C6FFBA", "#C6FFBA", "#B9FFB5", "#B9FFB5", "#B0FFB5", "#B0FFB5", "#ABFFBC", "#ABFFBC", "#A6FFC2", "#A6FFC2", "#A1FFCB", "#A1FFCB", "#9CFFD4", "#9CFFD4", "#96FFDC", "#96FFDC", "#91FFE9", "#91FFE9", "#8CFFF5", "#8CFFF5", "#87F9FF", "#87F9FF", "#85EBFF", "#85EBFF", "#7DD8FF", "#7DD8FF", "#7AC8FF", "#7AC8FF", "#73B2FF", "#73B2FF", "#73B2FF"], "esri_events_current_dir_4": ["#73DEFF", "#73DEFF", "#81E2F7", "#81E2F7", "#8AE2ED", "#8AE2ED", "#96E3E3", "#96E3E3", "#A1E6DB", "#A1E6DB", "#ACE8D2", "#ACE8D2", "#B5EBC9", "#B5EBC9", "#C0EDC1", "#C0EDC1", "#C8F0B9", "#C8F0B9", "#CEF0AF", "#CEF0AF", "#D7F2A5", "#D7F2A5", "#DFF59D", "#DFF59D", "#E6F792", "#E6F792", "#EFFA89", "#EFFA89", "#F6FC81", "#F6FC81", "#FDFF78", "#FDFF78", "#FFFF73", "#FFFF73", "#FFFA75", "#FFFA75", "#FFF875", "#FFF875", "#FFF675", "#FFF675", "#FFF178", "#FFF178", "#FFEF78", "#FFEF78", "#FFED78", "#FFED78", "#FFE97A", "#FFE97A", "#FFE77A", "#FFE77A", "#FFE47A", "#FFE47A", "#FFE17D", "#FFE17D", "#FFDE7D", "#FFDE7D", "#FFDA7D", "#FFDA7D", "#FFD87D", "#FFD87D", "#FFD580", "#FFD580", "#FFD280", "#FFD280", "#FCD483", "#FCD483", "#FAD787", "#FAD787", "#F7DA8B", "#F7DA8B", "#F5DD8E", "#F5DD8E", "#F2DF91", "#F2DF91", "#F0E297", "#F0E297", "#EDE59A", "#EDE59A", "#EBE89D", "#EBE89D", "#E9EDA4", "#E9EDA4", "#E6F0A8", "#E6F0A8", "#E3F2AC", "#E3F2AC", "#DFF5B0", "#DFF5B0", "#DCF7B5", "#DCF7B5", "#D8FAB9", "#D8FAB9", "#D4FCBD", "#D4FCBD", "#D2FFBF", "#D2FFBF", "#C8FFBA", "#C8FFBA", "#BBFFB5", "#BBFFB5", "#B0FFB0", "#B0FFB0", "#ABFFB5", "#ABFFB5", "#A6FFB8", "#A6FFB8", "#A1FFBF", "#A1FFBF", "#9CFFC5", "#9CFFC5", "#96FFCB", "#96FFCB", "#91FFD5", "#91FFD5", "#8CFFDD", "#8CFFDD", "#87FFE9", "#87FFE9", "#85FFF5", "#85FFF5", "#7DFDFF", "#7DFDFF", "#7AF0FF", "#7AF0FF", "#73DEFF", "#73DEFF", "#73DEFF"], "esri_events_desertification_5": ["#FFFFE6", "#FFFFE6", "#FFFFE3", "#FFFFE3", "#FFFFDB", "#FFFFDB", "#FFFFD6", "#FFFFD6", "#FFFFD1", "#FFFFD1", "#FFFFCC", "#FFFFCC", "#FFFFC7", "#FFFFC7", "#FFFFC2", "#FFFFC2", "#FFFFBA", "#FFFFBA", "#FFFFB5", "#FFFFB5", "#FFFFB0", "#FFFFB0", "#FFFFA8", "#FFFFA8", "#FFFFA6", "#FFFFA6", "#FFFF9E", "#FFFF9E", "#FFFF99", "#FFFF99", "#FFFF94", "#FFFF94", "#FFFF8F", "#FFFF8F", "#FFFF8A", "#FFFF8A", "#FFFF82", "#FFFF82", "#FFFF7D", "#FFFF7D", "#FFFF78", "#FFFF78", "#FCFA72", "#FCFA72", "#FCF86D", "#FCF86D", "#FAF366", "#FAF366", "#FAF061", "#FAF061", "#F7EA59", "#F7EA59", "#F7E754", "#F7E754", "#F5E14E", "#F5E14E", "#F5DE49", "#F5DE49", "#F5DD45", "#F5DD45", "#F2D73F", "#F2D73F", "#F2D338", "#F2D338", "#F0CD32", "#F0CD32", "#F0C92E", "#F0C92E", "#EDC328", "#EDC328", "#EDBE24", "#EDBE24", "#EBB71C", "#EBB71C", "#EBB217", "#EBB217", "#E8AC13", "#E8AC13", "#E8A70E", "#E8A70E", "#E6A009", "#E6A009", "#E69A02", "#E69A02", "#E39400", "#E39400", "#DE8D00", "#DE8D00", "#DB8B00", "#DB8B00", "#D68400", "#D68400", "#D47F00", "#D47F00", "#CF7800", "#CF7800", "#CC7400", "#CC7400", "#C77100", "#C77100", "#C46C00", "#C46C00", "#BF6600", "#BF6600", "#BD6100", "#BD6100", "#B85F00", "#B85F00", "#B55B00", "#B55B00", "#B05500", "#B05500", "#AD5100", "#AD5100", "#A84F00", "#A84F00", "#A64B00", "#A64B00", "#A14600", "#A14600", "#9E4200", "#9E4200", "#993D00", "#993D00", "#963C00", "#963C00", "#963C00"], "esri_events_dry_wet_4": ["#FFFFC9", "#FFFFC9", "#FCFCC5", "#FCFCC5", "#FAF8C0", "#FAF8C0", "#F7F4BA", "#F7F4BA", "#F5F1B5", "#F5F1B5", "#F2EDAE", "#F2EDAE", "#F0E9AA", "#F0E9AA", "#EDE5A6", "#EDE5A6", "#EBE1A0", "#EBE1A0", "#E8DD9B", "#E8DD9B", "#E6D895", "#E6D895", "#E3D491", "#E3D491", "#E0D08D", "#E0D08D", "#DECB87", "#DECB87", "#DBC784", "#DBC784", "#D9C27E", "#D9C27E", "#D6BE7A", "#D6BE7A", "#D4B977", "#D4B977", "#D1B471", "#D1B471", "#CFB06D", "#CFB06D", "#CCAB68", "#CCAB68", "#CCAC66", "#CCAC66", "#C7AA61", "#C7AA61", "#C2AA5D", "#C2AA5D", "#BFAB5A", "#BFAB5A", "#BAAB56", "#BAAB56", "#B5AB51", "#B5AB51", "#B0AB4D", "#B0AB4D", "#ABA948", "#ABA948", "#A7AB46", "#A7AB46", "#A4AB41", "#A4AB41", "#A0AB3E", "#A0AB3E", "#9AAB38", "#9AAB38", "#95AB33", "#95AB33", "#92AB30", "#92AB30", "#8DAB2C", "#8DAB2C", "#8AAB27", "#8AAB27", "#82A822", "#82A822", "#7EA81D", "#7EA81D", "#7AA818", "#7AA818", "#76A811", "#76A811", "#73A808", "#73A808", "#66A600", "#66A600", "#53A600", "#53A600", "#3DA600", "#3DA600", "#27A600", "#27A600", "#16A600", "#16A600", "#00A300", "#00A300", "#00A316", "#00A316", "#00A329", "#00A329", "#00A33F", "#00A33F", "#00A34F", "#00A34F", "#00A163", "#00A163", "#00A178", "#00A178", "#00A18E", "#00A18E", "#009EA1", "#009EA1", "#008BA1", "#008BA1", "#0078A1", "#0078A1", "#00649E", "#00649E", "#004F9E", "#004F9E", "#003A9E", "#003A9E", "#00259E", "#00259E", "#00109E", "#00109E", "#00109E"], "esri_events_fire_active_1": ["#4F4F4F", "#4F4F4F", "#52514F", "#52514F", "#575551", "#575551", "#5C5954", "#5C5954", "#615D55", "#615D55", "#666156", "#666156", "#6B6457", "#6B6457", "#706858", "#706858", "#736956", "#736956", "#786D56", "#786D56", "#807257", "#807257", "#827355", "#827355", "#877654", "#877654", "#8C7953", "#8C7953", "#917C51", "#917C51", "#967E4E", "#967E4E", "#9C814C", "#9C814C", "#A1844A", "#A1844A", "#A38446", "#A38446", "#A88743", "#A88743", "#B08A3F", "#B08A3F", "#B38B3B", "#B38B3B", "#B88D37", "#B88D37", "#BD8F33", "#BD8F33", "#C2902D", "#C2902D", "#C79228", "#C79228", "#CC9423", "#CC9423", "#D1951D", "#D1951D", "#D69718", "#D69718", "#DB970F", "#DB970F", "#E09909", "#E09909", "#E69900", "#E69900", "#E69500", "#E69500", "#E68E00", "#E68E00", "#E68A00", "#E68A00", "#E68600", "#E68600", "#E67E00", "#E67E00", "#E67A00", "#E67A00", "#E67700", "#E67700", "#E66F00", "#E66F00", "#E66B00", "#E66B00", "#E66700", "#E66700", "#E66300", "#E66300", "#E65C00", "#E65C00", "#E65800", "#E65800", "#E65400", "#E65400", "#E65000", "#E65000", "#E64900", "#E64900", "#E64500", "#E64500", "#E63D00", "#E63D00", "#E63900", "#E63900", "#E63600", "#E63600", "#E63200", "#E63200", "#E62A00", "#E62A00", "#E62600", "#E62600", "#E62200", "#E62200", "#E61F00", "#E61F00", "#E61700", "#E61700", "#E61300", "#E61300", "#E60F00", "#E60F00", "#E60800", "#E60800", "#E60400", "#E60400", "#E60000", "#E60000", "#E60000"], "esri_events_fire_active_2": ["#333333", "#333333", "#383836", "#383836", "#3D3D3A", "#3D3D3A", "#45453F", "#45453F", "#4A4A41", "#4A4A41", "#525245", "#525245", "#595948", "#595948", "#5E5E4A", "#5E5E4A", "#66664D", "#66664D", "#6B6B4D", "#6B6B4D", "#73734E", "#73734E", "#7A7A50", "#7A7A50", "#80804F", "#80804F", "#878750", "#878750", "#8C8C4F", "#8C8C4F", "#94944D", "#94944D", "#9C9C4C", "#9C9C4C", "#A1A14A", "#A1A14A", "#A8A848", "#A8A848", "#ADAD45", "#ADAD45", "#B5B541", "#B5B541", "#BDBD3E", "#BDBD3E", "#C2C23A", "#C2C23A", "#C7C736", "#C7C736", "#D1D130", "#D1D130", "#D6D62B", "#D6D62B", "#DEDE26", "#DEDE26", "#E3E320", "#E3E320", "#E8E81A", "#E8E81A", "#F2F211", "#F2F211", "#F7F70A", "#F7F70A", "#FFFF00", "#FFFF00", "#FCF400", "#FCF400", "#FCEC00", "#FCEC00", "#FCE300", "#FCE300", "#FAD900", "#FAD900", "#FAD000", "#FAD000", "#FACC00", "#FACC00", "#F7C200", "#F7C200", "#F7B500", "#F7B500", "#F7B100", "#F7B100", "#F5A700", "#F5A700", "#F59F00", "#F59F00", "#F59300", "#F59300", "#F28D00", "#F28D00", "#F28500", "#F28500", "#F27D00", "#F27D00", "#F07400", "#F07400", "#F06C00", "#F06C00", "#F06400", "#F06400", "#ED5B00", "#ED5B00", "#ED5300", "#ED5300", "#ED4B00", "#ED4B00", "#EB4200", "#EB4200", "#EB3B00", "#EB3B00", "#EB3300", "#EB3300", "#EB2F00", "#EB2F00", "#E82700", "#E82700", "#E81B00", "#E81B00", "#E81700", "#E81700", "#E60F00", "#E60F00", "#E60800", "#E60800", "#E60000", "#E60000", "#E60000"], "esri_events_global_warming": ["#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#19151A", "#19151A", "#302433", "#302433", "#452A4D", "#452A4D", "#572963", "#572963", "#69207D", "#69207D", "#781294", "#781294", "#810CA8", "#810CA8", "#731EA8", "#731EA8", "#662CA8", "#662CA8", "#5934A8", "#5934A8", "#493DA8", "#493DA8", "#3843A8", "#3843A8", "#2049A8", "#2049A8", "#0550AB", "#0550AB", "#0B5EB8", "#0B5EB8", "#0E6FC4", "#0E6FC4", "#0F80D1", "#0F80D1", "#1092DE", "#1092DE", "#0CA4EB", "#0CA4EB", "#07B7F7", "#07B7F7", "#1DC2F0", "#1DC2F0", "#32BDC9", "#32BDC9", "#3FBAA6", "#3FBAA6", "#43B582", "#43B582", "#44B361", "#44B361", "#42AD42", "#42AD42", "#3CAB1D", "#3CAB1D", "#38A800", "#38A800", "#38A800", "#38A800", "#38A800", "#38A800", "#38A800", "#38A800", "#38A800", "#38A800", "#38A800", "#38A800", "#38A800", "#38A800", "#43B000", "#43B000", "#51BA00", "#51BA00", "#61C900", "#61C900", "#71D400", "#71D400", "#84E300", "#84E300", "#92ED00", "#92ED00", "#A8FC00", "#A8FC00", "#B5F700", "#B5F700", "#C3EB00", "#C3EB00", "#CFDE00", "#CFDE00", "#DED300", "#DED300", "#E8C500", "#E8C500", "#F2BA00", "#F2BA00", "#FCAD00", "#FCAD00", "#FA9200", "#FA9200", "#F77800", "#F77800", "#F25D00", "#F25D00", "#F04400", "#F04400", "#EB2B00", "#EB2B00", "#E81700", "#E81700", "#E60000", "#E60000", "#E60000"], "esri_hillshade_illumination": ["#FFFFBF", "#FFFFBF", "#FCFCBD", "#FCFCBD", "#F9FABE", "#F9FABE", "#F6F7BC", "#F6F7BC", "#F3F5BC", "#F3F5BC", "#F0F2BB", "#F0F2BB", "#EDF0BB", "#EDF0BB", "#E7EBB9", "#E7EBB9", "#E7EBB9", "#E7EBB9", "#E2E6B8", "#E2E6B8", "#E1E6B8", "#E1E6B8", "#DBE0B6", "#DBE0B6", "#D8DEB6", "#D8DEB6", "#D5DBB4", "#D5DBB4", "#D2D9B4", "#D2D9B4", "#CFD6B4", "#CFD6B4", "#CCD4B2", "#CCD4B2", "#C6CFB0", "#C6CFB0", "#C6CFB2", "#C6CFB2", "#C3CCB1", "#C3CCB1", "#C0C9AF", "#C0C9AF", "#BDC7AF", "#BDC7AF", "#B7C2AC", "#B7C2AC", "#B6C2AC", "#B6C2AC", "#B1BDAA", "#B1BDAA", "#B1BDAC", "#B1BDAC", "#ACB8A9", "#ACB8A9", "#A9B5A8", "#A9B5A8", "#A8B5A9", "#A8B5A9", "#A2B0A6", "#A2B0A6", "#A2B0A7", "#A2B0A7", "#9EADA6", "#9EADA6", "#99A8A4", "#99A8A4", "#99A8A5", "#99A8A5", "#95A6A4", "#95A6A4", "#93A3A2", "#93A3A2", "#8FA0A1", "#8FA0A1", "#8C9EA1", "#8C9EA1", "#889A9E", "#889A9E", "#85989E", "#85989E", "#85989E", "#85989E", "#80939C", "#80939C", "#7C919C", "#7C919C", "#7B909C", "#7B909C", "#778D99", "#778D99", "#768C99", "#768C99", "#738A99", "#738A99", "#6E8696", "#6E8696", "#6C8496", "#6C8496", "#698296", "#698296", "#688094", "#688094", "#657E94", "#657E94", "#607A91", "#607A91", "#5E7991", "#5E7991", "#5C7791", "#5C7791", "#5A7791", "#5A7791", "#56728F", "#56728F", "#53718F", "#53718F", "#51708F", "#51708F", "#4D6C8C", "#4D6C8C", "#4C6B8C", "#4C6B8C", "#48688A", "#48688A", "#46678A", "#46678A", "#46678A"], "esri_hypsometry_bath_bath_111": ["#63ACFF", "#63ACFF", "#66B0FF", "#66B0FF", "#69B1FF", "#69B1FF", "#69B1FF", "#69B1FF", "#6BB5FF", "#6BB5FF", "#6BB5FF", "#6BB5FF", "#6EB6FF", "#6EB6FF", "#70BAFF", "#70BAFF", "#70BAFF", "#70BAFF", "#73BBFF", "#73BBFF", "#75BFFF", "#75BFFF", "#75BFFF", "#75BFFF", "#78C2FF", "#78C2FF", "#7AC3FF", "#7AC3FF", "#7AC3FF", "#7AC3FF", "#7DC4FF", "#7DC4FF", "#80C8FF", "#80C8FF", "#80C8FF", "#80C8FF", "#82C9FF", "#82C9FF", "#85CCFF", "#85CCFF", "#85CCFF", "#85CCFF", "#87CFFF", "#87CFFF", "#8AD0FF", "#8AD0FF", "#8AD0FF", "#8AD0FF", "#8CD3FF", "#8CD3FF", "#8CD3FF", "#8CD3FF", "#8FD4FF", "#8FD4FF", "#91D7FF", "#91D7FF", "#91D7FF", "#91D7FF", "#94D8FF", "#94D8FF", "#94D8FF", "#94D8FF", "#96DAFF", "#96DAFF", "#99DBFF", "#99DBFF", "#9CDEFF", "#9CDEFF", "#9CDEFF", "#9CDEFF", "#9EDFFF", "#9EDFFF", "#A1E1FF", "#A1E1FF", "#A1E1FF", "#A1E1FF", "#A3E2FF", "#A3E2FF", "#A6E4FF", "#A6E4FF", "#A6E4FF", "#A6E4FF", "#A8E5FF", "#A8E5FF", "#ABE7FF", "#ABE7FF", "#ABE7FF", "#ABE7FF", "#ADE8FF", "#ADE8FF", "#ADE9FF", "#ADE9FF", "#B0EAFF", "#B0EAFF", "#B3EBFF", "#B3EBFF", "#B3ECFF", "#B3ECFF", "#B5EDFF", "#B5EDFF", "#B5EDFF", "#B5EDFF", "#B8EEFF", "#B8EEFF", "#BAEFFF", "#BAEFFF", "#BAEFFF", "#BAEFFF", "#BDF1FF", "#BDF1FF", "#BFF1FF", "#BFF1FF", "#BFF1FF", "#BFF1FF", "#C2F3FF", "#C2F3FF", "#C4F3FF", "#C4F3FF", "#C4F3FF", "#C4F3FF", "#C7F5FF", "#C7F5FF", "#C9F5FF", "#C9F5FF", "#C9F5FF", "#C9F5FF", "#C9F5FF"], "esri_hypsometry_bath_bath_112": ["#002673", "#002673", "#002975", "#002975", "#002B7A", "#002B7A", "#002D80", "#002D80", "#002E82", "#002E82", "#002F87", "#002F87", "#00338C", "#00338C", "#003591", "#003591", "#003694", "#003694", "#003899", "#003899", "#003A9E", "#003A9E", "#003FA3", "#003FA3", "#0041A8", "#0041A8", "#0041AB", "#0041AB", "#0043B0", "#0043B0", "#0045B5", "#0045B5", "#004ABA", "#004ABA", "#004DBF", "#004DBF", "#004EC2", "#004EC2", "#0050C7", "#0050C7", "#0052CC", "#0052CC", "#0057D1", "#0057D1", "#0058D4", "#0058D4", "#005AD9", "#005AD9", "#005CDE", "#005CDE", "#005FE3", "#005FE3", "#0065E8", "#0065E8", "#0066EB", "#0066EB", "#0068F0", "#0068F0", "#006AF5", "#006AF5", "#006CFA", "#006CFA", "#006FFF", "#006FFF", "#0576FF", "#0576FF", "#0A78FF", "#0A78FF", "#1281FF", "#1281FF", "#1985FF", "#1985FF", "#1F87FF", "#1F87FF", "#248EFF", "#248EFF", "#2990FF", "#2990FF", "#3098FF", "#3098FF", "#389CFF", "#389CFF", "#3DA1FF", "#3DA1FF", "#42A4FF", "#42A4FF", "#4AA7FF", "#4AA7FF", "#52AEFF", "#52AEFF", "#57B0FF", "#57B0FF", "#5CB6FF", "#5CB6FF", "#61B8FF", "#61B8FF", "#69BEFF", "#69BEFF", "#70C1FF", "#70C1FF", "#75C3FF", "#75C3FF", "#7AC8FF", "#7AC8FF", "#80CAFF", "#80CAFF", "#8AD0FF", "#8AD0FF", "#8FD2FF", "#8FD2FF", "#94D4FF", "#94D4FF", "#99D8FF", "#99D8FF", "#A1DBFF", "#A1DBFF", "#A8DFFF", "#A8DFFF", "#ADE1FF", "#ADE1FF", "#B3E4FF", "#B3E4FF", "#B8E6FF", "#B8E6FF", "#BFE9FF", "#BFE9FF", "#BFE9FF"], "esri_hypsometry_bath_bath_113": ["#002673", "#002673", "#002673", "#002673", "#002673", "#002673", "#002673", "#002673", "#002673", "#002673", "#002673", "#002673", "#002673", "#002673", "#002673", "#002673", "#002673", "#002673", "#002673", "#002673", "#002673", "#002673", "#002673", "#002673", "#002673", "#002673", "#002673", "#002673", "#002673", "#002673", "#002673", "#002673", "#002873", "#002873", "#002975", "#002975", "#002D7A", "#002D7A", "#002E7D", "#002E7D", "#002F80", "#002F80", "#003385", "#003385", "#003487", "#003487", "#00388C", "#00388C", "#00398F", "#00398F", "#003D91", "#003D91", "#003F96", "#003F96", "#004299", "#004299", "#00439C", "#00439C", "#0048A1", "#0048A1", "#0049A3", "#0049A3", "#004CA8", "#004CA8", "#004DAB", "#004DAB", "#0050B3", "#0050B3", "#0053B8", "#0053B8", "#0055BD", "#0055BD", "#0057C2", "#0057C2", "#005BC9", "#005BC9", "#005DCF", "#005DCF", "#005FD4", "#005FD4", "#0062D9", "#0062D9", "#0064DE", "#0064DE", "#0067E6", "#0067E6", "#006AEB", "#006AEB", "#006CF0", "#006CF0", "#006EF5", "#006EF5", "#0070FA", "#0070FA", "#0576FF", "#0576FF", "#1281FF", "#1281FF", "#1F87FF", "#1F87FF", "#2990FF", "#2990FF", "#389CFF", "#389CFF", "#42A4FF", "#42A4FF", "#52AEFF", "#52AEFF", "#5CB6FF", "#5CB6FF", "#69BBFF", "#69BBFF", "#75C3FF", "#75C3FF", "#80CAFF", "#80CAFF", "#8FD2FF", "#8FD2FF", "#99D8FF", "#99D8FF", "#A8DFFF", "#A8DFFF", "#B3E4FF", "#B3E4FF", "#BFE9FF", "#BFE9FF", "#BFE9FF"], "esri_hypsometry_bath_bath_114": ["#C400FF", "#C400FF", "#BF00FF", "#BF00FF", "#BB00FF", "#BB00FF", "#B700FF", "#B700FF", "#B300FF", "#B300FF", "#AD00FC", "#AD00FC", "#A800FC", "#A800FC", "#A400FC", "#A400FC", "#A000FC", "#A000FC", "#9C00FC", "#9C00FC", "#9300FC", "#9300FC", "#8F00FC", "#8F00FC", "#8B00FC", "#8B00FC", "#8500FA", "#8500FA", "#8100FA", "#8100FA", "#7900FA", "#7900FA", "#7500FA", "#7500FA", "#7000FA", "#7000FA", "#6C00FA", "#6C00FA", "#6800FA", "#6800FA", "#5F00F7", "#5F00F7", "#5B00F7", "#5B00F7", "#5700F7", "#5700F7", "#4E00F7", "#4E00F7", "#4A00F7", "#4A00F7", "#4200F7", "#4200F7", "#3E00F7", "#3E00F7", "#3600F7", "#3600F7", "#2D00F5", "#2D00F5", "#2100F5", "#2100F5", "#1800F5", "#1800F5", "#0000F5", "#0000F5", "#130FF5", "#130FF5", "#1C18F5", "#1C18F5", "#2825F5", "#2825F5", "#2F2CF5", "#2F2CF5", "#3733F5", "#3733F5", "#3838F2", "#3838F2", "#3F3FF2", "#3F3FF2", "#4447F2", "#4447F2", "#494EF2", "#494EF2", "#4B56F2", "#4B56F2", "#505DF2", "#505DF2", "#5466F0", "#5466F0", "#566BF0", "#566BF0", "#5B74F0", "#5B74F0", "#5D7BF0", "#5D7BF0", "#5F80ED", "#5F80ED", "#6189ED", "#6189ED", "#6693ED", "#6693ED", "#689BED", "#689BED", "#67A0EB", "#67A0EB", "#6AA8EB", "#6AA8EB", "#6BB0E8", "#6BB0E8", "#6DB9E8", "#6DB9E8", "#6FC2E8", "#6FC2E8", "#70C8E6", "#70C8E6", "#70D0E6", "#70D0E6", "#71DBE3", "#71DBE3", "#71E3E3", "#71E3E3", "#73EBE1", "#73EBE1", "#73F5E1", "#73F5E1", "#74FCDF", "#74FCDF", "#74FCDF"], "esri_hypsometry_bath_bath_115": ["#8A6F45", "#8A6F45", "#8F7B43", "#8F7B43", "#948941", "#948941", "#97993F", "#97993F", "#92A13D", "#92A13D", "#85A638", "#85A638", "#7AAB35", "#7AAB35", "#6AB332", "#6AB332", "#57B82E", "#57B82E", "#42BD2A", "#42BD2A", "#26C423", "#26C423", "#1EC92F", "#1EC92F", "#19CF46", "#19CF46", "#13D65E", "#13D65E", "#0BDB7A", "#0BDB7A", "#04E097", "#04E097", "#00E6AC", "#00E6AC", "#00E6B8", "#00E6B8", "#00E6C3", "#00E6C3", "#00E6D2", "#00E6D2", "#00E6DE", "#00E6DE", "#00DEE6", "#00DEE6", "#00D2E6", "#00D2E6", "#00C3E6", "#00C3E6", "#00B8E6", "#00B8E6", "#00ACE6", "#00ACE6", "#009DE6", "#009DE6", "#0091E6", "#0091E6", "#0082E6", "#0082E6", "#0077E6", "#0077E6", "#006BE6", "#006BE6", "#005CE6", "#005CE6", "#0060E6", "#0060E6", "#0061E8", "#0061E8", "#0061E8", "#0061E8", "#0062EB", "#0062EB", "#0063ED", "#0063ED", "#0063ED", "#0063ED", "#0064F0", "#0064F0", "#0069F2", "#0069F2", "#0069F2", "#0069F2", "#006AF5", "#006AF5", "#006BF7", "#006BF7", "#006BF7", "#006BF7", "#006CFA", "#006CFA", "#006CFA", "#006CFA", "#006DFC", "#006DFC", "#0D72FF", "#0D72FF", "#1971FF", "#1971FF", "#2679FF", "#2679FF", "#2E7BFF", "#2E7BFF", "#367FFF", "#367FFF", "#3D84FF", "#3D84FF", "#4287FF", "#4287FF", "#4A8CFF", "#4A8CFF", "#4F92FF", "#4F92FF", "#5496FF", "#5496FF", "#5999FF", "#5999FF", "#5E9FFF", "#5E9FFF", "#63A4FF", "#63A4FF", "#69A7FF", "#69A7FF", "#6EADFF", "#6EADFF", "#73B2FF", "#73B2FF", "#73B2FF"], "esri_hypsometry_planet_mars_1": ["#4F4F4F", "#4F4F4F", "#4F4E4D", "#4F4E4D", "#545251", "#545251", "#575351", "#575351", "#595451", "#595451", "#5C5451", "#5C5451", "#5E5551", "#5E5551", "#615651", "#615651", "#635751", "#635751", "#665751", "#665751", "#6B5A51", "#6B5A51", "#6E5A51", "#6E5A51", "#705B51", "#705B51", "#735A4F", "#735A4F", "#755B4F", "#755B4F", "#785A4D", "#785A4D", "#7A5B4C", "#7A5B4C", "#7D5B4B", "#7D5B4B", "#805A49", "#805A49", "#855C49", "#855C49", "#875B46", "#875B46", "#8A5B45", "#8A5B45", "#8F5C43", "#8F5C43", "#915D41", "#915D41", "#966041", "#966041", "#9C623E", "#9C623E", "#A1653D", "#A1653D", "#A36539", "#A36539", "#A86838", "#A86838", "#AD6C36", "#AD6C36", "#B36E32", "#B36E32", "#B5702F", "#B5702F", "#BA722B", "#BA722B", "#BF7628", "#BF7628", "#C27925", "#C27925", "#C77C20", "#C77C20", "#CC801D", "#CC801D", "#D18417", "#D18417", "#D68813", "#D68813", "#D98B0D", "#D98B0D", "#DE9009", "#DE9009", "#E39505", "#E39505", "#E69705", "#E69705", "#E69809", "#E69809", "#E89D10", "#E89D10", "#E89E15", "#E89E15", "#EBA21A", "#EBA21A", "#EBA421", "#EBA421", "#EDA726", "#EDA726", "#EDAA2D", "#EDAA2D", "#F0AD32", "#F0AD32", "#F0AF37", "#F0AF37", "#F2B43F", "#F2B43F", "#F2B544", "#F2B544", "#F5BA4C", "#F5BA4C", "#F5BB51", "#F5BB51", "#F7C059", "#F7C059", "#F7C25E", "#F7C25E", "#F7C363", "#F7C363", "#FAC86B", "#FAC86B", "#FACA70", "#FACA70", "#FCCF79", "#FCCF79", "#FFD280", "#FFD280", "#FFD280"], "esri_hypsometry_planet_mars_2": ["#4F4F4F", "#4F4F4F", "#4F4E4D", "#4F4E4D", "#545251", "#545251", "#575351", "#575351", "#595451", "#595451", "#5C5451", "#5C5451", "#5E5551", "#5E5551", "#615651", "#615651", "#635751", "#635751", "#665751", "#665751", "#6B5A51", "#6B5A51", "#6E5A51", "#6E5A51", "#705B51", "#705B51", "#735A4F", "#735A4F", "#755B4F", "#755B4F", "#785A4D", "#785A4D", "#7A5B4C", "#7A5B4C", "#7D5B4B", "#7D5B4B", "#805A49", "#805A49", "#855C49", "#855C49", "#875B46", "#875B46", "#8A5B45", "#8A5B45", "#8C5E46", "#8C5E46", "#8F6047", "#8F6047", "#916349", "#916349", "#96684B", "#96684B", "#996B4D", "#996B4D", "#9C6E4E", "#9C6E4E", "#A17350", "#A17350", "#A37652", "#A37652", "#A67A53", "#A67A53", "#A87D54", "#A87D54", "#AD8257", "#AD8257", "#B08558", "#B08558", "#B38959", "#B38959", "#B58C5B", "#B58C5B", "#BA925D", "#BA925D", "#BD955E", "#BD955E", "#BF9960", "#BF9960", "#C49F62", "#C49F62", "#C7A263", "#C7A263", "#C9A665", "#C9A665", "#CCA866", "#CCA866", "#CFAA67", "#CFAA67", "#D1AD69", "#D1AD69", "#D4AF6A", "#D4AF6A", "#D6B16B", "#D6B16B", "#D9B36C", "#D9B36C", "#DBB56E", "#DBB56E", "#DEB76F", "#DEB76F", "#E0B970", "#E0B970", "#E3BB71", "#E3BB71", "#E6BD73", "#E6BD73", "#E8BF74", "#E8BF74", "#EBC275", "#EBC275", "#EDC477", "#EDC477", "#F0C678", "#F0C678", "#F0C678", "#F0C678", "#F2C879", "#F2C879", "#F5CA7A", "#F5CA7A", "#F7CC7C", "#F7CC7C", "#FACE7D", "#FACE7D", "#FFD280", "#FFD280", "#FFD280"], "gery_seismic": ["#FF2929", "#FF2929", "#FF6767", "#FF6767", "#FF8A8A", "#FF8A8A", "#FFA1A1", "#FFA1A1", "#FFB2B2", "#FFB2B2", "#FFBFBF", "#FFBFBF", "#FFCBCB", "#FFCBCB", "#FFD4D4", "#FFD4D4", "#FFDDDD", "#FFDDDD", "#FFE5E5", "#FFE5E5", "#FFEDED", "#FFEDED", "#FFF4F4", "#FFF4F4", "#FFFBFB", "#FFFBFB", "#FFFFFF", "#FFFFFF", "#FCFCFF", "#FCFCFF", "#F5F5FF", "#F5F5FF", "#EDEDFF", "#EDEDFF", "#E6E6FF", "#E6E6FF", "#DEDEFF", "#DEDEFF", "#D5D5FF", "#D5D5FF", "#CBCBFF", "#CBCBFF", "#C0C0FF", "#C0C0FF", "#B2B2FF", "#B2B2FF", "#A1A1FF", "#A1A1FF", "#8989FF", "#8989FF", "#6666FF", "#6666FF", "#2828FF", "#2828FF"], "gist_earth": ["#000000", "#00002E", "#00003A", "#000045", "#000051", "#00005C", "#000068", "#000074", "#000374", "#010674", "#020874", "#020B74", "#030D75", "#041075", "#051275", "#051575", "#061775", "#071A76", "#081C76", "#081F76", "#092176", "#0A2476", "#0B2677", "#0B2977", "#0C2B77", "#0D2D77", "#0E3077", "#0F3278", "#0F3478", "#103778", "#113978", "#123B78", "#123D79", "#134079", "#144279", "#154479", "#164679", "#16487A", "#174A7A", "#184D7A", "#194F7A", "#1A517A", "#1A537B", "#1B557B", "#1C577B", "#1D597B", "#1E5B7B", "#1F5D7C", "#1F5F7C", "#20617C", "#21637C", "#22647C", "#23667D", "#24687D", "#246A7D", "#256C7D", "#266D7D", "#276F7E", "#28717E", "#29737E", "#29747E", "#2A767E", "#2B787F", "#2C797F", "#2D7B7F", "#2E7D7F", "#2F7E7F", "#308080", "#30807E", "#30817D", "#31817C", "#31827B", "#32837A", "#328378", "#338477", "#338576", "#348575", "#348673", "#358672", "#358771", "#36886F", "#36886E", "#37896D", "#378A6C", "#388A6A", "#388B69", "#398C68", "#398C66", "#3A8D65", "#3A8D64", "#3B8E62", "#3B8F61", "#3C8F60", "#3D905E", "#3D915D", "#3E915C", "#3E925A", "#3F9259", "#3F9358", "#409456", "#409455", "#419554", "#419652", "#429651", "#439750", "#43974E", "#44984D", "#44994C", "#45994A", "#459A49", "#469B47", "#479B46", "#499C47", "#4C9C48", "#4E9D48", "#519E49", "#539E49", "#569F4A", "#58A04B", "#5BA04B", "#5EA14C", "#60A14C", "#63A24D", "#65A34D", "#68A34E", "#6AA44F", "#6DA54F", "#6FA550", "#72A650", "#75A651", "#77A752", "#79A852", "#7AA852", "#7CA853", "#7EA953", "#80A953", "#81AA54", "#83AA54", "#85AB54", "#87AB55", "#88AC55", "#8AAC55", "#8CAC56", "#8DAD56", "#8FAD56", "#91AE57", "#93AE57", "#95AF57", "#96AF58", "#98AF58", "#9AB058", "#9CB059", "#9DB159", "#9FB159", "#A1B25A", "#A3B25A", "#A5B35A", "#A6B35B", "#A8B35B", "#AAB45B", "#ACB45C", "#AEB55C", "#AFB55C", "#B1B65D", "#B3B65D", "#B5B75D", "#B7B75E", "#B7B65E", "#B8B55E", "#B8B55F", "#B9B45F", "#B9B35F", "#BAB260", "#BAB160", "#BBB061", "#BBAF61", "#BBAE61", "#BCAD62", "#BCAC62", "#BDAB62", "#BDAA63", "#BEA963", "#BEA863", "#BEA764", "#BFA664", "#BFA564", "#C0A465", "#C0A365", "#C1A368", "#C3A46A", "#C4A46C", "#C5A56F", "#C6A571", "#C7A674", "#C9A776", "#CAA779", "#CBA87B", "#CCA97E", "#CDAA81", "#CFAB83", "#D0AC86", "#D1AD89", "#D2AE8B", "#D3AF8E", "#D5B091", "#D6B194", "#D7B296", "#D8B399", "#D9B59C", "#DBB69F", "#DCB8A2", "#DDB9A5", "#DEBBA8", "#DFBCAA", "#E1BEAD", "#E2C0B0", "#E3C2B3", "#E4C4B6", "#E5C6B9", "#E7C8BD", "#E8CAC0", "#E9CCC3", "#EACEC6", "#EBD0C9", "#EDD3CC", "#EED5CF", "#EFD7D3", "#F0DAD6", "#F1DDD9", "#F3DFDC", "#F4E2E0", "#F5E5E3", "#F6E8E6", "#F7EBEA", "#F9EEED", "#FAF1F1", "#FBF4F4", "#FCF8F8", "#FDFBFB", "#FFFFFF"], "gist_gray": ["#000000", "#010101", "#020202", "#030303", "#040404", "#050505", "#060606", "#070707", "#090909", "#0A0A0A", "#0B0B0B", "#0C0C0C", "#0D0D0D", "#0E0E0E", "#0F0F0F", "#101010", "#111111", "#121212", "#131313", "#141414", "#151515", "#161616", "#171717", "#191919", "#1A1A1A", "#1B1B1B", "#1C1C1C", "#1D1D1D", "#1E1E1E", "#1F1F1F", "#202020", "#212121", "#222222", "#232323", "#242424", "#252525", "#262626", "#272727", "#292929", "#2A2A2A", "#2B2B2B", "#2C2C2C", "#2D2D2D", "#2E2E2E", "#2F2F2F", "#303030", "#313131", "#323232", "#333333", "#343434", "#353535", "#363636", "#373737", "#393939", "#3A3A3A", "#3B3B3B", "#3C3C3C", "#3D3D3D", "#3E3E3E", "#3F3F3F", "#404040", "#414141", "#424242", "#434343", "#444444", "#454545", "#464646", "#474747", "#494949", "#4A4A4A", "#4B4B4B", "#4C4C4C", "#4D4D4D", "#4E4E4E", "#4F4F4F", "#505050", "#515151", "#525252", "#535353", "#545454", "#555555", "#565656", "#575757", "#595959", "#5A5A5A", "#5B5B5B", "#5C5C5C", "#5D5D5D", "#5E5E5E", "#5F5F5F", "#606060", "#616161", "#626262", "#636363", "#646464", "#656565", "#666666", "#676767", "#696969", "#6A6A6A", "#6B6B6B", "#6C6C6C", "#6D6D6D", "#6E6E6E", "#6F6F6F", "#707070", "#717171", "#727272", "#737373", "#747474", "#757575", "#767676", "#777777", "#797979", "#7A7A7A", "#7B7B7B", "#7C7C7C", "#7D7D7D", "#7E7E7E", "#7F7F7F", "#808080", "#818181", "#828282", "#838383", "#848484", "#858585", "#868686", "#878787", "#898989", "#8A8A8A", "#8B8B8B", "#8C8C8C", "#8D8D8D", "#8E8E8E", "#8F8F8F", "#909090", "#919191", "#929292", "#939393", "#949494", "#959595", "#969696", "#979797", "#999999", "#9A9A9A", "#9B9B9B", "#9C9C9C", "#9D9D9D", "#9E9E9E", "#9F9F9F", "#A0A0A0", "#A1A1A1", "#A2A2A2", "#A3A3A3", "#A4A4A4", "#A5A5A5", "#A6A6A6", "#A7A7A7", "#A9A9A9", "#AAAAAA", "#ABABAB", "#ACACAC", "#ADADAD", "#AEAEAE", "#AFAFAF", "#B0B0B0", "#B1B1B1", "#B2B2B2", "#B3B3B3", "#B4B4B4", "#B5B5B5", "#B6B6B6", "#B7B7B7", "#B9B9B9", "#BABABA", "#BBBBBB", "#BCBCBC", "#BDBDBD", "#BEBEBE", "#BFBFBF", "#C0C0C0", "#C1C1C1", "#C2C2C2", "#C3C3C3", "#C4C4C4", "#C5C5C5", "#C6C6C6", "#C7C7C7", "#C9C9C9", "#CACACA", "#CBCBCB", "#CCCCCC", "#CDCDCD", "#CECECE", "#CFCFCF", "#D0D0D0", "#D1D1D1", "#D2D2D2", "#D3D3D3", "#D4D4D4", "#D5D5D5", "#D6D6D6", "#D7D7D7", "#D9D9D9", "#DADADA", "#DBDBDB", "#DCDCDC", "#DDDDDD", "#DEDEDE", "#DFDFDF", "#E0E0E0", "#E1E1E1", "#E2E2E2", "#E3E3E3", "#E4E4E4", "#E5E5E5", "#E6E6E6", "#E7E7E7", "#E9E9E9", "#EAEAEA", "#EBEBEB", "#ECECEC", "#EDEDED", "#EEEEEE", "#EFEFEF", "#F0F0F0", "#F1F1F1", "#F2F2F2", "#F3F3F3", "#F4F4F4", "#F5F5F5", "#F6F6F6", "#F7F7F7", "#F9F9F9", "#FAFAFA", "#FBFBFB", "#FCFCFC", "#FDFDFD", "#FEFEFE", "#FFFFFF"], "gist_heat": ["#000000", "#010000", "#020000", "#040000", "#050000", "#070000", "#080000", "#0A0000", "#0B0000", "#0D0000", "#0F0000", "#110000", "#120000", "#140000", "#150000", "#170000", "#180000", "#1A0000", "#1B0000", "#1C0000", "#1E0000", "#1F0000", "#210000", "#220000", "#240000", "#250000", "#270000", "#280000", "#2A0000", "#2B0000", "#2E0000", "#2F0000", "#310000", "#320000", "#340000", "#350000", "#370000", "#380000", "#390000", "#3B0000", "#3C0000", "#3E0000", "#3F0000", "#410000", "#420000", "#440000", "#450000", "#460000", "#480000", "#490000", "#4C0000", "#4E0000", "#4F0000", "#510000", "#520000", "#540000", "#550000", "#560000", "#580000", "#590000", "#5C0000", "#5E0000", "#5F0000", "#610000", "#620000", "#630000", "#650000", "#660000", "#680000", "#690000", "#6C0000", "#6E0000", "#6F0000", "#710000", "#720000", "#730000", "#750000", "#760000", "#780000", "#790000", "#7B0000", "#7C0000", "#7E0000", "#7F0000", "#800000", "#820000", "#830000", "#850000", "#860000", "#880000", "#8B0000", "#8C0000", "#8D0000", "#8F0000", "#900000", "#920000", "#930000", "#950000", "#960000", "#980000", "#990000", "#9B0000", "#9C0000", "#9D0000", "#9F0000", "#A00000", "#A20000", "#A30000", "#A50000", "#A60000", "#A90000", "#AA0000", "#AC0000", "#AD0000", "#AF0100", "#B00300", "#B20500", "#B30700", "#B50900", "#B60B00", "#B90F00", "#BA1100", "#BC1200", "#BD1400", "#BF1600", "#C01800", "#C21A00", "#C31C00", "#C51E00", "#C62000", "#C92300", "#CA2500", "#CC2700", "#CD2900", "#CF2B00", "#D02D00", "#D22F00", "#D33100", "#D43300", "#D63400", "#D73600", "#D93800", "#DA3A00", "#DC3C00", "#DD3E00", "#DF4000", "#E04200", "#E24400", "#E34500", "#E44700", "#E74B00", "#E94D00", "#EA4F00", "#EC5100", "#ED5300", "#EF5500", "#F05600", "#F15800", "#F35A00", "#F45C00", "#F65E00", "#F76000", "#F96200", "#FA6400", "#FC6600", "#FD6700", "#FF6900", "#FF6B00", "#FF6D00", "#FF6F00", "#FF7300", "#FF7500", "#FF7700", "#FF7800", "#FF7A00", "#FF7C00", "#FF7E00", "#FF8000", "#FF8200", "#FF8400", "#FF8807", "#FF890B", "#FF8B0F", "#FF8D13", "#FF8F17", "#FF911B", "#FF931F", "#FF9523", "#FF9727", "#FF992B", "#FF9C33", "#FF9E36", "#FFA03A", "#FFA23E", "#FFA442", "#FFA646", "#FFA84A", "#FFAA4E", "#FFAB52", "#FFAD56", "#FFAF5A", "#FFB15E", "#FFB362", "#FFB566", "#FFB769", "#FFB96D", "#FFBB71", "#FFBC75", "#FFBE79", "#FFC07D", "#FFC485", "#FFC689", "#FFC88D", "#FFCA91", "#FFCC95", "#FFCD99", "#FFCF9C", "#FFD1A0", "#FFD3A4", "#FFD5A8", "#FFD7AC", "#FFD9B0", "#FFDBB4", "#FFDDB8", "#FFDEBC", "#FFE0C0", "#FFE2C4", "#FFE4C8", "#FFE6CC", "#FFE8CF", "#FFECD7", "#FFEEDB", "#FFEFDF", "#FFF1E3", "#FFF3E7", "#FFF5EB", "#FFF7EF", "#FFF9F3", "#FFFBF7", "#FFFDFB"], "gist_ncar": ["#000080", "#000973", "#001367", "#001C5B", "#00264F", "#002F42", "#003936", "#00422A", "#004C1E", "#005512", "#005F05", "#005E0C", "#005525", "#004B3D", "#004255", "#00386E", "#002F86", "#00259E", "#001CB7", "#0012CF", "#0009E7", "#0000FF", "#0013FF", "#0025FF", "#0037FF", "#0049FF", "#005CFF", "#006EFF", "#0080FF", "#0092FF", "#00A5FF", "#00B7FF", "#00C2FF", "#00C8FF", "#00CEFF", "#00D4FF", "#00DAFF", "#00E1FF", "#00E7FF", "#00EDFF", "#00F3FF", "#00F9FF", "#00FEFD", "#00FEF4", "#00FDEA", "#00FDE1", "#00FDD7", "#00FCCD", "#00FCC4", "#00FBBA", "#00FBB0", "#00FAA7", "#00FA9D", "#00FA90", "#00FA82", "#00FB73", "#00FB64", "#00FC55", "#00FC47", "#00FD38", "#00FD29", "#00FE1B", "#00FE0C", "#01FE00", "#0BF900", "#15F400", "#1EEF00", "#28EB00", "#32E600", "#3BE100", "#45DC00", "#4FD800", "#59D300", "#62CE00", "#67D000", "#6AD500", "#6CD900", "#6EDE00", "#71E300", "#73E800", "#75EC00", "#78F100", "#7AF600", "#7DFB00", "#80FF01", "#86FF07", "#8CFF0D", "#92FF13", "#99FF18", "#9FFF1E", "#A5FF24", "#ABFF2A", "#B1FF30", "#B8FF36", "#BEFF3C", "#C4FF39", "#CAFF33", "#D0FF2D", "#D6FF27", "#DCFF21", "#E2FF1C", "#E8FF16", "#EEFF10", "#F4FF0A", "#FAFF04", "#FFFD00", "#FFFA00", "#FFF600", "#FFF200", "#FFEE00", "#FFEA00", "#FFE700", "#FFE300", "#FFDF00", "#FFDB00", "#FFD700", "#FFD401", "#FFD102", "#FFCF03", "#FFCC05", "#FFC906", "#FFC608", "#FFC309", "#FFC00B", "#FFBD0C", "#FFBA0E", "#FFB50E", "#FFAA0D", "#FF9F0B", "#FF940A", "#FF8908", "#FF7E07", "#FF7305", "#FF6704", "#FF5C03", "#FF5101", "#FF4600", "#FF3F00", "#FF3800", "#FF3200", "#FF2B00", "#FF2500", "#FF1E00", "#FF1700", "#FF1100", "#FF0A00", "#FF0400", "#FF0008", "#FF0021", "#FF0039", "#FF0052", "#FF006A", "#FF0082", "#FF009B", "#FF00B3", "#FF00CB", "#FF00E4", "#FF00FC", "#F604FF", "#EC08FF", "#E30DFF", "#D911FF", "#D016FF", "#C61BFF", "#BD1FFF", "#B324FF", "#AA28FF", "#A02DFF", "#9E33FE", "#A63BFC", "#AE42FB", "#B64AF9", "#BE52F7", "#C55AF6", "#CD62F4", "#D56AF2", "#DD71F1", "#E579EF", "#ED81EE", "#EE87EE", "#EF8DEF", "#EF92EF", "#F098F0", "#F19EF1", "#F1A4F1", "#F2A9F2", "#F3AFF3", "#F3B5F3", "#F4BAF4", "#F5C0F5", "#F6C7F6", "#F7CDF7", "#F8D3F8", "#F9D9F9", "#FADFFA", "#FBE6FB", "#FCECFC", "#FDF2FD", "#FEF8FE", "#FFFFFF"], "gist_rainbow": ["#FF002A", "#FF0024", "#FF001F", "#FF001A", "#FF0014", "#FF000F", "#FF000A", "#FF0004", "#FF0500", "#FF0B00", "#FF1000", "#FF1600", "#FF1B00", "#FF2000", "#FF2600", "#FF2B00", "#FF3000", "#FF3600", "#FF3B00", "#FF4100", "#FF4600", "#FF4B00", "#FF5100", "#FF5B00", "#FF6100", "#FF6600", "#FF6C00", "#FF7100", "#FF7600", "#FF7C00", "#FF8100", "#FF8700", "#FF8C00", "#FF9100", "#FF9700", "#FF9C00", "#FFA100", "#FFA700", "#FFB200", "#FFB700", "#FFBC00", "#FFC200", "#FFC700", "#FFCC00", "#FFD200", "#FFD700", "#FFDD00", "#FFE200", "#FFE700", "#FFED00", "#FFF200", "#FFF700", "#FFFD00", "#F5FF00", "#F0FF00", "#EBFF00", "#E5FF00", "#E0FF00", "#DBFF00", "#D5FF00", "#D0FF00", "#CAFF00", "#C5FF00", "#C0FF00", "#BAFF00", "#B5FF00", "#AFFF00", "#AAFF00", "#9FFF00", "#9AFF00", "#95FF00", "#8FFF00", "#8AFF00", "#84FF00", "#7FFF00", "#7AFF00", "#74FF00", "#6FFF00", "#6AFF00", "#64FF00", "#5FFF00", "#59FF00", "#54FF00", "#49FF00", "#44FF00", "#3FFF00", "#39FF00", "#34FF00", "#2EFF00", "#29FF00", "#24FF00", "#1EFF00", "#19FF00", "#13FF00", "#0EFF00", "#09FF00", "#03FF00", "#00FF01", "#00FF0C", "#00FF11", "#00FF17", "#00FF1C", "#00FF21", "#00FF27", "#00FF2C", "#00FF31", "#00FF37", "#00FF3C", "#00FF42", "#00FF47", "#00FF4C", "#00FF52", "#00FF57", "#00FF62", "#00FF67", "#00FF6D", "#00FF72", "#00FF77", "#00FF7D", "#00FF82", "#00FF87", "#00FF8D", "#00FF92", "#00FF98", "#00FF9D", "#00FFA2", "#00FFA8", "#00FFAD", "#00FFB8", "#00FFBD", "#00FFC3", "#00FFC8", "#00FFCD", "#00FFD3", "#00FFD8", "#00FFDE", "#00FFE3", "#00FFE8", "#00FFEE", "#00FFF3", "#00FFF8", "#00FFFE", "#00FAFF", "#00EFFF", "#00EAFF", "#00E4FF", "#00DFFF", "#00DAFF", "#00D4FF", "#00CFFF", "#00C9FF", "#00C4FF", "#00BFFF", "#00B9FF", "#00B4FF", "#00AEFF", "#00A9FF", "#00A4FF", "#0099FF", "#0094FF", "#008EFF", "#0089FF", "#0083FF", "#007EFF", "#0079FF", "#0073FF", "#006EFF", "#0069FF", "#0063FF", "#005EFF", "#0058FF", "#0053FF", "#004EFF", "#0043FF", "#003EFF", "#0038FF", "#0033FF", "#002DFF", "#0028FF", "#0023FF", "#001DFF", "#0018FF", "#0012FF", "#000DFF", "#0008FF", "#0002FF", "#0200FF", "#0700FF", "#1200FF", "#1800FF", "#1D00FF", "#2200FF", "#2800FF", "#2D00FF", "#3200FF", "#3800FF", "#3D00FF", "#4300FF", "#4800FF", "#4D00FF", "#5300FF", "#5800FF", "#5D00FF", "#6800FF", "#6E00FF", "#7300FF", "#7800FF", "#7E00FF", "#8300FF", "#8800FF", "#8E00FF", "#9300FF", "#9900FF", "#9E00FF", "#A300FF", "#A900FF", "#AE00FF", "#B400FF", "#BE00FF", "#C400FF", "#C900FF", "#CE00FF", "#D400FF", "#D900FF", "#DF00FF", "#E400FF", "#E900FF", "#EF00FF", "#F400FF", "#F900FF", "#FF00FE", "#FF00F9", "#FF00F3", "#FF00E9", "#FF00E3", "#FF00DE", "#FF00D9", "#FF00D3", "#FF00CE", "#FF00C9"], "gist_stern": ["#000000", "#120101", "#240203", "#360305", "#480407", "#5A0509", "#6C060B", "#7F070D", "#91080F", "#A30911", "#C70B15", "#D90C17", "#EB0D19", "#FE0E1B", "#F90F1D", "#F4101F", "#EF1121", "#EA1223", "#E51325", "#DF1427", "#DA1529", "#D5162B", "#D0172D", "#CB182F", "#C51931", "#C01A33", "#BB1B35", "#B61C37", "#B11D39", "#AC1E3B", "#A1203F", "#9C2141", "#972243", "#922345", "#8C2447", "#872549", "#82264B", "#7D274D", "#78284F", "#732951", "#6D2A53", "#682B55", "#632C57", "#5E2D59", "#592E5B", "#532F5D", "#4E305F", "#493161", "#443263", "#3F3365", "#343569", "#2F366B", "#2A376D", "#25386F", "#203971", "#1A3A73", "#153B75", "#103C77", "#0B3D79", "#063E7B", "#40407F", "#414181", "#424283", "#434385", "#444487", "#454589", "#46468B", "#47478D", "#48488F", "#494991", "#4B4B95", "#4C4C97", "#4D4D99", "#4E4E9B", "#4F4F9D", "#50509F", "#5151A1", "#5252A3", "#5353A5", "#5454A7", "#5555A9", "#5656AB", "#5757AD", "#5858AF", "#5959B1", "#5A5AB3", "#5B5BB5", "#5C5CB7", "#5D5DB9", "#5E5EBB", "#6060BF", "#6161C1", "#6262C3", "#6363C5", "#6464C7", "#6565C9", "#6666CB", "#6767CD", "#6868CF", "#6969D1", "#6A6AD3", "#6B6BD5", "#6C6CD7", "#6D6DD9", "#6E6EDB", "#6F6FDD", "#7070DF", "#7171E1", "#7272E3", "#7373E5", "#7575E9", "#7676EB", "#7777ED", "#7878EF", "#7979F1", "#7A7AF3", "#7B7BF5", "#7C7CF7", "#7D7DF9", "#7E7EFB", "#8080FF", "#8181FB", "#8282F7", "#8383F3", "#8484EE", "#8585EA", "#8686E6", "#8787E2", "#8888DD", "#8989D9", "#8B8BD1", "#8C8CCC", "#8D8DC8", "#8E8EC4", "#8F8FC0", "#9090BB", "#9191B7", "#9292B3", "#9393AF", "#9494AA", "#9595A6", "#9696A2", "#97979E", "#989899", "#999995", "#9A9A91", "#9B9B8D", "#9C9C88", "#9D9D84", "#9E9E80", "#A0A077", "#A1A173", "#A2A26F", "#A3A36B", "#A4A466", "#A5A562", "#A6A65E", "#A7A75A", "#A8A855", "#A9A951", "#AAAA4D", "#ABAB49", "#ACAC44", "#ADAD40", "#AEAE3C", "#AFAF38", "#B0B033", "#B1B12F", "#B2B22B", "#B3B327", "#B5B51E", "#B6B61A", "#B7B716", "#B8B811", "#B9B90D", "#BABA09", "#BBBB05", "#BCBC00", "#BDBD03", "#BEBE07", "#C0C00F", "#C1C113", "#C2C216", "#C3C31A", "#C4C41E", "#C5C522", "#C6C626", "#C7C729", "#C8C82D", "#C9C931", "#CBCB39", "#CCCC3C", "#CDCD40", "#CECE44", "#CFCF48", "#D0D04C", "#D1D14F", "#D2D253", "#D3D357", "#D4D45B", "#D5D55F", "#D6D662", "#D7D766", "#D8D86A", "#D9D96E", "#DADA72", "#DBDB75", "#DCDC79", "#DDDD7D", "#DEDE81", "#E0E089", "#E1E18C", "#E2E290", "#E3E394", "#E4E498", "#E5E59C", "#E6E69F", "#E7E7A3", "#E8E8A7", "#E9E9AB", "#EAEAAF", "#EBEBB2", "#ECECB6", "#EDEDBA", "#EEEEBE", "#EFEFC2", "#F0F0C5", "#F1F1C9", "#F2F2CD", "#F3F3D1", "#F5F5D8", "#F6F6DC", "#F7F7E0", "#F8F8E4", "#F9F9E8", "#FAFAEB", "#FBFBEF", "#FCFCF3", "#FDFDF7", "#FEFEFB"], "gmt_GMT_abyss": ["#000000", "#141E35", "#263C6A", "#2E5085", "#3563A0", "#4897D3", "#5AB9E9", "#8DD2EF", "#F5FFFF"], "gmt_GMT_bathy": ["#000000", "#1F284F", "#263C6A", "#3563A0", "#4897D3", "#66CDAA", "#8DD2EF", "#F5FFFF"], "gmt_GMT_cool": ["#00FFFF", "#FF00FF"], "gmt_GMT_copper": ["#000000", "#FF9F66", "#FFC880"], "gmt_GMT_cubhelix": ["#000000", "#010001", "#030103", "#040104", "#060206", "#080208", "#090309", "#0A040B", "#0C040D", "#0D050F", "#0E0611", "#0F0613", "#110715", "#120817", "#130919", "#140A1B", "#140B1D", "#150B1F", "#160C21", "#170D23", "#170E25", "#180F27", "#181129", "#19122B", "#19132D", "#19142F", "#1A1530", "#1A1632", "#1A1834", "#1A1936", "#1A1A38", "#1A1C39", "#1A1D3B", "#1A1F3C", "#1A203E", "#1A223F", "#1A2341", "#192542", "#192643", "#192845", "#192946", "#182B47", "#182D48", "#182E49", "#17304A", "#17324A", "#17344B", "#17354C", "#16374C", "#16394D", "#163A4D", "#153C4D", "#153E4E", "#15404E", "#15424E", "#15434E", "#15454E", "#14474E", "#14494E", "#144A4D", "#154C4D", "#154E4D", "#154F4C", "#15514C", "#15534B", "#16544B", "#16564A", "#165849", "#175949", "#175B48", "#185C47", "#195E46", "#1A5F45", "#1B6144", "#1B6243", "#1C6342", "#1E6542", "#1F6641", "#206740", "#21683F", "#236A3D", "#246B3C", "#266C3B", "#276D3A", "#296E3A", "#2B6F39", "#2D7038", "#2F7137", "#317236", "#337235", "#357334", "#377433", "#397433", "#3C7532", "#3E7631", "#417631", "#437730", "#467730", "#48782F", "#4B782F", "#4E782F", "#51792E", "#53792E", "#56792E", "#59792E", "#5C7A2E", "#5F7A2F", "#627A2F", "#657A2F", "#687A30", "#6B7A30", "#6E7A31", "#717A32", "#747A32", "#787A33", "#7B7A34", "#7E7A35", "#817A37", "#847A38", "#877A39", "#8A793B", "#8D793C", "#90793E", "#937940", "#967941", "#997943", "#9B7945", "#9E7947", "#A1794A", "#A4784C", "#A6784E", "#A97851", "#AB7853", "#AE7856", "#B07858", "#B2785B", "#B5785E", "#B77860", "#B97863", "#BB7966", "#BD7969", "#BF796C", "#C1796F", "#C27972", "#C47A75", "#C67A78", "#C77A7C", "#C97B7F", "#CA7B82", "#CB7C85", "#CC7C88", "#CD7D8C", "#CE7D8F", "#CF7E92", "#D07F95", "#D17F99", "#D1809C", "#D2819F", "#D382A2", "#D383A5", "#D383A9", "#D484AC", "#D485AF", "#D487B2", "#D488B5", "#D489B8", "#D48ABA", "#D48BBD", "#D48CC0", "#D38EC3", "#D38FC5", "#D390C8", "#D292CB", "#D293CD", "#D295CF", "#D196D2", "#D098D4", "#D09AD6", "#CF9BD8", "#CF9DDA", "#CE9EDC", "#CDA0DE", "#CDA2E0", "#CCA4E2", "#CBA5E3", "#CBA7E5", "#CAA9E6", "#C9ABE7", "#C9ACE9", "#C8AEEA", "#C7B0EB", "#C7B2EC", "#C6B4ED", "#C5B6EE", "#C5B7EF", "#C4B9EF", "#C4BBF0", "#C3BDF1", "#C3BFF1", "#C2C1F2", "#C2C2F2", "#C2C4F2", "#C1C6F3", "#C1C8F3", "#C1CAF3", "#C1CBF3", "#C1CDF3", "#C1CFF3", "#C1D0F3", "#C1D2F3", "#C1D4F3", "#C1D5F3", "#C2D7F2", "#C2D8F2", "#C3DAF2", "#C3DBF2", "#C4DDF1", "#C4DEF1", "#C5E0F1", "#C6E1F1", "#C7E2F0", "#C8E4F0", "#C8E5F0", "#CAE6EF", "#CBE7EF", "#CCE8EF", "#CDE9EF", "#CEEBEF", "#D0ECEE", "#D1EDEE", "#D2EEEE", "#D4EFEE", "#D5F0EE", "#D7F0EE", "#D9F1EE", "#DAF2EE", "#DCF3EF", "#DEF4EF", "#DFF4EF", "#E1F5F0", "#E3F6F0", "#E5F7F0", "#E7F7F1", "#E8F8F2", "#EAF8F2", "#ECF9F3", "#EEFAF4", "#F0FAF5", "#F2FBF6", "#F4FBF7", "#F5FCF8", "#F7FCF9", "#F9FDFA", "#FBFDFC", "#FDFEFD", "#FFFFFF"], "gmt_GMT_dem1": ["#336600", "#81C31F", "#FFFFCC", "#F4BD45", "#66330C", "#663300", "#FFFFFF"], "gmt_GMT_dem2": ["#006147", "#107A2F", "#E8D77D", "#A14300", "#643219", "#6E6E6E", "#FFFFFF", "#FFFFFF"], "gmt_GMT_dem3": ["#3CB371", "#DEB887", "#CD6600", "#8B4513", "#EED5B7", "#EEEEE0", "#FFFAFA"], "gmt_GMT_dem4": ["#AEEFD5", "#AFF0D3", "#B0F2D0", "#B0F2CA", "#B1F2C4", "#B0F3BE", "#B0F4BA", "#B2F6B5", "#B5F6B2", "#BAF7B2", "#C0F7B2", "#C6F8B2", "#CCF9B2", "#D2FAB1", "#D9FAB2", "#E0FBB2", "#E7FCB2", "#EEFCB3", "#F5FCB3", "#FAFCB2", "#F8F9AC", "#EEF4A2", "#E2F097", "#D5EB8C", "#C6E480", "#B8DE76", "#AAD86C", "#9AD362", "#8CCD59", "#7DC752", "#6EC24A", "#5EBC42", "#4DB639", "#3EB032", "#31AB2C", "#27A52A", "#1EA02B", "#189A2E", "#129431", "#0E8E34", "#098938", "#07843C", "#0C823F", "#18823F", "#28843D", "#34883C", "#408C3B", "#4C8E3B", "#579238", "#639436", "#6E9634", "#789A32", "#809C30", "#89A02E", "#93A22B", "#9CA429", "#A6A627", "#B0AA24", "#BBAD22", "#C5B01E", "#CFB11C", "#DAB318", "#E4B414", "#EEB60E", "#F6B608", "#F8B004", "#F4A602", "#EE9B02", "#E89002", "#E28402", "#DC7A02", "#D86F02", "#D36602", "#CE5C02", "#C85402", "#C04A02", "#BA4202", "#B43A02", "#AE3102", "#A92A02", "#A32402", "#9D1E02", "#971702", "#921201", "#8D0E01", "#870800", "#820500", "#7D0400", "#7A0802", "#770D02", "#761002", "#751204", "#751404", "#751504", "#741604", "#741805", "#721A06", "#721D06", "#701F07", "#6F2108", "#6E2308", "#6E2408", "#6D2609", "#6C280A", "#6C280A", "#6C2A0A", "#6B2C0B", "#6A2C0C", "#6A2E0C", "#6B300E", "#6E3412", "#713917", "#743E1C", "#764220", "#794625", "#7D4A2B", "#804F32", "#835538", "#875A3F", "#8A6045", "#8C654C", "#906A54", "#936F5A", "#967460", "#987A68", "#9C8170", "#9E8778", "#A08D82", "#A3938B", "#A69A93", "#A7A09C", "#AAA7A4", "#ACACAB", "#AEAEAE", "#B2B2B2", "#B5B5B5", "#B8B8B8", "#BCBCBC", "#C0C0C0", "#C4C4C4", "#C8C8C8", "#CCCCCC", "#D0CED0", "#D4D2D4", "#D8D6D8", "#DAD8DA", "#DDDBDD", "#E1DFE1", "#E5E3E5", "#E9E7E9", "#EBE9EB"], "gmt_GMT_drywet": ["#86612A", "#EEC764", "#B4EE87", "#32EEEB", "#0C78EE", "#2601B7", "#083371"], "gmt_GMT_elevation": ["#699885", "#76A992", "#83B59B", "#A5C0A7", "#D3C9B3", "#D4B8A4", "#D4C0B5", "#D6D1CE", "#DEDDDE", "#EEEEEE", "#F6F7F6"], "gmt_GMT_gebco": ["#00F0FF", "#00F0FF", "#23FFFF", "#23FFFF", "#5AFFFF", "#5AFFFF", "#8CFFE6", "#8CFFE6", "#A5FFD7", "#A5FFD7", "#C3FFD7", "#C3FFD7", "#D2FFD7", "#D2FFD7", "#E6FFF0", "#E6FFF0", "#EBFFFF", "#EBFFFF"], "gmt_GMT_globe": ["#9900FF", "#9900FF", "#9900FF", "#9900FF", "#8811FF", "#8811FF", "#7722FF", "#7722FF", "#6633FF", "#6633FF", "#5544FF", "#5544FF", "#4455FF", "#4455FF", "#3366FF", "#3366FF", "#2277FF", "#2277FF", "#1188FF", "#1188FF", "#0099FF", "#0099FF", "#1BA4FF", "#1BA4FF", "#36AFFF", "#36AFFF", "#51BAFF", "#51BAFF", "#6CC5FF", "#6CC5FF", "#86D0FF", "#86D0FF", "#A1DBFF", "#A1DBFF", "#BCE6FF", "#BCE6FF", "#D7F1FF", "#D7F1FF", "#F1FCFF", "#F1FCFF", "#336600", "#33CC66", "#BBE492", "#FFDCB9", "#F3CA89", "#E6B858", "#D9A627", "#A89A1F", "#A49019", "#A28613", "#9F7B0D", "#9C7107", "#996600", "#A25959", "#B27676", "#B79393", "#C2B0B0", "#CCCCCC", "#E5E5E5", "#F2F2F2", "#FFFFFF", "#FFFFFF", "#FFFFFF"], "gmt_GMT_haxby": ["#0A0079", "#0A0079", "#280096", "#280096", "#1405AF", "#1405AF", "#000AC8", "#000AC8", "#0019D4", "#0019D4", "#0028E0", "#0028E0", "#1A66F0", "#1A66F0", "#0D81F8", "#0D81F8", "#19AFFF", "#19AFFF", "#32BEFF", "#32BEFF", "#44CAFF", "#44CAFF", "#61E1F0", "#61E1F0", "#6AEBE1", "#6AEBE1", "#7CEBC8", "#7CEBC8", "#8AECAE", "#8AECAE", "#ACF5A8", "#ACF5A8", "#CDFFA2", "#CDFFA2", "#DFF58D", "#DFF58D", "#F0EC79", "#F0EC79", "#F7D768", "#F7D768", "#FFBD57", "#FFBD57", "#FFA045", "#FFA045", "#F4754B", "#F4754B", "#EE504E", "#EE504E", "#FF5A5A", "#FF5A5A", "#FF7C7C", "#FF7C7C", "#FF9E9E", "#FF9E9E", "#F5B3AE", "#F5B3AE", "#FFC4C4", "#FFC4C4", "#FFD7D7", "#FFD7D7", "#FFEBEB", "#FFEBEB", "#FFFFFF", "#FFFFFF"], "gmt_GMT_hot": ["#000000", "#FF0000", "#FFFF00", "#FFFFFF"], "gmt_GMT_ibcso": ["#1F284F", "#1F284F", "#263C6A", "#263C6A", "#2E5085", "#2E5085", "#3563A0", "#3563A0", "#3C77BC", "#3C77BC", "#4897D3", "#4897D3", "#5AB9E9", "#5AB9E9", "#5FC6F2", "#5FC6F2", "#72CAEE", "#72CAEE", "#8DD2EF", "#8DD2EF"], "gmt_GMT_jet": ["#00007F", "#0000FF", "#00FFFF", "#FFFFFF", "#FFFF7F", "#FFFF00", "#FF0000", "#7F0000"], "gmt_GMT_nighttime": ["#08001A", "#3F798C", "#868C3F", "#FFE6E6"], "gmt_GMT_no_green": ["#2060FF", "#2060FF", "#209FFF", "#209FFF", "#20BFFF", "#20BFFF", "#00CFFF", "#00CFFF", "#2AFFFF", "#2AFFFF", "#55FFFF", "#55FFFF", "#7FFFFF", "#7FFFFF", "#AAFFFF", "#AAFFFF", "#FFFF54", "#FFFF54", "#FFF000", "#FFF000", "#FFBF00", "#FFBF00", "#FFA800", "#FFA800", "#FF8A00", "#FF8A00", "#FF7000", "#FF7000", "#FF4D00", "#FF4D00", "#FF0000", "#FF0000"], "gmt_GMT_ocean": ["#000000", "#000519", "#000A32", "#00507D", "#0096C8", "#56C5B8", "#ACF5A8", "#D3FAD3", "#FAFFFF"], "gmt_GMT_panoply": ["#040ED8", "#040ED8", "#2050FF", "#2050FF", "#4196FF", "#4196FF", "#6DC1FF", "#6DC1FF", "#86D9FF", "#86D9FF", "#9CEEFF", "#9CEEFF", "#AFF5FF", "#AFF5FF", "#CEFFFF", "#CEFFFF", "#FFFE47", "#FFFE47", "#FFEB00", "#FFEB00", "#FFC400", "#FFC400", "#FF9000", "#FF9000", "#FF4800", "#FF4800", "#FF0000", "#FF0000", "#D50000", "#D50000", "#9E0000", "#9E0000"], "gmt_GMT_polar": ["#0000FF", "#FFFFFF", "#FF0000"], "gmt_GMT_rainbow": ["#FF00FF", "#FB00FF", "#F700FF", "#F200FF", "#EE00FF", "#EA00FF", "#E600FF", "#E100FF", "#DD00FF", "#D900FF", "#D500FF", "#D000FF", "#CC00FF", "#C800FF", "#C300FF", "#BF00FF", "#BB00FF", "#B700FF", "#B300FF", "#AE00FF", "#AA00FF", "#A600FF", "#A200FF", "#9D00FF", "#9900FF", "#9500FF", "#9000FF", "#8C00FF", "#8800FF", "#8400FF", "#8000FF", "#7B00FF", "#7700FF", "#7300FF", "#6F00FF", "#6A00FF", "#6600FF", "#6200FF", "#5D00FF", "#5900FF", "#5500FF", "#5100FF", "#4C00FF", "#4800FF", "#4400FF", "#4000FF", "#3C00FF", "#3700FF", "#3300FF", "#2F00FF", "#2A00FF", "#2600FF", "#2200FF", "#1E00FF", "#1900FF", "#1500FF", "#1100FF", "#0D00FF", "#0800FF", "#0400FF", "#0000FF", "#0004FF", "#0008FF", "#000DFF", "#0011FF", "#0015FF", "#0019FF", "#001EFF", "#0022FF", "#0026FF", "#002BFF", "#002FFF", "#0033FF", "#0037FF", "#003CFF", "#0040FF", "#0044FF", "#0048FF", "#004CFF", "#0051FF", "#0055FF", "#0059FF", "#005EFF", "#0062FF", "#0066FF", "#006AFF", "#006FFF", "#0073FF", "#0077FF", "#007BFF", "#0080FF", "#0084FF", "#0088FF", "#008CFF", "#0091FF", "#0095FF", "#0099FF", "#009DFF", "#00A2FF", "#00A6FF", "#00AAFF", "#00AEFF", "#00B2FF", "#00B7FF", "#00BBFF", "#00BFFF", "#00C3FF", "#00C8FF", "#00CCFF", "#00D0FF", "#00D4FF", "#00D9FF", "#00DDFF", "#00E1FF", "#00E5FF", "#00EAFF", "#00EEFF", "#00F2FF", "#00F7FF", "#00FBFF", "#00FFFF", "#00FFFB", "#00FFF7", "#00FFF2", "#00FFEE", "#00FFEA", "#00FFE5", "#00FFE1", "#00FFDD", "#00FFD9", "#00FFD4", "#00FFD0", "#00FFCC", "#00FFC8", "#00FFC3", "#00FFBF", "#00FFBB", "#00FFB7", "#00FFB3", "#00FFAE", "#00FFAA", "#00FFA6", "#00FFA2", "#00FF9D", "#00FF99", "#00FF95", "#00FF90", "#00FF8C", "#00FF88", "#00FF84", "#00FF80", "#00FF7B", "#00FF77", "#00FF73", "#00FF6F", "#00FF6A", "#00FF66", "#00FF62", "#00FF5E", "#00FF59", "#00FF55", "#00FF51", "#00FF4D", "#00FF48", "#00FF44", "#00FF40", "#00FF3C", "#00FF37", "#00FF33", "#00FF2F", "#00FF2A", "#00FF26", "#00FF22", "#00FF1E", "#00FF19", "#00FF15", "#00FF11", "#00FF0D", "#00FF08", "#00FF04", "#00FF00", "#04FF00", "#08FF00", "#0DFF00", "#11FF00", "#15FF00", "#1AFF00", "#1EFF00", "#22FF00", "#26FF00", "#2AFF00", "#2FFF00", "#33FF00", "#37FF00", "#3CFF00", "#40FF00", "#44FF00", "#48FF00", "#4DFF00", "#51FF00", "#55FF00", "#59FF00", "#5EFF00", "#62FF00", "#66FF00", "#6AFF00", "#6EFF00", "#73FF00", "#77FF00", "#7BFF00", "#80FF00", "#84FF00", "#88FF00", "#8CFF00", "#90FF00", "#95FF00", "#99FF00", "#9DFF00", "#A2FF00", "#A6FF00", "#AAFF00", "#AEFF00", "#B2FF00", "#B7FF00", "#BBFF00", "#BFFF00", "#C3FF00", "#C8FF00", "#CCFF00", "#D0FF00", "#D4FF00", "#D9FF00", "#DDFF00", "#E1FF00", "#E6FF00", "#EAFF00", "#EEFF00", "#F2FF00", "#F7FF00", "#FBFF00", "#FFFF00", "#FFFB00", "#FFF700", "#FFF200", "#FFEE00", "#FFEA00", "#FFE500", "#FFE100", "#FFDD00", "#FFD900", "#FFD400", "#FFD000", "#FFCC00", "#FFC800", "#FFC300", "#FFBF00", "#FFBB00", "#FFB700", "#FFB200", "#FFAE00", "#FFAA00", "#FFA600", "#FFA200", "#FF9D00", "#FF9900", "#FF9500", "#FF9000", "#FF8C00", "#FF8800", "#FF8400", "#FF8000", "#FF7B00", "#FF7700", "#FF7300", "#FF6E00", "#FF6A00", "#FF6600", "#FF6200", "#FF5E00", "#FF5900", "#FF5500", "#FF5100", "#FF4D00", "#FF4800", "#FF4400", "#FF4000", "#FF3C00", "#FF3700", "#FF3300", "#FF2F00", "#FF2A00", "#FF2600", "#FF2200", "#FF1E00", "#FF1900", "#FF1500", "#FF1100", "#FF0D00", "#FF0800", "#FF0400", "#FF0000"], "gmt_GMT_red2green": ["#FF0000", "#FFFFFF", "#00FF00"], "gmt_GMT_relief": ["#000000", "#000519", "#000A32", "#00507D", "#0096C8", "#56C5B8", "#ACF5A8", "#D3FAD3", "#FAFFFF", "#467832", "#786432", "#927E3C", "#C6B250", "#FAE664", "#FAEA7E", "#FCEE98", "#FCF3B1", "#FDF9D8", "#FFFFFF"], "gmt_GMT_seafloor": ["#6900B6", "#6E00BC", "#7300C1", "#7800C9", "#6D0ECC", "#611CCF", "#542AD2", "#4739D6", "#3A48D9", "#2C58DC", "#1E68DF", "#0F79E2", "#008AE6", "#1996E9", "#32A2EC", "#4CAEEF", "#67BBF2", "#81C8F5", "#9DD6F9", "#BAE3FC", "#D7F1FF", "#F1FCFF"], "gmt_GMT_sealand": ["#8C66FF", "#6666FF", "#668CFF", "#66B2FF", "#66D9FF", "#66FFFF", "#66FFD9", "#66FFB2", "#66FF8C", "#66FF66", "#8CFF66", "#B2FF66", "#D9FF66", "#FFFFA6", "#FFE1A6", "#FFC3A6", "#FFA6A6", "#FFB2C6", "#FFBFDF", "#FFCCF2"], "gmt_GMT_seis": ["#AA0000", "#FF0000", "#FF5500", "#FFAA00", "#FFFF00", "#FFFF00", "#5AFF1E", "#00F06E", "#0050FF", "#0000CD"], "gmt_GMT_split": ["#8080FF", "#000080", "#000000", "#800000", "#FF8080"], "gmt_GMT_topo": ["#C877D9", "#A077D9", "#B08AE6", "#8A8AE6", "#8AA8E6", "#8AC8E6", "#91F2EA", "#85F2BC", "#85F28E", "#ABF285", "#D7F285", "#F2E085", "#F2B385", "#D99A8D", "#D9A3A3", "#CC9999", "#74A3B2", "#6BB29B", "#62B269", "#90CC70", "#B5CC70", "#E6D895", "#FFF0E6", "#FFF8F2", "#FFFFFF"], "gmt_GMT_wysiwyg": ["#400040", "#400040", "#4000C0", "#4000C0", "#0040FF", "#0040FF", "#0080FF", "#0080FF", "#00A0FF", "#00A0FF", "#40C0FF", "#40C0FF", "#40E0FF", "#40E0FF", "#40FFFF", "#40FFFF", "#40FFC0", "#40FFC0", "#40FF40", "#40FF40", "#80FF40", "#80FF40", "#C0FF40", "#C0FF40", "#FFFF40", "#FFFF40", "#FFE040", "#FFE040", "#FFA040", "#FFA040", "#FF6040", "#FF6040", "#FF2040", "#FF2040", "#FF60C0", "#FF60C0", "#FFA0FF", "#FFA0FF", "#FFE0FF", "#FFE0E1"], "grass_aspect": ["#000000", "#FFFFFF", "#000000"], "grass_aspectcolr": ["#FFFFFF", "#FFFF00", "#00FF00", "#00FFFF", "#FF0000", "#FFFF00"], "grass_bcyr": ["#0000FF", "#00FFFF", "#FFFF00", "#FF0000"], "grass_bgyr": ["#0000FF", "#00FF00", "#FFFF00", "#FF0000"], "grass_byg": ["#0000FF", "#FFFF00", "#00FF00"], "grass_byr": ["#0000FF", "#FFFF00", "#FF0000"], "grass_celsius": ["#000028", "#5B0AA8", "#DCDCDC", "#5B3280", "#320096", "#041982", "#08366A", "#041496", "#0032FF", "#080A76", "#08719B", "#08769D", "#087B9E", "#08809F", "#08859F", "#0888A0", "#088CA2", "#0891A3", "#0896A5", "#089CA6", "#08A1A7", "#08A6A9", "#08ACAC", "#08B1B1", "#08B6B6", "#08BBBB", "#08C0C0", "#08C5C5", "#08C8C8", "#08CCCC", "#08D1D1", "#08D5D5", "#08D8D8", "#08DBDB", "#08DEDE", "#08E1E1", "#08E3E3", "#08E6E6", "#08E9E9", "#08EBEB", "#08EDEC", "#08EEEA", "#08EEE5", "#08EEDF", "#08EDD8", "#08EBD1", "#08EACA", "#08E8C0", "#08E7B2", "#08E6A2", "#08E593", "#08E385", "#08E27B", "#08E074", "#08DD72", "#08DB72", "#08D873", "#08D575", "#08D176", "#08CC76", "#08C775", "#08C173", "#08BC70", "#08B86B", "#08B563", "#08B25B", "#08AF54", "#08AC51", "#08A950", "#08A450", "#089F50", "#089950", "#08944F", "#088F4F", "#088A4F", "#08864E", "#08844B", "#088646", "#08893F", "#088C38", "#088C30", "#088B25", "#098A18", "#0E8B0E", "#188D09", "#259208", "#2F9708", "#349C08", "#37A108", "#39A608", "#3CAC08", "#41B108", "#46B608", "#4BBB08", "#50C008", "#55C408", "#59C708", "#5FC908", "#67CC08", "#6ECE08", "#76D108", "#7ED308", "#86D608", "#8ED908", "#97DB08", "#A0DE08", "#A9E108", "#B3E308", "#BBE508", "#C3E608", "#CDE608", "#D7E608", "#DFE508", "#E2E308", "#E1E008", "#E0DD08", "#E0D908", "#E0D308", "#E0CD08", "#E0C608", "#E0BF08", "#E0B908", "#E0B408", "#E0AE08", "#E0A608", "#E09F08", "#E09708", "#E08F08", "#E08708", "#E07F08", "#E07708", "#E06F08", "#E06708", "#E05F08", "#E05908", "#E05408", "#E04E08", "#DF4608", "#DF3F08", "#DF3708", "#DE2E08", "#DD2508", "#DB1C08", "#D81308", "#D50C08", "#D10908", "#CC0808", "#C80808", "#C40808", "#BE0808", "#B60808", "#AF0808", "#A70808", "#9F0808", "#970808", "#8F0808", "#870808", "#7F0808", "#780808", "#730808", "#6E0808", "#680808", "#6C0D0D", "#701313", "#721616", "#731A1A", "#761E1E", "#772221", "#792626", "#7B2929", "#7D2D2D", "#7F3131", "#803435", "#823838", "#843C3C", "#86403F", "#884343", "#8A4746", "#8C4B4A", "#8E4F4E", "#8F5252", "#915555", "#93595A", "#955D5D", "#966161", "#986464", "#9A6868", "#9C6B6C", "#9E706F", "#A07373", "#A27777", "#A47B7B", "#A57E7E", "#A88282", "#A98686", "#AA8A89", "#AD8D8D", "#AF9191", "#B09595", "#B29999", "#B59C9C", "#B69F9F", "#B7A3A3", "#B9A7A7", "#BCAAAB", "#BEAEAE", "#BFB2B2", "#C1B6B6", "#C3B9B9", "#C5BDBD", "#C7C0C1", "#C8C5C5", "#CAC8C9", "#CCCCCC", "#CECECE", "#9B0A9B"], "grass_differences": ["#0000FF", "#FFFFFF", "#FF0000"], "grass_elevation": ["#00BFBF", "#00FF00", "#FFFF00", "#FF7F00", "#BF7F3F", "#141414"], "grass_etopo2": ["#000000", "#000064", "#3232C8", "#9696FF", "#009600", "#5AA55A", "#5AAF5A", "#32B432", "#46AA46", "#46914B", "#469B4B", "#969C64", "#DCDCDC", "#F5F5F5", "#FFFFFF"], "grass_evi": ["#051852", "#051852", "#FFFFFF", "#FFFFFF", "#CEC5B4", "#BFA37C", "#A08650", "#8FAC38", "#A4C224", "#89B604", "#77B001", "#63A402", "#4A970D", "#298509", "#007200", "#005A00", "#004C00", "#003900", "#002000", "#010F02", "#000000"], "grass_gdd": ["#8000FF", "#0000FF", "#00FF00", "#FFFF00", "#FF0000", "#B44D19"], "grass_gyr": ["#00FF00", "#FFFF00", "#FF0000"], "grass_haxby": ["#2539AF", "#287FFB", "#32BEFF", "#6AEBFF", "#8AECAE", "#CDFFA2", "#F0EC79", "#FFBD57", "#FFA144", "#FFBA85", "#FFFFFF"], "grass_ndvi": ["#051852", "#051852", "#FFFFFF", "#FFFFFF", "#CEC5B4", "#BFA37C", "#B3AE60", "#A3B550", "#90AA3C", "#A6C31D", "#87B703", "#79AF01", "#65A300", "#4E9700", "#2B8404", "#007200", "#005A01", "#004900", "#003800", "#001F00", "#000000"], "grass_precipitation_monthly": ["#808080", "#B44D19", "#FFFF00", "#00FF00", "#6480FF", "#0000FF", "#8000FF", "#FF00FF", "#FF0000"], "grass_precipitation": ["#FFFFFF", "#9EFFDE", "#C8FFFF", "#00FFFF", "#0000FF", "#9933FF", "#8000FF", "#330033", "#140014", "#000000"], "grass_rainbow": ["#FFFF00", "#00FF00", "#00FFFF", "#0000FF", "#FF00FF", "#FF0000"], "grass_ramp": ["#000000", "#0000FF", "#000000", "#00FF00", "#000000", "#FF0000"], "grass_rstcurv": ["#8000FF", "#0000FF", "#0080FF", "#00FFFF", "#C8FFC8", "#FFFF00", "#FF8000", "#FF0000", "#FF00C8"], "grass_ryb": ["#FF0000", "#FFFF00", "#0000FF"], "grass_ryg": ["#FF0000", "#FFFF00", "#00FF00"], "grass_sepia": ["#000000", "#221709", "#442F13", "#654821", "#826031", "#9E7A47", "#B79360", "#CEAE7E", "#E1C8A2", "#F2E3CC", "#FFFEFB"], "grass_slope": ["#FFFFFF", "#FFFF00", "#00FF00", "#00FFFF", "#0000FF", "#FF00FF", "#FF0000", "#000000"], "grass_srtm": ["#000000", "#00000A", "#000014", "#000046", "#000082", "#0000CD", "#6480FF", "#399769", "#75C25D", "#E6E680", "#CA9E4B", "#D6BB62", "#B99A64", "#DCDCDC", "#FAFAFA", "#FFFFFF"], "grass_terrain": ["#000000", "#00001E", "#0000C8", "#9696FF", "#007800", "#009600", "#5AA55A", "#5AAF5A", "#32B432", "#46AA46", "#46914B", "#469B4B", "#969C64", "#DCDCDC", "#FFFFFF", "#FFFFFF"], "grass_wave": ["#FF5555", "#AAAA00", "#55FF55", "#00AAAA", "#5555FF", "#AA00AA", "#FF5555"], "h5_autumn": ["#FF0000", "#FFFF00"], "h5_bluered": ["#0000FF", "#FFFFFF", "#FF0000"], "h5_bone": ["#000001", "#030306", "#07070B", "#0A0A0F", "#0E0E14", "#111119", "#15151E", "#181823", "#1C1C28", "#1F1F2D", "#232332", "#262636", "#2A2A3B", "#2E2E40", "#313145", "#35354A", "#38384F", "#3C3C54", "#3F3F58", "#43435D", "#464662", "#4A4A67", "#4D4D6C", "#515171", "#545674", "#585B78", "#5C607B", "#5F647F", "#636983", "#666E86", "#6A738A", "#6D788D", "#717D91", "#748294", "#788798", "#7B8B9B", "#7F909F", "#8395A2", "#869AA6", "#8A9FAA", "#8DA4AD", "#91A9B1", "#94ADB4", "#98B2B8", "#9BB7BB", "#9FBCBF", "#A2C1C2", "#A6C6C6", "#ABC9C9", "#B1CDCD", "#B7D0D0", "#BCD4D4", "#C2D8D8", "#C7DBDB", "#CDDFDF", "#D2E2E2", "#D8E6E6", "#DDE9E9", "#E3EDED", "#E8F0F0", "#EEF4F4", "#F3F7F7", "#F9FBFB", "#FFFFFF"], "h5_cool": ["#00FFFF", "#FF00FF"], "h5_copper": ["#000000", "#050302", "#0A0604", "#0F0906", "#140C08", "#190F0A", "#1E120C", "#23160E", "#281910", "#2D1C12", "#321F14", "#372216", "#3C2518", "#41291A", "#462C1C", "#4B2F1E", "#503220", "#563522", "#5B3824", "#603C26", "#653F28", "#6A422A", "#6F452C", "#74482E", "#794B30", "#7E4F32", "#835234", "#885536", "#8D5838", "#925B3A", "#975E3C", "#9C623E", "#A16540", "#A66842", "#AC6B44", "#B16E46", "#B67148", "#BB744A", "#C0784C", "#C57B4E", "#CA7E50", "#CF8152", "#D48454", "#D98756", "#DE8B58", "#E38E5A", "#E8915C", "#ED945E", "#F29760", "#F79A62", "#FC9E64", "#FFA166", "#FFA468", "#FFA76A", "#FFAA6C", "#FFAD6E", "#FFB170", "#FFB472", "#FFB774", "#FFBA76", "#FFBD78", "#FFC07A", "#FFC47C", "#FFC77E"], "h5_dkbluered": ["#070033", "#11004F", "#19006B", "#1C0087", "#1900A3", "#1600BF", "#0F00DB", "#0200F7", "#1421FF", "#384CFF", "#5975FF", "#7A99FF", "#9BBAFF", "#BFD3FF", "#E0EDFF", "#FFFFFF", "#FFEDE0", "#FFD3BF", "#FFBA9B", "#FF997A", "#FF7559", "#FF4C38", "#FF2114", "#F70002", "#DB000F", "#BF0016", "#A30019", "#87001C", "#6B0019", "#4F0011", "#350007"], "h5_green": ["#FFFFFF", "#00FF00"], "h5_hot": ["#0A0000", "#150000", "#1F0000", "#2A0000", "#350000", "#3F0000", "#4A0000", "#540000", "#5F0000", "#6A0000", "#740000", "#7F0000", "#8A0000", "#940000", "#9F0000", "#AA0000", "#B40000", "#BF0000", "#C90000", "#D40000", "#DF0000", "#E90000", "#F40000", "#FF0000", "#FF0A00", "#FF1500", "#FF1F00", "#FF2A00", "#FF3500", "#FF3F00", "#FF4A00", "#FF5400", "#FF5F00", "#FF6A00", "#FF7400", "#FF7F00", "#FF8A00", "#FF9400", "#FF9F00", "#FFAA00", "#FFB400", "#FFBF00", "#FFC900", "#FFD400", "#FFDF00", "#FFE900", "#FFF400", "#FFFF00", "#FFFF0F", "#FFFF1F", "#FFFF2F", "#FFFF3F", "#FFFF4F", "#FFFF5F", "#FFFF6F", "#FFFF7F", "#FFFF8F", "#FFFF9F", "#FFFFAF", "#FFFFBF", "#FFFFCF", "#FFFFDF", "#FFFFEF", "#FFFFFF"], "h5_hsv": ["#FF0000", "#FF1700", "#FF2F00", "#FF4700", "#FF5F00", "#FF7700", "#FF8F00", "#FFA700", "#FFBF00", "#FFD700", "#FFEF00", "#F7FF00", "#DFFF00", "#C7FF00", "#AFFF00", "#97FF00", "#7FFF00", "#67FF00", "#4FFF00", "#37FF00", "#1FFF00", "#07FF00", "#00FF0F", "#00FF27", "#00FF3F", "#00FF57", "#00FF6F", "#00FF87", "#00FF9F", "#00FFB7", "#00FFCF", "#00FFE7", "#00FFFF", "#00E7FF", "#00CFFF", "#00B7FF", "#009FFF", "#0087FF", "#006FFF", "#0057FF", "#003FFF", "#0027FF", "#000FFF", "#0700FF", "#1F00FF", "#3700FF", "#4F00FF", "#6700FF", "#7F00FF", "#9700FF", "#AF00FF", "#C700FF", "#DF00FF", "#F700FF", "#FF00EF", "#FF00D7", "#FF00BF", "#FF00A7", "#FF008F", "#FF0077", "#FF005F", "#FF0047", "#FF002F", "#FF0017"], "h5_jet": ["#0000BF", "#0000FF", "#003FFF", "#007FFF", "#00BFFF", "#00FFFF", "#3FFFFF", "#7FFFBF", "#BFFF7F", "#FFFF3F", "#FFFF00", "#FFBF00", "#FF7F00", "#FF3F00", "#FF0000", "#BF0000"], "h5_pink": ["#1E0000", "#311A1A", "#3F2525", "#4B2D2D", "#553434", "#5E3A3A", "#664040", "#6D4545", "#744A4A", "#7B4E4E", "#815252", "#875757", "#8D5A5A", "#925E5E", "#986262", "#9D6565", "#A26868", "#A76C6C", "#AB6F6F", "#B07272", "#B47575", "#B97878", "#BD7B7B", "#C17D7D", "#C38380", "#C58983", "#C68F85", "#C89488", "#CA9A8A", "#CC9F8D", "#CDA48F", "#CFA892", "#D1AD94", "#D2B296", "#D4B698", "#D5BA9B", "#D7BF9D", "#D9C39F", "#DAC7A1", "#DCCBA3", "#DDCFA5", "#DFD2A7", "#E0D6AA", "#E2DAAC", "#E3DDAE", "#E5E1AF", "#E6E4B1", "#E8E8B3", "#E9E9B9", "#EBEBBE", "#ECECC4", "#EEEEC9", "#EFEFCE", "#F1F1D3", "#F2F2D7", "#F3F3DC", "#F5F5E1", "#F6F6E5", "#F8F8EA", "#F9F9EE", "#FAFAF2", "#FCFCF6", "#FDFDFA", "#FFFFFF"], "h5_spring": ["#FF00FF", "#FF11ED", "#FF21DD", "#FF33CC", "#FF44BA", "#FF54AA", "#FF6699", "#FF7787", "#FF8777", "#FF9966", "#FFAA54", "#FFBA44", "#FFCC33", "#FFDD21", "#FFED11", "#FFFF00"], "h5_summer": ["#007F66", "#118766", "#219066", "#339966", "#44A166", "#54AA66", "#66B266", "#77BA66", "#87C366", "#99CC66", "#AAD466", "#BADD66", "#CCE566", "#DDED66", "#EDF666", "#FFFF66"], "h5_winter": ["#0000FF", "#00FF7F"], "h5_yellow": ["#FFFFFF", "#FFFF00"], "heine_GTS2012_epochs": ["#FEF2EC", "#FEF2EC", "#FFF2AE", "#FFF2AE", "#FFFF99", "#FFFF99", "#FFFF00", "#FFFF00", "#FDC07A", "#FDC07A", "#FDB46C", "#FDB46C", "#FDA75F", "#FDA75F", "#A6D84A", "#A6D84A", "#8CCD57", "#8CCD57", "#B3E3EE", "#B3E3EE", "#80CFD8", "#80CFD8", "#42AED0", "#42AED0", "#BD8CC3", "#BD8CC3", "#B168B1", "#B168B1", "#983999", "#983999", "#FBA794", "#FBA794", "#FB745C", "#FB745C", "#EF5845", "#EF5845", "#99C2B5", "#99C2B5", "#678F66", "#678F66", "#F1E19D", "#F1E19D", "#F1C868", "#F1C868", "#F1C868", "#E6F5E1", "#E6F5E1", "#BFE6CF", "#BFE6CF", "#B3E1C2", "#B3E1C2", "#99D7B3", "#99D7B3", "#7FCA93", "#7FCA93", "#4DB47E", "#4DB47E", "#1A9D6F", "#1A9D6F", "#B3E095", "#B3E095", "#A6CF86", "#A6CF86", "#99C078", "#99C078", "#8CB06C", "#8CB06C"], "ibcso_ibcso_bath": ["#1F284F", "#1F284F", "#263C6A", "#263C6A", "#2E5085", "#2E5085", "#3563A0", "#3563A0", "#3C77BC", "#3C77BC", "#4897D3", "#4897D3", "#5AB9E9", "#5AB9E9", "#5FC6F2", "#5FC6F2", "#72CAEE", "#72CAEE", "#8DD2EF", "#8DD2EF"], "ibcso_ibcso": ["#1F284F", "#1F284F", "#263C6A", "#263C6A", "#2E5085", "#2E5085", "#3563A0", "#3563A0", "#3C77BC", "#3C77BC", "#4897D3", "#4897D3", "#5AB9E9", "#5AB9E9", "#5FC6F2", "#5FC6F2", "#72CAEE", "#72CAEE", "#8DD2EF", "#8DD2EF", "#FFFFFF", "#FFFFFF"], "imagej_001_fire": ["#000000", "#000000", "#000007", "#000007", "#00000F", "#00000F", "#000016", "#000016", "#00001E", "#00001E", "#000026", "#000026", "#00002D", "#00002D", "#000035", "#000035", "#00003D", "#00003D", "#000041", "#000041", "#000045", "#000045", "#00004A", "#00004A", "#00004E", "#00004E", "#000052", "#000052", "#000057", "#000057", "#00005B", "#00005B", "#010060", "#010060", "#040064", "#040064", "#070068", "#070068", "#0A006C", "#0A006C", "#0D0071", "#0D0071", "#100075", "#100075", "#130079", "#130079", "#16007D", "#16007D", "#190082", "#190082", "#1C0086", "#1C0086", "#1F008A", "#1F008A", "#22008F", "#22008F", "#250093", "#250093", "#280097", "#280097", "#2B009C", "#2B009C", "#2E00A0", "#2E00A0", "#3100A5", "#3100A5", "#3400A8", "#3400A8", "#3700AB", "#3700AB", "#3A00AF", "#3A00AF", "#3D00B2", "#3D00B2", "#4000B5", "#4000B5", "#4300B9", "#4300B9", "#4600BC", "#4600BC", "#4900C0", "#4900C0", "#4C00C3", "#4C00C3", "#4F00C7", "#4F00C7", "#5200CA", "#5200CA", "#5500CE", "#5500CE", "#5800D1", "#5800D1", "#5B00D5", "#5B00D5", "#5E00D8", "#5E00D8", "#6200DC", "#6200DC", "#6500DC", "#6500DC", "#6800DD", "#6800DD", "#6B00DE", "#6B00DE", "#6E00DF", "#6E00DF", "#7100E0", "#7100E0", "#7400E1", "#7400E1", "#7700E2", "#7700E2", "#7A00E3", "#7A00E3", "#7D00E0", "#7D00E0", "#8000DE", "#8000DE", "#8300DC", "#8300DC", "#8600DA", "#8600DA", "#8900D8", "#8900D8", "#8C00D6", "#8C00D6", "#8F00D4", "#8F00D4", "#9200D2", "#9200D2", "#9400CE", "#9400CE", "#9600CA", "#9600CA", "#9800C7", "#9800C7", "#9A00C3", "#9A00C3", "#9C00BF", "#9C00BF", "#9E00BC", "#9E00BC", "#A000B8", "#A000B8", "#A200B5", "#A200B5", "#A300B1", "#A300B1", "#A400AD", "#A400AD", "#A600A9", "#A600A9", "#A700A6", "#A700A6", "#A800A2", "#A800A2", "#AA009E", "#AA009E", "#AB009A", "#AB009A", "#AD0097", "#AD0097", "#AE0093", "#AE0093", "#AF008F", "#AF008F", "#B1008C", "#B1008C", "#B20088", "#B20088", "#B30084", "#B30084", "#B50081", "#B50081", "#B6007D", "#B6007D", "#B8007A", "#B8007A", "#B90076", "#B90076", "#BA0072", "#BA0072", "#BC006F", "#BC006F", "#BD006B", "#BD006B", "#BE0067", "#BE0067", "#C00064", "#C00064", "#C10060", "#C10060", "#C3005D", "#C3005D", "#C40159", "#C40159", "#C60355", "#C60355", "#C70552", "#C70552", "#C9074E", "#C9074E", "#CA084A", "#CA084A", "#CC0A47", "#CC0A47", "#CD0C43", "#CD0C43", "#CF0E40", "#CF0E40", "#D0103C", "#D0103C", "#D11338", "#D11338", "#D21535", "#D21535", "#D41831", "#D41831", "#D51B2D", "#D51B2D", "#D61D2A", "#D61D2A", "#D72026", "#D72026", "#D92323", "#D92323", "#DA251F", "#DA251F", "#DC281B", "#DC281B", "#DD2B17", "#DD2B17", "#DF2E14", "#DF2E14", "#E03010", "#E03010", "#E2330C", "#E2330C", "#E33608", "#E33608", "#E53905", "#E53905", "#E63B04", "#E63B04", "#E73E03", "#E73E03", "#E94103", "#E94103", "#EA4402", "#EA4402", "#EB4601", "#EB4601", "#ED4901", "#ED4901", "#EE4C00", "#EE4C00", "#F04F00", "#F04F00", "#F15100", "#F15100", "#F35400", "#F35400", "#F45700", "#F45700", "#F65A00", "#F65A00", "#F75C00", "#F75C00", "#F95F00", "#F95F00", "#FA6200", "#FA6200", "#FC6500", "#FC6500", "#FC6700", "#FC6700", "#FC6900", "#FC6900", "#FD6B00", "#FD6B00", "#FD6D00", "#FD6D00", "#FD6F00", "#FD6F00", "#FE7100", "#FE7100", "#FE7300", "#FE7300", "#FF7500", "#FF7500", "#FF7700", "#FF7700", "#FF7900", "#FF7900", "#FF7B00", "#FF7B00", "#FF7D00", "#FF7D00", "#FF7F00", "#FF7F00", "#FF8100", "#FF8100", "#FF8300", "#FF8300", "#FF8500", "#FF8500", "#FF8600", "#FF8600", "#FF8800", "#FF8800", "#FF8A00", "#FF8A00", "#FF8C00", "#FF8C00", "#FF8D00", "#FF8D00", "#FF8F00", "#FF8F00", "#FF9100", "#FF9100", "#FF9300", "#FF9300", "#FF9400", "#FF9400", "#FF9600", "#FF9600", "#FF9800", "#FF9800", "#FF9A00", "#FF9A00", "#FF9B00", "#FF9B00", "#FF9D00", "#FF9D00", "#FF9F00", "#FF9F00", "#FFA100", "#FFA100", "#FFA200", "#FFA200", "#FFA400", "#FFA400", "#FFA600", "#FFA600", "#FFA800", "#FFA800", "#FFA900", "#FFA900", "#FFAB00", "#FFAB00", "#FFAD00", "#FFAD00", "#FFAF00", "#FFAF00", "#FFB000", "#FFB000", "#FFB200", "#FFB200", "#FFB400", "#FFB400", "#FFB600", "#FFB600", "#FFB800", "#FFB800", "#FFBA00", "#FFBA00", "#FFBC00", "#FFBC00", "#FFBE00", "#FFBE00", "#FFBF00", "#FFBF00", "#FFC100", "#FFC100", "#FFC300", "#FFC300", "#FFC500", "#FFC500", "#FFC700", "#FFC700", "#FFC900", "#FFC900", "#FFCB00", "#FFCB00", "#FFCD00", "#FFCD00", "#FFCE00", "#FFCE00", "#FFD000", "#FFD000", "#FFD200", "#FFD200", "#FFD400", "#FFD400", "#FFD500", "#FFD500", "#FFD700", "#FFD700", "#FFD900", "#FFD900", "#FFDB00", "#FFDB00", "#FFDC00", "#FFDC00", "#FFDE00", "#FFDE00", "#FFE000", "#FFE000", "#FFE200", "#FFE200", "#FFE400", "#FFE400", "#FFE600", "#FFE600", "#FFE800", "#FFE800", "#FFEA00", "#FFEA00", "#FFEB04", "#FFEB04", "#FFED08", "#FFED08", "#FFEF0D", "#FFEF0D", "#FFF111", "#FFF111", "#FFF215", "#FFF215", "#FFF41A", "#FFF41A", "#FFF61E", "#FFF61E", "#FFF823", "#FFF823", "#FFF82A", "#FFF82A", "#FFF932", "#FFF932", "#FFFA3A", "#FFFA3A", "#FFFB42", "#FFFB42", "#FFFC4A", "#FFFC4A", "#FFFD52", "#FFFD52", "#FFFE5A", "#FFFE5A", "#FFFF62", "#FFFF62", "#FFFF69", "#FFFF69", "#FFFF71", "#FFFF71", "#FFFF79", "#FFFF79", "#FFFF81", "#FFFF81", "#FFFF88", "#FFFF88", "#FFFF90", "#FFFF90", "#FFFF98", "#FFFF98", "#FFFFA0", "#FFFFA0", "#FFFFA7", "#FFFFA7", "#FFFFAF", "#FFFFAF", "#FFFFB7", "#FFFFB7", "#FFFFBF", "#FFFFBF", "#FFFFC7", "#FFFFC7", "#FFFFCF", "#FFFFCF", "#FFFFD7", "#FFFFD7", "#FFFFDF", "#FFFFDF", "#FFFFE3", "#FFFFE3", "#FFFFE7", "#FFFFE7", "#FFFFEB", "#FFFFEB", "#FFFFEF", "#FFFFEF", "#FFFFF3", "#FFFFF3", "#FFFFF7", "#FFFFF7", "#FFFFFB", "#FFFFFB", "#FFFFFF", "#FFFFFF", "#FFFFFF", "#FFFFFF", "#FFFFFF", "#FFFFFF", "#FFFFFF", "#FFFFFF", "#FFFFFF"], "imagej_002_spectrum": ["#FF0000", "#FF0000", "#FF0600", "#FF0600", "#FF0C00", "#FF0C00", "#FF1200", "#FF1200", "#FF1800", "#FF1800", "#FF1E00", "#FF1E00", "#FF2400", "#FF2400", "#FF2A00", "#FF2A00", "#FF3000", "#FF3000", "#FF3600", "#FF3600", "#FF3C00", "#FF3C00", "#FF4200", "#FF4200", "#FF4800", "#FF4800", "#FF4E00", "#FF4E00", "#FF5400", "#FF5400", "#FF5A00", "#FF5A00", "#FF6000", "#FF6000", "#FF6600", "#FF6600", "#FF6C00", "#FF6C00", "#FF7200", "#FF7200", "#FF7800", "#FF7800", "#FF7E00", "#FF7E00", "#FF8400", "#FF8400", "#FF8A00", "#FF8A00", "#FF9000", "#FF9000", "#FF9600", "#FF9600", "#FF9C00", "#FF9C00", "#FFA200", "#FFA200", "#FFA800", "#FFA800", "#FFAE00", "#FFAE00", "#FFB400", "#FFB400", "#FFBA00", "#FFBA00", "#FFC000", "#FFC000", "#FFC600", "#FFC600", "#FFCC00", "#FFCC00", "#FFD200", "#FFD200", "#FFD800", "#FFD800", "#FFDE00", "#FFDE00", "#FFE400", "#FFE400", "#FFEA00", "#FFEA00", "#FFF000", "#FFF000", "#FFF600", "#FFF600", "#FFFC00", "#FFFC00", "#FCFF00", "#FCFF00", "#F6FF00", "#F6FF00", "#F0FF00", "#F0FF00", "#EAFF00", "#EAFF00", "#E4FF00", "#E4FF00", "#DEFF00", "#DEFF00", "#D8FF00", "#D8FF00", "#D2FF00", "#D2FF00", "#CCFF00", "#CCFF00", "#C6FF00", "#C6FF00", "#C0FF00", "#C0FF00", "#BAFF00", "#BAFF00", "#B4FF00", "#B4FF00", "#AEFF00", "#AEFF00", "#A8FF00", "#A8FF00", "#A2FF00", "#A2FF00", "#9CFF00", "#9CFF00", "#96FF00", "#96FF00", "#90FF00", "#90FF00", "#8AFF00", "#8AFF00", "#84FF00", "#84FF00", "#7EFF00", "#7EFF00", "#78FF00", "#78FF00", "#72FF00", "#72FF00", "#6CFF00", "#6CFF00", "#66FF00", "#66FF00", "#60FF00", "#60FF00", "#5AFF00", "#5AFF00", "#54FF00", "#54FF00", "#4EFF00", "#4EFF00", "#48FF00", "#48FF00", "#42FF00", "#42FF00", "#3CFF00", "#3CFF00", "#36FF00", "#36FF00", "#30FF00", "#30FF00", "#2AFF00", "#2AFF00", "#24FF00", "#24FF00", "#1EFF00", "#1EFF00", "#18FF00", "#18FF00", "#12FF00", "#12FF00", "#0CFF00", "#0CFF00", "#06FF00", "#06FF00", "#00FF00", "#00FF00", "#00FF06", "#00FF06", "#00FF0C", "#00FF0C", "#00FF12", "#00FF12", "#00FF18", "#00FF18", "#00FF1E", "#00FF1E", "#00FF24", "#00FF24", "#00FF2A", "#00FF2A", "#00FF30", "#00FF30", "#00FF36", "#00FF36", "#00FF3C", "#00FF3C", "#00FF42", "#00FF42", "#00FF48", "#00FF48", "#00FF4E", "#00FF4E", "#00FF54", "#00FF54", "#00FF5A", "#00FF5A", "#00FF60", "#00FF60", "#00FF66", "#00FF66", "#00FF6C", "#00FF6C", "#00FF72", "#00FF72", "#00FF78", "#00FF78", "#00FF7E", "#00FF7E", "#00FF84", "#00FF84", "#00FF8A", "#00FF8A", "#00FF90", "#00FF90", "#00FF96", "#00FF96", "#00FF9C", "#00FF9C", "#00FFA2", "#00FFA2", "#00FFA8", "#00FFA8", "#00FFAE", "#00FFAE", "#00FFB4", "#00FFB4", "#00FFBA", "#00FFBA", "#00FFC0", "#00FFC0", "#00FFC6", "#00FFC6", "#00FFCC", "#00FFCC", "#00FFD2", "#00FFD2", "#00FFD8", "#00FFD8", "#00FFDE", "#00FFDE", "#00FFE4", "#00FFE4", "#00FFEA", "#00FFEA", "#00FFF0", "#00FFF0", "#00FFF6", "#00FFF6", "#00FFFC", "#00FFFC", "#00FCFF", "#00FCFF", "#00F6FF", "#00F6FF", "#00F0FF", "#00F0FF", "#00EAFF", "#00EAFF", "#00E4FF", "#00E4FF", "#00DEFF", "#00DEFF", "#00D8FF", "#00D8FF", "#00D2FF", "#00D2FF", "#00CCFF", "#00CCFF", "#00C6FF", "#00C6FF", "#00C0FF", "#00C0FF", "#00BAFF", "#00BAFF", "#00B4FF", "#00B4FF", "#00AEFF", "#00AEFF", "#00A8FF", "#00A8FF", "#00A2FF", "#00A2FF", "#009CFF", "#009CFF", "#0096FF", "#0096FF", "#0090FF", "#0090FF", "#008AFF", "#008AFF", "#0084FF", "#0084FF", "#007EFF", "#007EFF", "#0078FF", "#0078FF", "#0072FF", "#0072FF", "#006CFF", "#006CFF", "#0066FF", "#0066FF", "#0060FF", "#0060FF", "#005AFF", "#005AFF", "#0054FF", "#0054FF", "#004EFF", "#004EFF", "#0048FF", "#0048FF", "#0042FF", "#0042FF", "#003CFF", "#003CFF", "#0036FF", "#0036FF", "#0030FF", "#0030FF", "#002AFF", "#002AFF", "#0024FF", "#0024FF", "#001EFF", "#001EFF", "#0018FF", "#0018FF", "#0012FF", "#0012FF", "#000CFF", "#000CFF", "#0006FF", "#0006FF", "#0000FF", "#0000FF", "#0600FF", "#0600FF", "#0C00FF", "#0C00FF", "#1200FF", "#1200FF", "#1800FF", "#1800FF", "#1E00FF", "#1E00FF", "#2400FF", "#2400FF", "#2A00FF", "#2A00FF", "#3000FF", "#3000FF", "#3600FF", "#3600FF", "#3C00FF", "#3C00FF", "#4200FF", "#4200FF", "#4800FF", "#4800FF", "#4E00FF", "#4E00FF", "#5400FF", "#5400FF", "#5A00FF", "#5A00FF", "#6000FF", "#6000FF", "#6600FF", "#6600FF", "#6C00FF", "#6C00FF", "#7200FF", "#7200FF", "#7800FF", "#7800FF", "#7E00FF", "#7E00FF", "#8400FF", "#8400FF", "#8A00FF", "#8A00FF", "#9000FF", "#9000FF", "#9600FF", "#9600FF", "#9C00FF", "#9C00FF", "#A200FF", "#A200FF", "#A800FF", "#A800FF", "#AE00FF", "#AE00FF", "#B400FF", "#B400FF", "#BA00FF", "#BA00FF", "#C000FF", "#C000FF", "#C600FF", "#C600FF", "#CC00FF", "#CC00FF", "#D200FF", "#D200FF", "#D800FF", "#D800FF", "#DE00FF", "#DE00FF", "#E400FF", "#E400FF", "#EA00FF", "#EA00FF", "#F000FF", "#F000FF", "#F600FF", "#F600FF", "#FC00FF", "#FC00FF", "#FF00FC", "#FF00FC", "#FF00F6", "#FF00F6", "#FF00F0", "#FF00F0", "#FF00EA", "#FF00EA", "#FF00E4", "#FF00E4", "#FF00DE", "#FF00DE", "#FF00D8", "#FF00D8", "#FF00D2", "#FF00D2", "#FF00CC", "#FF00CC", "#FF00C6", "#FF00C6", "#FF00C0", "#FF00C0", "#FF00BA", "#FF00BA", "#FF00B4", "#FF00B4", "#FF00AE", "#FF00AE", "#FF00A8", "#FF00A8", "#FF00A2", "#FF00A2", "#FF009C", "#FF009C", "#FF0096", "#FF0096", "#FF0090", "#FF0090", "#FF008A", "#FF008A", "#FF0084", "#FF0084", "#FF007E", "#FF007E", "#FF0078", "#FF0078", "#FF0072", "#FF0072", "#FF006C", "#FF006C", "#FF0066", "#FF0066", "#FF0060", "#FF0060", "#FF005A", "#FF005A", "#FF0054", "#FF0054", "#FF004E", "#FF004E", "#FF0048", "#FF0048", "#FF0042", "#FF0042", "#FF003C", "#FF003C", "#FF0036", "#FF0036", "#FF0030", "#FF0030", "#FF002A", "#FF002A", "#FF0024", "#FF0024", "#FF001E", "#FF001E", "#FF0018", "#FF0018", "#FF0012", "#FF0012", "#FF000C", "#FF000C", "#FF0006", "#FF0006", "#FF0000", "#FF0000"], "imagej_003_ice": ["#009C8C", "#009C8C", "#009D8C", "#009D8C", "#009E8D", "#009E8D", "#009F8E", "#009F8E", "#00A08F", "#00A08F", "#00A190", "#00A190", "#00A291", "#00A291", "#00A392", "#00A392", "#00A593", "#00A593", "#00A694", "#00A694", "#00A795", "#00A795", "#00A997", "#00A997", "#00AA98", "#00AA98", "#00AB99", "#00AB99", "#00AD9B", "#00AD9B", "#00AE9C", "#00AE9C", "#00B09E", "#00B09E", "#00B19F", "#00B19F", "#00B2A0", "#00B2A0", "#00B3A1", "#00B3A1", "#00B4A2", "#00B4A2", "#00B5A3", "#00B5A3", "#00B6A4", "#00B6A4", "#00B7A5", "#00B7A5", "#00B8A6", "#00B8A6", "#00B8A6", "#00B9A7", "#00B9A7", "#00BAA7", "#00BAA7", "#00BBA8", "#00BBA8", "#00BBA8", "#00BCA9", "#00BCA9", "#00BDA9", "#00BDA9", "#00BEAA", "#00BEAA", "#00BEAA", "#00BFAB", "#00BFAB", "#00C0AC", "#00C0AC", "#00C1AD", "#00C1AD", "#00C1AD", "#00C2AE", "#00C2AE", "#00C3AF", "#00C3AF", "#00C4B0", "#00C4B0", "#02C3B4", "#02C3B4", "#04C3B8", "#04C3B8", "#07C2BC", "#07C2BC", "#09C2C0", "#09C2C0", "#0BC2C4", "#0BC2C4", "#0EC1C8", "#0EC1C8", "#10C1CC", "#10C1CC", "#13C1D1", "#13C1D1", "#14BFD2", "#14BFD2", "#15BED3", "#15BED3", "#16BDD5", "#16BDD5", "#18BCD6", "#18BCD6", "#19BBD7", "#19BBD7", "#1ABAD9", "#1ABAD9", "#1BB9DA", "#1BB9DA", "#1DB8DC", "#1DB8DC", "#1FB6DD", "#1FB6DD", "#22B4DF", "#22B4DF", "#24B3E1", "#24B3E1", "#27B1E3", "#27B1E3", "#2AAFE4", "#2AAFE4", "#2CAEE6", "#2CAEE6", "#2FACE8", "#2FACE8", "#32ABEA", "#32ABEA", "#31A9E8", "#31A9E8", "#31A8E7", "#31A8E7", "#31A7E6", "#31A7E6", "#31A6E5", "#31A6E5", "#30A5E4", "#30A5E4", "#30A4E3", "#30A4E3", "#30A3E2", "#30A3E2", "#30A2E1", "#30A2E1", "#33A0E2", "#33A0E2", "#379EE3", "#379EE3", "#3B9CE5", "#3B9CE5", "#3F9AE6", "#3F9AE6", "#4398E7", "#4398E7", "#4796E9", "#4796E9", "#4B94EA", "#4B94EA", "#4F92EC", "#4F92EC", "#538FED", "#538FED", "#578CEE", "#578CEE", "#5B8AEF", "#5B8AEF", "#5F87F1", "#5F87F1", "#6384F2", "#6384F2", "#6782F3", "#6782F3", "#6B7FF4", "#6B7FF4", "#707DF6", "#707DF6", "#727AF6", "#727AF6", "#7578F7", "#7578F7", "#7876F7", "#7876F7", "#7B74F8", "#7B74F8", "#7D71F8", "#7D71F8", "#806FF9", "#806FF9", "#836DF9", "#836DF9", "#866BFA", "#866BFA", "#8969FA", "#8969FA", "#8C67FA", "#8C67FA", "#8F65FA", "#8F65FA", "#9264FA", "#9264FA", "#9562FA", "#9562FA", "#9860FA", "#9860FA", "#9B5EFA", "#9B5EFA", "#9E5DFB", "#9E5DFB", "#A15BFA", "#A15BFA", "#A55AFA", "#A55AFA", "#A858FA", "#A858FA", "#AC57FA", "#AC57FA", "#AF55FA", "#AF55FA", "#B354FA", "#B354FA", "#B652FA", "#B652FA", "#BA51FA", "#BA51FA", "#BB51FA", "#BB51FA", "#BD52FA", "#BD52FA", "#BF53FA", "#BF53FA", "#C154FA", "#C154FA", "#C354FA", "#C354FA", "#C555FA", "#C555FA", "#C756FA", "#C756FA", "#C957FA", "#C957FA", "#CB57F9", "#CB57F9", "#CD58F8", "#CD58F8", "#CF58F8", "#CF58F8", "#D159F7", "#D159F7", "#D35AF6", "#D35AF6", "#D55AF6", "#D55AF6", "#D75BF5", "#D75BF5", "#D95CF5", "#D95CF5", "#DA5CF3", "#DA5CF3", "#DC5DF1", "#DC5DF1", "#DD5DEF", "#DD5DEF", "#DF5EED", "#DF5EED", "#E05FEB", "#E05FEB", "#E25FE9", "#E25FE9", "#E360E7", "#E360E7", "#E561E6", "#E561E6", "#E660E6", "#E660E6", "#E860E6", "#E860E6", "#E960E6", "#E960E6", "#EB60E6", "#EB60E6", "#ED5FE6", "#ED5FE6", "#EE5FE6", "#EE5FE6", "#F05FE6", "#F05FE6", "#F25FE6", "#F25FE6", "#F35EE5", "#F35EE5", "#F45EE4", "#F45EE4", "#F55EE3", "#F55EE3", "#F65EE2", "#F65EE2", "#F75DE1", "#F75DE1", "#F85DE0", "#F85DE0", "#F95DDF", "#F95DDF", "#FA5DDE", "#FA5DDE", "#FA5DDB", "#FA5DDB", "#FA5DD9", "#FA5DD9", "#FA5DD6", "#FA5DD6", "#FA5DD4", "#FA5DD4", "#FA5DD1", "#FA5DD1", "#FA5DCF", "#FA5DCF", "#FA5DCC", "#FA5DCC", "#FA5DCA", "#FA5DCA", "#FA5CC7", "#FA5CC7", "#FA5CC4", "#FA5CC4", "#FA5BC1", "#FA5BC1", "#FA5BBF", "#FA5BBF", "#FA5BBC", "#FA5BBC", "#FA5AB9", "#FA5AB9", "#FA5AB6", "#FA5AB6", "#FA5AB4", "#FA5AB4", "#FA59B1", "#FA59B1", "#FA58AF", "#FA58AF", "#FA58AD", "#FA58AD", "#FA57AB", "#FA57AB", "#FA56A9", "#FA56A9", "#FA56A7", "#FA56A7", "#FA55A5", "#FA55A5", "#FA55A3", "#FA55A3", "#FA53A0", "#FA53A0", "#FA519D", "#FA519D", "#FA4F9B", "#FA4F9B", "#FA4D98", "#FA4D98", "#FA4B95", "#FA4B95", "#FA4993", "#FA4993", "#FA4790", "#FA4790", "#FB458E", "#FB458E", "#FA448B", "#FA448B", "#FA4389", "#FA4389", "#FA4386", "#FA4386", "#FA4284", "#FA4284", "#FA4182", "#FA4182", "#FA417F", "#FA417F", "#FA407D", "#FA407D", "#FA407B", "#FA407B", "#FA3E79", "#FA3E79", "#FA3D78", "#FA3D78", "#FA3C77", "#FA3C77", "#FA3B76", "#FA3B76", "#FA3975", "#FA3975", "#FA3874", "#FA3874", "#FA3773", "#FA3773", "#FA3672", "#FA3672", "#FA3571", "#FA3571", "#FA3470", "#FA3470", "#FA336F", "#FA336F", "#FA326E", "#FA326E", "#FA316D", "#FA316D", "#FA306C", "#FA306C", "#FA2F6B", "#FA2F6B", "#FA2F6A", "#FA2F6A", "#FA2D68", "#FA2D68", "#FA2C67", "#FA2C67", "#FA2A65", "#FA2A65", "#FA2964", "#FA2964", "#FA2762", "#FA2762", "#FA2661", "#FA2661", "#FA245F", "#FA245F", "#FA235E", "#FA235E", "#FA215C", "#FA215C", "#FA1F5B", "#FA1F5B", "#FA1D5A", "#FA1D5A", "#FA1B59", "#FA1B59", "#FA1957", "#FA1957", "#FA1756", "#FA1756", "#FA1555", "#FA1555", "#FB1354", "#FB1354", "#FB1051", "#FB1051", "#FB0E4F", "#FB0E4F", "#FB0B4C", "#FB0B4C", "#FB094A", "#FB094A", "#FB0747", "#FB0747", "#FB0445", "#FB0445", "#FB0242", "#FB0242", "#FB0040", "#FB0040", "#FA003B", "#FA003B", "#F90136", "#F90136", "#F80131", "#F80131", "#F7022D", "#F7022D", "#F60228", "#F60228", "#F50323", "#F50323", "#F4031E", "#F4031E", "#F3041A", "#F3041A", "#F1031A", "#F1031A", "#EF031A", "#EF031A", "#EE021A", "#EE021A", "#EC021A", "#EC021A", "#EA011A", "#EA011A", "#E9011A", "#E9011A", "#E7001A", "#E7001A", "#E6001B", "#E6001B", "#E6001B", "#E6001B", "#E6001B", "#E6001B", "#E6001B", "#E6001B", "#E6001B"], "imagej_004_phase": ["#0000FC", "#0000FC", "#0000FC", "#0000FC", "#0404FC", "#0404FC", "#0404FC", "#0404FC", "#0808FC", "#0808FC", "#0808FC", "#0C0CFC", "#0C0CFC", "#0C0CFC", "#0C0CF8", "#0C0CF8", "#1010F8", "#1010F8", "#1010F8", "#1414F8", "#1414F8", "#1414F8", "#1414F8", "#1818F8", "#1818F8", "#1818F8", "#1C1CF8", "#1C1CF8", "#1C1CF8", "#1C1CF4", "#1C1CF4", "#2020F4", "#2020F4", "#2020F4", "#2424F4", "#2424F4", "#2424F4", "#2424F4", "#2828F4", "#2828F4", "#2828F4", "#2C2CF4", "#2C2CF4", "#2C2CF4", "#2C2CF0", "#2C2CF0", "#3030F0", "#3030F0", "#3030F0", "#3434F0", "#3434F0", "#3434F0", "#3434F0", "#3838F0", "#3838F0", "#3838F0", "#3C3CF0", "#3C3CF0", "#3C3CEC", "#3C3CEC", "#3C3CEC", "#4040EC", "#4040EC", "#4040EC", "#4444EC", "#4444EC", "#4444EC", "#4444EC", "#4848EC", "#4848EC", "#4848EC", "#4C4CEC", "#4C4CEC", "#4C4CE8", "#4C4CE8", "#4C4CE8", "#5050E8", "#5050E8", "#5050E8", "#5454E8", "#5454E8", "#5454E8", "#5454E8", "#5858E8", "#5858E8", "#5858E8", "#5C5CE8", "#5C5CE8", "#5C5CE4", "#5C5CE4", "#5C5CE4", "#6060E4", "#6060E4", "#6060E4", "#6060E4", "#6464E4", "#6464E4", "#6464E4", "#6868E4", "#6868E4", "#6868E4", "#6868E0", "#6868E0", "#6C6CE0", "#6C6CE0", "#6C6CE0", "#7070E0", "#7070E0", "#7070E0", "#7070E0", "#7474E0", "#7474E0", "#7474E0", "#7878E0", "#7878E0", "#7878E0", "#7878DC", "#7878DC", "#7C7CDC", "#7C7CDC", "#7C7CDC", "#8080DC", "#8080DC", "#8080DC", "#8080DC", "#8484DC", "#8484DC", "#8484DC", "#8888DC", "#8888DC", "#8888DC", "#8888D8", "#8888D8", "#8C8CD8", "#8C8CD8", "#8C8CD8", "#9090D8", "#9090D8", "#9090D8", "#9090D8", "#9494D8", "#9494D8", "#9494D8", "#9898D8", "#9898D8", "#9898D4", "#9898D4", "#9898D4", "#9C9CD4", "#9C9CD4", "#9C9CD4", "#A0A0D4", "#A0A0D4", "#A0A0D4", "#A0A0D4", "#A4A4D4", "#A4A4D4", "#A4A4D4", "#A8A8D4", "#A8A8D4", "#A8A8D0", "#A8A8D0", "#A8A8D0", "#ACACD0", "#ACACD0", "#ACACD0", "#B0B0D0", "#B0B0D0", "#B0B0D0", "#B0B0D0", "#B4B4D0", "#B4B4D0", "#B4B4D0", "#B8B8D0", "#B8B8D0", "#B8B8CC", "#B8B8CC", "#B8B8CC", "#BCBCCC", "#BCBCCC", "#BCBCCC", "#C0C0CC", "#C0C0CC", "#C0C0CC", "#C0C0CC", "#C4C4CC", "#C4C4CC", "#C4C4CC", "#C8C8C8", "#C8C8C8", "#C8C8C8", "#C8C8C8", "#C8C4C4", "#C8C4C4", "#C8C4C4", "#C8C4C4", "#C8C0C0", "#C8C0C0", "#C8C0C0", "#C8BCBC", "#C8BCBC", "#C8BCBC", "#CCBCBC", "#CCBCBC", "#CCB8B8", "#CCB8B8", "#CCB8B8", "#CCB4B4", "#CCB4B4", "#CCB4B4", "#CCB4B4", "#CCB0B0", "#CCB0B0", "#CCB0B0", "#CCACAC", "#CCACAC", "#CCACAC", "#D0ACAC", "#D0ACAC", "#D0A8A8", "#D0A8A8", "#D0A8A8", "#D0A8A8", "#D0A4A4", "#D0A4A4", "#D0A4A4", "#D0A0A0", "#D0A0A0", "#D0A0A0", "#D0A0A0", "#D09C9C", "#D09C9C", "#D49C9C", "#D49C9C", "#D49898", "#D49898", "#D49898", "#D49898", "#D49494", "#D49494", "#D49494", "#D49090", "#D49090", "#D49090", "#D49090", "#D48C8C", "#D48C8C", "#D88C8C", "#D88C8C", "#D88888", "#D88888", "#D88888", "#D88888", "#D88484", "#D88484", "#D88484", "#D88484", "#D88080", "#D88080", "#D88080", "#D87C7C", "#D87C7C", "#DC7C7C", "#DC7C7C", "#DC7C7C", "#DC7878", "#DC7878", "#DC7878", "#DC7474", "#DC7474", "#DC7474", "#DC7474", "#DC7070", "#DC7070", "#DC7070", "#DC6C6C", "#DC6C6C", "#E06C6C", "#E06C6C", "#E06C6C", "#E06868", "#E06868", "#E06868", "#E06464", "#E06464", "#E06464", "#E06464", "#E06060", "#E06060", "#E06060", "#E46060", "#E46060", "#E45C5C", "#E45C5C", "#E45C5C", "#E45858", "#E45858", "#E45858", "#E45858", "#E45454", "#E45454", "#E45454", "#E45050", "#E45050", "#E45050", "#E85050", "#E85050", "#E84C4C", "#E84C4C", "#E84C4C", "#E84848", "#E84848", "#E84848", "#E84848", "#E84444", "#E84444", "#E84444", "#E84444", "#E84040", "#E84040", "#EC4040", "#EC4040", "#EC3C3C", "#EC3C3C", "#EC3C3C", "#EC3C3C", "#EC3838", "#EC3838", "#EC3838", "#EC3434", "#EC3434", "#EC3434", "#EC3434", "#EC3030", "#EC3030", "#F03030", "#F03030", "#F02C2C", "#F02C2C", "#F02C2C", "#F02C2C", "#F02828", "#F02828", "#F02828", "#F02424", "#F02424", "#F02424", "#F02424", "#F02020", "#F02020", "#F42020", "#F42020", "#F42020", "#F41C1C", "#F41C1C", "#F41C1C", "#F41818", "#F41818", "#F41818", "#F41818", "#F41414", "#F41414", "#F41414", "#F41010", "#F41010", "#F81010", "#F81010", "#F81010", "#F80C0C", "#F80C0C", "#F80C0C", "#F80808", "#F80808", "#F80808", "#F80808", "#F80404", "#F80404", "#F80404", "#FC0000", "#FC0000", "#FC0000"], "imagej_16_colors": ["#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#0101AB", "#0101AB", "#0101AB", "#0101AB", "#0101AB", "#0101AB", "#0101AB", "#0101AB", "#0101AB", "#0101AB", "#0101AB", "#0101AB", "#0101AB", "#0101AB", "#0101AB", "#0101AB", "#0101AB", "#0101E0", "#0101E0", "#0101E0", "#0101E0", "#0101E0", "#0101E0", "#0101E0", "#0101E0", "#0101E0", "#0101E0", "#0101E0", "#0101E0", "#0101E0", "#0101E0", "#0101E0", "#0101E0", "#0101E0", "#006EFF", "#006EFF", "#006EFF", "#006EFF", "#006EFF", "#006EFF", "#006EFF", "#006EFF", "#006EFF", "#006EFF", "#006EFF", "#006EFF", "#006EFF", "#006EFF", "#006EFF", "#006EFF", "#006EFF", "#01ABFE", "#01ABFE", "#01ABFE", "#01ABFE", "#01ABFE", "#01ABFE", "#01ABFE", "#01ABFE", "#01ABFE", "#01ABFE", "#01ABFE", "#01ABFE", "#01ABFE", "#01ABFE", "#01ABFE", "#01ABFE", "#01ABFE", "#01E0FE", "#01E0FE", "#01E0FE", "#01E0FE", "#01E0FE", "#01E0FE", "#01E0FE", "#01E0FE", "#01E0FE", "#01E0FE", "#01E0FE", "#01E0FE", "#01E0FE", "#01E0FE", "#01E0FE", "#01E0FE", "#01E0FE", "#01FE01", "#01FE01", "#01FE01", "#01FE01", "#01FE01", "#01FE01", "#01FE01", "#01FE01", "#01FE01", "#01FE01", "#01FE01", "#01FE01", "#01FE01", "#01FE01", "#01FE01", "#01FE01", "#01FE01", "#BEFF00", "#BEFF00", "#BEFF00", "#BEFF00", "#BEFF00", "#BEFF00", "#BEFF00", "#BEFF00", "#BEFF00", "#BEFF00", "#BEFF00", "#BEFF00", "#BEFF00", "#BEFF00", "#BEFF00", "#BEFF00", "#BEFF00", "#FFFF00", "#FFFF00", "#FFFF00", "#FFFF00", "#FFFF00", "#FFFF00", "#FFFF00", "#FFFF00", "#FFFF00", "#FFFF00", "#FFFF00", "#FFFF00", "#FFFF00", "#FFFF00", "#FFFF00", "#FFFF00", "#FFFF00", "#FFE000", "#FFE000", "#FFE000", "#FFE000", "#FFE000", "#FFE000", "#FFE000", "#FFE000", "#FFE000", "#FFE000", "#FFE000", "#FFE000", "#FFE000", "#FFE000", "#FFE000", "#FFE000", "#FFE000", "#FF8D00", "#FF8D00", "#FF8D00", "#FF8D00", "#FF8D00", "#FF8D00", "#FF8D00", "#FF8D00", "#FF8D00", "#FF8D00", "#FF8D00", "#FF8D00", "#FF8D00", "#FF8D00", "#FF8D00", "#FF8D00", "#FF8D00", "#FA5E00", "#FA5E00", "#FA5E00", "#FA5E00", "#FA5E00", "#FA5E00", "#FA5E00", "#FA5E00", "#FA5E00", "#FA5E00", "#FA5E00", "#FA5E00", "#FA5E00", "#FA5E00", "#FA5E00", "#FA5E00", "#FA5E00", "#F50000", "#F50000", "#F50000", "#F50000", "#F50000", "#F50000", "#F50000", "#F50000", "#F50000", "#F50000", "#F50000", "#F50000", "#F50000", "#F50000", "#F50000", "#F50000", "#F50000", "#F50087", "#F50087", "#F5008D", "#F5008D", "#F50093", "#F50093", "#F50099", "#F50099", "#F500A0", "#F500A0", "#F500A6", "#F500A6", "#F500AC", "#F500AC", "#F500B2", "#F500B2", "#F500B9", "#F500B9", "#F500BF", "#F500BF", "#F500C5", "#F500C5", "#F500CB", "#F500CB", "#F500D2", "#F500D2", "#F500D8", "#F500D8", "#F500DE", "#F500DE", "#F500E4", "#F500E4", "#DEB4DE", "#DEB4DE", "#DEB4DE", "#DEB4DE", "#DEB4DE", "#DEB4DE", "#DEB4DE", "#DEB4DE", "#DEB4DE", "#DEB4DE", "#DEB4DE", "#DEB4DE", "#DEB4DE", "#DEB4DE", "#DEB4DE", "#DEB4DE", "#DEB4DE", "#FFFFFF", "#FFFFFF", "#FFFFFF", "#FFFFFF", "#FFFFFF", "#FFFFFF", "#FFFFFF", "#FFFFFF", "#FFFFFF", "#FFFFFF", "#FFFFFF", "#FFFFFF", "#FFFFFF", "#FFFFFF", "#FFFFFF", "#FFFFFF", "#FFFFFF"], "imagej_16_equal": ["#000000", "#000000", "#7C0000", "#7C0000", "#7C0000", "#7C0000", "#7C0000", "#7C0000", "#7C0000", "#7C0000", "#7C0000", "#7C0000", "#7C0000", "#7C0000", "#7C0000", "#7C0000", "#7C0000", "#7C0000", "#C80000", "#C80000", "#C80000", "#C80000", "#C80000", "#C80000", "#C80000", "#C80000", "#C80000", "#C80000", "#C80000", "#C80000", "#C80000", "#C80000", "#C80000", "#C80000", "#C80000", "#FC2400", "#FC2400", "#FC2400", "#FC2400", "#FC2400", "#FC2400", "#FC2400", "#FC2400", "#FC2400", "#FC2400", "#FC2400", "#FC2400", "#FC2400", "#FC2400", "#FC2400", "#FC2400", "#FC2400", "#FC9000", "#FC9000", "#FC9000", "#FC9000", "#FC9000", "#FC9000", "#FC9000", "#FC9000", "#FC9000", "#FC9000", "#FC9000", "#FC9000", "#FC9000", "#FC9000", "#FC9000", "#FC9000", "#FC9000", "#FCFC00", "#FCFC00", "#FCFC00", "#FCFC00", "#FCFC00", "#FCFC00", "#FCFC00", "#FCFC00", "#FCFC00", "#FCFC00", "#FCFC00", "#FCFC00", "#FCFC00", "#FCFC00", "#FCFC00", "#FCFC00", "#FCFC00", "#80E004", "#80E004", "#80E004", "#80E004", "#80E004", "#80E004", "#80E004", "#80E004", "#80E004", "#80E004", "#80E004", "#80E004", "#80E004", "#80E004", "#80E004", "#88E400", "#88E400", "#80E004", "#80E004", "#00C408", "#00C408", "#00C408", "#00C408", "#00C408", "#00C408", "#00C408", "#00C408", "#00C408", "#00C408", "#00C408", "#00C408", "#00C408", "#00C408", "#00C408", "#00C408", "#00C408", "#00BCC0", "#00BCC0", "#00BCC0", "#00BCC0", "#00BCC0", "#00BCC0", "#00BCC0", "#00BCC0", "#00BCC0", "#00BCC0", "#00BCC0", "#00BCC0", "#00BCC0", "#00BCC0", "#00BCC0", "#00BCC0", "#00BCC0", "#0864D0", "#0864D0", "#0864D0", "#0864D0", "#0864D0", "#0864D0", "#0864D0", "#0864D0", "#0864D0", "#0864D0", "#0864D0", "#0864D0", "#0864D0", "#0864D0", "#0864D0", "#0864D0", "#0864D0", "#1810E8", "#1810E8", "#1810E8", "#1810E8", "#1810E8", "#1810E8", "#1810E8", "#1810E8", "#1810E8", "#1810E8", "#1810E8", "#1810E8", "#1810E8", "#1810E8", "#1810E8", "#1810E8", "#1810E8", "#4C14C4", "#4C14C4", "#4C14C4", "#4C14C4", "#4C14C4", "#4C14C4", "#4C14C4", "#4C14C4", "#4C14C4", "#4C14C4", "#4C14C4", "#4C14C4", "#4C14C4", "#4C14C4", "#4C14C4", "#4C14C4", "#4C14C4", "#7424B0", "#7424B0", "#7424B0", "#7424B0", "#7424B0", "#7424B0", "#7424B0", "#7424B0", "#7424B0", "#7424B0", "#7424B0", "#7424B0", "#7424B0", "#7424B0", "#7424B0", "#7424B0", "#7424B0", "#884898", "#884898", "#884898", "#884898", "#884898", "#884898", "#884898", "#884898", "#884898", "#884898", "#884898", "#884898", "#884898", "#884898", "#884898", "#884898", "#884898", "#808080", "#808080", "#808080", "#808080", "#808080", "#808080", "#808080", "#808080", "#808080", "#808080", "#808080", "#808080", "#808080", "#808080", "#808080", "#808080", "#808080", "#C0C0C0", "#C0C0C0", "#C0C0C0", "#C0C0C0", "#C0C0C0", "#C0C0C0", "#C0C0C0", "#C0C0C0", "#C0C0C0", "#C0C0C0", "#C0C0C0", "#C0C0C0", "#C0C0C0", "#C0C0C0", "#C0C0C0", "#C0C0C0", "#C0C0C0", "#FCFCFC", "#FCFCFC", "#FCFCFC", "#FCFCFC", "#FCFCFC", "#FCFCFC", "#FCFCFC", "#FCFCFC", "#FCFCFC", "#FCFCFC", "#FCFCFC", "#FCFCFC", "#FCFCFC", "#FCFCFC", "#FCFCFC", "#FCFCFC", "#FCFCFC"], "imagej_20_colors": ["#310194", "#310194", "#310194", "#310194", "#310194", "#310194", "#310194", "#310194", "#310194", "#310194", "#310194", "#310194", "#310194", "#310194", "#01019E", "#01019E", "#01019E", "#01019E", "#01019E", "#01019E", "#01019E", "#01019E", "#01019E", "#01019E", "#01019E", "#01019E", "#01019E", "#01019E", "#0101CF", "#0101CF", "#0101CF", "#0101CF", "#0101CF", "#0101CF", "#0101CF", "#0101CF", "#0101CF", "#0101CF", "#0101CF", "#0101CF", "#0101CF", "#0101CF", "#0101F0", "#0101F0", "#0101F0", "#0101F0", "#0101F0", "#0101F0", "#0101F0", "#0101F0", "#0101F0", "#0101F0", "#0101F0", "#0101F0", "#0101F0", "#0101F0", "#0162F0", "#0162F0", "#0162F0", "#0162F0", "#0162F0", "#0162F0", "#0162F0", "#0162F0", "#0162F0", "#0162F0", "#0162F0", "#0162F0", "#0162F0", "#0184C5", "#0184C5", "#0184C5", "#0184C5", "#0184C5", "#0184C5", "#0184C5", "#0184C5", "#0184C5", "#0184C5", "#0184C5", "#0184C5", "#0184C5", "#0184C5", "#01859E", "#01859E", "#01859E", "#01859E", "#01859E", "#01859E", "#01859E", "#01859E", "#01859E", "#01859E", "#01859E", "#01859E", "#01859E", "#01859E", "#019E80", "#019E80", "#019E80", "#019E80", "#019E80", "#019E80", "#019E80", "#019E80", "#019E80", "#019E80", "#019E80", "#019E80", "#019E80", "#019E80", "#019401", "#019401", "#019401", "#019401", "#019401", "#019401", "#019401", "#019401", "#019401", "#019401", "#019401", "#019401", "#019401", "#01C501", "#01C501", "#01C501", "#01C501", "#01C501", "#01C501", "#01C501", "#01C501", "#01C501", "#01C501", "#01C501", "#01C501", "#01C501", "#01C501", "#01E301", "#01E301", "#01E301", "#01E301", "#01E301", "#01E301", "#01E301", "#01E301", "#01E301", "#01E301", "#01E301", "#01E301", "#01E301", "#01E301", "#80ED01", "#80ED01", "#80ED01", "#80ED01", "#80ED01", "#80ED01", "#80ED01", "#80ED01", "#80ED01", "#80ED01", "#80ED01", "#80ED01", "#80ED01", "#80ED01", "#C5F001", "#C5F001", "#C5F001", "#C5F001", "#C5F001", "#C5F001", "#C5F001", "#C5F001", "#C5F001", "#C5F001", "#C5F001", "#C5F001", "#C5F001", "#F0F001", "#F0F001", "#F0F001", "#F0F001", "#F0F001", "#F0F001", "#F0F001", "#F0F001", "#F0F001", "#F0F001", "#F0F001", "#F0F001", "#F0F001", "#F0F001", "#F0CF01", "#F0CF01", "#F0CF01", "#F0CF01", "#F0CF01", "#F0CF01", "#F0CF01", "#F0CF01", "#F0CF01", "#F0CF01", "#F0CF01", "#F0CF01", "#F0CF01", "#F0CF01", "#F0B201", "#F0B201", "#F0B201", "#F0B201", "#F0B201", "#F0B201", "#F0B201", "#F0B201", "#F0B201", "#F0B201", "#F0B201", "#F0B201", "#F0B201", "#F0B201", "#F08E01", "#F08E01", "#F08E01", "#F08E01", "#F08E01", "#F08E01", "#F08E01", "#F08E01", "#F08E01", "#F08E01", "#F08E01", "#F08E01", "#F08E01", "#F06201", "#F06201", "#F06201", "#F06201", "#F06201", "#F06201", "#F06201", "#F06201", "#F06201", "#F06201", "#F06201", "#F06201", "#F06201", "#F06201", "#F00101", "#F00101", "#F00101", "#F00101", "#F00101", "#F00101", "#F00101", "#F00101", "#F00101", "#F00101", "#F00101", "#F00101", "#F00101", "#F00101", "#C5C5C5", "#C5C5C5", "#C5C5C5", "#C5C5C5", "#C5C5C5", "#C5C5C5", "#C5C5C5", "#C5C5C5", "#C5C5C5", "#C5C5C5", "#C5C5C5", "#C5C5C5", "#C5C5C5", "#C5C5C5"], "imagej_amber": ["#E7F39B", "#E7F39B", "#E7F39B", "#F2FE9A", "#F2FE9A", "#F2FE99", "#F2FE99", "#F3FE98", "#F3FE98", "#F3FE96", "#F3FE96", "#F3FE95", "#F3FE95", "#F3FE94", "#F3FE94", "#F4FE93", "#F4FE93", "#F4FE92", "#F4FE92", "#F4FE91", "#F4FE91", "#F5FE90", "#F5FE90", "#F5FE8F", "#F5FE8F", "#F5FE8E", "#F5FE8E", "#F6FE8D", "#F6FE8D", "#F6FE8C", "#F6FE8C", "#F6FE8B", "#F6FE8B", "#F7FE8A", "#F7FE8A", "#F7FE89", "#F7FE89", "#F8FE88", "#F8FE88", "#F8FE87", "#F8FE87", "#F9FE85", "#F9FE85", "#F9FE84", "#F9FE84", "#FAFE83", "#FAFE83", "#FAFE82", "#FAFE82", "#FBFE81", "#FBFE81", "#FBFE80", "#FBFE80", "#FCFE7F", "#FCFE7F", "#FCFE7E", "#FCFE7E", "#FDFE7D", "#FDFE7D", "#FDFE7C", "#FDFE7C", "#FEFE7B", "#FEFE7B", "#FEFD7A", "#FEFD7A", "#FEFD79", "#FEFD79", "#FEFC78", "#FEFC78", "#FEFB77", "#FEFB77", "#FEFB76", "#FEFB76", "#FEFA74", "#FEFA74", "#FEF973", "#FEF973", "#FEF872", "#FEF872", "#FEF871", "#FEF871", "#FEF770", "#FEF770", "#FEF66F", "#FEF66F", "#FEF56E", "#FEF56E", "#FEF56D", "#FEF56D", "#FEF46C", "#FEF46C", "#FEF36B", "#FEF36B", "#FEF26A", "#FEF26A", "#FEF169", "#FEF169", "#FEF068", "#FEF068", "#FEEF67", "#FEEF67", "#FEEE66", "#FEEE66", "#FEED65", "#FEED65", "#FDED63", "#FDED63", "#FDEC62", "#FDEC62", "#FDEB61", "#FDEB61", "#FDEA60", "#FDEA60", "#FDE95F", "#FDE95F", "#FDE85E", "#FDE85E", "#FDE75D", "#FDE75D", "#FDE65C", "#FDE65C", "#FDE45B", "#FDE45B", "#FDE35A", "#FDE35A", "#FDE259", "#FDE259", "#FDE158", "#FDE158", "#FDE057", "#FDE057", "#FDDF56", "#FDDF56", "#FDDE55", "#FDDE55", "#FDDD54", "#FDDD54", "#FDDB52", "#FDDB52", "#FDDA51", "#FDDA51", "#FDD950", "#FDD950", "#FDD84F", "#FDD84F", "#FDD74E", "#FDD74E", "#FDD54D", "#FDD54D", "#FDD44C", "#FDD44C", "#FDD34B", "#FDD34B", "#FDD24A", "#FDD24A", "#FDD049", "#FDD049", "#FDCF48", "#FDCF48", "#FDCE47", "#FDCE47", "#FDCC46", "#FDCC46", "#FDCB45", "#FDCB45", "#FDCA44", "#FDCA44", "#FDC843", "#FDC843", "#FDC741", "#FDC741", "#FDC540", "#FDC540", "#FDC43F", "#FDC43F", "#FDC33E", "#FDC33E", "#FDC13D", "#FDC13D", "#FDC03C", "#FDC03C", "#FDBE3B", "#FDBE3B", "#FDBD3A", "#FDBD3A", "#FDBB39", "#FDBB39", "#FDBA38", "#FDBA38", "#FDB837", "#FDB837", "#FDB736", "#FDB736", "#FDB535", "#FDB535", "#FDB334", "#FDB334", "#FBB133", "#FBB133", "#FAAF32", "#FAAF32", "#F8AD30", "#F8AD30", "#F6AB2F", "#F6AB2F", "#F5A82E", "#F5A82E", "#F3A62D", "#F3A62D", "#F2A42C", "#F2A42C", "#F0A22B", "#F0A22B", "#EEA02A", "#EEA02A", "#ED9E29", "#ED9E29", "#EB9C28", "#EB9C28", "#E99927", "#E99927", "#E89726", "#E89726", "#E69525", "#E69525", "#E59324", "#E59324", "#E39123", "#E39123", "#E18F22", "#E18F22", "#E08D21", "#E08D21", "#DE8B1F", "#DE8B1F", "#DD891E", "#DD891E", "#DB871D", "#DB871D", "#D9851C", "#D9851C", "#D8831B", "#D8831B", "#D6811A", "#D6811A", "#D48019", "#D48019", "#D37E18", "#D37E18", "#D17C17", "#D17C17", "#D07A16", "#D07A16", "#CE7815", "#CE7815", "#CC7614", "#CC7614", "#CB7413", "#CB7413", "#C97312", "#C97312", "#C77111", "#C77111", "#C66F10", "#C66F10", "#C46D0E", "#C46D0E", "#C36B0D", "#C36B0D", "#C16A0C", "#C16A0C", "#BF680B", "#BF680B", "#BE660A", "#BE660A", "#BC6509", "#BC6509", "#BA6308", "#BA6308", "#B96107", "#B96107", "#B76006", "#B76006", "#B65E05", "#B65E05", "#B45C04", "#B45C04", "#B25B03", "#B25B03", "#B15902", "#B15902", "#AF5701", "#AF5701", "#AD5600", "#AD5600", "#AC5401", "#AC5401", "#AA5301", "#AA5301", "#A95101", "#A95101", "#A75001", "#A75001", "#A54E01", "#A54E01", "#A44D01", "#A44D01", "#A24B01", "#A24B01", "#A14A01", "#A14A01", "#9F4801", "#9F4801", "#9D4701", "#9D4701", "#9C4501", "#9C4501", "#9A4401", "#9A4401", "#984301", "#984301", "#974101", "#974101", "#954001", "#954001", "#943F01", "#943F01", "#923D01", "#923D01", "#903C01", "#903C01", "#8F3B01", "#8F3B01", "#8D3901", "#8D3901", "#8B3801", "#8B3801", "#8A3701", "#8A3701", "#883601", "#883601", "#873401", "#873401", "#853301", "#853301", "#833201", "#833201", "#823101", "#823101", "#803001", "#803001", "#7E2F01", "#7E2F01", "#7D2D01", "#7D2D01", "#7B2C01", "#7B2C01", "#7A2B01", "#7A2B01", "#782A01", "#782A01", "#762901", "#762901", "#752801", "#752801", "#732701", "#732701", "#712601", "#712601", "#702501", "#702501", "#6E2401", "#6E2401", "#6D2301", "#6D2301", "#6B2200", "#6B2200", "#692100", "#692100", "#682000", "#682000", "#661F00", "#661F00", "#641E00", "#641E00", "#631D00", "#631D00", "#611C00", "#611C00", "#601B00", "#601B00", "#5E1A00", "#5E1A00", "#5C1900", "#5C1900", "#5B1800", "#5B1800", "#591800", "#591800", "#571700", "#571700", "#561600", "#561600", "#541500", "#541500", "#531400", "#531400", "#511400", "#511400", "#4F1300", "#4F1300", "#4E1200", "#4E1200", "#4C1100", "#4C1100", "#4A1100", "#4A1100", "#491000", "#491000", "#470F00", "#470F00", "#460F00", "#460F00", "#440E00", "#440E00", "#420D00", "#420D00", "#410D00", "#410D00", "#3F0C00", "#3F0C00", "#3D0C00", "#3D0C00", "#3C0B00", "#3C0B00", "#3A0A00", "#3A0A00", "#390A00", "#390A00", "#370900", "#370900", "#350900", "#350900", "#340800", "#340800", "#320800", "#320800", "#300700", "#300700", "#2F0700", "#2F0700", "#2D0600", "#2D0600", "#2C0600", "#2C0600", "#2A0600", "#2A0600", "#280500", "#280500", "#270500", "#270500", "#250400", "#250400", "#230400", "#230400", "#220400", "#220400", "#200300", "#200300", "#1F0300", "#1F0300", "#1D0300", "#1D0300", "#1B0200", "#1B0200", "#1A0200", "#1A0200", "#180200", "#180200", "#160200", "#160200", "#150100", "#150100", "#130100", "#130100", "#120100", "#120100", "#100100", "#100100", "#0E0100", "#0E0100", "#0D0000", "#0D0000", "#0B0000", "#0B0000", "#090000", "#090000", "#080000", "#080000", "#060000", "#060000", "#050000", "#050000", "#030000", "#030000", "#010000", "#010000", "#010101", "#010101", "#010101"], "imagej_auxctq": ["#010401", "#010401", "#010401", "#010501", "#010501", "#010601", "#010601", "#010701", "#010701", "#010801", "#010801", "#010901", "#010901", "#010A01", "#010A01", "#010B01", "#010B01", "#010C01", "#010C01", "#010D01", "#010D01", "#010E01", "#010E01", "#010F01", "#010F01", "#011001", "#011001", "#011101", "#011101", "#011201", "#011201", "#011301", "#011301", "#011401", "#011401", "#011501", "#011501", "#011601", "#011601", "#011701", "#011701", "#011901", "#011901", "#011A01", "#011A01", "#011B01", "#011B01", "#011C01", "#011C01", "#011D01", "#011D01", "#011E01", "#011E01", "#011F01", "#011F01", "#012001", "#012001", "#012101", "#012101", "#012201", "#012201", "#012301", "#012301", "#012401", "#012401", "#012501", "#012501", "#012601", "#012601", "#012701", "#012701", "#012801", "#012801", "#012901", "#012901", "#012A01", "#012A01", "#012B01", "#012B01", "#012C01", "#012C01", "#012E01", "#012E01", "#012F01", "#012F01", "#013001", "#013001", "#013101", "#013101", "#013201", "#013201", "#013301", "#013301", "#013401", "#013401", "#013501", "#013501", "#013601", "#013601", "#013701", "#013701", "#013801", "#013801", "#013901", "#013901", "#013A01", "#013A01", "#013B01", "#013B01", "#013C01", "#013C01", "#013D01", "#013D01", "#013E01", "#013E01", "#013F01", "#013F01", "#014001", "#014001", "#014101", "#014101", "#014201", "#014201", "#014301", "#014301", "#014401", "#014401", "#014501", "#014501", "#014601", "#014601", "#014701", "#014701", "#014801", "#014801", "#014901", "#014901", "#014A01", "#014A01", "#014B01", "#014B01", "#014C01", "#014C01", "#014D01", "#014D01", "#014E01", "#014E01", "#014F01", "#014F01", "#015001", "#015001", "#015104", "#015104", "#015208", "#015208", "#01530B", "#01530B", "#01540F", "#01540F", "#015616", "#015616", "#015719", "#015719", "#01581D", "#01581D", "#015920", "#015920", "#015A24", "#015A24", "#015B27", "#015B27", "#015C2B", "#015C2B", "#015D2E", "#015D2E", "#015E32", "#015E32", "#015F35", "#015F35", "#016039", "#016039", "#015B3D", "#015B3D", "#015640", "#015640", "#015143", "#015143", "#014C46", "#014C46", "#01474A", "#01474A", "#01434D", "#01434D", "#013F51", "#013F51", "#013A54", "#013A54", "#013558", "#013558", "#012C5F", "#012C5F", "#012762", "#012762", "#012266", "#012266", "#011D69", "#011D69", "#01186D", "#01186D", "#011471", "#011471", "#010F71", "#010F71", "#010A72", "#010A72", "#010573", "#010573", "#010174", "#010174", "#010175", "#010175", "#010176", "#010176", "#010177", "#010177", "#010178", "#010178", "#010179", "#010179", "#01017A", "#01017A", "#01017B", "#01017B", "#01017C", "#01017C", "#01017D", "#01017D", "#01017F", "#01017F", "#0A0180", "#0A0180", "#130181", "#130181", "#1C0182", "#1C0182", "#250183", "#250183", "#2E0184", "#2E0184", "#370185", "#370185", "#400186", "#400186", "#480187", "#480187", "#510188", "#510188", "#5A0189", "#5A0189", "#63018A", "#63018A", "#6C018B", "#6C018B", "#75018C", "#75018C", "#7E018D", "#7E018D", "#87018E", "#87018E", "#90018F", "#90018F", "#910190", "#910190", "#920191", "#920191", "#930192", "#930192", "#950194", "#950194", "#960195", "#960195", "#970196", "#970196", "#980197", "#980197", "#990198", "#990198", "#9A0199", "#9A0199", "#9B019A", "#9B019A", "#9C019B", "#9C019B", "#9D019C", "#9D019C", "#9E019D", "#9E019D", "#9F019E", "#9F019E", "#A0019F", "#A0019F", "#A103A0", "#A103A0", "#A2059D", "#A2059D", "#A3079B", "#A3079B", "#A40A98", "#A40A98", "#A50C96", "#A50C96", "#A60E93", "#A60E93", "#A71091", "#A71091", "#A8138E", "#A8138E", "#AA1789", "#AA1789", "#AB1987", "#AB1987", "#AC1C84", "#AC1C84", "#AD1E82", "#AD1E82", "#AE207F", "#AE207F", "#AF227D", "#AF227D", "#B0257A", "#B0257A", "#B12778", "#B12778", "#B22975", "#B22975", "#B32C73", "#B32C73", "#B42E70", "#B42E70", "#B5306E", "#B5306E", "#B6326B", "#B6326B", "#B73569", "#B73569", "#B83766", "#B83766", "#B93964", "#B93964", "#BA3B61", "#BA3B61", "#BB3E5F", "#BB3E5F", "#BC405C", "#BC405C", "#BE4357", "#BE4357", "#BF4655", "#BF4655", "#BF4852", "#BF4852", "#C04A50", "#C04A50", "#C14D4D", "#C14D4D", "#C24F4B", "#C24F4B", "#C35148", "#C35148", "#C45346", "#C45346", "#C55643", "#C55643", "#C65841", "#C65841", "#C75A3F", "#C75A3F", "#C85C3D", "#C85C3D", "#C95F3A", "#C95F3A", "#CA6138", "#CA6138", "#CB6335", "#CB6335", "#CC6533", "#CC6533", "#CD6830", "#CD6830", "#CE6A2E", "#CE6A2E", "#CF6C2B", "#CF6C2B", "#D06F29", "#D06F29", "#D27324", "#D27324", "#D37521", "#D37521", "#D4781F", "#D4781F", "#D57A1C", "#D57A1C", "#D67C1A", "#D67C1A", "#D77E17", "#D77E17", "#D88115", "#D88115", "#D98312", "#D98312", "#DA8510", "#DA8510", "#DB870D", "#DB870D", "#DC8A0B", "#DC8A0B", "#DD8C08", "#DD8C08", "#DE8E06", "#DE8E06", "#DF9103", "#DF9103", "#E09401", "#E09401", "#E19809", "#E19809", "#E29B12", "#E29B12", "#E39F1A", "#E39F1A", "#E4A223", "#E4A223", "#E5A62B", "#E5A62B", "#E7AD3C", "#E7AD3C", "#E8B044", "#E8B044", "#E9B44C", "#E9B44C", "#EAB855", "#EAB855", "#EBBB5D", "#EBBB5D", "#ECBF66", "#ECBF66", "#EDC16E", "#EDC16E", "#EEC577", "#EEC577", "#EFC87F", "#EFC87F", "#F0CC88", "#F0CC88", "#F1CF90", "#F1CF90", "#F2D399", "#F2D399", "#F3D6A1", "#F3D6A1", "#F4DAAA", "#F4DAAA", "#F5DEB2", "#F5DEB2", "#F6E1BB", "#F6E1BB", "#F7E5C2", "#F7E5C2", "#F8E8CB", "#F8E8CB", "#F9ECD3", "#F9ECD3", "#FBF2E0", "#FBF2E0", "#FDF7EA", "#FDF7EA", "#FDFDF1", "#FDFDF1", "#FDFDF7", "#FDFDF7", "#FDFDFD", "#FDFDFD", "#FDFDFD", "#FDFDFD", "#FDFDFD", "#FDFDFD", "#FDFDFD", "#FDFDFD", "#FDFDFD", "#FDFDFD", "#FDFDFD", "#FDFDFD", "#FDFDFD", "#FDFDFD", "#FDFDFD", "#FDFDFD"], "imagej_blue_orange": ["#020303", "#020303", "#020303", "#030505", "#030505", "#040607", "#040607", "#050808", "#050808", "#060A0A", "#060A0A", "#070C0C", "#070C0C", "#080E0E", "#080E0E", "#091010", "#091010", "#0A1112", "#0A1112", "#0C1314", "#0C1314", "#0D1516", "#0D1516", "#0E1717", "#0E1717", "#0F1919", "#0F1919", "#101A1B", "#101A1B", "#111C1D", "#111C1D", "#121E1F", "#121E1F", "#132021", "#132021", "#142223", "#142223", "#152425", "#152425", "#162526", "#162526", "#172728", "#172728", "#18292A", "#18292A", "#192B2C", "#192B2C", "#1A2D2E", "#1A2D2E", "#1B2F30", "#1B2F30", "#1C3032", "#1C3032", "#1D3234", "#1D3234", "#1E3435", "#1E3435", "#1F3637", "#1F3637", "#213839", "#213839", "#22393B", "#22393B", "#233B3D", "#233B3D", "#243D3F", "#243D3F", "#253F40", "#253F40", "#264042", "#264042", "#274243", "#274243", "#284345", "#284345", "#294547", "#294547", "#2A4749", "#2A4749", "#2B464A", "#2B464A", "#2C444C", "#2C444C", "#2C434D", "#2C434D", "#2D424E", "#2D424E", "#2E414F", "#2E414F", "#2F4051", "#2F4051", "#2F3F52", "#2F3F52", "#303E53", "#303E53", "#313D54", "#313D54", "#323B56", "#323B56", "#323A57", "#323A57", "#333958", "#333958", "#343859", "#343859", "#35365B", "#35365B", "#35355C", "#35355C", "#36345D", "#36345D", "#37325F", "#37325F", "#383160", "#383160", "#383061", "#383061", "#392F62", "#392F62", "#3A2D64", "#3A2D64", "#3B2C65", "#3B2C65", "#3B2B66", "#3B2B66", "#3C2A67", "#3C2A67", "#3D2869", "#3D2869", "#3E276A", "#3E276A", "#3E266B", "#3E266B", "#3F246C", "#3F246C", "#40236E", "#40236E", "#40226F", "#40226F", "#402170", "#402170", "#411F72", "#411F72", "#421E73", "#421E73", "#431D74", "#431D74", "#431C75", "#431C75", "#441A77", "#441A77", "#451978", "#451978", "#461879", "#461879", "#46177A", "#46177A", "#47157C", "#47157C", "#48147D", "#48147D", "#49137E", "#49137E", "#491180", "#491180", "#4A1081", "#4A1081", "#4B0F82", "#4B0F82", "#4C0E83", "#4C0E83", "#4C0C85", "#4C0C85", "#4D0B86", "#4D0B86", "#4E0A87", "#4E0A87", "#4F0988", "#4F0988", "#4F078A", "#4F078A", "#50068B", "#50068B", "#51058C", "#51058C", "#52048D", "#52048D", "#52028F", "#52028F", "#530190", "#530190", "#550390", "#550390", "#57048F", "#57048F", "#59068F", "#59068F", "#5B088E", "#5B088E", "#5D0A8E", "#5D0A8E", "#5F0B8D", "#5F0B8D", "#610D8D", "#610D8D", "#630F8C", "#630F8C", "#66118C", "#66118C", "#68128C", "#68128C", "#6A148B", "#6A148B", "#6C168B", "#6C168B", "#6E178A", "#6E178A", "#70198A", "#70198A", "#721B89", "#721B89", "#741D89", "#741D89", "#761E88", "#761E88", "#782088", "#782088", "#7A2288", "#7A2288", "#7C2487", "#7C2487", "#7E2587", "#7E2587", "#802786", "#802786", "#822986", "#822986", "#842B85", "#842B85", "#862C85", "#862C85", "#892E85", "#892E85", "#8B3084", "#8B3084", "#8D3184", "#8D3184", "#8F3383", "#8F3383", "#913583", "#913583", "#933782", "#933782", "#953882", "#953882", "#973A81", "#973A81", "#993C81", "#993C81", "#9B3E81", "#9B3E81", "#9D3F80", "#9D3F80", "#9F4080", "#9F4080", "#A1427F", "#A1427F", "#A3447F", "#A3447F", "#A5457E", "#A5457E", "#A7477E", "#A7477E", "#A9497D", "#A9497D", "#AB4A7D", "#AB4A7D", "#AE4C7D", "#AE4C7D", "#B04E7C", "#B04E7C", "#B2507C", "#B2507C", "#B4517B", "#B4517B", "#B6537B", "#B6537B", "#B8557A", "#B8557A", "#BA577A", "#BA577A", "#BC5879", "#BC5879", "#BE5A79", "#BE5A79", "#BF5A77", "#BF5A77", "#BF5B75", "#BF5B75", "#C05B73", "#C05B73", "#C15C71", "#C15C71", "#C25C6F", "#C25C6F", "#C45C6D", "#C45C6D", "#C55D6B", "#C55D6B", "#C65D69", "#C65D69", "#C75E67", "#C75E67", "#C85E65", "#C85E65", "#C95E63", "#C95E63", "#CA5F61", "#CA5F61", "#CB5F5F", "#CB5F5F", "#CC605D", "#CC605D", "#CD605B", "#CD605B", "#CE6059", "#CE6059", "#CF6157", "#CF6157", "#D16155", "#D16155", "#D26253", "#D26253", "#D36251", "#D36251", "#D4624F", "#D4624F", "#D5634D", "#D5634D", "#D6634B", "#D6634B", "#D76449", "#D76449", "#D86447", "#D86447", "#D96445", "#D96445", "#DA6543", "#DA6543", "#DB6541", "#DB6541", "#DC6640", "#DC6640", "#DE663E", "#DE663E", "#DF663B", "#DF663B", "#E06739", "#E06739", "#E16737", "#E16737", "#E26835", "#E26835", "#E36833", "#E36833", "#E46831", "#E46831", "#E5692F", "#E5692F", "#E6692D", "#E6692D", "#E76A2B", "#E76A2B", "#E86A29", "#E86A29", "#E96A27", "#E96A27", "#EB6B25", "#EB6B25", "#EC6B23", "#EC6B23", "#ED6C21", "#ED6C21", "#EE6C1F", "#EE6C1F", "#EF6C1D", "#EF6C1D", "#F06D1B", "#F06D1B", "#F16D19", "#F16D19", "#F26E17", "#F26E17", "#F36E15", "#F36E15", "#F46E13", "#F46E13", "#F56F11", "#F56F11", "#F66F0F", "#F66F0F", "#F8700D", "#F8700D", "#F9700B", "#F9700B", "#FA7009", "#FA7009", "#FB7107", "#FB7107", "#FC7105", "#FC7105", "#FD7203", "#FD7203", "#FE7201", "#FE7201", "#FE7506", "#FE7506", "#FE780C", "#FE780C", "#FE7B11", "#FE7B11", "#FE7E16", "#FE7E16", "#FE811C", "#FE811C", "#FE8421", "#FE8421", "#FE8726", "#FE8726", "#FE8A2C", "#FE8A2C", "#FE8C31", "#FE8C31", "#FE8F36", "#FE8F36", "#FE923B", "#FE923B", "#FE9540", "#FE9540", "#FE9845", "#FE9845", "#FE9B4A", "#FE9B4A", "#FE9E50", "#FE9E50", "#FEA155", "#FEA155", "#FEA45A", "#FEA45A", "#FEA760", "#FEA760", "#FEAA65", "#FEAA65", "#FEAD6A", "#FEAD6A", "#FEB070", "#FEB070", "#FEB375", "#FEB375", "#FEB67A", "#FEB67A", "#FEB980", "#FEB980", "#FEBB85", "#FEBB85", "#FEBE8A", "#FEBE8A", "#FEC08F", "#FEC08F", "#FEC395", "#FEC395", "#FEC69A", "#FEC69A", "#FEC99F", "#FEC99F", "#FECCA5", "#FECCA5", "#FECFAA", "#FECFAA", "#FED2AF", "#FED2AF", "#FED5B5", "#FED5B5", "#FED8BA", "#FED8BA", "#FEDBBF", "#FEDBBF", "#FEDEC4", "#FEDEC4", "#FEE1C9", "#FEE1C9", "#FEE4CE", "#FEE4CE", "#FEE7D4", "#FEE7D4", "#FEE9D9", "#FEE9D9", "#FEECDE", "#FEECDE", "#FEEFE3", "#FEEFE3", "#FEF2E9", "#FEF2E9", "#FEF5EE", "#FEF5EE", "#FEF8F3", "#FEF8F3", "#FEFBF9", "#FEFBF9", "#FEFBF9"], "imagej_brain": ["#010301", "#010301", "#010301", "#020501", "#020501", "#030802", "#030802", "#030A02", "#030A02", "#040D03", "#040D03", "#050F03", "#050F03", "#061203", "#061203", "#061404", "#061404", "#071604", "#071604", "#081905", "#081905", "#091B05", "#091B05", "#091E05", "#091E05", "#0A2006", "#0A2006", "#0B2306", "#0B2306", "#0C2507", "#0C2507", "#0C2707", "#0C2707", "#0D2A07", "#0D2A07", "#0E2C08", "#0E2C08", "#0E2F08", "#0E2F08", "#0F3109", "#0F3109", "#103409", "#103409", "#113609", "#113609", "#11380A", "#11380A", "#123B0A", "#123B0A", "#133D0B", "#133D0B", "#14400B", "#14400B", "#14410B", "#14410B", "#15440C", "#15440C", "#16460C", "#16460C", "#17490D", "#17490D", "#15490D", "#15490D", "#14490D", "#14490D", "#13490D", "#13490D", "#12490D", "#12490D", "#11490D", "#11490D", "#10490D", "#10490D", "#0F490D", "#0F490D", "#0E490D", "#0E490D", "#0C490D", "#0C490D", "#0B490D", "#0B490D", "#0A490D", "#0A490D", "#09490D", "#09490D", "#08490D", "#08490D", "#07490D", "#07490D", "#06490D", "#06490D", "#05490E", "#05490E", "#054D1C", "#054D1C", "#05522B", "#05522B", "#055739", "#055739", "#055C47", "#055C47", "#056155", "#056155", "#056664", "#056664", "#056B72", "#056B72", "#057081", "#057081", "#057490", "#057490", "#05799E", "#05799E", "#057EAD", "#057EAD", "#0583BB", "#0583BB", "#0588C9", "#0588C9", "#058DD7", "#058DD7", "#0592E6", "#0592E6", "#0597F5", "#0597F5", "#0A95F5", "#0A95F5", "#0F93F6", "#0F93F6", "#1491F6", "#1491F6", "#198FF7", "#198FF7", "#1E8DF7", "#1E8DF7", "#238BF8", "#238BF8", "#2889F8", "#2889F8", "#2D88F9", "#2D88F9", "#3286FA", "#3286FA", "#3784FA", "#3784FA", "#3C82FB", "#3C82FB", "#4080FB", "#4080FB", "#457EFC", "#457EFC", "#4A7CFC", "#4A7CFC", "#4F7AFD", "#4F7AFD", "#5579FE", "#5579FE", "#5072FE", "#5072FE", "#4B6BFE", "#4B6BFE", "#4664FE", "#4664FE", "#415EFE", "#415EFE", "#3D57FE", "#3D57FE", "#3850FE", "#3850FE", "#3349FE", "#3349FE", "#2E43FE", "#2E43FE", "#293DFE", "#293DFE", "#2436FE", "#2436FE", "#1F2FFE", "#1F2FFE", "#1A29FE", "#1A29FE", "#1522FE", "#1522FE", "#101BFE", "#101BFE", "#0B14FE", "#0B14FE", "#070EFE", "#070EFE", "#070DF9", "#070DF9", "#070CF5", "#070CF5", "#070BF0", "#070BF0", "#080BEC", "#080BEC", "#080AE7", "#080AE7", "#0809E3", "#0809E3", "#0809DE", "#0809DE", "#0908DA", "#0908DA", "#0907D5", "#0907D5", "#0907D1", "#0907D1", "#0906CC", "#0906CC", "#0A05C8", "#0A05C8", "#0A05C3", "#0A05C3", "#0A04BF", "#0A04BF", "#0A03BB", "#0A03BB", "#0B03B7", "#0B03B7", "#0F06B8", "#0F06B8", "#130ABA", "#130ABA", "#170DBB", "#170DBB", "#1B11BD", "#1B11BD", "#1F14BE", "#1F14BE", "#2318BF", "#2318BF", "#271BC0", "#271BC0", "#2C1FC2", "#2C1FC2", "#3022C4", "#3022C4", "#3426C5", "#3426C5", "#3829C7", "#3829C7", "#3C2DC8", "#3C2DC8", "#4030CA", "#4030CA", "#4334CB", "#4334CB", "#4737CD", "#4737CD", "#4C3BCF", "#4C3BCF", "#4F38D1", "#4F38D1", "#5335D4", "#5335D4", "#5732D7", "#5732D7", "#5B30DA", "#5B30DA", "#5F2DDD", "#5F2DDD", "#632AE0", "#632AE0", "#6728E3", "#6728E3", "#6B25E6", "#6B25E6", "#6F22E8", "#6F22E8", "#7320EB", "#7320EB", "#771DEE", "#771DEE", "#7B1AF1", "#7B1AF1", "#7F18F4", "#7F18F4", "#8315F7", "#8315F7", "#8712FA", "#8712FA", "#8B10FD", "#8B10FD", "#8C10FC", "#8C10FC", "#8E10FB", "#8E10FB", "#9010FA", "#9010FA", "#9210F9", "#9210F9", "#9410F8", "#9410F8", "#9610F7", "#9610F7", "#9810F6", "#9810F6", "#9A10F6", "#9A10F6", "#9B10F5", "#9B10F5", "#9D10F4", "#9D10F4", "#9F10F3", "#9F10F3", "#A110F2", "#A110F2", "#A310F1", "#A310F1", "#A510F0", "#A510F0", "#A710EF", "#A710EF", "#A910EF", "#A910EF", "#AE12E1", "#AE12E1", "#B315D3", "#B315D3", "#B817C5", "#B817C5", "#BE1AB8", "#BE1AB8", "#C21DAA", "#C21DAA", "#C71F9C", "#C71F9C", "#CD228E", "#CD228E", "#D22580", "#D22580", "#D72772", "#D72772", "#DD2A64", "#DD2A64", "#E22C56", "#E22C56", "#E72F48", "#E72F48", "#ED323B", "#ED323B", "#F2342D", "#F2342D", "#F7371F", "#F7371F", "#FD3A11", "#FD3A11", "#FD3C12", "#FD3C12", "#FD3E13", "#FD3E13", "#FD4014", "#FD4014", "#FD4216", "#FD4216", "#FD4417", "#FD4417", "#FD4618", "#FD4618", "#FD491A", "#FD491A", "#FD4B1B", "#FD4B1B", "#FD4D1C", "#FD4D1C", "#FD501E", "#FD501E", "#FD521F", "#FD521F", "#FD5420", "#FD5420", "#FD5722", "#FD5722", "#FD5923", "#FD5923", "#FD5B24", "#FD5B24", "#FD5E26", "#FD5E26", "#FD6024", "#FD6024", "#FD6322", "#FD6322", "#FD6620", "#FD6620", "#FD681E", "#FD681E", "#FD6B1C", "#FD6B1C", "#FD6E1A", "#FD6E1A", "#FD7018", "#FD7018", "#FD7316", "#FD7316", "#FD7614", "#FD7614", "#FD7812", "#FD7812", "#FD7B10", "#FD7B10", "#FD7E0E", "#FD7E0E", "#FD800C", "#FD800C", "#FD830A", "#FD830A", "#FD8608", "#FD8608", "#FE8907", "#FE8907", "#FD8B06", "#FD8B06", "#FD8D06", "#FD8D06", "#FD8F06", "#FD8F06", "#FD9106", "#FD9106", "#FD9306", "#FD9306", "#FD9605", "#FD9605", "#FD9805", "#FD9805", "#FD9A05", "#FD9A05", "#FD9C05", "#FD9C05", "#FD9E05", "#FD9E05", "#FDA104", "#FDA104", "#FDA304", "#FDA304", "#FDA504", "#FDA504", "#FDA704", "#FDA704", "#FDA904", "#FDA904", "#FDAC04", "#FDAC04", "#FDAF0B", "#FDAF0B", "#FDB313", "#FDB313", "#FDB61B", "#FDB61B", "#FDBA23", "#FDBA23", "#FDBE2B", "#FDBE2B", "#FDC032", "#FDC032", "#FDC43A", "#FDC43A", "#FDC841", "#FDC841", "#FDCB49", "#FDCB49", "#FDCF51", "#FDCF51", "#FDD258", "#FDD258", "#FDD660", "#FDD660", "#FDDA68", "#FDDA68", "#FDDD70", "#FDDD70", "#FDE178", "#FDE178", "#FEE580", "#FEE580", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE"], "imagej_cequal": ["#010101", "#010101", "#010101", "#010101", "#010101", "#010101", "#010101", "#010101", "#010101", "#010101", "#010101", "#010101", "#010101", "#010101", "#010101", "#010101", "#010101", "#010101", "#010101", "#010101", "#010101", "#010101", "#010101", "#010101", "#010101", "#010101", "#010101", "#010101", "#010101", "#010101", "#010101", "#010101", "#010101", "#010101", "#010708", "#010708", "#010E0F", "#010E0F", "#011416", "#011416", "#011B1D", "#011B1D", "#012224", "#012224", "#01282B", "#01282B", "#012F32", "#012F32", "#01363A", "#01363A", "#013C40", "#013C40", "#014247", "#014247", "#01484E", "#01484E", "#014F55", "#014F55", "#01565C", "#01565C", "#015C63", "#015C63", "#01636A", "#01636A", "#016A72", "#016A72", "#016A74", "#016A74", "#016B77", "#016B77", "#016B7A", "#016B7A", "#016C7C", "#016C7C", "#016C7F", "#016C7F", "#016D82", "#016D82", "#016D85", "#016D85", "#016E87", "#016E87", "#016F8A", "#016F8A", "#016F8D", "#016F8D", "#017090", "#017090", "#017092", "#017092", "#017195", "#017195", "#017198", "#017198", "#01729B", "#01729B", "#01739E", "#01739E", "#0372A0", "#0372A0", "#0672A3", "#0672A3", "#0972A6", "#0972A6", "#0C72A9", "#0C72A9", "#0F71AC", "#0F71AC", "#1271AE", "#1271AE", "#1571B1", "#1571B1", "#1871B4", "#1871B4", "#1B70B7", "#1B70B7", "#1E70BA", "#1E70BA", "#2170BC", "#2170BC", "#2470BF", "#2470BF", "#276FC1", "#276FC1", "#2A6FC4", "#2A6FC4", "#2D6FC7", "#2D6FC7", "#306FCE", "#306FCE", "#346FD1", "#346FD1", "#386FD4", "#386FD4", "#3C6FD7", "#3C6FD7", "#406FDB", "#406FDB", "#436FDE", "#436FDE", "#476FE1", "#476FE1", "#4B6FE4", "#4B6FE4", "#4F6FE8", "#4F6FE8", "#536FEB", "#536FEB", "#576FEE", "#576FEE", "#5B6FF1", "#5B6FF1", "#5F6FF5", "#5F6FF5", "#636FF8", "#636FF8", "#676FFB", "#676FFB", "#6B6FFE", "#6B6FFE", "#7070FE", "#7070FE", "#7269FE", "#7269FE", "#7462FE", "#7462FE", "#765BFE", "#765BFE", "#7854FE", "#7854FE", "#7A4DFE", "#7A4DFE", "#7C46FE", "#7C46FE", "#7E40FE", "#7E40FE", "#8139FE", "#8139FE", "#8332FE", "#8332FE", "#852BFE", "#852BFE", "#8724FE", "#8724FE", "#891DFE", "#891DFE", "#8B16FE", "#8B16FE", "#8D0FFE", "#8D0FFE", "#8F08FE", "#8F08FE", "#9201FE", "#9201FE", "#9401FB", "#9401FB", "#9701F9", "#9701F9", "#9A01F7", "#9A01F7", "#9D01F5", "#9D01F5", "#A001F3", "#A001F3", "#A301F1", "#A301F1", "#A601EF", "#A601EF", "#A901ED", "#A901ED", "#AC01EA", "#AC01EA", "#AF01E8", "#AF01E8", "#B101E6", "#B101E6", "#B401E4", "#B401E4", "#B701E2", "#B701E2", "#BA01E0", "#BA01E0", "#BD01DE", "#BD01DE", "#AF02DC", "#AF02DC", "#B107D7", "#B107D7", "#B40CD2", "#B40CD2", "#B712CD", "#B712CD", "#BA17C9", "#BA17C9", "#BD1CC4", "#BD1CC4", "#BF22BF", "#BF22BF", "#C227BC", "#C227BC", "#C52DB7", "#C52DB7", "#C832B2", "#C832B2", "#CB37AE", "#CB37AE", "#CE3DA9", "#CE3DA9", "#D141A4", "#D141A4", "#D446A0", "#D446A0", "#D74C9B", "#D74C9B", "#DA5196", "#DA5196", "#DD5792", "#DD5792", "#DD588F", "#DD588F", "#DE5A8C", "#DE5A8C", "#DF5B8A", "#DF5B8A", "#E05D87", "#E05D87", "#E15F84", "#E15F84", "#E26082", "#E26082", "#E3627F", "#E3627F", "#E4647D", "#E4647D", "#E5657A", "#E5657A", "#E66777", "#E66777", "#E76875", "#E76875", "#E86A72", "#E86A72", "#E96C6F", "#E96C6F", "#EA6D6D", "#EA6D6D", "#EB6F6A", "#EB6F6A", "#EC7168", "#EC7168", "#ED7461", "#ED7461", "#EE775B", "#EE775B", "#EF7A54", "#EF7A54", "#F07E4E", "#F07E4E", "#F18147", "#F18147", "#F28441", "#F28441", "#F3883B", "#F3883B", "#F58B35", "#F58B35", "#F68E2E", "#F68E2E", "#F79228", "#F79228", "#F89521", "#F89521", "#F9981B", "#F9981B", "#FA9C14", "#FA9C14", "#FB9F0E", "#FB9F0E", "#FCA207", "#FCA207", "#FEA601", "#FEA601", "#FEAA01", "#FEAA01", "#FEAE01", "#FEAE01", "#FEB201", "#FEB201", "#FEB601", "#FEB601", "#FEBA01", "#FEBA01", "#FEBF01", "#FEBF01", "#FEC201", "#FEC201", "#FEC601", "#FEC601", "#FECA01", "#FECA01", "#FECE01", "#FECE01", "#FED301", "#FED301", "#FED701", "#FED701", "#FEDB01", "#FEDB01", "#FEDF01", "#FEDF01", "#FEE301", "#FEE301", "#FED401", "#FED401", "#FED60C", "#FED60C", "#FED817", "#FED817", "#FEDA22", "#FEDA22", "#FEDC2E", "#FEDC2E", "#FEDE39", "#FEDE39", "#FEE043", "#FEE043", "#FEE24F", "#FEE24F", "#FEE45A", "#FEE45A", "#FEE665", "#FEE665", "#FEE871", "#FEE871", "#FEEA7C", "#FEEA7C", "#FEEC87", "#FEEC87", "#FEEE93", "#FEEE93", "#FEF09E", "#FEF09E", "#FEF2A9", "#FEF2A9", "#FEF594", "#FEF594", "#FEF597", "#FEF597", "#FEF69B", "#FEF69B", "#FEF69F", "#FEF69F", "#FEF7A3", "#FEF7A3", "#FEF7A7", "#FEF7A7", "#FEF8AB", "#FEF8AB", "#FEF8AF", "#FEF8AF", "#FEF9B3", "#FEF9B3", "#FEFAB6", "#FEFAB6", "#FEFABA", "#FEFABA", "#FEFBBE", "#FEFBBE", "#FEFBC1", "#FEFBC1", "#FEFCC5", "#FEFCC5", "#FEFCC9", "#FEFCC9", "#FEFDCD", "#FEFDCD", "#FEFED1", "#FEFED1", "#FEFED3", "#FEFED3", "#FEFED6", "#FEFED6", "#FEFED9", "#FEFED9", "#FEFEDC", "#FEFEDC", "#FEFEDF", "#FEFEDF", "#FEFEE1", "#FEFEE1", "#FEFEE4", "#FEFEE4", "#FEFEE7", "#FEFEE7", "#FEFEEA", "#FEFEEA", "#FEFEED", "#FEFEED", "#FEFEEF", "#FEFEEF", "#FEFEF2", "#FEFEF2", "#FEFEF5", "#FEFEF5", "#FEFEF8", "#FEFEF8", "#FEFEFB", "#FEFEFB", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE"], "imagej_cmy_yellow": ["#000000", "#000000", "#010100", "#010100", "#020200", "#020200", "#030300", "#030300", "#040400", "#040400", "#050500", "#050500", "#060600", "#060600", "#070700", "#070700", "#080800", "#080800", "#090900", "#090900", "#0A0A00", "#0A0A00", "#0B0B00", "#0B0B00", "#0C0C00", "#0C0C00", "#0D0D00", "#0D0D00", "#0E0E00", "#0E0E00", "#0F0F00", "#0F0F00", "#101000", "#101000", "#111100", "#111100", "#121200", "#121200", "#131300", "#131300", "#141400", "#141400", "#151500", "#151500", "#161600", "#161600", "#171700", "#171700", "#181800", "#181800", "#191900", "#191900", "#1A1A00", "#1A1A00", "#1B1B00", "#1B1B00", "#1C1C00", "#1C1C00", "#1D1D00", "#1D1D00", "#1E1E00", "#1E1E00", "#1F1F00", "#1F1F00", "#202000", "#202000", "#212100", "#212100", "#222200", "#222200", "#232300", "#232300", "#242400", "#242400", "#252500", "#252500", "#262600", "#262600", "#272700", "#272700", "#282800", "#282800", "#292900", "#292900", "#2A2A00", "#2A2A00", "#2B2B00", "#2B2B00", "#2C2C00", "#2C2C00", "#2D2D00", "#2D2D00", "#2E2E00", "#2E2E00", "#2F2F00", "#2F2F00", "#303000", "#303000", "#313100", "#313100", "#323200", "#323200", "#333300", "#333300", "#343400", "#343400", "#353500", "#353500", "#363600", "#363600", "#373700", "#373700", "#383800", "#383800", "#393900", "#393900", "#3A3A00", "#3A3A00", "#3B3B00", "#3B3B00", "#3C3C00", "#3C3C00", "#3D3D00", "#3D3D00", "#3E3E00", "#3E3E00", "#3F3F00", "#3F3F00", "#404000", "#404000", "#414100", "#414100", "#424200", "#424200", "#434300", "#434300", "#444400", "#444400", "#454500", "#454500", "#464600", "#464600", "#474700", "#474700", "#484800", "#484800", "#494900", "#494900", "#4A4A00", "#4A4A00", "#4B4B00", "#4B4B00", "#4C4C00", "#4C4C00", "#4D4D00", "#4D4D00", "#4E4E00", "#4E4E00", "#4F4F00", "#4F4F00", "#505000", "#505000", "#515100", "#515100", "#525200", "#525200", "#535300", "#535300", "#545400", "#545400", "#555500", "#555500", "#565600", "#565600", "#575700", "#575700", "#585800", "#585800", "#595900", "#595900", "#5A5A00", "#5A5A00", "#5B5B00", "#5B5B00", "#5C5C00", "#5C5C00", "#5D5D00", "#5D5D00", "#5E5E00", "#5E5E00", "#5F5F00", "#5F5F00", "#606000", "#606000", "#616100", "#616100", "#626200", "#626200", "#636300", "#636300", "#646400", "#646400", "#656500", "#656500", "#666600", "#666600", "#676700", "#676700", "#686800", "#686800", "#696900", "#696900", "#6A6A00", "#6A6A00", "#6B6B00", "#6B6B00", "#6C6C00", "#6C6C00", "#6D6D00", "#6D6D00", "#6E6E00", "#6E6E00", "#6F6F00", "#6F6F00", "#707000", "#707000", "#717100", "#717100", "#727200", "#727200", "#737300", "#737300", "#747400", "#747400", "#757500", "#757500", "#767600", "#767600", "#777700", "#777700", "#787800", "#787800", "#797900", "#797900", "#7A7A00", "#7A7A00", "#7B7B00", "#7B7B00", "#7C7C00", "#7C7C00", "#7D7D00", "#7D7D00", "#7E7E00", "#7E7E00", "#7F7F00", "#7F7F00", "#808000", "#808000", "#818100", "#818100", "#828200", "#828200", "#838300", "#838300", "#848400", "#848400", "#858500", "#858500", "#868600", "#868600", "#878700", "#878700", "#888800", "#888800", "#898900", "#898900", "#8A8A00", "#8A8A00", "#8B8B00", "#8B8B00", "#8C8C00", "#8C8C00", "#8D8D00", "#8D8D00", "#8E8E00", "#8E8E00", "#8F8F00", "#8F8F00", "#909000", "#909000", "#919100", "#919100", "#929200", "#929200", "#939300", "#939300", "#949400", "#949400", "#959500", "#959500", "#969600", "#969600", "#979700", "#979700", "#989800", "#989800", "#999900", "#999900", "#9A9A00", "#9A9A00", "#9B9B00", "#9B9B00", "#9C9C00", "#9C9C00", "#9D9D00", "#9D9D00", "#9E9E00", "#9E9E00", "#9F9F00", "#9F9F00", "#A0A000", "#A0A000", "#A1A100", "#A1A100", "#A2A200", "#A2A200", "#A3A300", "#A3A300", "#A4A400", "#A4A400", "#A5A500", "#A5A500", "#A6A600", "#A6A600", "#A7A700", "#A7A700", "#A8A800", "#A8A800", "#A9A900", "#A9A900", "#AAAA00", "#AAAA00", "#ABAB00", "#ABAB00", "#ACAC00", "#ACAC00", "#ADAD00", "#ADAD00", "#AEAE00", "#AEAE00", "#AFAF00", "#AFAF00", "#B0B000", "#B0B000", "#B1B100", "#B1B100", "#B2B200", "#B2B200", "#B3B300", "#B3B300", "#B4B400", "#B4B400", "#B5B500", "#B5B500", "#B6B600", "#B6B600", "#B7B700", "#B7B700", "#B8B800", "#B8B800", "#B9B900", "#B9B900", "#BABA00", "#BABA00", "#BBBB00", "#BBBB00", "#BCBC00", "#BCBC00", "#BDBD00", "#BDBD00", "#BEBE00", "#BEBE00", "#BFBF00", "#BFBF00", "#C0C000", "#C0C000", "#C1C100", "#C1C100", "#C2C200", "#C2C200", "#C3C300", "#C3C300", "#C4C400", "#C4C400", "#C5C500", "#C5C500", "#C6C600", "#C6C600", "#C7C700", "#C7C700", "#C8C800", "#C8C800", "#C9C900", "#C9C900", "#CACA00", "#CACA00", "#CBCB00", "#CBCB00", "#CCCC00", "#CCCC00", "#CDCD00", "#CDCD00", "#CECE00", "#CECE00", "#CFCF00", "#CFCF00", "#D0D000", "#D0D000", "#D1D100", "#D1D100", "#D2D200", "#D2D200", "#D3D300", "#D3D300", "#D4D400", "#D4D400", "#D5D500", "#D5D500", "#D6D600", "#D6D600", "#D7D700", "#D7D700", "#D8D800", "#D8D800", "#D9D900", "#D9D900", "#DADA00", "#DADA00", "#DBDB00", "#DBDB00", "#DCDC00", "#DCDC00", "#DDDD00", "#DDDD00", "#DEDE00", "#DEDE00", "#DFDF00", "#DFDF00", "#E0E000", "#E0E000", "#E1E100", "#E1E100", "#E2E200", "#E2E200", "#E3E300", "#E3E300", "#E4E400", "#E4E400", "#E5E500", "#E5E500", "#E6E600", "#E6E600", "#E7E700", "#E7E700", "#E8E800", "#E8E800", "#E9E900", "#E9E900", "#EAEA00", "#EAEA00", "#EBEB00", "#EBEB00", "#ECEC00", "#ECEC00", "#EDED00", "#EDED00", "#EEEE00", "#EEEE00", "#EFEF00", "#EFEF00", "#F0F000", "#F0F000", "#F1F100", "#F1F100", "#F2F200", "#F2F200", "#F3F300", "#F3F300", "#F4F400", "#F4F400", "#F5F500", "#F5F500", "#F6F600", "#F6F600", "#F7F700", "#F7F700", "#F8F800", "#F8F800", "#F9F900", "#F9F900", "#FAFA00", "#FAFA00", "#FBFB00", "#FBFB00", "#FCFC00", "#FCFC00", "#FDFD00", "#FDFD00", "#FEFE00", "#FEFE00", "#FFFF00", "#FFFF00"], "imagej_cold": ["#141414", "#141414", "#141414", "#262727", "#262727", "#363939", "#363939", "#444A4A", "#444A4A", "#515A5A", "#515A5A", "#5D6A6A", "#5D6A6A", "#687979", "#687979", "#728787", "#728787", "#7A9494", "#7A9494", "#81A1A1", "#81A1A1", "#87ADAD", "#87ADAD", "#8CB8B8", "#8CB8B8", "#90C1C1", "#90C1C1", "#93CACA", "#93CACA", "#96D3D3", "#96D3D3", "#97DBDB", "#97DBDB", "#97E2E2", "#97E2E2", "#97E8E8", "#97E8E8", "#96EEEE", "#96EEEE", "#94F3F3", "#94F3F3", "#91F7F7", "#91F7F7", "#8EFAFA", "#8EFAFA", "#8BFCFC", "#8BFCFC", "#87FEFE", "#87FEFE", "#82FEFE", "#82FEFE", "#7DFEFE", "#7DFEFE", "#78FEFE", "#78FEFE", "#73FEFE", "#73FEFE", "#6EFEFE", "#6EFEFE", "#69FEFE", "#69FEFE", "#64FEFE", "#64FEFE", "#5FFEFE", "#5FFEFE", "#5AFEFE", "#5AFEFE", "#55FEFE", "#55FEFE", "#50FEFE", "#50FEFE", "#4BFEFE", "#4BFEFE", "#46FEFE", "#46FEFE", "#41FEFE", "#41FEFE", "#3DFEFE", "#3DFEFE", "#38FEFE", "#38FEFE", "#33FEFE", "#33FEFE", "#2EFEFE", "#2EFEFE", "#29FEFE", "#29FEFE", "#24FEFE", "#24FEFE", "#1FFEFE", "#1FFEFE", "#1AFEFE", "#1AFEFE", "#15FEFE", "#15FEFE", "#10FEFE", "#10FEFE", "#0BFEFE", "#0BFEFE", "#06FEFE", "#06FEFE", "#01FEFE", "#01FEFE", "#03FCFE", "#03FCFE", "#06F9FE", "#06F9FE", "#08F7FE", "#08F7FE", "#0BF4FE", "#0BF4FE", "#0DF2FE", "#0DF2FE", "#10EFFE", "#10EFFE", "#12EDFE", "#12EDFE", "#15EAFE", "#15EAFE", "#17E8FE", "#17E8FE", "#1AE5FE", "#1AE5FE", "#1CE3FE", "#1CE3FE", "#1FE0FE", "#1FE0FE", "#21DEFE", "#21DEFE", "#24DBFE", "#24DBFE", "#26D9FE", "#26D9FE", "#29D6FE", "#29D6FE", "#2BD4FE", "#2BD4FE", "#2ED1FE", "#2ED1FE", "#30CFFE", "#30CFFE", "#33CCFE", "#33CCFE", "#35CAFE", "#35CAFE", "#38C7FE", "#38C7FE", "#3AC5FE", "#3AC5FE", "#3DC2FE", "#3DC2FE", "#3FC0FE", "#3FC0FE", "#41BEFE", "#41BEFE", "#43BCFE", "#43BCFE", "#46B9FE", "#46B9FE", "#48B7FE", "#48B7FE", "#4BB4FE", "#4BB4FE", "#4DB2FE", "#4DB2FE", "#50AFFE", "#50AFFE", "#52ADFE", "#52ADFE", "#55AAFE", "#55AAFE", "#57A8FE", "#57A8FE", "#5AA5FE", "#5AA5FE", "#5CA3FE", "#5CA3FE", "#5FA0FE", "#5FA0FE", "#619EFE", "#619EFE", "#649BFE", "#649BFE", "#6699FE", "#6699FE", "#6996FE", "#6996FE", "#6B94FE", "#6B94FE", "#6E91FE", "#6E91FE", "#708FFE", "#708FFE", "#738CFE", "#738CFE", "#758AFE", "#758AFE", "#7887FE", "#7887FE", "#7A85FE", "#7A85FE", "#7D82FE", "#7D82FE", "#8080FE", "#8080FE", "#827DFE", "#827DFE", "#857AFE", "#857AFE", "#8778FE", "#8778FE", "#8A75FE", "#8A75FE", "#8C73FE", "#8C73FE", "#8F70FE", "#8F70FE", "#916EFE", "#916EFE", "#946BFE", "#946BFE", "#9669FE", "#9669FE", "#9966FE", "#9966FE", "#9B64FE", "#9B64FE", "#9E61FE", "#9E61FE", "#A05FFE", "#A05FFE", "#A35CFE", "#A35CFE", "#A55AFE", "#A55AFE", "#A857FE", "#A857FE", "#AA55FE", "#AA55FE", "#AD52FE", "#AD52FE", "#AF50FE", "#AF50FE", "#B24DFE", "#B24DFE", "#B44BFE", "#B44BFE", "#B748FE", "#B748FE", "#B946FE", "#B946FE", "#BC43FE", "#BC43FE", "#BE41FE", "#BE41FE", "#C03FFE", "#C03FFE", "#C23DFE", "#C23DFE", "#C53AFE", "#C53AFE", "#C738FE", "#C738FE", "#CA35FE", "#CA35FE", "#CC33FE", "#CC33FE", "#CF30FE", "#CF30FE", "#D12EFE", "#D12EFE", "#D42BFE", "#D42BFE", "#D629FE", "#D629FE", "#D926FE", "#D926FE", "#DB24FE", "#DB24FE", "#DE21FE", "#DE21FE", "#E01FFE", "#E01FFE", "#E31CFE", "#E31CFE", "#E51AFE", "#E51AFE", "#E817FE", "#E817FE", "#EA15FE", "#EA15FE", "#ED12FE", "#ED12FE", "#EF10FE", "#EF10FE", "#F20DFE", "#F20DFE", "#F40BFE", "#F40BFE", "#F708FE", "#F708FE", "#F906FE", "#F906FE", "#FC03FE", "#FC03FE", "#FE01FE", "#FE01FE", "#FE03FC", "#FE03FC", "#FE06F9", "#FE06F9", "#FE08F7", "#FE08F7", "#FE0BF4", "#FE0BF4", "#FE0DF2", "#FE0DF2", "#FE10EF", "#FE10EF", "#FE12ED", "#FE12ED", "#FE15EA", "#FE15EA", "#FE17E8", "#FE17E8", "#FE1AE5", "#FE1AE5", "#FE1CE3", "#FE1CE3", "#FE1FE0", "#FE1FE0", "#FE21DE", "#FE21DE", "#FE24DB", "#FE24DB", "#FE26D9", "#FE26D9", "#FE29D6", "#FE29D6", "#FE2BD4", "#FE2BD4", "#FE2ED1", "#FE2ED1", "#FE30CF", "#FE30CF", "#FE33CC", "#FE33CC", "#FE35CA", "#FE35CA", "#FE38C7", "#FE38C7", "#FE3AC5", "#FE3AC5", "#FE3DC2", "#FE3DC2", "#FE3FC0", "#FE3FC0", "#FE41BE", "#FE41BE", "#FE43BC", "#FE43BC", "#FE46B9", "#FE46B9", "#FE48B7", "#FE48B7", "#FE4BB4", "#FE4BB4", "#FE4DB2", "#FE4DB2", "#FE50AF", "#FE50AF", "#FE52AD", "#FE52AD", "#FE55AA", "#FE55AA", "#FE57A8", "#FE57A8", "#FE5AA5", "#FE5AA5", "#FE5CA3", "#FE5CA3", "#FE5FA0", "#FE5FA0", "#FE619E", "#FE619E", "#FE649B", "#FE649B", "#FE6699", "#FE6699", "#FE6996", "#FE6996", "#FE6B94", "#FE6B94", "#FE6E91", "#FE6E91", "#FE708F", "#FE708F", "#FE738C", "#FE738C", "#FE758A", "#FE758A", "#FE7887", "#FE7887", "#FE7A85", "#FE7A85", "#FE7D82", "#FE7D82", "#FE807F", "#FE807F", "#FE827D", "#FE827D", "#FE857A", "#FE857A", "#FE8778", "#FE8778", "#FE8A75", "#FE8A75", "#FE8C73", "#FE8C73", "#FE8F70", "#FE8F70", "#FE916E", "#FE916E", "#FE946B", "#FE946B", "#FE9669", "#FE9669", "#FE9966", "#FE9966", "#FE9B64", "#FE9B64", "#FE9E61", "#FE9E61", "#FEA05F", "#FEA05F", "#FEA35C", "#FEA35C", "#FEA55A", "#FEA55A", "#FEA857", "#FEA857", "#FEAA55", "#FEAA55", "#FEAD52", "#FEAD52", "#FEAF50", "#FEAF50", "#FEB24D", "#FEB24D", "#FEB44B", "#FEB44B", "#FEB748", "#FEB748", "#FEB946", "#FEB946", "#FEBC43", "#FEBC43", "#FEBE41", "#FEBE41", "#FEC03F", "#FEC03F", "#FEC23D", "#FEC23D", "#FEC53C", "#FEC53C", "#FEC83B", "#FEC83B", "#FECB3C", "#FECB3C", "#FECF3C", "#FECF3C", "#FED23E", "#FED23E", "#FED540", "#FED540", "#FED942", "#FED942", "#FEDC46", "#FEDC46", "#FEDF4A", "#FEDF4A", "#FEE350", "#FEE350", "#FEE656", "#FEE656", "#FEE95D", "#FEE95D", "#FEEC65", "#FEEC65", "#FEEF6E", "#FEEF6E", "#FEF178", "#FEF178", "#FEF483", "#FEF483", "#FEF68F", "#FEF68F", "#FEF89B", "#FEF89B", "#FEFAA9", "#FEFAA9", "#FEFCB8", "#FEFCB8", "#FEFDC7", "#FEFDC7", "#FEFED9", "#FEFED9", "#FEFEEB", "#FEFEEB", "#FEFEEB"], "imagej_gem_256": ["#010202", "#010202", "#010202", "#010203", "#010203", "#010304", "#010304", "#010305", "#010305", "#010406", "#010406", "#010407", "#010407", "#010508", "#010508", "#010509", "#010509", "#01060A", "#01060A", "#01060B", "#01060B", "#01070C", "#01070C", "#01070D", "#01070D", "#01080E", "#01080E", "#01080F", "#01080F", "#010910", "#010910", "#010911", "#010911", "#010A12", "#010A12", "#010A13", "#010A13", "#010B14", "#010B14", "#010B15", "#010B15", "#010C16", "#010C16", "#010C17", "#010C17", "#010D18", "#010D18", "#010D19", "#010D19", "#010E1A", "#010E1A", "#010E1B", "#010E1B", "#010F1C", "#010F1C", "#010F1D", "#010F1D", "#01101E", "#01101E", "#01101F", "#01101F", "#011120", "#011120", "#011121", "#011121", "#011222", "#011222", "#011223", "#011223", "#011324", "#011324", "#011325", "#011325", "#011426", "#011426", "#011427", "#011427", "#011528", "#011528", "#011529", "#011529", "#01162A", "#01162A", "#01162B", "#01162B", "#01172C", "#01172C", "#01172D", "#01172D", "#01182E", "#01182E", "#01182F", "#01182F", "#011930", "#011930", "#011931", "#011931", "#011A32", "#011A32", "#011A33", "#011A33", "#011B34", "#011B34", "#011B35", "#011B35", "#011C36", "#011C36", "#011C37", "#011C37", "#011D38", "#011D38", "#011D39", "#011D39", "#011E3A", "#011E3A", "#011E3B", "#011E3B", "#011F3C", "#011F3C", "#011F3D", "#011F3D", "#01203E", "#01203E", "#01203F", "#01203F", "#012140", "#012140", "#012140", "#022041", "#022041", "#042042", "#042042", "#061F43", "#061F43", "#081F44", "#081F44", "#0A1E45", "#0A1E45", "#0C1E46", "#0C1E46", "#0E1D47", "#0E1D47", "#101D48", "#101D48", "#121C49", "#121C49", "#141C4A", "#141C4A", "#161B4B", "#161B4B", "#181B4C", "#181B4C", "#1A1A4D", "#1A1A4D", "#1C1A4E", "#1C1A4E", "#1E194F", "#1E194F", "#201950", "#201950", "#221851", "#221851", "#241852", "#241852", "#261753", "#261753", "#281754", "#281754", "#2A1655", "#2A1655", "#2C1656", "#2C1656", "#2E1557", "#2E1557", "#301558", "#301558", "#321459", "#321459", "#34145A", "#34145A", "#36135B", "#36135B", "#38135C", "#38135C", "#3A125D", "#3A125D", "#3C125E", "#3C125E", "#3E115F", "#3E115F", "#401160", "#401160", "#411061", "#411061", "#431062", "#431062", "#450F63", "#450F63", "#470F64", "#470F64", "#490E65", "#490E65", "#4B0E66", "#4B0E66", "#4D0D67", "#4D0D67", "#4F0D68", "#4F0D68", "#510C69", "#510C69", "#530C6A", "#530C6A", "#550B6B", "#550B6B", "#570B6C", "#570B6C", "#590A6D", "#590A6D", "#5B0A6E", "#5B0A6E", "#5D096F", "#5D096F", "#5F0970", "#5F0970", "#610871", "#610871", "#630872", "#630872", "#650773", "#650773", "#670774", "#670774", "#690675", "#690675", "#6B0676", "#6B0676", "#6D0577", "#6D0577", "#6F0578", "#6F0578", "#710479", "#710479", "#73047A", "#73047A", "#75037B", "#75037B", "#77037C", "#77037C", "#79027D", "#79027D", "#7B027E", "#7B027E", "#7D017F", "#7D017F", "#7F037F", "#7F037F", "#81047D", "#81047D", "#83067B", "#83067B", "#850779", "#850779", "#870977", "#870977", "#890A75", "#890A75", "#8B0C73", "#8B0C73", "#8D0D71", "#8D0D71", "#8F0F6F", "#8F0F6F", "#91106D", "#91106D", "#93126B", "#93126B", "#951369", "#951369", "#971567", "#971567", "#991665", "#991665", "#9B1863", "#9B1863", "#9D1961", "#9D1961", "#9F1B5F", "#9F1B5F", "#A11C5D", "#A11C5D", "#A31E5B", "#A31E5B", "#A51F59", "#A51F59", "#A72157", "#A72157", "#A92255", "#A92255", "#AB2453", "#AB2453", "#AD2551", "#AD2551", "#AF274F", "#AF274F", "#B1284D", "#B1284D", "#B32A4B", "#B32A4B", "#B52B49", "#B52B49", "#B72D47", "#B72D47", "#B92E45", "#B92E45", "#BB3043", "#BB3043", "#BD3141", "#BD3141", "#BF3340", "#BF3340", "#C0343E", "#C0343E", "#C2363C", "#C2363C", "#C4373A", "#C4373A", "#C63938", "#C63938", "#C83A36", "#C83A36", "#CA3C34", "#CA3C34", "#CC3D32", "#CC3D32", "#CE3F30", "#CE3F30", "#D0402E", "#D0402E", "#D2412C", "#D2412C", "#D4422A", "#D4422A", "#D64428", "#D64428", "#D84526", "#D84526", "#DA4724", "#DA4724", "#DC4822", "#DC4822", "#DE4A20", "#DE4A20", "#E04B1E", "#E04B1E", "#E24D1C", "#E24D1C", "#E44E1A", "#E44E1A", "#E65018", "#E65018", "#E85116", "#E85116", "#EA5314", "#EA5314", "#EC5412", "#EC5412", "#EE5610", "#EE5610", "#F0570E", "#F0570E", "#F2590C", "#F2590C", "#F45A0A", "#F45A0A", "#F65C08", "#F65C08", "#F85D06", "#F85D06", "#FA5F04", "#FA5F04", "#FC5F01", "#FC5F01", "#FE6204", "#FE6204", "#FE6408", "#FE6408", "#FE670C", "#FE670C", "#FE6910", "#FE6910", "#FE6C14", "#FE6C14", "#FE6E18", "#FE6E18", "#FE711C", "#FE711C", "#FE7320", "#FE7320", "#FE7624", "#FE7624", "#FE7828", "#FE7828", "#FE7B2C", "#FE7B2C", "#FE7D30", "#FE7D30", "#FE8034", "#FE8034", "#FE8238", "#FE8238", "#FE853C", "#FE853C", "#FE8740", "#FE8740", "#FE8A43", "#FE8A43", "#FE8C47", "#FE8C47", "#FE8F4B", "#FE8F4B", "#FE914F", "#FE914F", "#FE9453", "#FE9453", "#FE9657", "#FE9657", "#FE995B", "#FE995B", "#FE9B5F", "#FE9B5F", "#FE9E63", "#FE9E63", "#FEA067", "#FEA067", "#FEA36B", "#FEA36B", "#FEA56F", "#FEA56F", "#FEA873", "#FEA873", "#FEAA77", "#FEAA77", "#FEAD7B", "#FEAD7B", "#FEAF7F", "#FEAF7F", "#FEB283", "#FEB283", "#FEB487", "#FEB487", "#FEB78B", "#FEB78B", "#FEB98F", "#FEB98F", "#FEBC93", "#FEBC93", "#FEBE97", "#FEBE97", "#FEC09B", "#FEC09B", "#FEC29F", "#FEC29F", "#FEC5A3", "#FEC5A3", "#FEC7A7", "#FEC7A7", "#FECAAB", "#FECAAB", "#FECCAF", "#FECCAF", "#FECFB3", "#FECFB3", "#FED1B7", "#FED1B7", "#FED4BB", "#FED4BB", "#FED6BF", "#FED6BF", "#FED9C2", "#FED9C2", "#FEDBC6", "#FEDBC6", "#FEDECA", "#FEDECA", "#FEE0CE", "#FEE0CE", "#FEE3D2", "#FEE3D2", "#FEE5D6", "#FEE5D6", "#FEE8DA", "#FEE8DA", "#FEEADE", "#FEEADE", "#FEEDE2", "#FEEDE2", "#FEEFE6", "#FEEFE6", "#FEF2EA", "#FEF2EA", "#FEF4EE", "#FEF4EE", "#FEF7F2", "#FEF7F2", "#FEF9F6", "#FEF9F6", "#FEFCFA", "#FEFCFA", "#FEFCFA"], "imagej_gold": ["#000000", "#000000", "#020100", "#020100", "#050300", "#050300", "#080400", "#080400", "#0A0600", "#0A0600", "#0D0700", "#0D0700", "#100900", "#100900", "#120A01", "#120A01", "#150C01", "#150C01", "#180D01", "#180D01", "#1B0F01", "#1B0F01", "#1D1001", "#1D1001", "#201201", "#201201", "#231301", "#231301", "#251502", "#251502", "#281702", "#281702", "#2B1802", "#2B1802", "#2D1A02", "#2D1A02", "#301B02", "#301B02", "#331D02", "#331D02", "#361E03", "#361E03", "#382003", "#382003", "#3B2103", "#3B2103", "#3E2303", "#3E2303", "#402403", "#402403", "#432603", "#432603", "#462703", "#462703", "#482904", "#482904", "#4B2B04", "#4B2B04", "#4E2C04", "#4E2C04", "#512E04", "#512E04", "#532F04", "#532F04", "#563104", "#563104", "#593204", "#593204", "#5B3405", "#5B3405", "#5E3505", "#5E3505", "#613705", "#613705", "#633805", "#633805", "#663A05", "#663A05", "#693B05", "#693B05", "#6C3D06", "#6C3D06", "#6E3F06", "#6E3F06", "#714006", "#714006", "#744206", "#744206", "#764306", "#764306", "#794506", "#794506", "#7C4606", "#7C4606", "#7E4807", "#7E4807", "#814907", "#814907", "#844B07", "#844B07", "#874C07", "#874C07", "#894E07", "#894E07", "#8C4F07", "#8C4F07", "#8F5107", "#8F5107", "#915308", "#915308", "#945408", "#945408", "#975608", "#975608", "#995708", "#995708", "#9C5908", "#9C5908", "#9F5A08", "#9F5A08", "#A25C09", "#A25C09", "#A45D09", "#A45D09", "#A75F09", "#A75F09", "#AA6009", "#AA6009", "#AC6209", "#AC6209", "#AF6309", "#AF6309", "#B26509", "#B26509", "#B4670A", "#B4670A", "#B7680A", "#B7680A", "#BA6A0A", "#BA6A0A", "#BD6B0A", "#BD6B0A", "#BF6D0A", "#BF6D0A", "#C26E0A", "#C26E0A", "#C5700A", "#C5700A", "#C7710B", "#C7710B", "#CA730B", "#CA730B", "#CD740B", "#CD740B", "#CF760B", "#CF760B", "#D2770B", "#D2770B", "#D5790B", "#D5790B", "#D57A0B", "#D57A0B", "#D57C0B", "#D57C0B", "#D57D0B", "#D57D0B", "#D57F0B", "#D57F0B", "#D5800B", "#D5800B", "#D6820B", "#D6820B", "#D6840C", "#D6840C", "#D6850C", "#D6850C", "#D6870C", "#D6870C", "#D6880C", "#D6880C", "#D78A0C", "#D78A0C", "#D78B0C", "#D78B0C", "#D78D0C", "#D78D0C", "#D78F0D", "#D78F0D", "#D7900D", "#D7900D", "#D7920D", "#D7920D", "#D8930D", "#D8930D", "#D8950D", "#D8950D", "#D8960D", "#D8960D", "#D8980E", "#D8980E", "#D89A0E", "#D89A0E", "#D99B0E", "#D99B0E", "#D99D0E", "#D99D0E", "#D99E0E", "#D99E0E", "#D9A00E", "#D9A00E", "#D9A10E", "#D9A10E", "#D9A30F", "#D9A30F", "#DAA50F", "#DAA50F", "#DAA60F", "#DAA60F", "#DAA80F", "#DAA80F", "#DAA90F", "#DAA90F", "#DAAB0F", "#DAAB0F", "#DDAF10", "#DDAF10", "#DFB010", "#DFB010", "#E1B211", "#E1B211", "#E3B311", "#E3B311", "#E5B511", "#E5B511", "#E7B611", "#E7B611", "#E9B811", "#E9B811", "#EBB911", "#EBB911", "#EDBB11", "#EDBB11", "#EFBD12", "#EFBD12", "#F1BE12", "#F1BE12", "#F3C012", "#F3C012", "#F5C112", "#F5C112", "#F7C312", "#F7C312", "#F9C412", "#F9C412", "#FBC612", "#FBC612", "#FBC713", "#FBC713", "#FBC815", "#FBC815", "#FBC916", "#FBC916", "#FBCA18", "#FBCA18", "#FBCB19", "#FBCB19", "#FBCC1B", "#FBCC1B", "#FBCE1C", "#FBCE1C", "#FBCF1E", "#FBCF1E", "#FBD01F", "#FBD01F", "#FBD121", "#FBD121", "#FBD222", "#FBD222", "#FBD324", "#FBD324", "#FCD525", "#FCD525", "#FCD627", "#FCD627", "#FCD728", "#FCD728", "#FCD82A", "#FCD82A", "#FCD92B", "#FCD92B", "#FCDA2D", "#FCDA2D", "#FCDC2E", "#FCDC2E", "#FCDD30", "#FCDD30", "#FCDE31", "#FCDE31", "#FCDF33", "#FCDF33", "#FCE034", "#FCE034", "#FCE136", "#FCE136", "#FDE337", "#FDE337", "#FDE439", "#FDE439", "#FDE53A", "#FDE53A", "#FDE63C", "#FDE63C", "#FDE73D", "#FDE73D", "#FDE83F", "#FDE83F", "#FDEA40", "#FDEA40", "#FDEB42", "#FDEB42", "#FDEC49", "#FDEC49", "#FDED50", "#FDED50", "#FDEE57", "#FDEE57", "#FDEF5E", "#FDEF5E", "#FDF065", "#FDF065", "#FDF16C", "#FDF16C", "#FDF273", "#FDF273", "#FDF37A", "#FDF37A", "#FDF482", "#FDF482", "#FDF589", "#FDF589", "#FDF690", "#FDF690", "#FDF797", "#FDF797", "#FDF89E", "#FDF89E", "#FDF9A5", "#FDF9A5", "#FDFAAC", "#FDFAAC", "#FDFBB9", "#FDFBB9", "#FCF9B6", "#FCF9B6", "#FBF8B4", "#FBF8B4", "#FBF6B1", "#FBF6B1", "#FAF5AF", "#FAF5AF", "#F9F4AC", "#F9F4AC", "#F9F2AA", "#F9F2AA", "#F8F1A8", "#F8F1A8", "#F7EFA5", "#F7EFA5", "#F7EEA3", "#F7EEA3", "#F6EDA0", "#F6EDA0", "#F6EB9E", "#F6EB9E", "#F5EA9B", "#F5EA9B", "#F4E899", "#F4E899", "#F4E797", "#F4E797", "#F3E694", "#F3E694", "#F2E492", "#F2E492", "#F2E38F", "#F2E38F", "#F1E18D", "#F1E18D", "#F0E08A", "#F0E08A", "#F0DF88", "#F0DF88", "#EFDD86", "#EFDD86", "#EFDC83", "#EFDC83", "#EEDA81", "#EEDA81", "#EDD97E", "#EDD97E", "#EDD87C", "#EDD87C", "#ECD679", "#ECD679", "#EBD577", "#EBD577", "#EBD375", "#EBD375", "#EAD272", "#EAD272", "#E9D170", "#E9D170", "#E9CF6D", "#E9CF6D", "#E8CE6B", "#E8CE6B", "#E8D66B", "#E8D66B", "#E8D76E", "#E8D76E", "#E9D871", "#E9D871", "#E9D974", "#E9D974", "#EADA77", "#EADA77", "#EADB7A", "#EADB7A", "#EBDB7D", "#EBDB7D", "#EBDC80", "#EBDC80", "#ECDD83", "#ECDD83", "#ECDE86", "#ECDE86", "#EDDF89", "#EDDF89", "#EDE08C", "#EDE08C", "#EEE090", "#EEE090", "#EEE193", "#EEE193", "#EFE296", "#EFE296", "#EFE399", "#EFE399", "#EFE49C", "#EFE49C", "#F0E59F", "#F0E59F", "#F0E5A2", "#F0E5A2", "#F1E6A5", "#F1E6A5", "#F1E7A8", "#F1E7A8", "#F2E8AB", "#F2E8AB", "#F2E9AE", "#F2E9AE", "#F3EAB1", "#F3EAB1", "#F3EAB5", "#F3EAB5", "#F4EBB8", "#F4EBB8", "#F4ECBB", "#F4ECBB", "#F5EDBE", "#F5EDBE", "#F5EEC1", "#F5EEC1", "#F6EFC4", "#F6EFC4", "#F6EFC7", "#F6EFC7", "#F7F0CA", "#F7F0CA", "#F7F1CD", "#F7F1CD", "#F7F2D0", "#F7F2D0", "#F8F3D3", "#F8F3D3", "#F8F4D6", "#F8F4D6", "#F9F4DA", "#F9F4DA", "#F9F5DD", "#F9F5DD", "#FAF6E0", "#FAF6E0", "#FAF7E3", "#FAF7E3", "#FBF8E6", "#FBF8E6", "#FBF9E9", "#FBF9E9", "#FCF9EC", "#FCF9EC", "#FCFAEF", "#FCFAEF", "#FDFBF2", "#FDFBF2", "#FDFCF5", "#FDFCF5", "#FEFDF8", "#FEFDF8", "#FFFFFF", "#FFFFFF"], "imagej_gyr_centre": ["#000000", "#000000", "#016C00", "#016C00", "#027300", "#027300", "#047A01", "#047A01", "#068101", "#068101", "#078802", "#078802", "#098F03", "#098F03", "#0B9603", "#0B9603", "#0D9D04", "#0D9D04", "#0EA405", "#0EA405", "#10AB05", "#10AB05", "#12B206", "#12B206", "#16B907", "#16B907", "#18B907", "#18B907", "#1ABA07", "#1ABA07", "#1CBA07", "#1CBA07", "#1EBA07", "#1EBA07", "#20BB06", "#20BB06", "#22BB06", "#22BB06", "#24BB06", "#24BB06", "#26BC06", "#26BC06", "#28BC06", "#28BC06", "#2ABC06", "#2ABC06", "#2CBD06", "#2CBD06", "#2EBD06", "#2EBD06", "#30BD06", "#30BD06", "#32BE06", "#32BE06", "#34BE06", "#34BE06", "#36BE06", "#36BE06", "#38BF06", "#38BF06", "#3ABF06", "#3ABF06", "#3CBF06", "#3CBF06", "#3EC006", "#3EC006", "#40C005", "#40C005", "#42C005", "#42C005", "#44C005", "#44C005", "#46C105", "#46C105", "#48C105", "#48C105", "#4AC105", "#4AC105", "#4CC205", "#4CC205", "#4EC205", "#4EC205", "#50C205", "#50C205", "#52C305", "#52C305", "#54C305", "#54C305", "#55C305", "#55C305", "#57C405", "#57C405", "#59C405", "#59C405", "#5BC405", "#5BC405", "#5DC505", "#5DC505", "#5FC504", "#5FC504", "#61C504", "#61C504", "#63C604", "#63C604", "#65C604", "#65C604", "#67C604", "#67C604", "#69C704", "#69C704", "#6BC704", "#6BC704", "#6DC704", "#6DC704", "#6FC804", "#6FC804", "#71C804", "#71C804", "#73C804", "#73C804", "#75C904", "#75C904", "#77C904", "#77C904", "#79C904", "#79C904", "#7BCA04", "#7BCA04", "#7DCA04", "#7DCA04", "#7FCA03", "#7FCA03", "#81CA03", "#81CA03", "#83CB03", "#83CB03", "#85CB03", "#85CB03", "#87CB03", "#87CB03", "#89CC03", "#89CC03", "#8BCC03", "#8BCC03", "#8DCC03", "#8DCC03", "#8FCD03", "#8FCD03", "#91CD03", "#91CD03", "#93CD03", "#93CD03", "#95CE03", "#95CE03", "#97CE03", "#97CE03", "#99CE03", "#99CE03", "#9BCF03", "#9BCF03", "#9DCF03", "#9DCF03", "#9FCF02", "#9FCF02", "#A1D002", "#A1D002", "#A3D002", "#A3D002", "#A5D002", "#A5D002", "#A7D102", "#A7D102", "#A8D102", "#A8D102", "#AAD102", "#AAD102", "#ACD202", "#ACD202", "#AED202", "#AED202", "#B0D202", "#B0D202", "#B2D302", "#B2D302", "#B4D302", "#B4D302", "#B6D302", "#B6D302", "#B8D402", "#B8D402", "#BAD402", "#BAD402", "#BCD402", "#BCD402", "#BED401", "#BED401", "#C0D501", "#C0D501", "#C2D501", "#C2D501", "#C4D501", "#C4D501", "#C6D601", "#C6D601", "#C8D601", "#C8D601", "#CAD601", "#CAD601", "#CCD701", "#CCD701", "#CED701", "#CED701", "#D0D701", "#D0D701", "#D2D801", "#D2D801", "#D4D801", "#D4D801", "#D6D801", "#D6D801", "#D8D901", "#D8D901", "#DAD901", "#DAD901", "#DCD901", "#DCD901", "#DEDA00", "#DEDA00", "#E0DA00", "#E0DA00", "#E2DA00", "#E2DA00", "#E4DB00", "#E4DB00", "#E6DB00", "#E6DB00", "#E8DB00", "#E8DB00", "#EADC00", "#EADC00", "#ECDC00", "#ECDC00", "#EEDC00", "#EEDC00", "#F0DD00", "#F0DD00", "#F2DD00", "#F2DD00", "#F4DD00", "#F4DD00", "#F6DE00", "#F6DE00", "#F8DE00", "#F8DE00", "#FEE200", "#FEE200", "#FBDD00", "#FBDD00", "#FBDB00", "#FBDB00", "#FBD900", "#FBD900", "#FBD800", "#FBD800", "#FBD600", "#FBD600", "#FBD400", "#FBD400", "#FBD200", "#FBD200", "#FBD100", "#FBD100", "#FBCF00", "#FBCF00", "#FBCD00", "#FBCD00", "#FBCB00", "#FBCB00", "#FBCA00", "#FBCA00", "#FBC800", "#FBC800", "#FBC600", "#FBC600", "#FBC400", "#FBC400", "#FBC300", "#FBC300", "#FBC100", "#FBC100", "#FBBF00", "#FBBF00", "#FBBD00", "#FBBD00", "#FBBC00", "#FBBC00", "#FBBA00", "#FBBA00", "#FBB800", "#FBB800", "#FBB600", "#FBB600", "#FBB500", "#FBB500", "#FBB300", "#FBB300", "#FBB100", "#FBB100", "#FBAF00", "#FBAF00", "#FBAE00", "#FBAE00", "#FBAC00", "#FBAC00", "#FBAA00", "#FBAA00", "#FBA800", "#FBA800", "#FBA700", "#FBA700", "#FBA500", "#FBA500", "#FBA300", "#FBA300", "#FBA200", "#FBA200", "#FBA000", "#FBA000", "#FB9E00", "#FB9E00", "#FB9C00", "#FB9C00", "#FB9B00", "#FB9B00", "#FB9900", "#FB9900", "#FB9700", "#FB9700", "#FB9500", "#FB9500", "#FB9400", "#FB9400", "#FB9200", "#FB9200", "#FB9000", "#FB9000", "#FB8E00", "#FB8E00", "#FB8D00", "#FB8D00", "#FB8B00", "#FB8B00", "#FB8900", "#FB8900", "#FB8700", "#FB8700", "#FB8600", "#FB8600", "#FB8400", "#FB8400", "#FB8200", "#FB8200", "#FB8000", "#FB8000", "#FB7F00", "#FB7F00", "#FB7D00", "#FB7D00", "#FB7B00", "#FB7B00", "#FB7900", "#FB7900", "#FB7800", "#FB7800", "#FB7600", "#FB7600", "#FB7400", "#FB7400", "#FB7200", "#FB7200", "#FB7100", "#FB7100", "#FB6F00", "#FB6F00", "#FA6D00", "#FA6D00", "#FA6C00", "#FA6C00", "#FA6A00", "#FA6A00", "#FA6800", "#FA6800", "#FA6600", "#FA6600", "#FA6500", "#FA6500", "#FA6300", "#FA6300", "#FA6100", "#FA6100", "#FA5F00", "#FA5F00", "#FA5E00", "#FA5E00", "#FA5C00", "#FA5C00", "#FA5A00", "#FA5A00", "#FA5800", "#FA5800", "#FA5700", "#FA5700", "#FA5500", "#FA5500", "#FA5300", "#FA5300", "#FA5100", "#FA5100", "#FA5000", "#FA5000", "#FA4E00", "#FA4E00", "#FA4C00", "#FA4C00", "#FA4A00", "#FA4A00", "#FA4900", "#FA4900", "#FA4700", "#FA4700", "#FA4500", "#FA4500", "#FA4300", "#FA4300", "#FA4200", "#FA4200", "#FA4000", "#FA4000", "#FA3E00", "#FA3E00", "#FA3C00", "#FA3C00", "#FA3B00", "#FA3B00", "#FA3900", "#FA3900", "#FA3700", "#FA3700", "#FA3600", "#FA3600", "#FA3400", "#FA3400", "#FA3200", "#FA3200", "#FA3000", "#FA3000", "#FA2F00", "#FA2F00", "#FA2D00", "#FA2D00", "#FA2B00", "#FA2B00", "#FA2900", "#FA2900", "#FA2800", "#FA2800", "#FA2600", "#FA2600", "#FA2400", "#FA2400", "#FA2200", "#FA2200", "#FA2C0C", "#FA2C0C", "#FA3618", "#FA3618", "#FA4124", "#FA4124", "#FA4B30", "#FA4B30", "#FA553C", "#FA553C", "#FA6048", "#FA6048", "#FA6A54", "#FA6A54", "#FA7560", "#FA7560", "#FA7F6C", "#FA7F6C", "#FA8978", "#FA8978", "#FB9484", "#FB9484", "#FB9E90", "#FB9E90", "#FBA89C", "#FBA89C", "#FBB3A8", "#FBB3A8", "#FBBDB4", "#FBBDB4", "#FBC8C0", "#FBC8C0", "#FBD2CC", "#FBD2CC", "#FBDCD8", "#FBDCD8", "#FBE7E4", "#FBE7E4", "#FBF1F0", "#FBF1F0"], "imagej_heart": ["#010101", "#010101", "#010101", "#010101", "#010101", "#010101", "#010101", "#010101", "#010101", "#010101", "#010101", "#010101", "#010101", "#010101", "#010101", "#040404", "#040404", "#080808", "#080808", "#0C0C0C", "#0C0C0C", "#101010", "#101010", "#131313", "#131313", "#171717", "#171717", "#1B1B1B", "#1B1B1B", "#222222", "#222222", "#262626", "#262626", "#2A2A2A", "#2A2A2A", "#2E2E2E", "#2E2E2E", "#313131", "#313131", "#353535", "#353535", "#393939", "#393939", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3C3C3C", "#3C3C3C", "#3B3B3B", "#3B3B3B", "#3B3B3B", "#3A3A3A", "#3A3A3A", "#393939", "#393939", "#383838", "#383838", "#383838", "#373737", "#373737", "#363636", "#363636", "#363636", "#353535", "#353535", "#343434", "#343434", "#343434", "#333333", "#333333", "#333333", "#2F2F2F", "#2F2F2F", "#2C2C2C", "#2C2C2C", "#292929", "#292929", "#262626", "#262626", "#232323", "#232323", "#202020", "#202020", "#1D1D1D", "#1D1D1D", "#1A1A1A", "#1A1A1A", "#161616", "#161616", "#131313", "#131313", "#0D0D0D", "#0D0D0D", "#0A0A0A", "#0A0A0A", "#070707", "#070707", "#040404", "#040404", "#010101", "#010101", "#040101", "#040101", "#070201", "#070201", "#0A0201", "#0A0201", "#0D0301", "#0D0301", "#100401", "#100401", "#130401", "#130401", "#160501", "#160501", "#1A0601", "#1A0601", "#1D0601", "#1D0601", "#200701", "#200701", "#230701", "#230701", "#260801", "#260801", "#290901", "#290901", "#2C0901", "#2C0901", "#330B01", "#330B01", "#350C01", "#350C01", "#370D01", "#370D01", "#390E01", "#390E01", "#3B1002", "#3B1002", "#3D1102", "#3D1102", "#401202", "#401202", "#411303", "#411303", "#431503", "#431503", "#451603", "#451603", "#471704", "#471704", "#4A1804", "#4A1804", "#4C1A04", "#4C1A04", "#4E1B05", "#4E1B05", "#501C05", "#501C05", "#521D05", "#521D05", "#551F06", "#551F06", "#562006", "#562006", "#582107", "#582107", "#5A2207", "#5A2207", "#5E2509", "#5E2509", "#602609", "#602609", "#62270A", "#62270A", "#64290B", "#64290B", "#652A0B", "#652A0B", "#672B0C", "#672B0C", "#692C0C", "#692C0C", "#6B2E0D", "#6B2E0D", "#6D2F0E", "#6D2F0E", "#6F300E", "#6F300E", "#71310F", "#71310F", "#733310", "#733310", "#743410", "#743410", "#763511", "#763511", "#783611", "#783611", "#7A3812", "#7A3812", "#7C3913", "#7C3913", "#7E3A13", "#7E3A13", "#803B14", "#803B14", "#823D15", "#823D15", "#853F16", "#853F16", "#874016", "#874016", "#894117", "#894117", "#8B4218", "#8B4218", "#8D4318", "#8D4318", "#8F4419", "#8F4419", "#91461A", "#91461A", "#92471A", "#92471A", "#93491B", "#93491B", "#944B1C", "#944B1C", "#964D1D", "#964D1D", "#974F1E", "#974F1E", "#98511F", "#98511F", "#995320", "#995320", "#9B5521", "#9B5521", "#9C5622", "#9C5622", "#9D5823", "#9D5823", "#9E5A24", "#9E5A24", "#A05C25", "#A05C25", "#A26027", "#A26027", "#A36228", "#A36228", "#A56429", "#A56429", "#A6652A", "#A6652A", "#A7672C", "#A7672C", "#A8692E", "#A8692E", "#AA6B30", "#AA6B30", "#AB6D32", "#AB6D32", "#AC6F34", "#AC6F34", "#AD7136", "#AD7136", "#AF7338", "#AF7338", "#B07439", "#B07439", "#B1763B", "#B1763B", "#B2783D", "#B2783D", "#B47A3F", "#B47A3F", "#B57C40", "#B57C40", "#B67E42", "#B67E42", "#B78044", "#B78044", "#B98246", "#B98246", "#BA8347", "#BA8347", "#BC874A", "#BC874A", "#BE894C", "#BE894C", "#BF8B4D", "#BF8B4D", "#BF8D4F", "#BF8D4F", "#C08F50", "#C08F50", "#C29152", "#C29152", "#C39254", "#C39254", "#C49455", "#C49455", "#C59657", "#C59657", "#C79858", "#C79858", "#C89A5A", "#C89A5A", "#C99C5B", "#C99C5B", "#CA9E5D", "#CA9E5D", "#CCA05F", "#CCA05F", "#CDA362", "#CDA362", "#CFA665", "#CFA665", "#D0A968", "#D0A968", "#D2AC6B", "#D2AC6B", "#D3AF6E", "#D3AF6E", "#D5B271", "#D5B271", "#D8B978", "#D8B978", "#DABC7B", "#DABC7B", "#DBBF7E", "#DBBF7E", "#DDC181", "#DDC181", "#DEC484", "#DEC484", "#E0C787", "#E0C787", "#E1CA8A", "#E1CA8A", "#E3CD8D", "#E3CD8D", "#E5D191", "#E5D191", "#E6D398", "#E6D398", "#E7D69F", "#E7D69F", "#E8D9A6", "#E8D9A6", "#EADBAD", "#EADBAD", "#EBDEB4", "#EBDEB4", "#ECE1BB", "#ECE1BB", "#EEE3C1", "#EEE3C1", "#EFE6C8", "#EFE6C8", "#F0E9CF", "#F0E9CF", "#F2EBD6", "#F2EBD6", "#FBF2E0", "#FBF2E0", "#FCF7E9", "#FCF7E9", "#FDFBF0", "#FDFBF0", "#FDFDF6", "#FDFDF6", "#FDFDFB", "#FDFDFB", "#FDFDFD", "#FDFDFD", "#FDFDFD", "#FDFDFD", "#FDFDFD", "#FDFDFD", "#FDFDFD", "#FDFDFD", "#FDFDFD", "#FDFDFD", "#FDFDFD", "#FDFDFD", "#FDFDFD", "#FDFDFD", "#FDFDFD"], "imagej_hue": ["#FF0000", "#FF0000", "#F80700", "#F80700", "#F20D00", "#F20D00", "#EC1300", "#EC1300", "#E61900", "#E61900", "#E11E00", "#E11E00", "#DC2300", "#DC2300", "#D82700", "#D82700", "#D32C00", "#D32C00", "#CF3000", "#CF3000", "#CC3300", "#CC3300", "#C83700", "#C83700", "#C43B00", "#C43B00", "#C13E00", "#C13E00", "#BE4100", "#BE4100", "#BB4400", "#BB4400", "#B84700", "#B84700", "#B54A00", "#B54A00", "#B24D00", "#B24D00", "#B04F00", "#B04F00", "#AD5200", "#AD5200", "#AB5400", "#AB5400", "#A85700", "#A85700", "#A65900", "#A65900", "#A45B00", "#A45B00", "#A25D00", "#A25D00", "#9F6000", "#9F6000", "#9D6200", "#9D6200", "#9B6400", "#9B6400", "#996600", "#996600", "#976800", "#976800", "#956A00", "#956A00", "#936C00", "#936C00", "#916E00", "#916E00", "#8F7000", "#8F7000", "#8E7100", "#8E7100", "#8C7300", "#8C7300", "#8A7500", "#8A7500", "#887700", "#887700", "#867900", "#867900", "#847B00", "#847B00", "#837C00", "#837C00", "#817E00", "#817E00", "#7F8000", "#7F8000", "#7D8200", "#7D8200", "#7B8400", "#7B8400", "#798600", "#798600", "#788700", "#788700", "#768900", "#768900", "#748B00", "#748B00", "#728D00", "#728D00", "#708F00", "#708F00", "#6E9100", "#6E9100", "#6C9300", "#6C9300", "#6A9500", "#6A9500", "#699600", "#699600", "#679800", "#679800", "#649B00", "#649B00", "#629D00", "#629D00", "#609F00", "#609F00", "#5EA100", "#5EA100", "#5CA300", "#5CA300", "#5AA500", "#5AA500", "#57A800", "#57A800", "#55AA00", "#55AA00", "#53AC00", "#53AC00", "#50AF00", "#50AF00", "#4DB200", "#4DB200", "#4BB400", "#4BB400", "#48B700", "#48B700", "#45BA00", "#45BA00", "#42BD00", "#42BD00", "#3FC000", "#3FC000", "#3CC300", "#3CC300", "#38C700", "#38C700", "#35CA00", "#35CA00", "#31CE00", "#31CE00", "#2DD200", "#2DD200", "#29D600", "#29D600", "#24DB00", "#24DB00", "#20DF00", "#20DF00", "#1BE400", "#1BE400", "#15EA00", "#15EA00", "#0FF000", "#0FF000", "#09F600", "#09F600", "#02FD00", "#02FD00", "#00FA05", "#00FA05", "#00F40B", "#00F40B", "#00EE11", "#00EE11", "#00E817", "#00E817", "#00E31C", "#00E31C", "#00DE21", "#00DE21", "#00D926", "#00D926", "#00D52A", "#00D52A", "#00D12E", "#00D12E", "#00CD32", "#00CD32", "#00C936", "#00C936", "#00C639", "#00C639", "#00C23D", "#00C23D", "#00BF40", "#00BF40", "#00BC43", "#00BC43", "#00B946", "#00B946", "#00B649", "#00B649", "#00B34C", "#00B34C", "#00B14E", "#00B14E", "#00AE51", "#00AE51", "#00AC53", "#00AC53", "#00A956", "#00A956", "#00A758", "#00A758", "#00A55A", "#00A55A", "#00A25D", "#00A25D", "#00A05F", "#00A05F", "#009E61", "#009E61", "#009C63", "#009C63", "#009A65", "#009A65", "#009867", "#009867", "#009669", "#009669", "#00946B", "#00946B", "#00926D", "#00926D", "#00906F", "#00906F", "#008E71", "#008E71", "#008C73", "#008C73", "#008A75", "#008A75", "#008976", "#008976", "#008778", "#008778", "#00857A", "#00857A", "#00837C", "#00837C", "#00817E", "#00817E", "#00807F", "#00807F", "#007E81", "#007E81", "#007C83", "#007C83", "#007A85", "#007A85", "#007887", "#007887", "#007689", "#007689", "#00758A", "#00758A", "#00738C", "#00738C", "#00718E", "#00718E", "#006F90", "#006F90", "#006D92", "#006D92", "#006B94", "#006B94", "#006996", "#006996", "#006798", "#006798", "#00659A", "#00659A", "#00639C", "#00639C", "#00619E", "#00619E", "#005FA0", "#005FA0", "#005DA2", "#005DA2", "#005AA5", "#005AA5", "#0058A7", "#0058A7", "#0056A9", "#0056A9", "#0053AC", "#0053AC", "#0051AE", "#0051AE", "#004EB1", "#004EB1", "#004CB3", "#004CB3", "#0049B6", "#0049B6", "#0046B9", "#0046B9", "#0043BC", "#0043BC", "#0040BF", "#0040BF", "#003DC2", "#003DC2", "#0039C6", "#0039C6", "#0036C9", "#0036C9", "#0032CD", "#0032CD", "#002ED1", "#002ED1", "#002AD5", "#002AD5", "#0026D9", "#0026D9", "#0021DE", "#0021DE", "#001CE3", "#001CE3", "#0017E8", "#0017E8", "#0011EE", "#0011EE", "#000BF4", "#000BF4", "#0005FA", "#0005FA", "#0200FD", "#0200FD", "#0900F6", "#0900F6", "#0F00F0", "#0F00F0", "#1500EA", "#1500EA", "#1B00E4", "#1B00E4", "#2000DF", "#2000DF", "#2400DB", "#2400DB", "#2900D6", "#2900D6", "#2D00D2", "#2D00D2", "#3100CE", "#3100CE", "#3500CA", "#3500CA", "#3800C7", "#3800C7", "#3C00C3", "#3C00C3", "#3F00C0", "#3F00C0", "#4200BD", "#4200BD", "#4500BA", "#4500BA", "#4800B7", "#4800B7", "#4B00B4", "#4B00B4", "#4D00B2", "#4D00B2", "#5000AF", "#5000AF", "#5300AC", "#5300AC", "#5500AA", "#5500AA", "#5700A8", "#5700A8", "#5A00A5", "#5A00A5", "#5C00A3", "#5C00A3", "#5E00A1", "#5E00A1", "#60009F", "#60009F", "#62009D", "#62009D", "#64009B", "#64009B", "#670098", "#670098", "#690096", "#690096", "#6A0095", "#6A0095", "#6C0093", "#6C0093", "#6E0091", "#6E0091", "#70008F", "#70008F", "#72008D", "#72008D", "#74008B", "#74008B", "#760089", "#760089", "#780087", "#780087", "#790086", "#790086", "#7B0084", "#7B0084", "#7D0082", "#7D0082", "#7F0080", "#7F0080", "#81007E", "#81007E", "#83007C", "#83007C", "#84007B", "#84007B", "#860079", "#860079", "#880077", "#880077", "#8A0075", "#8A0075", "#8C0073", "#8C0073", "#8E0071", "#8E0071", "#8F0070", "#8F0070", "#91006E", "#91006E", "#93006C", "#93006C", "#95006A", "#95006A", "#970068", "#970068", "#990066", "#990066", "#9B0064", "#9B0064", "#9D0062", "#9D0062", "#9F0060", "#9F0060", "#A2005D", "#A2005D", "#A4005B", "#A4005B", "#A60059", "#A60059", "#A80057", "#A80057", "#AB0054", "#AB0054", "#AD0052", "#AD0052", "#B0004F", "#B0004F", "#B2004D", "#B2004D", "#B5004A", "#B5004A", "#B80047", "#B80047", "#BB0044", "#BB0044", "#BE0041", "#BE0041", "#C1003E", "#C1003E", "#C4003B", "#C4003B", "#C80037", "#C80037", "#CC0033", "#CC0033", "#CF0030", "#CF0030", "#D3002C", "#D3002C", "#D80027", "#D80027", "#DC0023", "#DC0023", "#E1001E", "#E1001E", "#E60019", "#E60019", "#EC0013", "#EC0013", "#F2000D", "#F2000D", "#F80007", "#F80007"], "imagej_icool": ["#010302", "#010302", "#010302", "#010504", "#010504", "#010706", "#010706", "#010908", "#010908", "#010B0A", "#010B0A", "#010D0C", "#010D0C", "#010F0E", "#010F0E", "#011110", "#011110", "#011312", "#011312", "#011514", "#011514", "#011716", "#011716", "#011918", "#011918", "#011B1A", "#011B1A", "#011D1C", "#011D1C", "#011F1E", "#011F1E", "#012120", "#012120", "#012322", "#012322", "#012524", "#012524", "#012726", "#012726", "#012928", "#012928", "#012B2A", "#012B2A", "#012D2C", "#012D2C", "#012F2E", "#012F2E", "#013130", "#013130", "#013332", "#013332", "#013534", "#013534", "#013736", "#013736", "#013938", "#013938", "#013B3A", "#013B3A", "#013D3C", "#013D3C", "#013F3E", "#013F3E", "#014040", "#014040", "#014241", "#014241", "#014443", "#014443", "#014645", "#014645", "#014847", "#014847", "#014A49", "#014A49", "#014C4B", "#014C4B", "#014E4D", "#014E4D", "#01504F", "#01504F", "#015251", "#015251", "#015453", "#015453", "#015655", "#015655", "#015857", "#015857", "#015A59", "#015A59", "#015C5B", "#015C5B", "#015E5D", "#015E5D", "#01605F", "#01605F", "#016261", "#016261", "#016463", "#016463", "#016665", "#016665", "#016867", "#016867", "#016A69", "#016A69", "#016C6B", "#016C6B", "#016E6D", "#016E6D", "#01706F", "#01706F", "#017271", "#017271", "#017473", "#017473", "#017675", "#017675", "#017877", "#017877", "#017A79", "#017A79", "#017C7B", "#017C7B", "#017E7D", "#017E7D", "#01807F", "#01807F", "#027E81", "#027E81", "#047C83", "#047C83", "#067A85", "#067A85", "#087887", "#087887", "#0A7689", "#0A7689", "#0C748B", "#0C748B", "#0E728D", "#0E728D", "#10708F", "#10708F", "#126E91", "#126E91", "#146C93", "#146C93", "#166A95", "#166A95", "#186897", "#186897", "#1A6699", "#1A6699", "#1C649B", "#1C649B", "#1E629D", "#1E629D", "#20609F", "#20609F", "#225EA1", "#225EA1", "#245CA3", "#245CA3", "#265AA5", "#265AA5", "#2858A7", "#2858A7", "#2A56A9", "#2A56A9", "#2C54AB", "#2C54AB", "#2E52AD", "#2E52AD", "#3050AF", "#3050AF", "#324EB1", "#324EB1", "#344CB3", "#344CB3", "#364AB5", "#364AB5", "#3848B7", "#3848B7", "#3A46B9", "#3A46B9", "#3C44BB", "#3C44BB", "#3E42BD", "#3E42BD", "#4040BF", "#4040BF", "#413FC0", "#413FC0", "#433DC2", "#433DC2", "#453BC4", "#453BC4", "#4739C6", "#4739C6", "#4937C8", "#4937C8", "#4B35CA", "#4B35CA", "#4D33CC", "#4D33CC", "#4F31CE", "#4F31CE", "#512FD0", "#512FD0", "#532DD2", "#532DD2", "#552BD4", "#552BD4", "#5729D6", "#5729D6", "#5927D8", "#5927D8", "#5B25DA", "#5B25DA", "#5D23DC", "#5D23DC", "#5F21DE", "#5F21DE", "#611FE0", "#611FE0", "#631DE2", "#631DE2", "#651BE4", "#651BE4", "#6719E6", "#6719E6", "#6917E8", "#6917E8", "#6B15EA", "#6B15EA", "#6D13EC", "#6D13EC", "#6F11EE", "#6F11EE", "#710FF0", "#710FF0", "#730DF2", "#730DF2", "#750BF4", "#750BF4", "#7709F6", "#7709F6", "#7907F8", "#7907F8", "#7B05FA", "#7B05FA", "#7D03FC", "#7D03FC", "#7F01FE", "#7F01FE", "#8102FA", "#8102FA", "#8304F6", "#8304F6", "#8506F2", "#8506F2", "#8708EE", "#8708EE", "#890AEA", "#890AEA", "#8B0CE6", "#8B0CE6", "#8D0EE2", "#8D0EE2", "#8F10DE", "#8F10DE", "#9112DA", "#9112DA", "#9314D6", "#9314D6", "#9516D2", "#9516D2", "#9718CE", "#9718CE", "#991ACA", "#991ACA", "#9B1CC6", "#9B1CC6", "#9D1EC2", "#9D1EC2", "#9F20BF", "#9F20BF", "#A122BB", "#A122BB", "#A324B7", "#A324B7", "#A526B3", "#A526B3", "#A728AF", "#A728AF", "#A92AAB", "#A92AAB", "#AB2CA7", "#AB2CA7", "#AD2EA3", "#AD2EA3", "#AF309F", "#AF309F", "#B1329B", "#B1329B", "#B33497", "#B33497", "#B53693", "#B53693", "#B7388F", "#B7388F", "#B93A8B", "#B93A8B", "#BB3C87", "#BB3C87", "#BD3E83", "#BD3E83", "#BF407F", "#BF407F", "#C0417B", "#C0417B", "#C24377", "#C24377", "#C44573", "#C44573", "#C6476F", "#C6476F", "#C8496B", "#C8496B", "#CA4B67", "#CA4B67", "#CC4D63", "#CC4D63", "#CE4F5F", "#CE4F5F", "#D0515B", "#D0515B", "#D25357", "#D25357", "#D45553", "#D45553", "#D6574F", "#D6574F", "#D8594B", "#D8594B", "#DA5B47", "#DA5B47", "#DC5D43", "#DC5D43", "#DE5F40", "#DE5F40", "#E0613C", "#E0613C", "#E26338", "#E26338", "#E46534", "#E46534", "#E66730", "#E66730", "#E8692C", "#E8692C", "#EA6B28", "#EA6B28", "#EC6D24", "#EC6D24", "#EE6F20", "#EE6F20", "#F0711C", "#F0711C", "#F27318", "#F27318", "#F47514", "#F47514", "#F67710", "#F67710", "#F8790C", "#F8790C", "#FA7B08", "#FA7B08", "#FC7D04", "#FC7D04", "#FE7F01", "#FE7F01", "#FE8104", "#FE8104", "#FE8308", "#FE8308", "#FE850C", "#FE850C", "#FE8710", "#FE8710", "#FE8914", "#FE8914", "#FE8B18", "#FE8B18", "#FE8D1C", "#FE8D1C", "#FE8F20", "#FE8F20", "#FE9124", "#FE9124", "#FE9328", "#FE9328", "#FE952C", "#FE952C", "#FE9730", "#FE9730", "#FE9934", "#FE9934", "#FE9B38", "#FE9B38", "#FE9D3C", "#FE9D3C", "#FE9F40", "#FE9F40", "#FEA143", "#FEA143", "#FEA347", "#FEA347", "#FEA54B", "#FEA54B", "#FEA74F", "#FEA74F", "#FEA953", "#FEA953", "#FEAB57", "#FEAB57", "#FEAD5B", "#FEAD5B", "#FEAF5F", "#FEAF5F", "#FEB163", "#FEB163", "#FEB367", "#FEB367", "#FEB56B", "#FEB56B", "#FEB76F", "#FEB76F", "#FEB973", "#FEB973", "#FEBB77", "#FEBB77", "#FEBD7B", "#FEBD7B", "#FEBF7F", "#FEBF7F", "#FEC083", "#FEC083", "#FEC287", "#FEC287", "#FEC48B", "#FEC48B", "#FEC68F", "#FEC68F", "#FEC893", "#FEC893", "#FECA97", "#FECA97", "#FECC9B", "#FECC9B", "#FECE9F", "#FECE9F", "#FED0A3", "#FED0A3", "#FED2A7", "#FED2A7", "#FED4AB", "#FED4AB", "#FED6AF", "#FED6AF", "#FED8B3", "#FED8B3", "#FEDAB7", "#FEDAB7", "#FEDCBB", "#FEDCBB", "#FEDEBF", "#FEDEBF", "#FEE0C2", "#FEE0C2", "#FEE2C6", "#FEE2C6", "#FEE4CA", "#FEE4CA", "#FEE6CE", "#FEE6CE", "#FEE8D2", "#FEE8D2", "#FEEAD6", "#FEEAD6", "#FEECDA", "#FEECDA", "#FEEEDE", "#FEEEDE", "#FEF0E2", "#FEF0E2", "#FEF2E6", "#FEF2E6", "#FEF4EA", "#FEF4EA", "#FEF6EE", "#FEF6EE", "#FEF8F2", "#FEF8F2", "#FEFAF6", "#FEFAF6", "#FEFAF6"], "imagej_iman": ["#000000", "#000000", "#380000", "#380000", "#3C0000", "#3C0000", "#400000", "#400000", "#440000", "#440000", "#480000", "#480000", "#500000", "#500000", "#540000", "#540000", "#580000", "#580000", "#5C0000", "#5C0000", "#640000", "#640000", "#680000", "#680000", "#6C0000", "#6C0000", "#700000", "#700000", "#740000", "#740000", "#7C0000", "#7C0000", "#800000", "#800000", "#840000", "#840000", "#880000", "#880000", "#900000", "#900000", "#940000", "#940000", "#980000", "#980000", "#9C0000", "#9C0000", "#A00000", "#A00000", "#A80000", "#A80000", "#AC0000", "#AC0000", "#B00000", "#B00000", "#B40000", "#B40000", "#BC0000", "#BC0000", "#C00000", "#C00000", "#C40000", "#C40000", "#C80000", "#C80000", "#CC0000", "#CC0000", "#D40000", "#D40000", "#D80000", "#D80000", "#DC0000", "#DC0000", "#E00000", "#E00000", "#E80000", "#E80000", "#EC0000", "#EC0000", "#F00000", "#F00000", "#F40000", "#F40000", "#FC0000", "#FC0000", "#FC0400", "#FC0400", "#FC0C00", "#FC0C00", "#FC1000", "#FC1000", "#FC1800", "#FC1800", "#FC2000", "#FC2000", "#FC2400", "#FC2400", "#FC2C00", "#FC2C00", "#FC3400", "#FC3400", "#FC3800", "#FC3800", "#FC4000", "#FC4000", "#FC4800", "#FC4800", "#FC4C00", "#FC4C00", "#FC5400", "#FC5400", "#FC5C00", "#FC5C00", "#FC6000", "#FC6000", "#FC6800", "#FC6800", "#FC7000", "#FC7000", "#FC7400", "#FC7400", "#FC7C00", "#FC7C00", "#FC8400", "#FC8400", "#FC8800", "#FC8800", "#FC9000", "#FC9000", "#FC9800", "#FC9800", "#FC9C00", "#FC9C00", "#FCA400", "#FCA400", "#FCAC00", "#FCAC00", "#FCB000", "#FCB000", "#FCB800", "#FCB800", "#FCC000", "#FCC000", "#FCC400", "#FCC400", "#FCCC00", "#FCCC00", "#FCD400", "#FCD400", "#FCD800", "#FCD800", "#FCE000", "#FCE000", "#FCE800", "#FCE800", "#FCEC00", "#FCEC00", "#FCF400", "#FCF400", "#FCFC00", "#FCFC00", "#F8FC00", "#F8FC00", "#F0FC00", "#F0FC00", "#E8F800", "#E8F800", "#E0F800", "#E0F800", "#D8F400", "#D8F400", "#D0F400", "#D0F400", "#C8F000", "#C8F000", "#C0F000", "#C0F000", "#B8F000", "#B8F000", "#B0EC00", "#B0EC00", "#A8EC00", "#A8EC00", "#A0E800", "#A0E800", "#98E800", "#98E800", "#90E400", "#90E400", "#88E400", "#88E400", "#80E004", "#80E004", "#78E004", "#78E004", "#70E004", "#70E004", "#68DC04", "#68DC04", "#60DC04", "#60DC04", "#58D804", "#58D804", "#50D804", "#50D804", "#48D404", "#48D404", "#40D404", "#40D404", "#38D404", "#38D404", "#30D004", "#30D004", "#28D004", "#28D004", "#20CC04", "#20CC04", "#18CC04", "#18CC04", "#10C804", "#10C804", "#08C804", "#08C804", "#00C408", "#00C408", "#00C418", "#00C418", "#00C82C", "#00C82C", "#00C83C", "#00C83C", "#00CC50", "#00CC50", "#00CC60", "#00CC60", "#00D074", "#00D074", "#00D084", "#00D084", "#00D498", "#00D498", "#00D4A8", "#00D4A8", "#00D8BC", "#00D8BC", "#00D4BC", "#00D4BC", "#00D0BC", "#00D0BC", "#00CCBC", "#00CCBC", "#00C8BC", "#00C8BC", "#00C0BC", "#00C0BC", "#00BCC0", "#00BCC0", "#00B8C0", "#00B8C0", "#00B0C0", "#00B0C0", "#00ACC4", "#00ACC4", "#04A8C4", "#04A8C4", "#04A0C4", "#04A0C4", "#049CC4", "#049CC4", "#0494C8", "#0494C8", "#0490C8", "#0490C8", "#048CC8", "#048CC8", "#0484CC", "#0484CC", "#0480CC", "#0480CC", "#087CCC", "#087CCC", "#0874D0", "#0874D0", "#0870D0", "#0870D0", "#086CD0", "#086CD0", "#0864D0", "#0864D0", "#0860D4", "#0860D4", "#0858D4", "#0858D4", "#0C54D4", "#0C54D4", "#0C50D8", "#0C50D8", "#0C48D8", "#0C48D8", "#0C44D8", "#0C44D8", "#0C40DC", "#0C40DC", "#0C38DC", "#0C38DC", "#0C34DC", "#0C34DC", "#102CE0", "#102CE0", "#1028E0", "#1028E0", "#1024E4", "#1024E4", "#101CE4", "#101CE4", "#1018E4", "#1018E4", "#1410E8", "#1410E8", "#1810E8", "#1810E8", "#1C10E4", "#1C10E4", "#2010E0", "#2010E0", "#2410E0", "#2410E0", "#2810DC", "#2810DC", "#2C10D8", "#2C10D8", "#3010D4", "#3010D4", "#3410D4", "#3410D4", "#3810D0", "#3810D0", "#3C10CC", "#3C10CC", "#4010C8", "#4010C8", "#4010C8", "#4410C8", "#4410C8", "#4410C8", "#4814C4", "#4814C4", "#4C14C4", "#4C14C4", "#4C14C4", "#5014C0", "#5014C0", "#5418C0", "#5418C0", "#5418C0", "#5818C0", "#5818C0", "#5818BC", "#5818BC", "#5C1CBC", "#5C1CBC", "#601CBC", "#601CBC", "#601CB8", "#601CB8", "#641CB8", "#641CB8", "#6820B8", "#6820B8", "#6820B4", "#6820B4", "#6C20B4", "#6C20B4", "#7024B4", "#7024B4", "#7024B4", "#7424B0", "#7424B0", "#7424B0", "#7828B0", "#7828B0", "#7C28AC", "#7C28AC", "#7C28AC", "#8028AC", "#8028AC", "#842CA8", "#842CA8", "#842CA8", "#882CA8", "#882CA8", "#8C30A4", "#8C30A4", "#8C30A4", "#8C34A4", "#8C34A4", "#8C38A0", "#8C38A0", "#8C3CA0", "#8C3CA0", "#8C40A0", "#8C40A0", "#8C449C", "#8C449C", "#8C449C", "#884898", "#884898", "#884C98", "#884C98", "#885098", "#885098", "#885494", "#885494", "#885894", "#885894", "#885894", "#885C90", "#885C90", "#886090", "#886090", "#84648C", "#84648C", "#84688C", "#84688C", "#846C8C", "#846C8C", "#846C88", "#846C88", "#847088", "#847088", "#847488", "#847488", "#847884", "#847884", "#847C84", "#847C84", "#808080", "#808080", "#848484", "#848484", "#888888", "#888888", "#8C8C8C", "#8C8C8C", "#909090", "#909090", "#949494", "#949494", "#989898", "#989898", "#9C9C9C", "#9C9C9C", "#A0A0A0", "#A0A0A0", "#A4A4A4", "#A4A4A4", "#A8A8A8", "#A8A8A8", "#ACACAC", "#ACACAC", "#B0B0B0", "#B0B0B0", "#B4B4B4", "#B4B4B4", "#B8B8B8", "#B8B8B8", "#BCBCBC", "#BCBCBC", "#C0C0C0", "#C0C0C0", "#C4C4C4", "#C4C4C4", "#C8C8C8", "#C8C8C8", "#CCCCCC", "#CCCCCC", "#D0D0D0", "#D0D0D0", "#D4D4D4", "#D4D4D4", "#D8D8D8", "#D8D8D8", "#DCDCDC", "#DCDCDC", "#E0E0E0", "#E0E0E0", "#E4E4E4", "#E4E4E4", "#E8E8E8", "#E8E8E8", "#ECECEC", "#ECECEC", "#F0F0F0", "#F0F0F0", "#F4F4F4", "#F4F4F4", "#F8F8F8", "#F8F8F8", "#FCFCFC", "#FCFCFC", "#FCFCFC"], "imagej_neon_blue": ["#000000", "#000000", "#000001", "#000001", "#000003", "#000003", "#000005", "#000005", "#000007", "#000007", "#000009", "#000009", "#00000B", "#00000B", "#00000D", "#00000D", "#00000F", "#00000F", "#000011", "#000011", "#000013", "#000013", "#000015", "#000015", "#000017", "#000017", "#000019", "#000019", "#00001B", "#00001B", "#00001D", "#00001D", "#00001F", "#00001F", "#000021", "#000021", "#000023", "#000023", "#000025", "#000025", "#000027", "#000027", "#000029", "#000029", "#00002B", "#00002B", "#00002D", "#00002D", "#00002F", "#00002F", "#000031", "#000031", "#000033", "#000033", "#000035", "#000035", "#000037", "#000037", "#000039", "#000039", "#00003B", "#00003B", "#00003D", "#00003D", "#00003F", "#00003F", "#000041", "#000041", "#000043", "#000043", "#000045", "#000045", "#000047", "#000047", "#000049", "#000049", "#00004B", "#00004B", "#00004D", "#00004D", "#00004F", "#00004F", "#000051", "#000051", "#000053", "#000053", "#000055", "#000055", "#000057", "#000057", "#000059", "#000059", "#00005B", "#00005B", "#00005D", "#00005D", "#00005F", "#00005F", "#000061", "#000061", "#000063", "#000063", "#000065", "#000065", "#000067", "#000067", "#000069", "#000069", "#00006B", "#00006B", "#00006D", "#00006D", "#00006F", "#00006F", "#000071", "#000071", "#000073", "#000073", "#000075", "#000075", "#000077", "#000077", "#000079", "#000079", "#00007B", "#00007B", "#00007D", "#00007D", "#00007F", "#00007F", "#000081", "#000081", "#000083", "#000083", "#000085", "#000085", "#000087", "#000087", "#000089", "#000089", "#00008B", "#00008B", "#00008D", "#00008D", "#00008F", "#00008F", "#000091", "#000091", "#000093", "#000093", "#000095", "#000095", "#000097", "#000097", "#000099", "#000099", "#00009B", "#00009B", "#00009D", "#00009D", "#00009F", "#00009F", "#0000A1", "#0000A1", "#0000A3", "#0000A3", "#0000A5", "#0000A5", "#0000A7", "#0000A7", "#0000A9", "#0000A9", "#0000AB", "#0000AB", "#0000AD", "#0000AD", "#0000AF", "#0000AF", "#0000B1", "#0000B1", "#0000B3", "#0000B3", "#0000B5", "#0000B5", "#0000B7", "#0000B7", "#0000B9", "#0000B9", "#0000BB", "#0000BB", "#0000BD", "#0000BD", "#0000BF", "#0000BF", "#0000C1", "#0000C1", "#0000C3", "#0000C3", "#0000C5", "#0000C5", "#0000C7", "#0000C7", "#0000C9", "#0000C9", "#0000CB", "#0000CB", "#0000CD", "#0000CD", "#0000CF", "#0000CF", "#0000D1", "#0000D1", "#0000D3", "#0000D3", "#0000D5", "#0000D5", "#0000D7", "#0000D7", "#0000D9", "#0000D9", "#0000DB", "#0000DB", "#0000DD", "#0000DD", "#0000DF", "#0000DF", "#0000E1", "#0000E1", "#0000E3", "#0000E3", "#0000E5", "#0000E5", "#0000E7", "#0000E7", "#0000E9", "#0000E9", "#0000EB", "#0000EB", "#0000ED", "#0000ED", "#0000EF", "#0000EF", "#0000F1", "#0000F1", "#0000F3", "#0000F3", "#0000F5", "#0000F5", "#0000F7", "#0000F7", "#0000F9", "#0000F9", "#0000FB", "#0000FB", "#0000FF", "#0000FF", "#0000FF", "#0101FF", "#0101FF", "#0303FF", "#0303FF", "#0505FF", "#0505FF", "#0707FF", "#0707FF", "#0909FF", "#0909FF", "#0B0BFF", "#0B0BFF", "#0D0DFF", "#0D0DFF", "#0F0FFF", "#0F0FFF", "#1111FF", "#1111FF", "#1313FF", "#1313FF", "#1515FF", "#1515FF", "#1717FF", "#1717FF", "#1919FF", "#1919FF", "#1B1BFF", "#1B1BFF", "#1D1DFF", "#1D1DFF", "#1F1FFF", "#1F1FFF", "#2121FF", "#2121FF", "#2323FF", "#2323FF", "#2525FF", "#2525FF", "#2727FF", "#2727FF", "#2929FF", "#2929FF", "#2B2BFF", "#2B2BFF", "#2D2DFF", "#2D2DFF", "#2F2FFF", "#2F2FFF", "#3131FF", "#3131FF", "#3333FF", "#3333FF", "#3535FF", "#3535FF", "#3737FF", "#3737FF", "#3939FF", "#3939FF", "#3B3BFF", "#3B3BFF", "#3D3DFF", "#3D3DFF", "#3F3FFF", "#3F3FFF", "#4141FF", "#4141FF", "#4343FF", "#4343FF", "#4545FF", "#4545FF", "#4747FF", "#4747FF", "#4949FF", "#4949FF", "#4B4BFF", "#4B4BFF", "#4D4DFF", "#4D4DFF", "#4F4FFF", "#4F4FFF", "#5151FF", "#5151FF", "#5353FF", "#5353FF", "#5555FF", "#5555FF", "#5757FF", "#5757FF", "#5959FF", "#5959FF", "#5B5BFF", "#5B5BFF", "#5D5DFF", "#5D5DFF", "#5F5FFF", "#5F5FFF", "#6161FF", "#6161FF", "#6363FF", "#6363FF", "#6565FF", "#6565FF", "#6767FF", "#6767FF", "#6969FF", "#6969FF", "#6B6BFF", "#6B6BFF", "#6D6DFF", "#6D6DFF", "#6F6FFF", "#6F6FFF", "#7171FF", "#7171FF", "#7373FF", "#7373FF", "#7575FF", "#7575FF", "#7777FF", "#7777FF", "#7979FF", "#7979FF", "#7B7BFF", "#7B7BFF", "#7D7DFF", "#7D7DFF", "#7F7FFF", "#7F7FFF", "#8181FF", "#8181FF", "#8383FF", "#8383FF", "#8585FF", "#8585FF", "#8787FF", "#8787FF", "#8989FF", "#8989FF", "#8B8BFF", "#8B8BFF", "#8D8DFF", "#8D8DFF", "#8F8FFF", "#8F8FFF", "#9191FF", "#9191FF", "#9393FF", "#9393FF", "#9595FF", "#9595FF", "#9797FF", "#9797FF", "#9999FF", "#9999FF", "#9B9BFF", "#9B9BFF", "#9D9DFF", "#9D9DFF", "#9F9FFF", "#9F9FFF", "#A1A1FF", "#A1A1FF", "#A3A3FF", "#A3A3FF", "#A5A5FF", "#A5A5FF", "#A7A7FF", "#A7A7FF", "#A9A9FF", "#A9A9FF", "#ABABFF", "#ABABFF", "#ADADFF", "#ADADFF", "#AFAFFF", "#AFAFFF", "#B1B1FF", "#B1B1FF", "#B3B3FF", "#B3B3FF", "#B5B5FF", "#B5B5FF", "#B7B7FF", "#B7B7FF", "#B9B9FF", "#B9B9FF", "#BBBBFF", "#BBBBFF", "#BDBDFF", "#BDBDFF", "#BFBFFF", "#BFBFFF", "#C1C1FF", "#C1C1FF", "#C3C3FF", "#C3C3FF", "#C5C5FF", "#C5C5FF", "#C7C7FF", "#C7C7FF", "#C9C9FF", "#C9C9FF", "#CBCBFF", "#CBCBFF", "#CDCDFF", "#CDCDFF", "#CFCFFF", "#CFCFFF", "#D1D1FF", "#D1D1FF", "#D3D3FF", "#D3D3FF", "#D5D5FF", "#D5D5FF", "#D7D7FF", "#D7D7FF", "#D9D9FF", "#D9D9FF", "#DBDBFF", "#DBDBFF", "#DDDDFF", "#DDDDFF", "#DFDFFF", "#DFDFFF", "#E1E1FF", "#E1E1FF", "#E3E3FF", "#E3E3FF", "#E5E5FF", "#E5E5FF", "#E7E7FF", "#E7E7FF", "#E9E9FF", "#E9E9FF", "#EBEBFF", "#EBEBFF", "#EDEDFF", "#EDEDFF", "#EFEFFF", "#EFEFFF", "#F1F1FF", "#F1F1FF", "#F3F3FF", "#F3F3FF", "#F5F5FF", "#F5F5FF", "#F7F7FF", "#F7F7FF", "#F9F9FF", "#F9F9FF", "#FBFBFF", "#FBFBFF", "#FFFFFF", "#FFFFFF"], "imagej_neon_green": ["#000000", "#000000", "#000100", "#000100", "#000300", "#000300", "#000500", "#000500", "#000700", "#000700", "#000900", "#000900", "#000B00", "#000B00", "#000D00", "#000D00", "#000F00", "#000F00", "#001100", "#001100", "#001300", "#001300", "#001500", "#001500", "#001700", "#001700", "#001900", "#001900", "#001B00", "#001B00", "#001D00", "#001D00", "#001F00", "#001F00", "#002100", "#002100", "#002300", "#002300", "#002500", "#002500", "#002700", "#002700", "#002900", "#002900", "#002B00", "#002B00", "#002D00", "#002D00", "#002F00", "#002F00", "#003100", "#003100", "#003300", "#003300", "#003500", "#003500", "#003700", "#003700", "#003900", "#003900", "#003B00", "#003B00", "#003D00", "#003D00", "#003F00", "#003F00", "#004100", "#004100", "#004300", "#004300", "#004500", "#004500", "#004700", "#004700", "#004900", "#004900", "#004B00", "#004B00", "#004D00", "#004D00", "#004F00", "#004F00", "#005100", "#005100", "#005300", "#005300", "#005500", "#005500", "#005700", "#005700", "#005900", "#005900", "#005B00", "#005B00", "#005D00", "#005D00", "#005F00", "#005F00", "#006100", "#006100", "#006300", "#006300", "#006500", "#006500", "#006700", "#006700", "#006900", "#006900", "#006B00", "#006B00", "#006D00", "#006D00", "#006F00", "#006F00", "#007100", "#007100", "#007300", "#007300", "#007500", "#007500", "#007700", "#007700", "#007900", "#007900", "#007B00", "#007B00", "#007D00", "#007D00", "#007F00", "#007F00", "#008100", "#008100", "#008300", "#008300", "#008500", "#008500", "#008700", "#008700", "#008900", "#008900", "#008B00", "#008B00", "#008D00", "#008D00", "#008F00", "#008F00", "#009100", "#009100", "#009300", "#009300", "#009500", "#009500", "#009700", "#009700", "#009900", "#009900", "#009B00", "#009B00", "#009D00", "#009D00", "#009F00", "#009F00", "#00A100", "#00A100", "#00A300", "#00A300", "#00A500", "#00A500", "#00A700", "#00A700", "#00A900", "#00A900", "#00AB00", "#00AB00", "#00AD00", "#00AD00", "#00AF00", "#00AF00", "#00B100", "#00B100", "#00B300", "#00B300", "#00B500", "#00B500", "#00B700", "#00B700", "#00B900", "#00B900", "#00BB00", "#00BB00", "#00BD00", "#00BD00", "#00BF00", "#00BF00", "#00C100", "#00C100", "#00C300", "#00C300", "#00C500", "#00C500", "#00C700", "#00C700", "#00C900", "#00C900", "#00CB00", "#00CB00", "#00CD00", "#00CD00", "#00CF00", "#00CF00", "#00D100", "#00D100", "#00D300", "#00D300", "#00D500", "#00D500", "#00D700", "#00D700", "#00D900", "#00D900", "#00DB00", "#00DB00", "#00DD00", "#00DD00", "#00DF00", "#00DF00", "#00E100", "#00E100", "#00E300", "#00E300", "#00E500", "#00E500", "#00E700", "#00E700", "#00E900", "#00E900", "#00EB00", "#00EB00", "#00ED00", "#00ED00", "#00EF00", "#00EF00", "#00F100", "#00F100", "#00F300", "#00F300", "#00F500", "#00F500", "#00F700", "#00F700", "#00F900", "#00F900", "#00FB00", "#00FB00", "#00FF00", "#00FF00", "#00FF00", "#01FF01", "#01FF01", "#03FF03", "#03FF03", "#05FF05", "#05FF05", "#07FF07", "#07FF07", "#09FF09", "#09FF09", "#0BFF0B", "#0BFF0B", "#0DFF0D", "#0DFF0D", "#0FFF0F", "#0FFF0F", "#11FF11", "#11FF11", "#13FF13", "#13FF13", "#15FF15", "#15FF15", "#17FF17", "#17FF17", "#19FF19", "#19FF19", "#1BFF1B", "#1BFF1B", "#1DFF1D", "#1DFF1D", "#1FFF1F", "#1FFF1F", "#21FF21", "#21FF21", "#23FF23", "#23FF23", "#25FF25", "#25FF25", "#27FF27", "#27FF27", "#29FF29", "#29FF29", "#2BFF2B", "#2BFF2B", "#2DFF2D", "#2DFF2D", "#2FFF2F", "#2FFF2F", "#31FF31", "#31FF31", "#33FF33", "#33FF33", "#35FF35", "#35FF35", "#37FF37", "#37FF37", "#39FF39", "#39FF39", "#3BFF3B", "#3BFF3B", "#3DFF3D", "#3DFF3D", "#3FFF3F", "#3FFF3F", "#41FF41", "#41FF41", "#43FF43", "#43FF43", "#45FF45", "#45FF45", "#47FF47", "#47FF47", "#49FF49", "#49FF49", "#4BFF4B", "#4BFF4B", "#4DFF4D", "#4DFF4D", "#4FFF4F", "#4FFF4F", "#51FF51", "#51FF51", "#53FF53", "#53FF53", "#55FF55", "#55FF55", "#57FF57", "#57FF57", "#59FF59", "#59FF59", "#5BFF5B", "#5BFF5B", "#5DFF5D", "#5DFF5D", "#5FFF5F", "#5FFF5F", "#61FF61", "#61FF61", "#63FF63", "#63FF63", "#65FF65", "#65FF65", "#67FF67", "#67FF67", "#69FF69", "#69FF69", "#6BFF6B", "#6BFF6B", "#6DFF6D", "#6DFF6D", "#6FFF6F", "#6FFF6F", "#71FF71", "#71FF71", "#73FF73", "#73FF73", "#75FF75", "#75FF75", "#77FF77", "#77FF77", "#79FF79", "#79FF79", "#7BFF7B", "#7BFF7B", "#7DFF7D", "#7DFF7D", "#7FFF7F", "#7FFF7F", "#81FF81", "#81FF81", "#83FF83", "#83FF83", "#85FF85", "#85FF85", "#87FF87", "#87FF87", "#89FF89", "#89FF89", "#8BFF8B", "#8BFF8B", "#8DFF8D", "#8DFF8D", "#8FFF8F", "#8FFF8F", "#91FF91", "#91FF91", "#93FF93", "#93FF93", "#95FF95", "#95FF95", "#97FF97", "#97FF97", "#99FF99", "#99FF99", "#9BFF9B", "#9BFF9B", "#9DFF9D", "#9DFF9D", "#9FFF9F", "#9FFF9F", "#A1FFA1", "#A1FFA1", "#A3FFA3", "#A3FFA3", "#A5FFA5", "#A5FFA5", "#A7FFA7", "#A7FFA7", "#A9FFA9", "#A9FFA9", "#ABFFAB", "#ABFFAB", "#ADFFAD", "#ADFFAD", "#AFFFAF", "#AFFFAF", "#B1FFB1", "#B1FFB1", "#B3FFB3", "#B3FFB3", "#B5FFB5", "#B5FFB5", "#B7FFB7", "#B7FFB7", "#B9FFB9", "#B9FFB9", "#BBFFBB", "#BBFFBB", "#BDFFBD", "#BDFFBD", "#BFFFBF", "#BFFFBF", "#C1FFC1", "#C1FFC1", "#C3FFC3", "#C3FFC3", "#C5FFC5", "#C5FFC5", "#C7FFC7", "#C7FFC7", "#C9FFC9", "#C9FFC9", "#CBFFCB", "#CBFFCB", "#CDFFCD", "#CDFFCD", "#CFFFCF", "#CFFFCF", "#D1FFD1", "#D1FFD1", "#D3FFD3", "#D3FFD3", "#D5FFD5", "#D5FFD5", "#D7FFD7", "#D7FFD7", "#D9FFD9", "#D9FFD9", "#DBFFDB", "#DBFFDB", "#DDFFDD", "#DDFFDD", "#DFFFDF", "#DFFFDF", "#E1FFE1", "#E1FFE1", "#E3FFE3", "#E3FFE3", "#E5FFE5", "#E5FFE5", "#E7FFE7", "#E7FFE7", "#E9FFE9", "#E9FFE9", "#EBFFEB", "#EBFFEB", "#EDFFED", "#EDFFED", "#EFFFEF", "#EFFFEF", "#F1FFF1", "#F1FFF1", "#F3FFF3", "#F3FFF3", "#F5FFF5", "#F5FFF5", "#F7FFF7", "#F7FFF7", "#F9FFF9", "#F9FFF9", "#FBFFFB", "#FBFFFB", "#FFFFFF", "#FFFFFF"], "imagej_neon_magenta": ["#000000", "#000000", "#010001", "#010001", "#030003", "#030003", "#050005", "#050005", "#070007", "#070007", "#090009", "#090009", "#0B000B", "#0B000B", "#0D000D", "#0D000D", "#0F000F", "#0F000F", "#110011", "#110011", "#130013", "#130013", "#150015", "#150015", "#170017", "#170017", "#190019", "#190019", "#1B001B", "#1B001B", "#1D001D", "#1D001D", "#1F001F", "#1F001F", "#210021", "#210021", "#230023", "#230023", "#250025", "#250025", "#270027", "#270027", "#290029", "#290029", "#2B002B", "#2B002B", "#2D002D", "#2D002D", "#2F002F", "#2F002F", "#310031", "#310031", "#330033", "#330033", "#350035", "#350035", "#370037", "#370037", "#390039", "#390039", "#3B003B", "#3B003B", "#3D003D", "#3D003D", "#3F003F", "#3F003F", "#410041", "#410041", "#430043", "#430043", "#450045", "#450045", "#470047", "#470047", "#490049", "#490049", "#4B004B", "#4B004B", "#4D004D", "#4D004D", "#4F004F", "#4F004F", "#510051", "#510051", "#530053", "#530053", "#550055", "#550055", "#570057", "#570057", "#590059", "#590059", "#5B005B", "#5B005B", "#5D005D", "#5D005D", "#5F005F", "#5F005F", "#610061", "#610061", "#630063", "#630063", "#650065", "#650065", "#670067", "#670067", "#690069", "#690069", "#6B006B", "#6B006B", "#6D006D", "#6D006D", "#6F006F", "#6F006F", "#710071", "#710071", "#730073", "#730073", "#750075", "#750075", "#770077", "#770077", "#790079", "#790079", "#7B007B", "#7B007B", "#7D007D", "#7D007D", "#7F007F", "#7F007F", "#810081", "#810081", "#830083", "#830083", "#850085", "#850085", "#870087", "#870087", "#890089", "#890089", "#8B008B", "#8B008B", "#8D008D", "#8D008D", "#8F008F", "#8F008F", "#910091", "#910091", "#930093", "#930093", "#950095", "#950095", "#970097", "#970097", "#990099", "#990099", "#9B009B", "#9B009B", "#9D009D", "#9D009D", "#9F009F", "#9F009F", "#A100A1", "#A100A1", "#A300A3", "#A300A3", "#A500A5", "#A500A5", "#A700A7", "#A700A7", "#A900A9", "#A900A9", "#AB00AB", "#AB00AB", "#AD00AD", "#AD00AD", "#AF00AF", "#AF00AF", "#B100B1", "#B100B1", "#B300B3", "#B300B3", "#B500B5", "#B500B5", "#B700B7", "#B700B7", "#B900B9", "#B900B9", "#BB00BB", "#BB00BB", "#BD00BD", "#BD00BD", "#BF00BF", "#BF00BF", "#C100C1", "#C100C1", "#C300C3", "#C300C3", "#C500C5", "#C500C5", "#C700C7", "#C700C7", "#C900C9", "#C900C9", "#CB00CB", "#CB00CB", "#CD00CD", "#CD00CD", "#CF00CF", "#CF00CF", "#D100D1", "#D100D1", "#D300D3", "#D300D3", "#D500D5", "#D500D5", "#D700D7", "#D700D7", "#D900D9", "#D900D9", "#DB00DB", "#DB00DB", "#DD00DD", "#DD00DD", "#DF00DF", "#DF00DF", "#E100E1", "#E100E1", "#E300E3", "#E300E3", "#E500E5", "#E500E5", "#E700E7", "#E700E7", "#E900E9", "#E900E9", "#EB00EB", "#EB00EB", "#ED00ED", "#ED00ED", "#EF00EF", "#EF00EF", "#F100F1", "#F100F1", "#F300F3", "#F300F3", "#F500F5", "#F500F5", "#F700F7", "#F700F7", "#F900F9", "#F900F9", "#FB00FB", "#FB00FB", "#FF00FF", "#FF00FF", "#FF00FF", "#FF01FF", "#FF01FF", "#FF03FF", "#FF03FF", "#FF05FF", "#FF05FF", "#FF07FF", "#FF07FF", "#FF09FF", "#FF09FF", "#FF0BFF", "#FF0BFF", "#FF0DFF", "#FF0DFF", "#FF0FFF", "#FF0FFF", "#FF11FF", "#FF11FF", "#FF13FF", "#FF13FF", "#FF15FF", "#FF15FF", "#FF17FF", "#FF17FF", "#FF19FF", "#FF19FF", "#FF1BFF", "#FF1BFF", "#FF1DFF", "#FF1DFF", "#FF1FFF", "#FF1FFF", "#FF21FF", "#FF21FF", "#FF23FF", "#FF23FF", "#FF25FF", "#FF25FF", "#FF27FF", "#FF27FF", "#FF29FF", "#FF29FF", "#FF2BFF", "#FF2BFF", "#FF2DFF", "#FF2DFF", "#FF2FFF", "#FF2FFF", "#FF31FF", "#FF31FF", "#FF33FF", "#FF33FF", "#FF35FF", "#FF35FF", "#FF37FF", "#FF37FF", "#FF39FF", "#FF39FF", "#FF3BFF", "#FF3BFF", "#FF3DFF", "#FF3DFF", "#FF3FFF", "#FF3FFF", "#FF41FF", "#FF41FF", "#FF43FF", "#FF43FF", "#FF45FF", "#FF45FF", "#FF47FF", "#FF47FF", "#FF49FF", "#FF49FF", "#FF4BFF", "#FF4BFF", "#FF4DFF", "#FF4DFF", "#FF4FFF", "#FF4FFF", "#FF51FF", "#FF51FF", "#FF53FF", "#FF53FF", "#FF55FF", "#FF55FF", "#FF57FF", "#FF57FF", "#FF59FF", "#FF59FF", "#FF5BFF", "#FF5BFF", "#FF5DFF", "#FF5DFF", "#FF5FFF", "#FF5FFF", "#FF61FF", "#FF61FF", "#FF63FF", "#FF63FF", "#FF65FF", "#FF65FF", "#FF67FF", "#FF67FF", "#FF69FF", "#FF69FF", "#FF6BFF", "#FF6BFF", "#FF6DFF", "#FF6DFF", "#FF6FFF", "#FF6FFF", "#FF71FF", "#FF71FF", "#FF73FF", "#FF73FF", "#FF75FF", "#FF75FF", "#FF77FF", "#FF77FF", "#FF79FF", "#FF79FF", "#FF7BFF", "#FF7BFF", "#FF7DFF", "#FF7DFF", "#FF7FFF", "#FF7FFF", "#FF81FF", "#FF81FF", "#FF83FF", "#FF83FF", "#FF85FF", "#FF85FF", "#FF87FF", "#FF87FF", "#FF89FF", "#FF89FF", "#FF8BFF", "#FF8BFF", "#FF8DFF", "#FF8DFF", "#FF8FFF", "#FF8FFF", "#FF91FF", "#FF91FF", "#FF93FF", "#FF93FF", "#FF95FF", "#FF95FF", "#FF97FF", "#FF97FF", "#FF99FF", "#FF99FF", "#FF9BFF", "#FF9BFF", "#FF9DFF", "#FF9DFF", "#FF9FFF", "#FF9FFF", "#FFA1FF", "#FFA1FF", "#FFA3FF", "#FFA3FF", "#FFA5FF", "#FFA5FF", "#FFA7FF", "#FFA7FF", "#FFA9FF", "#FFA9FF", "#FFABFF", "#FFABFF", "#FFADFF", "#FFADFF", "#FFAFFF", "#FFAFFF", "#FFB1FF", "#FFB1FF", "#FFB3FF", "#FFB3FF", "#FFB5FF", "#FFB5FF", "#FFB7FF", "#FFB7FF", "#FFB9FF", "#FFB9FF", "#FFBBFF", "#FFBBFF", "#FFBDFF", "#FFBDFF", "#FFBFFF", "#FFBFFF", "#FFC1FF", "#FFC1FF", "#FFC3FF", "#FFC3FF", "#FFC5FF", "#FFC5FF", "#FFC7FF", "#FFC7FF", "#FFC9FF", "#FFC9FF", "#FFCBFF", "#FFCBFF", "#FFCDFF", "#FFCDFF", "#FFCFFF", "#FFCFFF", "#FFD1FF", "#FFD1FF", "#FFD3FF", "#FFD3FF", "#FFD5FF", "#FFD5FF", "#FFD7FF", "#FFD7FF", "#FFD9FF", "#FFD9FF", "#FFDBFF", "#FFDBFF", "#FFDDFF", "#FFDDFF", "#FFDFFF", "#FFDFFF", "#FFE1FF", "#FFE1FF", "#FFE3FF", "#FFE3FF", "#FFE5FF", "#FFE5FF", "#FFE7FF", "#FFE7FF", "#FFE9FF", "#FFE9FF", "#FFEBFF", "#FFEBFF", "#FFEDFF", "#FFEDFF", "#FFEFFF", "#FFEFFF", "#FFF1FF", "#FFF1FF", "#FFF3FF", "#FFF3FF", "#FFF5FF", "#FFF5FF", "#FFF7FF", "#FFF7FF", "#FFF9FF", "#FFF9FF", "#FFFBFF", "#FFFBFF", "#FFFFFF", "#FFFFFF"], "imagej_neon_red": ["#000000", "#000000", "#010000", "#010000", "#030000", "#030000", "#050000", "#050000", "#070000", "#070000", "#090000", "#090000", "#0B0000", "#0B0000", "#0D0000", "#0D0000", "#0F0000", "#0F0000", "#110000", "#110000", "#130000", "#130000", "#150000", "#150000", "#170000", "#170000", "#190000", "#190000", "#1B0000", "#1B0000", "#1D0000", "#1D0000", "#1F0000", "#1F0000", "#210000", "#210000", "#230000", "#230000", "#250000", "#250000", "#270000", "#270000", "#290000", "#290000", "#2B0000", "#2B0000", "#2D0000", "#2D0000", "#2F0000", "#2F0000", "#310000", "#310000", "#330000", "#330000", "#350000", "#350000", "#370000", "#370000", "#390000", "#390000", "#3B0000", "#3B0000", "#3D0000", "#3D0000", "#3F0000", "#3F0000", "#410000", "#410000", "#430000", "#430000", "#450000", "#450000", "#470000", "#470000", "#490000", "#490000", "#4B0000", "#4B0000", "#4D0000", "#4D0000", "#4F0000", "#4F0000", "#510000", "#510000", "#530000", "#530000", "#550000", "#550000", "#570000", "#570000", "#590000", "#590000", "#5B0000", "#5B0000", "#5D0000", "#5D0000", "#5F0000", "#5F0000", "#610000", "#610000", "#630000", "#630000", "#650000", "#650000", "#670000", "#670000", "#690000", "#690000", "#6B0000", "#6B0000", "#6D0000", "#6D0000", "#6F0000", "#6F0000", "#710000", "#710000", "#730000", "#730000", "#750000", "#750000", "#770000", "#770000", "#790000", "#790000", "#7B0000", "#7B0000", "#7D0000", "#7D0000", "#7F0000", "#7F0000", "#810000", "#810000", "#830000", "#830000", "#850000", "#850000", "#870000", "#870000", "#890000", "#890000", "#8B0000", "#8B0000", "#8D0000", "#8D0000", "#8F0000", "#8F0000", "#910000", "#910000", "#930000", "#930000", "#950000", "#950000", "#970000", "#970000", "#990000", "#990000", "#9B0000", "#9B0000", "#9D0000", "#9D0000", "#9F0000", "#9F0000", "#A10000", "#A10000", "#A30000", "#A30000", "#A50000", "#A50000", "#A70000", "#A70000", "#A90000", "#A90000", "#AB0000", "#AB0000", "#AD0000", "#AD0000", "#AF0000", "#AF0000", "#B10000", "#B10000", "#B30000", "#B30000", "#B50000", "#B50000", "#B70000", "#B70000", "#B90000", "#B90000", "#BB0000", "#BB0000", "#BD0000", "#BD0000", "#BF0000", "#BF0000", "#C10000", "#C10000", "#C30000", "#C30000", "#C50000", "#C50000", "#C70000", "#C70000", "#C90000", "#C90000", "#CB0000", "#CB0000", "#CD0000", "#CD0000", "#CF0000", "#CF0000", "#D10000", "#D10000", "#D30000", "#D30000", "#D50000", "#D50000", "#D70000", "#D70000", "#D90000", "#D90000", "#DB0000", "#DB0000", "#DD0000", "#DD0000", "#DF0000", "#DF0000", "#E10000", "#E10000", "#E30000", "#E30000", "#E50000", "#E50000", "#E70000", "#E70000", "#E90000", "#E90000", "#EB0000", "#EB0000", "#ED0000", "#ED0000", "#EF0000", "#EF0000", "#F10000", "#F10000", "#F30000", "#F30000", "#F50000", "#F50000", "#F70000", "#F70000", "#F90000", "#F90000", "#FB0000", "#FB0000", "#FF0000", "#FF0000", "#FF0000", "#FF0101", "#FF0101", "#FF0303", "#FF0303", "#FF0505", "#FF0505", "#FF0707", "#FF0707", "#FF0909", "#FF0909", "#FF0B0B", "#FF0B0B", "#FF0D0D", "#FF0D0D", "#FF0F0F", "#FF0F0F", "#FF1111", "#FF1111", "#FF1313", "#FF1313", "#FF1515", "#FF1515", "#FF1717", "#FF1717", "#FF1919", "#FF1919", "#FF1B1B", "#FF1B1B", "#FF1D1D", "#FF1D1D", "#FF1F1F", "#FF1F1F", "#FF2121", "#FF2121", "#FF2323", "#FF2323", "#FF2525", "#FF2525", "#FF2727", "#FF2727", "#FF2929", "#FF2929", "#FF2B2B", "#FF2B2B", "#FF2D2D", "#FF2D2D", "#FF2F2F", "#FF2F2F", "#FF3131", "#FF3131", "#FF3333", "#FF3333", "#FF3535", "#FF3535", "#FF3737", "#FF3737", "#FF3939", "#FF3939", "#FF3B3B", "#FF3B3B", "#FF3D3D", "#FF3D3D", "#FF3F3F", "#FF3F3F", "#FF4141", "#FF4141", "#FF4343", "#FF4343", "#FF4545", "#FF4545", "#FF4747", "#FF4747", "#FF4949", "#FF4949", "#FF4B4B", "#FF4B4B", "#FF4D4D", "#FF4D4D", "#FF4F4F", "#FF4F4F", "#FF5151", "#FF5151", "#FF5353", "#FF5353", "#FF5555", "#FF5555", "#FF5757", "#FF5757", "#FF5959", "#FF5959", "#FF5B5B", "#FF5B5B", "#FF5D5D", "#FF5D5D", "#FF5F5F", "#FF5F5F", "#FF6161", "#FF6161", "#FF6363", "#FF6363", "#FF6565", "#FF6565", "#FF6767", "#FF6767", "#FF6969", "#FF6969", "#FF6B6B", "#FF6B6B", "#FF6D6D", "#FF6D6D", "#FF6F6F", "#FF6F6F", "#FF7171", "#FF7171", "#FF7373", "#FF7373", "#FF7575", "#FF7575", "#FF7777", "#FF7777", "#FF7979", "#FF7979", "#FF7B7B", "#FF7B7B", "#FF7D7D", "#FF7D7D", "#FF7F7F", "#FF7F7F", "#FF8181", "#FF8181", "#FF8383", "#FF8383", "#FF8585", "#FF8585", "#FF8787", "#FF8787", "#FF8989", "#FF8989", "#FF8B8B", "#FF8B8B", "#FF8D8D", "#FF8D8D", "#FF8F8F", "#FF8F8F", "#FF9191", "#FF9191", "#FF9393", "#FF9393", "#FF9595", "#FF9595", "#FF9797", "#FF9797", "#FF9999", "#FF9999", "#FF9B9B", "#FF9B9B", "#FF9D9D", "#FF9D9D", "#FF9F9F", "#FF9F9F", "#FFA1A1", "#FFA1A1", "#FFA3A3", "#FFA3A3", "#FFA5A5", "#FFA5A5", "#FFA7A7", "#FFA7A7", "#FFA9A9", "#FFA9A9", "#FFABAB", "#FFABAB", "#FFADAD", "#FFADAD", "#FFAFAF", "#FFAFAF", "#FFB1B1", "#FFB1B1", "#FFB3B3", "#FFB3B3", "#FFB5B5", "#FFB5B5", "#FFB7B7", "#FFB7B7", "#FFB9B9", "#FFB9B9", "#FFBBBB", "#FFBBBB", "#FFBDBD", "#FFBDBD", "#FFBFBF", "#FFBFBF", "#FFC1C1", "#FFC1C1", "#FFC3C3", "#FFC3C3", "#FFC5C5", "#FFC5C5", "#FFC7C7", "#FFC7C7", "#FFC9C9", "#FFC9C9", "#FFCBCB", "#FFCBCB", "#FFCDCD", "#FFCDCD", "#FFCFCF", "#FFCFCF", "#FFD1D1", "#FFD1D1", "#FFD3D3", "#FFD3D3", "#FFD5D5", "#FFD5D5", "#FFD7D7", "#FFD7D7", "#FFD9D9", "#FFD9D9", "#FFDBDB", "#FFDBDB", "#FFDDDD", "#FFDDDD", "#FFDFDF", "#FFDFDF", "#FFE1E1", "#FFE1E1", "#FFE3E3", "#FFE3E3", "#FFE5E5", "#FFE5E5", "#FFE7E7", "#FFE7E7", "#FFE9E9", "#FFE9E9", "#FFEBEB", "#FFEBEB", "#FFEDED", "#FFEDED", "#FFEFEF", "#FFEFEF", "#FFF1F1", "#FFF1F1", "#FFF3F3", "#FFF3F3", "#FFF5F5", "#FFF5F5", "#FFF7F7", "#FFF7F7", "#FFF9F9", "#FFF9F9", "#FFFBFB", "#FFFBFB", "#FFFFFF", "#FFFFFF"], "imagej_rgb_blue": ["#000000", "#000000", "#000001", "#000001", "#000002", "#000002", "#000003", "#000003", "#000004", "#000004", "#000005", "#000005", "#000006", "#000006", "#000007", "#000007", "#000008", "#000008", "#000009", "#000009", "#00000A", "#00000A", "#00000B", "#00000B", "#00000C", "#00000C", "#00000D", "#00000D", "#00000E", "#00000E", "#00000F", "#00000F", "#000010", "#000010", "#000011", "#000011", "#000012", "#000012", "#000013", "#000013", "#000014", "#000014", "#000015", "#000015", "#000016", "#000016", "#000017", "#000017", "#000018", "#000018", "#000019", "#000019", "#00001A", "#00001A", "#00001B", "#00001B", "#00001C", "#00001C", "#00001D", "#00001D", "#00001E", "#00001E", "#00001F", "#00001F", "#000020", "#000020", "#000021", "#000021", "#000022", "#000022", "#000023", "#000023", "#000024", "#000024", "#000025", "#000025", "#000026", "#000026", "#000027", "#000027", "#000028", "#000028", "#000029", "#000029", "#00002A", "#00002A", "#00002B", "#00002B", "#00002C", "#00002C", "#00002D", "#00002D", "#00002E", "#00002E", "#00002F", "#00002F", "#000030", "#000030", "#000031", "#000031", "#000032", "#000032", "#000033", "#000033", "#000034", "#000034", "#000035", "#000035", "#000036", "#000036", "#000037", "#000037", "#000038", "#000038", "#000039", "#000039", "#00003A", "#00003A", "#00003B", "#00003B", "#00003C", "#00003C", "#00003D", "#00003D", "#00003E", "#00003E", "#00003F", "#00003F", "#000040", "#000040", "#000041", "#000041", "#000042", "#000042", "#000043", "#000043", "#000044", "#000044", "#000045", "#000045", "#000046", "#000046", "#000047", "#000047", "#000048", "#000048", "#000049", "#000049", "#00004A", "#00004A", "#00004B", "#00004B", "#00004C", "#00004C", "#00004D", "#00004D", "#00004E", "#00004E", "#00004F", "#00004F", "#000050", "#000050", "#000051", "#000051", "#000052", "#000052", "#000053", "#000053", "#000054", "#000054", "#000055", "#000055", "#000056", "#000056", "#000057", "#000057", "#000058", "#000058", "#000059", "#000059", "#00005A", "#00005A", "#00005B", "#00005B", "#00005C", "#00005C", "#00005D", "#00005D", "#00005E", "#00005E", "#00005F", "#00005F", "#000060", "#000060", "#000061", "#000061", "#000062", "#000062", "#000063", "#000063", "#000064", "#000064", "#000065", "#000065", "#000066", "#000066", "#000067", "#000067", "#000068", "#000068", "#000069", "#000069", "#00006A", "#00006A", "#00006B", "#00006B", "#00006C", "#00006C", "#00006D", "#00006D", "#00006E", "#00006E", "#00006F", "#00006F", "#000070", "#000070", "#000071", "#000071", "#000072", "#000072", "#000073", "#000073", "#000074", "#000074", "#000075", "#000075", "#000076", "#000076", "#000077", "#000077", "#000078", "#000078", "#000079", "#000079", "#00007A", "#00007A", "#00007B", "#00007B", "#00007C", "#00007C", "#00007D", "#00007D", "#00007E", "#00007E", "#00007F", "#00007F", "#000080", "#000080", "#000081", "#000081", "#000082", "#000082", "#000083", "#000083", "#000084", "#000084", "#000085", "#000085", "#000086", "#000086", "#000087", "#000087", "#000088", "#000088", "#000089", "#000089", "#00008A", "#00008A", "#00008B", "#00008B", "#00008C", "#00008C", "#00008D", "#00008D", "#00008E", "#00008E", "#00008F", "#00008F", "#000090", "#000090", "#000091", "#000091", "#000092", "#000092", "#000093", "#000093", "#000094", "#000094", "#000095", "#000095", "#000096", "#000096", "#000097", "#000097", "#000098", "#000098", "#000099", "#000099", "#00009A", "#00009A", "#00009B", "#00009B", "#00009C", "#00009C", "#00009D", "#00009D", "#00009E", "#00009E", "#00009F", "#00009F", "#0000A0", "#0000A0", "#0000A1", "#0000A1", "#0000A2", "#0000A2", "#0000A3", "#0000A3", "#0000A4", "#0000A4", "#0000A5", "#0000A5", "#0000A6", "#0000A6", "#0000A7", "#0000A7", "#0000A8", "#0000A8", "#0000A9", "#0000A9", "#0000AA", "#0000AA", "#0000AB", "#0000AB", "#0000AC", "#0000AC", "#0000AD", "#0000AD", "#0000AE", "#0000AE", "#0000AF", "#0000AF", "#0000B0", "#0000B0", "#0000B1", "#0000B1", "#0000B2", "#0000B2", "#0000B3", "#0000B3", "#0000B4", "#0000B4", "#0000B5", "#0000B5", "#0000B6", "#0000B6", "#0000B7", "#0000B7", "#0000B8", "#0000B8", "#0000B9", "#0000B9", "#0000BA", "#0000BA", "#0000BB", "#0000BB", "#0000BC", "#0000BC", "#0000BD", "#0000BD", "#0000BE", "#0000BE", "#0000BF", "#0000BF", "#0000C0", "#0000C0", "#0000C1", "#0000C1", "#0000C2", "#0000C2", "#0000C3", "#0000C3", "#0000C4", "#0000C4", "#0000C5", "#0000C5", "#0000C6", "#0000C6", "#0000C7", "#0000C7", "#0000C8", "#0000C8", "#0000C9", "#0000C9", "#0000CA", "#0000CA", "#0000CB", "#0000CB", "#0000CC", "#0000CC", "#0000CD", "#0000CD", "#0000CE", "#0000CE", "#0000CF", "#0000CF", "#0000D0", "#0000D0", "#0000D1", "#0000D1", "#0000D2", "#0000D2", "#0000D3", "#0000D3", "#0000D4", "#0000D4", "#0000D5", "#0000D5", "#0000D6", "#0000D6", "#0000D7", "#0000D7", "#0000D8", "#0000D8", "#0000D9", "#0000D9", "#0000DA", "#0000DA", "#0000DB", "#0000DB", "#0000DC", "#0000DC", "#0000DD", "#0000DD", "#0000DE", "#0000DE", "#0000DF", "#0000DF", "#0000E0", "#0000E0", "#0000E1", "#0000E1", "#0000E2", "#0000E2", "#0000E3", "#0000E3", "#0000E4", "#0000E4", "#0000E5", "#0000E5", "#0000E6", "#0000E6", "#0000E7", "#0000E7", "#0000E8", "#0000E8", "#0000E9", "#0000E9", "#0000EA", "#0000EA", "#0000EB", "#0000EB", "#0000EC", "#0000EC", "#0000ED", "#0000ED", "#0000EE", "#0000EE", "#0000EF", "#0000EF", "#0000F0", "#0000F0", "#0000F1", "#0000F1", "#0000F2", "#0000F2", "#0000F3", "#0000F3", "#0000F4", "#0000F4", "#0000F5", "#0000F5", "#0000F6", "#0000F6", "#0000F7", "#0000F7", "#0000F8", "#0000F8", "#0000F9", "#0000F9", "#0000FA", "#0000FA", "#0000FB", "#0000FB", "#0000FC", "#0000FC", "#0000FD", "#0000FD", "#0000FE", "#0000FE", "#0000FF", "#0000FF"], "imagej_rgb_green": ["#000000", "#000000", "#000100", "#000100", "#000200", "#000200", "#000300", "#000300", "#000400", "#000400", "#000500", "#000500", "#000600", "#000600", "#000700", "#000700", "#000800", "#000800", "#000900", "#000900", "#000A00", "#000A00", "#000B00", "#000B00", "#000C00", "#000C00", "#000D00", "#000D00", "#000E00", "#000E00", "#000F00", "#000F00", "#001000", "#001000", "#001100", "#001100", "#001200", "#001200", "#001300", "#001300", "#001400", "#001400", "#001500", "#001500", "#001600", "#001600", "#001700", "#001700", "#001800", "#001800", "#001900", "#001900", "#001A00", "#001A00", "#001B00", "#001B00", "#001C00", "#001C00", "#001D00", "#001D00", "#001E00", "#001E00", "#001F00", "#001F00", "#002000", "#002000", "#002100", "#002100", "#002200", "#002200", "#002300", "#002300", "#002400", "#002400", "#002500", "#002500", "#002600", "#002600", "#002700", "#002700", "#002800", "#002800", "#002900", "#002900", "#002A00", "#002A00", "#002B00", "#002B00", "#002C00", "#002C00", "#002D00", "#002D00", "#002E00", "#002E00", "#002F00", "#002F00", "#003000", "#003000", "#003100", "#003100", "#003200", "#003200", "#003300", "#003300", "#003400", "#003400", "#003500", "#003500", "#003600", "#003600", "#003700", "#003700", "#003800", "#003800", "#003900", "#003900", "#003A00", "#003A00", "#003B00", "#003B00", "#003C00", "#003C00", "#003D00", "#003D00", "#003E00", "#003E00", "#003F00", "#003F00", "#004000", "#004000", "#004100", "#004100", "#004200", "#004200", "#004300", "#004300", "#004400", "#004400", "#004500", "#004500", "#004600", "#004600", "#004700", "#004700", "#004800", "#004800", "#004900", "#004900", "#004A00", "#004A00", "#004B00", "#004B00", "#004C00", "#004C00", "#004D00", "#004D00", "#004E00", "#004E00", "#004F00", "#004F00", "#005000", "#005000", "#005100", "#005100", "#005200", "#005200", "#005300", "#005300", "#005400", "#005400", "#005500", "#005500", "#005600", "#005600", "#005700", "#005700", "#005800", "#005800", "#005900", "#005900", "#005A00", "#005A00", "#005B00", "#005B00", "#005C00", "#005C00", "#005D00", "#005D00", "#005E00", "#005E00", "#005F00", "#005F00", "#006000", "#006000", "#006100", "#006100", "#006200", "#006200", "#006300", "#006300", "#006400", "#006400", "#006500", "#006500", "#006600", "#006600", "#006700", "#006700", "#006800", "#006800", "#006900", "#006900", "#006A00", "#006A00", "#006B00", "#006B00", "#006C00", "#006C00", "#006D00", "#006D00", "#006E00", "#006E00", "#006F00", "#006F00", "#007000", "#007000", "#007100", "#007100", "#007200", "#007200", "#007300", "#007300", "#007400", "#007400", "#007500", "#007500", "#007600", "#007600", "#007700", "#007700", "#007800", "#007800", "#007900", "#007900", "#007A00", "#007A00", "#007B00", "#007B00", "#007C00", "#007C00", "#007D00", "#007D00", "#007E00", "#007E00", "#007F00", "#007F00", "#008000", "#008000", "#008100", "#008100", "#008200", "#008200", "#008300", "#008300", "#008400", "#008400", "#008500", "#008500", "#008600", "#008600", "#008700", "#008700", "#008800", "#008800", "#008900", "#008900", "#008A00", "#008A00", "#008B00", "#008B00", "#008C00", "#008C00", "#008D00", "#008D00", "#008E00", "#008E00", "#008F00", "#008F00", "#009000", "#009000", "#009100", "#009100", "#009200", "#009200", "#009300", "#009300", "#009400", "#009400", "#009500", "#009500", "#009600", "#009600", "#009700", "#009700", "#009800", "#009800", "#009900", "#009900", "#009A00", "#009A00", "#009B00", "#009B00", "#009C00", "#009C00", "#009D00", "#009D00", "#009E00", "#009E00", "#009F00", "#009F00", "#00A000", "#00A000", "#00A100", "#00A100", "#00A200", "#00A200", "#00A300", "#00A300", "#00A400", "#00A400", "#00A500", "#00A500", "#00A600", "#00A600", "#00A700", "#00A700", "#00A800", "#00A800", "#00A900", "#00A900", "#00AA00", "#00AA00", "#00AB00", "#00AB00", "#00AC00", "#00AC00", "#00AD00", "#00AD00", "#00AE00", "#00AE00", "#00AF00", "#00AF00", "#00B000", "#00B000", "#00B100", "#00B100", "#00B200", "#00B200", "#00B300", "#00B300", "#00B400", "#00B400", "#00B500", "#00B500", "#00B600", "#00B600", "#00B700", "#00B700", "#00B800", "#00B800", "#00B900", "#00B900", "#00BA00", "#00BA00", "#00BB00", "#00BB00", "#00BC00", "#00BC00", "#00BD00", "#00BD00", "#00BE00", "#00BE00", "#00BF00", "#00BF00", "#00C000", "#00C000", "#00C100", "#00C100", "#00C200", "#00C200", "#00C300", "#00C300", "#00C400", "#00C400", "#00C500", "#00C500", "#00C600", "#00C600", "#00C700", "#00C700", "#00C800", "#00C800", "#00C900", "#00C900", "#00CA00", "#00CA00", "#00CB00", "#00CB00", "#00CC00", "#00CC00", "#00CD00", "#00CD00", "#00CE00", "#00CE00", "#00CF00", "#00CF00", "#00D000", "#00D000", "#00D100", "#00D100", "#00D200", "#00D200", "#00D300", "#00D300", "#00D400", "#00D400", "#00D500", "#00D500", "#00D600", "#00D600", "#00D700", "#00D700", "#00D800", "#00D800", "#00D900", "#00D900", "#00DA00", "#00DA00", "#00DB00", "#00DB00", "#00DC00", "#00DC00", "#00DD00", "#00DD00", "#00DE00", "#00DE00", "#00DF00", "#00DF00", "#00E000", "#00E000", "#00E100", "#00E100", "#00E200", "#00E200", "#00E300", "#00E300", "#00E400", "#00E400", "#00E500", "#00E500", "#00E600", "#00E600", "#00E700", "#00E700", "#00E800", "#00E800", "#00E900", "#00E900", "#00EA00", "#00EA00", "#00EB00", "#00EB00", "#00EC00", "#00EC00", "#00ED00", "#00ED00", "#00EE00", "#00EE00", "#00EF00", "#00EF00", "#00F000", "#00F000", "#00F100", "#00F100", "#00F200", "#00F200", "#00F300", "#00F300", "#00F400", "#00F400", "#00F500", "#00F500", "#00F600", "#00F600", "#00F700", "#00F700", "#00F800", "#00F800", "#00F900", "#00F900", "#00FA00", "#00FA00", "#00FB00", "#00FB00", "#00FC00", "#00FC00", "#00FD00", "#00FD00", "#00FE00", "#00FE00", "#00FF00", "#00FF00"], "imagej_rgb_red": ["#000000", "#000000", "#010000", "#010000", "#020000", "#020000", "#030000", "#030000", "#040000", "#040000", "#050000", "#050000", "#060000", "#060000", "#070000", "#070000", "#080000", "#080000", "#090000", "#090000", "#0A0000", "#0A0000", "#0B0000", "#0B0000", "#0C0000", "#0C0000", "#0D0000", "#0D0000", "#0E0000", "#0E0000", "#0F0000", "#0F0000", "#100000", "#100000", "#110000", "#110000", "#120000", "#120000", "#130000", "#130000", "#140000", "#140000", "#150000", "#150000", "#160000", "#160000", "#170000", "#170000", "#180000", "#180000", "#190000", "#190000", "#1A0000", "#1A0000", "#1B0000", "#1B0000", "#1C0000", "#1C0000", "#1D0000", "#1D0000", "#1E0000", "#1E0000", "#1F0000", "#1F0000", "#200000", "#200000", "#210000", "#210000", "#220000", "#220000", "#230000", "#230000", "#240000", "#240000", "#250000", "#250000", "#260000", "#260000", "#270000", "#270000", "#280000", "#280000", "#290000", "#290000", "#2A0000", "#2A0000", "#2B0000", "#2B0000", "#2C0000", "#2C0000", "#2D0000", "#2D0000", "#2E0000", "#2E0000", "#2F0000", "#2F0000", "#300000", "#300000", "#310000", "#310000", "#320000", "#320000", "#330000", "#330000", "#340000", "#340000", "#350000", "#350000", "#360000", "#360000", "#370000", "#370000", "#380000", "#380000", "#390000", "#390000", "#3A0000", "#3A0000", "#3B0000", "#3B0000", "#3C0000", "#3C0000", "#3D0000", "#3D0000", "#3E0000", "#3E0000", "#3F0000", "#3F0000", "#400000", "#400000", "#410000", "#410000", "#420000", "#420000", "#430000", "#430000", "#440000", "#440000", "#450000", "#450000", "#460000", "#460000", "#470000", "#470000", "#480000", "#480000", "#490000", "#490000", "#4A0000", "#4A0000", "#4B0000", "#4B0000", "#4C0000", "#4C0000", "#4D0000", "#4D0000", "#4E0000", "#4E0000", "#4F0000", "#4F0000", "#500000", "#500000", "#510000", "#510000", "#520000", "#520000", "#530000", "#530000", "#540000", "#540000", "#550000", "#550000", "#560000", "#560000", "#570000", "#570000", "#580000", "#580000", "#590000", "#590000", "#5A0000", "#5A0000", "#5B0000", "#5B0000", "#5C0000", "#5C0000", "#5D0000", "#5D0000", "#5E0000", "#5E0000", "#5F0000", "#5F0000", "#600000", "#600000", "#610000", "#610000", "#620000", "#620000", "#630000", "#630000", "#640000", "#640000", "#650000", "#650000", "#660000", "#660000", "#670000", "#670000", "#680000", "#680000", "#690000", "#690000", "#6A0000", "#6A0000", "#6B0000", "#6B0000", "#6C0000", "#6C0000", "#6D0000", "#6D0000", "#6E0000", "#6E0000", "#6F0000", "#6F0000", "#700000", "#700000", "#710000", "#710000", "#720000", "#720000", "#730000", "#730000", "#740000", "#740000", "#750000", "#750000", "#760000", "#760000", "#770000", "#770000", "#780000", "#780000", "#790000", "#790000", "#7A0000", "#7A0000", "#7B0000", "#7B0000", "#7C0000", "#7C0000", "#7D0000", "#7D0000", "#7E0000", "#7E0000", "#7F0000", "#7F0000", "#800000", "#800000", "#810000", "#810000", "#820000", "#820000", "#830000", "#830000", "#840000", "#840000", "#850000", "#850000", "#860000", "#860000", "#870000", "#870000", "#880000", "#880000", "#890000", "#890000", "#8A0000", "#8A0000", "#8B0000", "#8B0000", "#8C0000", "#8C0000", "#8D0000", "#8D0000", "#8E0000", "#8E0000", "#8F0000", "#8F0000", "#900000", "#900000", "#910000", "#910000", "#920000", "#920000", "#930000", "#930000", "#940000", "#940000", "#950000", "#950000", "#960000", "#960000", "#970000", "#970000", "#980000", "#980000", "#990000", "#990000", "#9A0000", "#9A0000", "#9B0000", "#9B0000", "#9C0000", "#9C0000", "#9D0000", "#9D0000", "#9E0000", "#9E0000", "#9F0000", "#9F0000", "#A00000", "#A00000", "#A10000", "#A10000", "#A20000", "#A20000", "#A30000", "#A30000", "#A40000", "#A40000", "#A50000", "#A50000", "#A60000", "#A60000", "#A70000", "#A70000", "#A80000", "#A80000", "#A90000", "#A90000", "#AA0000", "#AA0000", "#AB0000", "#AB0000", "#AC0000", "#AC0000", "#AD0000", "#AD0000", "#AE0000", "#AE0000", "#AF0000", "#AF0000", "#B00000", "#B00000", "#B10000", "#B10000", "#B20000", "#B20000", "#B30000", "#B30000", "#B40000", "#B40000", "#B50000", "#B50000", "#B60000", "#B60000", "#B70000", "#B70000", "#B80000", "#B80000", "#B90000", "#B90000", "#BA0000", "#BA0000", "#BB0000", "#BB0000", "#BC0000", "#BC0000", "#BD0000", "#BD0000", "#BE0000", "#BE0000", "#BF0000", "#BF0000", "#C00000", "#C00000", "#C10000", "#C10000", "#C20000", "#C20000", "#C30000", "#C30000", "#C40000", "#C40000", "#C50000", "#C50000", "#C60000", "#C60000", "#C70000", "#C70000", "#C80000", "#C80000", "#C90000", "#C90000", "#CA0000", "#CA0000", "#CB0000", "#CB0000", "#CC0000", "#CC0000", "#CD0000", "#CD0000", "#CE0000", "#CE0000", "#CF0000", "#CF0000", "#D00000", "#D00000", "#D10000", "#D10000", "#D20000", "#D20000", "#D30000", "#D30000", "#D40000", "#D40000", "#D50000", "#D50000", "#D60000", "#D60000", "#D70000", "#D70000", "#D80000", "#D80000", "#D90000", "#D90000", "#DA0000", "#DA0000", "#DB0000", "#DB0000", "#DC0000", "#DC0000", "#DD0000", "#DD0000", "#DE0000", "#DE0000", "#DF0000", "#DF0000", "#E00000", "#E00000", "#E10000", "#E10000", "#E20000", "#E20000", "#E30000", "#E30000", "#E40000", "#E40000", "#E50000", "#E50000", "#E60000", "#E60000", "#E70000", "#E70000", "#E80000", "#E80000", "#E90000", "#E90000", "#EA0000", "#EA0000", "#EB0000", "#EB0000", "#EC0000", "#EC0000", "#ED0000", "#ED0000", "#EE0000", "#EE0000", "#EF0000", "#EF0000", "#F00000", "#F00000", "#F10000", "#F10000", "#F20000", "#F20000", "#F30000", "#F30000", "#F40000", "#F40000", "#F50000", "#F50000", "#F60000", "#F60000", "#F70000", "#F70000", "#F80000", "#F80000", "#F90000", "#F90000", "#FA0000", "#FA0000", "#FB0000", "#FB0000", "#FC0000", "#FC0000", "#FD0000", "#FD0000", "#FE0000", "#FE0000", "#FF0000", "#FF0000"], "imagej_royal": ["#010107", "#010107", "#010107", "#01010D", "#01010D", "#010112", "#010112", "#010118", "#010118", "#01011E", "#01011E", "#010124", "#010124", "#01012A", "#01012A", "#01012F", "#01012F", "#010135", "#010135", "#01013B", "#01013B", "#010140", "#010140", "#010146", "#010146", "#01014B", "#01014B", "#010151", "#010151", "#010155", "#010155", "#010159", "#010159", "#01015D", "#01015D", "#010162", "#010162", "#010168", "#010168", "#01016D", "#01016D", "#010173", "#010173", "#010179", "#010179", "#01017E", "#01017E", "#010184", "#010184", "#010189", "#010189", "#01018F", "#01018F", "#010195", "#010195", "#01019A", "#01019A", "#0101A0", "#0101A0", "#0101A5", "#0101A5", "#0101A9", "#0101A9", "#0101AE", "#0101AE", "#0107B1", "#0107B1", "#010DB6", "#010DB6", "#0112BC", "#0112BC", "#0118C0", "#0118C0", "#011EC6", "#011EC6", "#0124CC", "#0124CC", "#012AD1", "#012AD1", "#012FD7", "#012FD7", "#0135DC", "#0135DC", "#013BE2", "#013BE2", "#0140E8", "#0140E8", "#0146ED", "#0146ED", "#014BF3", "#014BF3", "#0151F8", "#0151F8", "#0155FE", "#0155FE", "#0159FE", "#0159FE", "#015DFE", "#015DFE", "#0162FE", "#0162FE", "#0168FE", "#0168FE", "#016DFE", "#016DFE", "#0173FE", "#0173FE", "#0179FE", "#0179FE", "#017EFE", "#017EFE", "#0184FE", "#0184FE", "#0189FE", "#0189FE", "#018FFE", "#018FFE", "#0195FE", "#0195FE", "#019AFE", "#019AFE", "#01A0FE", "#01A0FE", "#01A5FE", "#01A5FE", "#01A9FE", "#01A9FE", "#01AEFE", "#01AEFE", "#01B1FE", "#01B1FE", "#01B6FE", "#01B6FE", "#01BCFE", "#01BCFE", "#01C0FE", "#01C0FE", "#01C6FE", "#01C6FE", "#01CCFE", "#01CCFE", "#01D1FE", "#01D1FE", "#01D7FE", "#01D7FE", "#01DCFE", "#01DCFE", "#01E2FE", "#01E2FE", "#01E8FE", "#01E8FE", "#01EDFE", "#01EDFE", "#01F3FE", "#01F3FE", "#01F8FE", "#01F8FE", "#01FEFE", "#01FEFE", "#01FEFE", "#01FEFE", "#01FEFE", "#01FEFE", "#01FEFE", "#01FEFE", "#01FEFE", "#01FEFE", "#01FEFE", "#01FEFE", "#01FEFE", "#01FEFE", "#01FEFE", "#01FEFE", "#01FEFE", "#01FEFE", "#01FEEE", "#01FEEE", "#0AFEDE", "#0AFEDE", "#12FECE", "#12FECE", "#1BFEBF", "#1BFEBF", "#24FEAF", "#24FEAF", "#2DFE9F", "#2DFE9F", "#35FE8F", "#35FE8F", "#3EFE7F", "#3EFE7F", "#46FE6F", "#46FE6F", "#4FFE5F", "#4FFE5F", "#57FE4F", "#57FE4F", "#60FE40", "#60FE40", "#69FE30", "#69FE30", "#72FE20", "#72FE20", "#7AFE10", "#7AFE10", "#80FE01", "#80FE01", "#86FE01", "#86FE01", "#8BFC01", "#8BFC01", "#94FA01", "#94FA01", "#9CF801", "#9CF801", "#A4F501", "#A4F501", "#ACF301", "#ACF301", "#B5F101", "#B5F101", "#BDEF01", "#BDEF01", "#C4ED01", "#C4ED01", "#CCEB01", "#CCEB01", "#D5E901", "#D5E901", "#DDE701", "#DDE701", "#E5E401", "#E5E401", "#EDE201", "#EDE201", "#F6E001", "#F6E001", "#FEDE01", "#FEDE01", "#FEDE01", "#FEDB01", "#FEDB01", "#FED901", "#FED901", "#FED601", "#FED601", "#FED301", "#FED301", "#FED101", "#FED101", "#FECE01", "#FECE01", "#FECB01", "#FECB01", "#FEC901", "#FEC901", "#FEC601", "#FEC601", "#FEC301", "#FEC301", "#FEC101", "#FEC101", "#FEBF01", "#FEBF01", "#FEBC01", "#FEBC01", "#FEBA01", "#FEBA01", "#FEB801", "#FEB801", "#FEB601", "#FEB601", "#FEB401", "#FEB401", "#FEB001", "#FEB001", "#FEAD01", "#FEAD01", "#FEA901", "#FEA901", "#FEA601", "#FEA601", "#FEA201", "#FEA201", "#FE9F01", "#FE9F01", "#FE9B01", "#FE9B01", "#FE9801", "#FE9801", "#FE9401", "#FE9401", "#FE9101", "#FE9101", "#FE8D01", "#FE8D01", "#FE8A01", "#FE8A01", "#FE8601", "#FE8601", "#FE8101", "#FE8101", "#FE8301", "#FE8301", "#FE7F01", "#FE7F01", "#FE7A01", "#FE7A01", "#FE7601", "#FE7601", "#FE7201", "#FE7201", "#FE6E01", "#FE6E01", "#FE6901", "#FE6901", "#FE6501", "#FE6501", "#FE6101", "#FE6101", "#FE5D01", "#FE5D01", "#FE5801", "#FE5801", "#FE5401", "#FE5401", "#FE5001", "#FE5001", "#FE4C01", "#FE4C01", "#FE4701", "#FE4701", "#FE4201", "#FE4201", "#FE4401", "#FE4401", "#FE4001", "#FE4001", "#FE3B01", "#FE3B01", "#FE3701", "#FE3701", "#FE3201", "#FE3201", "#FE2E01", "#FE2E01", "#FE2901", "#FE2901", "#FE2501", "#FE2501", "#FE2001", "#FE2001", "#FE1C01", "#FE1C01", "#FE1701", "#FE1701", "#FE1301", "#FE1301", "#FE0E01", "#FE0E01", "#FE0A01", "#FE0A01", "#FE0501", "#FE0501", "#FE0101", "#FE0101", "#FE0101", "#FC0E0E", "#FC0E0E", "#FA1A1A", "#FA1A1A", "#F82727", "#F82727", "#F53434", "#F53434", "#F34040", "#F34040", "#F14C4C", "#F14C4C", "#EF5959", "#EF5959", "#ED6666", "#ED6666", "#EB7373", "#EB7373", "#E97F7F", "#E97F7F", "#E78C8C", "#E78C8C", "#E49999", "#E49999", "#E2A6A6", "#E2A6A6", "#E0B2B2", "#E0B2B2", "#DEB7B7", "#DEB7B7", "#DEBCBC", "#DEBCBC", "#DEC0C0", "#DEC0C0", "#DEC2C2", "#DEC2C2", "#DEC4C4", "#DEC4C4", "#DEC7C7", "#DEC7C7", "#DEC9C9", "#DEC9C9", "#DECBCB", "#DECBCB", "#DECDCD", "#DECDCD", "#DECFCF", "#DECFCF", "#DED1D1", "#DED1D1", "#DED3D3", "#DED3D3", "#DED5D5", "#DED5D5", "#DED8D8", "#DED8D8", "#DEDADA", "#DEDADA", "#DEDCDC", "#DEDCDC", "#DEDEDE", "#DEDEDE", "#DEDEDE", "#E0E0E0", "#E0E0E0", "#E2E2E2", "#E2E2E2", "#E4E4E4", "#E4E4E4", "#E7E7E7", "#E7E7E7", "#E9E9E9", "#E9E9E9", "#EBEBEB", "#EBEBEB", "#EDEDED", "#EDEDED", "#EFEFEF", "#EFEFEF", "#F1F1F1", "#F1F1F1", "#F3F3F3", "#F3F3F3", "#F5F5F5", "#F5F5F5", "#F8F8F8", "#F8F8F8", "#FAFAFA", "#FAFAFA", "#FCFCFC", "#FCFCFC", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#FEFEFE"], "imagej_sepia": ["#000000", "#000000", "#2B1C04", "#2B1C04", "#392305", "#392305", "#412306", "#412306", "#422407", "#422407", "#432508", "#432508", "#442609", "#442609", "#45270A", "#45270A", "#46280B", "#46280B", "#47290C", "#47290C", "#482A0D", "#482A0D", "#492B0E", "#492B0E", "#4A2C0F", "#4A2C0F", "#4B2D10", "#4B2D10", "#4C2E11", "#4C2E11", "#4D2F12", "#4D2F12", "#4E3013", "#4E3013", "#4F3114", "#4F3114", "#503215", "#503215", "#513316", "#513316", "#523417", "#523417", "#533518", "#533518", "#533518", "#543619", "#543619", "#55371A", "#55371A", "#56381B", "#56381B", "#57391C", "#57391C", "#583A1D", "#583A1D", "#593B1E", "#593B1E", "#5A3C1F", "#5A3C1F", "#5B3D20", "#5B3D20", "#5C3E21", "#5C3E21", "#5D3F22", "#5D3F22", "#5E4023", "#5E4023", "#5F4124", "#5F4124", "#604225", "#604225", "#614326", "#614326", "#624427", "#624427", "#634528", "#634528", "#644629", "#644629", "#65472A", "#65472A", "#66482B", "#66482B", "#67492C", "#67492C", "#684A2D", "#684A2D", "#694B2E", "#694B2E", "#6A4C2F", "#6A4C2F", "#6B4D30", "#6B4D30", "#6B4D30", "#6C4E31", "#6C4E31", "#6D4F32", "#6D4F32", "#6E5033", "#6E5033", "#6F5134", "#6F5134", "#705235", "#705235", "#715336", "#715336", "#725437", "#725437", "#735538", "#735538", "#745639", "#745639", "#75573A", "#75573A", "#76583B", "#76583B", "#77593C", "#77593C", "#785A3D", "#785A3D", "#795B3E", "#795B3E", "#7A5C3F", "#7A5C3F", "#7B5D40", "#7B5D40", "#7C5E41", "#7C5E41", "#7D5F42", "#7D5F42", "#7D5F42", "#7E6043", "#7E6043", "#7F6144", "#7F6144", "#806245", "#806245", "#816346", "#816346", "#826447", "#826447", "#836548", "#836548", "#846649", "#846649", "#85674A", "#85674A", "#86684B", "#86684B", "#87694C", "#87694C", "#886A4D", "#886A4D", "#896B4E", "#896B4E", "#8A6C4F", "#8A6C4F", "#8B6D50", "#8B6D50", "#8C6E51", "#8C6E51", "#8D6F52", "#8D6F52", "#8E7053", "#8E7053", "#8F7154", "#8F7154", "#907255", "#907255", "#917356", "#917356", "#927457", "#927457", "#937558", "#937558", "#947659", "#947659", "#95775A", "#95775A", "#96785B", "#96785B", "#97795C", "#97795C", "#987A5D", "#987A5D", "#997B5E", "#997B5E", "#9A7C5F", "#9A7C5F", "#9B7D60", "#9B7D60", "#9C7E61", "#9C7E61", "#9D7F62", "#9D7F62", "#9E8063", "#9E8063", "#9F8164", "#9F8164", "#A08265", "#A08265", "#A18366", "#A18366", "#A28467", "#A28467", "#A38568", "#A38568", "#A48669", "#A48669", "#A5876A", "#A5876A", "#A6886B", "#A6886B", "#A7896C", "#A7896C", "#A88A6D", "#A88A6D", "#A98B6E", "#A98B6E", "#AA8C6F", "#AA8C6F", "#AB8D70", "#AB8D70", "#AC8E71", "#AC8E71", "#AD8F72", "#AD8F72", "#AE9073", "#AE9073", "#AF9174", "#AF9174", "#B09275", "#B09275", "#B19376", "#B19376", "#B29477", "#B29477", "#B39578", "#B39578", "#B49679", "#B49679", "#B5977A", "#B5977A", "#B6987B", "#B6987B", "#B7997C", "#B7997C", "#B89A7D", "#B89A7D", "#B99B7E", "#B99B7E", "#BA9C7F", "#BA9C7F", "#BB9D80", "#BB9D80", "#BB9D80", "#BC9E81", "#BC9E81", "#BD9F82", "#BD9F82", "#BEA083", "#BEA083", "#BFA184", "#BFA184", "#C0A285", "#C0A285", "#C1A386", "#C1A386", "#C2A487", "#C2A487", "#C3A588", "#C3A588", "#C4A689", "#C4A689", "#C5A78A", "#C5A78A", "#C6A88B", "#C6A88B", "#C7A98C", "#C7A98C", "#C8AA8D", "#C8AA8D", "#C9AB8E", "#C9AB8E", "#CAAC8F", "#CAAC8F", "#CBAD90", "#CBAD90", "#CCAE91", "#CCAE91", "#CDAF92", "#CDAF92", "#CEB093", "#CEB093", "#CFB194", "#CFB194", "#D0B295", "#D0B295", "#D1B396", "#D1B396", "#D2B497", "#D2B497", "#D3B598", "#D3B598", "#D4B699", "#D4B699", "#D5B79A", "#D5B79A", "#D6B89B", "#D6B89B", "#D7B99C", "#D7B99C", "#D8BA9D", "#D8BA9D", "#D9BB9E", "#D9BB9E", "#DABC9F", "#DABC9F", "#DBBDA0", "#DBBDA0", "#DCBEA1", "#DCBEA1", "#DDBFA2", "#DDBFA2", "#DEC0A3", "#DEC0A3", "#DFC1A4", "#DFC1A4", "#E0C2A5", "#E0C2A5", "#E1C3A6", "#E1C3A6", "#E2C4A7", "#E2C4A7", "#E3C5A8", "#E3C5A8", "#E4C6A9", "#E4C6A9", "#E5C7AA", "#E5C7AA", "#E6C8AB", "#E6C8AB", "#E7C9AC", "#E7C9AC", "#E8CAAD", "#E8CAAD", "#E9CBAE", "#E9CBAE", "#EACCAF", "#EACCAF", "#EBCDB0", "#EBCDB0", "#ECCEB1", "#ECCEB1", "#EDCFB2", "#EDCFB2", "#EED0B3", "#EED0B3", "#EFD1B4", "#EFD1B4", "#F0D2B5", "#F0D2B5", "#F1D3B6", "#F1D3B6", "#F2D4B7", "#F2D4B7", "#F3D5B8", "#F3D5B8", "#F4D6B9", "#F4D6B9", "#F5D7BA", "#F5D7BA", "#F6D8BB", "#F6D8BB", "#F7D9BC", "#F7D9BC", "#F8DABD", "#F8DABD", "#F9DBBE", "#F9DBBE", "#FADCBF", "#FADCBF", "#FBDDC0", "#FBDDC0", "#FCDEC1", "#FCDEC1", "#FDDFC2", "#FDDFC2", "#FEE0C3", "#FEE0C3", "#FFE1C4", "#FFE1C4", "#FFE1C4", "#FFE1C4", "#FFE1C4", "#FFE1C4", "#FFE1C5", "#FFE1C5", "#FFE1C5", "#FFE1C5", "#FFE1C5", "#FFE2C6", "#FFE2C6", "#FFE2C6", "#FFE2C6", "#FFE2C6", "#FFE2C6", "#FFE2C7", "#FFE2C7", "#FFE2C7", "#FFE2C7", "#FFE2C7", "#FFE2C7", "#FFE3C8", "#FFE3C8", "#FFE3C8", "#FFE3C8", "#FFE3C8", "#FFE3C8", "#FFE3C9", "#FFE3C9", "#FFE3C9", "#FFE3C9", "#FFE3C9", "#FFE3C9", "#FFE4CA", "#FFE4CA", "#FFE4CA", "#FFE4CA", "#FFE4CA", "#FFE4CA", "#FFE4CA", "#FFE4CB", "#FFE4CB", "#FFE4CB", "#FFE4CB", "#FFE4CB", "#FFE4CB", "#FFE5CC", "#FFE5CC", "#FFE5CC", "#FFE5CC", "#FFE5CC", "#FFE5CC", "#FFE5CC", "#FFE5CD", "#FFE5CD", "#FFE5CD", "#FFE5CD", "#FFE5CD", "#FFE5CD", "#FFE6CD", "#FFE6CD", "#FFE6CD", "#FFE7CD", "#FFE7CD", "#FFE7D1", "#FFE7D1", "#FFE9D6", "#FFE9D6", "#FFE9D9", "#FFE9D9", "#FFF2E9", "#FFF2E9", "#FFFFFF", "#FFFFFF"], "imagej_smart": ["#020202", "#020202", "#020202", "#020202", "#030303", "#030303", "#040404", "#040404", "#050505", "#050505", "#050505", "#060606", "#060606", "#070707", "#070707", "#080808", "#080808", "#080808", "#090909", "#090909", "#0A0A0A", "#0A0A0A", "#0B0B0B", "#0B0B0B", "#0B0B0B", "#0C0C0C", "#0C0C0C", "#0D0D0D", "#0D0D0D", "#0E0E0E", "#0E0E0E", "#0E0E0E", "#0F0F0F", "#0F0F0F", "#101010", "#101010", "#101010", "#111111", "#111111", "#121212", "#121212", "#131313", "#131313", "#131313", "#141414", "#141414", "#151515", "#151515", "#161616", "#161616", "#161616", "#171717", "#171717", "#181818", "#181818", "#191919", "#191919", "#191919", "#1A1A1A", "#1A1A1A", "#1B1B1B", "#1B1B1B", "#1B1B1B", "#1C1C1C", "#1C1C1C", "#1D1D1D", "#1D1D1D", "#1E1E1E", "#1E1E1E", "#1E1E1E", "#1F1F1F", "#1F1F1F", "#202020", "#202020", "#212121", "#212121", "#212121", "#222222", "#222222", "#232323", "#232323", "#242424", "#242424", "#242424", "#252525", "#252525", "#262626", "#262626", "#272727", "#272727", "#272727", "#282828", "#282828", "#292929", "#292929", "#292929", "#2A2A2A", "#2A2A2A", "#2B2B2B", "#2B2B2B", "#2C2C2C", "#2C2C2C", "#2C2C2C", "#2D2D2D", "#2D2D2D", "#2E2E2E", "#2E2E2E", "#2F2F2F", "#2F2F2F", "#2F2F2F", "#303030", "#303030", "#313131", "#313131", "#323232", "#323232", "#323232", "#333333", "#333333", "#343434", "#343434", "#343434", "#353535", "#353535", "#363636", "#363636", "#373737", "#373737", "#373737", "#383838", "#383838", "#393939", "#393939", "#3A3A3A", "#3A3A3A", "#3A3A3A", "#3B3B3B", "#3B3B3B", "#3C3C3C", "#3C3C3C", "#3D3D3D", "#3D3D3D", "#3D3D3D", "#3E3E3E", "#3E3E3E", "#3F3F3F", "#3F3F3F", "#404040", "#404040", "#404040", "#404040", "#414141", "#414141", "#414141", "#424242", "#424242", "#434343", "#434343", "#444444", "#444444", "#444444", "#454545", "#454545", "#464646", "#464646", "#474747", "#474747", "#474747", "#484848", "#484848", "#494949", "#494949", "#4A4A4A", "#4A4A4A", "#4A4A4A", "#4B4B4B", "#4B4B4B", "#4C4747", "#4C4747", "#4D4442", "#4D4442", "#4D403E", "#4D403E", "#4E3E3A", "#4E3E3A", "#4F3A35", "#4F3A35", "#503730", "#503730", "#50332B", "#50332B", "#512F28", "#512F28", "#522D26", "#522D26", "#532B24", "#532B24", "#532A22", "#532A22", "#542820", "#542820", "#55261E", "#55261E", "#56241C", "#56241C", "#56221A", "#56221A", "#572018", "#572018", "#581E16", "#581E16", "#591D15", "#591D15", "#591B14", "#591B14", "#5A1A13", "#5A1A13", "#5B1A13", "#5B1A13", "#5C1912", "#5C1912", "#5C1812", "#5C1812", "#5D1811", "#5D1811", "#5E1711", "#5E1711", "#5F1711", "#5F1711", "#5F1610", "#5F1610", "#601610", "#601610", "#61160F", "#61160F", "#62150E", "#62150E", "#62150D", "#62150D", "#63140D", "#63140D", "#64140D", "#64140D", "#65140C", "#65140C", "#65130C", "#65130C", "#66130B", "#66130B", "#67120B", "#67120B", "#66120B", "#66120B", "#69120A", "#69120A", "#6A1109", "#6A1109", "#6B1108", "#6B1108", "#6D1107", "#6D1107", "#6F1006", "#6F1006", "#701006", "#701006", "#711005", "#711005", "#721004", "#721004", "#740F04", "#740F04", "#750F04", "#750F04", "#770F03", "#770F03", "#7A1003", "#7A1003", "#7D1002", "#7D1002", "#801002", "#801002", "#821002", "#821002", "#851001", "#851001", "#881001", "#881001", "#8B1001", "#8B1001", "#8E1001", "#8E1001", "#911101", "#911101", "#951201", "#951201", "#981401", "#981401", "#9C1501", "#9C1501", "#9F1701", "#9F1701", "#A31801", "#A31801", "#A61A01", "#A61A01", "#BD1B01", "#BD1B01", "#AD1D01", "#AD1D01", "#B11F01", "#B11F01", "#B31F01", "#B31F01", "#B61F01", "#B61F01", "#B92001", "#B92001", "#BD2101", "#BD2101", "#BF2201", "#BF2201", "#C22401", "#C22401", "#C42501", "#C42501", "#C72701", "#C72701", "#C92901", "#C92901", "#CB2B01", "#CB2B01", "#CD2F01", "#CD2F01", "#CF3201", "#CF3201", "#D13501", "#D13501", "#D23701", "#D23701", "#D43901", "#D43901", "#D53B01", "#D53B01", "#D73E01", "#D73E01", "#D84001", "#D84001", "#DA4301", "#DA4301", "#DC4701", "#DC4701", "#DD4A02", "#DD4A02", "#DE4E02", "#DE4E02", "#E05302", "#E05302", "#DE5803", "#DE5803", "#E25C03", "#E25C03", "#E36104", "#E36104", "#E46404", "#E46404", "#E56704", "#E56704", "#E56B05", "#E56B05", "#E66E05", "#E66E05", "#E77106", "#E77106", "#E97906", "#E97906", "#EA8206", "#EA8206", "#EC8807", "#EC8807", "#EE9007", "#EE9007", "#EF9C08", "#EF9C08", "#F0A208", "#F0A208", "#F0A708", "#F0A708", "#F1AD09", "#F1AD09", "#F2B309", "#F2B309", "#F2B90A", "#F2B90A", "#F3BB0A", "#F3BB0A", "#F5BE0B", "#F5BE0B", "#F6C00B", "#F6C00B", "#F7C30C", "#F7C30C", "#F8C60C", "#F8C60C", "#F8C90D", "#F8C90D", "#F9CC0D", "#F9CC0D", "#F9CF0E", "#F9CF0E", "#FAD20E", "#FAD20E", "#FAD50F", "#FAD50F", "#FBD711", "#FBD711", "#FCD812", "#FCD812", "#FCD914", "#FCD914", "#FDDA16", "#FDDA16", "#FDDB18", "#FDDB18", "#FEDC1C", "#FEDC1C", "#FEDE20", "#FEDE20", "#FEDE24", "#FEDE24", "#FEE028", "#FEE028", "#FEE12B", "#FEE12B", "#FEE22F", "#FEE22F", "#FEE332", "#FEE332", "#FEE335", "#FEE335", "#FEE438", "#FEE438", "#FEE53B", "#FEE53B", "#FEE542", "#FEE542", "#FEE64A", "#FEE64A", "#FEE652", "#FEE652", "#FEE759", "#FEE759", "#FEE765", "#FEE765", "#FEEB71", "#FEEB71", "#FEEE7D", "#FEEE7D", "#FEF088", "#FEF088", "#FEF294", "#FEF294", "#FEF5A4", "#FEF5A4", "#FEF5B3", "#FEF5B3", "#FEF6BB", "#FEF6BB", "#FEF7C6", "#FEF7C6", "#FEF8D1", "#FEF8D1", "#FEF9E1", "#FEF9E1", "#FEFAF1", "#FEFAF1", "#FEFBF5", "#FEFBF5", "#FEFCF9", "#FEFCF9", "#FEFDFC", "#FEFDFC", "#FEFDFC"], "imagej_topography": ["#000000", "#000000", "#010101", "#010101", "#000003", "#000003", "#000006", "#000006", "#000009", "#000009", "#00000B", "#00000B", "#00000E", "#00000E", "#000011", "#000011", "#000013", "#000013", "#000016", "#000016", "#000019", "#000019", "#00001B", "#00001B", "#00001E", "#00001E", "#000021", "#000021", "#000023", "#000023", "#000026", "#000026", "#000029", "#000029", "#00002B", "#00002B", "#00002E", "#00002E", "#000031", "#000031", "#000033", "#000033", "#000036", "#000036", "#000039", "#000039", "#00003B", "#00003B", "#00003E", "#00003E", "#000041", "#000041", "#000043", "#000043", "#000046", "#000046", "#000049", "#000049", "#00004B", "#00004B", "#00004E", "#00004E", "#000051", "#000051", "#000053", "#000053", "#000056", "#000056", "#000059", "#000059", "#00005B", "#00005B", "#00005E", "#00005E", "#000061", "#000061", "#000063", "#000063", "#000066", "#000066", "#000069", "#000069", "#00006B", "#00006B", "#00006E", "#00006E", "#000071", "#000071", "#000073", "#000073", "#000076", "#000076", "#000079", "#000079", "#00007B", "#00007B", "#00007E", "#00007E", "#000081", "#000081", "#000084", "#000084", "#000086", "#000086", "#000089", "#000089", "#00008C", "#00008C", "#00008E", "#00008E", "#000091", "#000091", "#000094", "#000094", "#000096", "#000096", "#000099", "#000099", "#00009C", "#00009C", "#00009E", "#00009E", "#0000A1", "#0000A1", "#0000A4", "#0000A4", "#0000A6", "#0000A6", "#0000A9", "#0000A9", "#0000AC", "#0000AC", "#0000AE", "#0000AE", "#0000B1", "#0000B1", "#0000B4", "#0000B4", "#0000B6", "#0000B6", "#0000B9", "#0000B9", "#0000BC", "#0000BC", "#0000BE", "#0000BE", "#0000C1", "#0000C1", "#0000C4", "#0000C4", "#0000C6", "#0000C6", "#0000C9", "#0000C9", "#0000CC", "#0000CC", "#0000CE", "#0000CE", "#0000D1", "#0000D1", "#0000D4", "#0000D4", "#0000D6", "#0000D6", "#0000D9", "#0000D9", "#0000DC", "#0000DC", "#0000DE", "#0000DE", "#0000E1", "#0000E1", "#0000E4", "#0000E4", "#0000E6", "#0000E6", "#0000E9", "#0000E9", "#0000EC", "#0000EC", "#0000EE", "#0000EE", "#0000F1", "#0000F1", "#0000F4", "#0000F4", "#0000F6", "#0000F6", "#0000F9", "#0000F9", "#0000FC", "#0000FC", "#0000FF", "#0000FF", "#0205FF", "#0205FF", "#040BFF", "#040BFF", "#0611FF", "#0611FF", "#0917FF", "#0917FF", "#0B1DFF", "#0B1DFF", "#0D23FF", "#0D23FF", "#1029FF", "#1029FF", "#122EFF", "#122EFF", "#1434FF", "#1434FF", "#163AFF", "#163AFF", "#1940FF", "#1940FF", "#1B46FF", "#1B46FF", "#1D4CFF", "#1D4CFF", "#2052FF", "#2052FF", "#2258FF", "#2258FF", "#245DFF", "#245DFF", "#2663FF", "#2663FF", "#2969FF", "#2969FF", "#2B6FFF", "#2B6FFF", "#2D75FF", "#2D75FF", "#307BFF", "#307BFF", "#3281FF", "#3281FF", "#3487FF", "#3487FF", "#368CFF", "#368CFF", "#3992FF", "#3992FF", "#3B98FF", "#3B98FF", "#3D9EFF", "#3D9EFF", "#40A4FF", "#40A4FF", "#42AAFF", "#42AAFF", "#FFFF00", "#FFFF00", "#FFFF00", "#FFF566", "#FFF566", "#F3F733", "#F3F733", "#9EFB33", "#9EFB33", "#48FD30", "#48FD30", "#47FB2D", "#47FB2D", "#46F92A", "#46F92A", "#45F827", "#45F827", "#44F624", "#44F624", "#43F421", "#43F421", "#42F31E", "#42F31E", "#41F11B", "#41F11B", "#40EF18", "#40EF18", "#3FED15", "#3FED15", "#3EEC12", "#3EEC12", "#3DEA0F", "#3DEA0F", "#3CE80C", "#3CE80C", "#39E509", "#39E509", "#38E308", "#38E308", "#36E108", "#36E108", "#34DF08", "#34DF08", "#32DE08", "#32DE08", "#30DC07", "#30DC07", "#2FDA07", "#2FDA07", "#2DD807", "#2DD807", "#2BD606", "#2BD606", "#29D406", "#29D406", "#27D206", "#27D206", "#26D005", "#26D005", "#24CE05", "#24CE05", "#22CC05", "#22CC05", "#20CA05", "#20CA05", "#1EC804", "#1EC804", "#1CC604", "#1CC604", "#1BC404", "#1BC404", "#19C304", "#19C304", "#17C103", "#17C103", "#15BF03", "#15BF03", "#13BD03", "#13BD03", "#12BB02", "#12BB02", "#10B902", "#10B902", "#0EB702", "#0EB702", "#0CB502", "#0CB502", "#0AB301", "#0AB301", "#09B101", "#09B101", "#07AF01", "#07AF01", "#05AD00", "#05AD00", "#03AB00", "#03AB00", "#01A900", "#01A900", "#11A200", "#11A200", "#229B00", "#229B00", "#269900", "#269900", "#2A9700", "#2A9700", "#2F9500", "#2F9500", "#339300", "#339300", "#379100", "#379100", "#3C8F00", "#3C8F00", "#408D00", "#408D00", "#458C00", "#458C00", "#498A00", "#498A00", "#4D8800", "#4D8800", "#528600", "#528600", "#568400", "#568400", "#5A8200", "#5A8200", "#5F8000", "#5F8000", "#637E00", "#637E00", "#687D00", "#687D00", "#6C7B00", "#6C7B00", "#707900", "#707900", "#757700", "#757700", "#797500", "#797500", "#7D7300", "#7D7300", "#827100", "#827100", "#866F00", "#866F00", "#876E00", "#876E00", "#896E00", "#896E00", "#8A6D00", "#8A6D00", "#8C6D00", "#8C6D00", "#8D6C00", "#8D6C00", "#8F6C00", "#8F6C00", "#906B00", "#906B00", "#926B00", "#926B00", "#936A00", "#936A00", "#956A00", "#956A00", "#966900", "#966900", "#986900", "#986900", "#996800", "#996800", "#9B6800", "#9B6800", "#9C6700", "#9C6700", "#9E6700", "#9E6700", "#9F6600", "#9F6600", "#A16600", "#A16600", "#BA934F", "#BA934F", "#C19F62", "#C19F62", "#C9AB76", "#C9AB76", "#D1B789", "#D1B789", "#D8C39D", "#D8C39D", "#E0CFB0", "#E0CFB0", "#E8DBC4", "#E8DBC4", "#EFE7D7", "#EFE7D7", "#FFFFFF", "#FFFFFF", "#FEFEFE", "#FEFEFE", "#FDFEFE", "#FDFEFE", "#FCFEFE", "#FCFEFE", "#FBFDFE", "#FBFDFE", "#FBFDFE", "#FAFDFE", "#FAFDFE", "#F9FCFE", "#F9FCFE", "#F8FCFE", "#F8FCFE", "#F8FCFE", "#F7FBFE", "#F7FBFE", "#F6FBFE", "#F6FBFE", "#F5FBFE", "#F5FBFE", "#F5FAFE", "#F5FAFE", "#F4FAFE", "#F4FAFE", "#F3FAFE", "#F3FAFE", "#F2FAFE", "#F2FAFE", "#F2F9FE", "#F2F9FE", "#F1F9FE", "#F1F9FE", "#F0F9FE", "#F0F9FE", "#EFF8FE", "#EFF8FE", "#EFF8FE", "#EEF8FE", "#EEF8FE", "#EDF7FE", "#EDF7FE", "#ECF7FE", "#ECF7FE", "#ECF7FE", "#EBF6FE", "#EBF6FE", "#EAF6FE", "#EAF6FE", "#E9F6FE", "#E9F6FE"], "imagej_unionjack": ["#000000", "#000000", "#000002", "#000002", "#000005", "#000005", "#000008", "#000008", "#00000B", "#00000B", "#00000E", "#00000E", "#000011", "#000011", "#000014", "#000014", "#000017", "#000017", "#00001A", "#00001A", "#00001D", "#00001D", "#000020", "#000020", "#000023", "#000023", "#000026", "#000026", "#000029", "#000029", "#00002C", "#00002C", "#00002F", "#00002F", "#000032", "#000032", "#000035", "#000035", "#000038", "#000038", "#00003B", "#00003B", "#00003E", "#00003E", "#000041", "#000041", "#000044", "#000044", "#000047", "#000047", "#00004A", "#00004A", "#00004D", "#00004D", "#000050", "#000050", "#000053", "#000053", "#000056", "#000056", "#000059", "#000059", "#00005C", "#00005C", "#00005F", "#00005F", "#000061", "#000061", "#000064", "#000064", "#000067", "#000067", "#00006A", "#00006A", "#00006D", "#00006D", "#000070", "#000070", "#000073", "#000073", "#000076", "#000076", "#000079", "#000079", "#00007C", "#00007C", "#00007F", "#00007F", "#000082", "#000082", "#000085", "#000085", "#000088", "#000088", "#00008B", "#00008B", "#00008E", "#00008E", "#000091", "#000091", "#000094", "#000094", "#000097", "#000097", "#00009A", "#00009A", "#00009D", "#00009D", "#0000A0", "#0000A0", "#0000A3", "#0000A3", "#0000A6", "#0000A6", "#0000A9", "#0000A9", "#0000AC", "#0000AC", "#0000AF", "#0000AF", "#0000B2", "#0000B2", "#0000B5", "#0000B5", "#0000B8", "#0000B8", "#0000BE", "#0000BE", "#0000BE", "#0303BF", "#0303BF", "#0707C0", "#0707C0", "#0B0BC1", "#0B0BC1", "#0F0FC2", "#0F0FC2", "#1313C3", "#1313C3", "#1717C4", "#1717C4", "#1B1BC5", "#1B1BC5", "#1F1FC6", "#1F1FC6", "#2323C7", "#2323C7", "#2727C8", "#2727C8", "#2B2BC9", "#2B2BC9", "#2F2FCA", "#2F2FCA", "#3333CB", "#3333CB", "#3737CC", "#3737CC", "#3B3BCD", "#3B3BCD", "#3F3FCE", "#3F3FCE", "#4343CF", "#4343CF", "#4747D0", "#4747D0", "#4B4BD1", "#4B4BD1", "#4F4FD2", "#4F4FD2", "#5353D3", "#5353D3", "#5757D4", "#5757D4", "#5B5BD5", "#5B5BD5", "#5F5FD6", "#5F5FD6", "#6363D7", "#6363D7", "#6767D8", "#6767D8", "#6B6BD9", "#6B6BD9", "#6F6FDA", "#6F6FDA", "#7373DB", "#7373DB", "#7777DC", "#7777DC", "#7B7BDD", "#7B7BDD", "#7F7FDE", "#7F7FDE", "#8383DF", "#8383DF", "#8787E0", "#8787E0", "#8B8BE1", "#8B8BE1", "#8F8FE2", "#8F8FE2", "#9393E3", "#9393E3", "#9797E4", "#9797E4", "#9B9BE5", "#9B9BE5", "#9F9FE6", "#9F9FE6", "#A3A3E7", "#A3A3E7", "#A7A7E8", "#A7A7E8", "#ABABE9", "#ABABE9", "#AFAFEA", "#AFAFEA", "#B3B3EB", "#B3B3EB", "#B7B7EC", "#B7B7EC", "#BBBBED", "#BBBBED", "#BFBFEE", "#BFBFEE", "#C3C3EF", "#C3C3EF", "#C7C7F0", "#C7C7F0", "#CBCBF1", "#CBCBF1", "#CFCFF2", "#CFCFF2", "#D3D3F3", "#D3D3F3", "#D7D7F4", "#D7D7F4", "#DBDBF5", "#DBDBF5", "#DFDFF6", "#DFDFF6", "#E3E3F7", "#E3E3F7", "#E7E7F8", "#E7E7F8", "#EBEBF9", "#EBEBF9", "#EFEFFA", "#EFEFFA", "#F3F3FB", "#F3F3FB", "#F7F7FC", "#F7F7FC", "#FFFFFF", "#FFFFFF", "#FFFFFF", "#FDFBFB", "#FDFBFB", "#FCF7F7", "#FCF7F7", "#FBF3F3", "#FBF3F3", "#FAEFEF", "#FAEFEF", "#F9EBEB", "#F9EBEB", "#F8E7E7", "#F8E7E7", "#F7E3E3", "#F7E3E3", "#F6DFDF", "#F6DFDF", "#F5DBDB", "#F5DBDB", "#F4D7D7", "#F4D7D7", "#F3D3D3", "#F3D3D3", "#F2CFCF", "#F2CFCF", "#F1CBCB", "#F1CBCB", "#F0C7C7", "#F0C7C7", "#EFC3C3", "#EFC3C3", "#EEBFBF", "#EEBFBF", "#EDBBBB", "#EDBBBB", "#ECB7B7", "#ECB7B7", "#EBB3B3", "#EBB3B3", "#EAAFAF", "#EAAFAF", "#E9ABAB", "#E9ABAB", "#E8A7A7", "#E8A7A7", "#E7A3A3", "#E7A3A3", "#E69F9F", "#E69F9F", "#E59B9B", "#E59B9B", "#E49797", "#E49797", "#E39393", "#E39393", "#E28F8F", "#E28F8F", "#E18B8B", "#E18B8B", "#E08787", "#E08787", "#DF8383", "#DF8383", "#DE7F7F", "#DE7F7F", "#DD7B7B", "#DD7B7B", "#DC7777", "#DC7777", "#DB7373", "#DB7373", "#DA6F6F", "#DA6F6F", "#D96B6B", "#D96B6B", "#D86767", "#D86767", "#D76363", "#D76363", "#D65F5F", "#D65F5F", "#D55B5B", "#D55B5B", "#D45757", "#D45757", "#D35353", "#D35353", "#D24F4F", "#D24F4F", "#D14B4B", "#D14B4B", "#D04747", "#D04747", "#CF4343", "#CF4343", "#CE3F3F", "#CE3F3F", "#CD3B3B", "#CD3B3B", "#CC3737", "#CC3737", "#CB3333", "#CB3333", "#CA2F2F", "#CA2F2F", "#C92B2B", "#C92B2B", "#C82727", "#C82727", "#C72323", "#C72323", "#C61F1F", "#C61F1F", "#C51B1B", "#C51B1B", "#C41717", "#C41717", "#C31313", "#C31313", "#C20F0F", "#C20F0F", "#C10B0B", "#C10B0B", "#C00707", "#C00707", "#BE0000", "#BE0000", "#BE0000", "#BF0303", "#BF0303", "#C00707", "#C00707", "#C10B0B", "#C10B0B", "#C20F0F", "#C20F0F", "#C31313", "#C31313", "#C41717", "#C41717", "#C51B1B", "#C51B1B", "#C61F1F", "#C61F1F", "#C72323", "#C72323", "#C82727", "#C82727", "#C92B2B", "#C92B2B", "#CA2F2F", "#CA2F2F", "#CB3333", "#CB3333", "#CC3737", "#CC3737", "#CD3B3B", "#CD3B3B", "#CE3F3F", "#CE3F3F", "#CF4343", "#CF4343", "#D04747", "#D04747", "#D14B4B", "#D14B4B", "#D24F4F", "#D24F4F", "#D35353", "#D35353", "#D45757", "#D45757", "#D55B5B", "#D55B5B", "#D65F5F", "#D65F5F", "#D76363", "#D76363", "#D86767", "#D86767", "#D96B6B", "#D96B6B", "#DA6F6F", "#DA6F6F", "#DB7373", "#DB7373", "#DC7777", "#DC7777", "#DD7B7B", "#DD7B7B", "#DE7F7F", "#DE7F7F", "#DF8383", "#DF8383", "#E08787", "#E08787", "#E18B8B", "#E18B8B", "#E28F8F", "#E28F8F", "#E39393", "#E39393", "#E49797", "#E49797", "#E59B9B", "#E59B9B", "#E69F9F", "#E69F9F", "#E7A3A3", "#E7A3A3", "#E8A7A7", "#E8A7A7", "#E9ABAB", "#E9ABAB", "#EAAFAF", "#EAAFAF", "#EBB3B3", "#EBB3B3", "#ECB7B7", "#ECB7B7", "#EDBBBB", "#EDBBBB", "#EEBFBF", "#EEBFBF", "#EFC3C3", "#EFC3C3", "#F0C7C7", "#F0C7C7", "#F1CBCB", "#F1CBCB", "#F2CFCF", "#F2CFCF", "#F3D3D3", "#F3D3D3", "#F4D7D7", "#F4D7D7", "#F5DBDB", "#F5DBDB", "#F6DFDF", "#F6DFDF", "#F7E3E3", "#F7E3E3", "#F8E7E7", "#F8E7E7", "#F9EBEB", "#F9EBEB", "#FAEFEF", "#FAEFEF", "#FBF3F3", "#FBF3F3", "#FCF7F7", "#FCF7F7", "#FFFFFF", "#FFFFFF"], "jjg_cbcont_div_cbcBrBG": ["#543005", "#543005", "#704008", "#8C510A", "#A6691C", "#BF812D", "#CFA255", "#DFC27D", "#EBD5A0", "#F6E8C3", "#F6EEDC", "#F5F5F5", "#DEF0ED", "#C7EAE5", "#A3DCD3", "#80CDC1", "#5AB2A8", "#35978F", "#1B7E76", "#01665E", "#005147", "#003C30", "#003C30"], "jjg_cbcont_div_cbcPiYG": ["#8E0152", "#8E0152", "#AA0E68", "#C51B7D", "#D24996", "#DE77AE", "#E896C4", "#F1B6DA", "#F7CBE4", "#FDE0EF", "#FAECF3", "#F7F7F7", "#EEF6E3", "#E6F5D0", "#CFEBAB", "#B8E186", "#9CCE64", "#7FBC41", "#66A731", "#4D9221", "#3A7B1D", "#276419", "#276419"], "jjg_cbcont_div_cbcPRGn": ["#40004B", "#40004B", "#5B1567", "#762A83", "#884D97", "#9970AB", "#AE8BBD", "#C2A5CF", "#D4BCDC", "#E7D4E8", "#EFE6F0", "#F7F7F7", "#E8F3E5", "#D9F0D3", "#C0E5BA", "#A6DBA0", "#80C480", "#5AAE61", "#3B934C", "#1B7837", "#0E5E29", "#00441B", "#00441B"], "jjg_cbcont_div_cbcPuOr": ["#7F3B08", "#7F3B08", "#994A07", "#B35806", "#CA6D0D", "#E08214", "#EE9D3C", "#FDB863", "#FECC8C", "#FEE0B6", "#FBECD6", "#F7F7F7", "#E8E8F1", "#D8DAEB", "#C5C2DE", "#B2ABD2", "#998FBF", "#8073AC", "#6A4D9A", "#542788", "#40146A", "#2D004B", "#2D004B"], "jjg_cbcont_div_cbcRdBu": ["#67001F", "#67001F", "#8C0C25", "#B2182B", "#C43C3C", "#D6604D", "#E58268", "#F4A582", "#F9C0A4", "#FDDBC7", "#FAE9DF", "#F7F7F7", "#E4EEF3", "#D1E5F0", "#B2D5E7", "#92C5DE", "#6AACD0", "#4393C3", "#327CB8", "#2166AC", "#134B86", "#053061", "#053061"], "jjg_cbcont_div_cbcRdGy": ["#67001F", "#67001F", "#8C0C25", "#B2182B", "#C43C3C", "#D6604D", "#E58268", "#F4A582", "#F9C0A4", "#FDDBC7", "#FEEDE3", "#FFFFFF", "#F0F0F0", "#E0E0E0", "#CDCDCD", "#BABABA", "#A0A0A0", "#878787", "#6A6A6A", "#4D4D4D", "#343434", "#1A1A1A", "#1A1A1A"], "jjg_cbcont_div_cbcRdYlBu": ["#A50026", "#A50026", "#BE1827", "#D73027", "#E64E35", "#F46D43", "#F98E52", "#FDAE61", "#FEC778", "#FEE090", "#FEF0A8", "#FFFFBF", "#F0F9DC", "#E0F3F8", "#C5E6F0", "#ABD9E9", "#90C3DD", "#74ADD1", "#5C91C2", "#4575B4", "#3B56A4", "#313695", "#313695"], "jjg_cbcont_div_cbcRdYlGn": ["#A50026", "#A50026", "#BE1827", "#D73027", "#E64E35", "#F46D43", "#F98E52", "#FDAE61", "#FEC776", "#FEE08B", "#FEF0A5", "#FFFFBF", "#ECF7A5", "#D9EF8B", "#C0E47A", "#A6D96A", "#86CB66", "#66BD63", "#40AB5A", "#1A9850", "#0D8044", "#006837", "#006837"], "jjg_cbcont_div_cbcSpectral": ["#9E0142", "#9E0142", "#BA2048", "#D53E4F", "#E45649", "#F46D43", "#F98E52", "#FDAE61", "#FEC776", "#FEE08B", "#FEF0A5", "#FFFFBF", "#F2FAAC", "#E6F598", "#C8E99E", "#ABDDA4", "#88D0A4", "#66C2A5", "#4CA5B1", "#3288BD", "#486CB0", "#5E4FA2", "#5E4FA2"], "jjg_cbcont_seq_cbcBlues": ["#F7FBFF", "#EBF3FB", "#D2E3F3", "#B2D2E8", "#84BCDC", "#56A0CE", "#3282BE", "#1461A9", "#084084", "#08306B"], "jjg_cbcont_seq_cbcBuGn": ["#F7FCFD", "#EEF9FB", "#D9F0F0", "#B2E2D8", "#80CDB6", "#54B88D", "#329C5E", "#127C38", "#005824", "#00441B"], "jjg_cbcont_seq_cbcBuPu": ["#F7FCFD", "#ECF4F9", "#D0E0ED", "#AEC8E0", "#95A9D0", "#8C80BC", "#8A56A7", "#84288C", "#670864", "#4D004B"], "jjg_cbcont_seq_cbcGnBu": ["#F7FCF0", "#ECF8E5", "#D6EFD0", "#BAE4BD", "#92D4BC", "#65C0CC", "#3DA0C8", "#1A7AB5", "#085496", "#084081"], "jjg_cbcont_seq_cbcGreens": ["#F7FCF5", "#EEF9EB", "#D6EFD0", "#B4E1AE", "#8ACE88", "#5AB86A", "#329B51", "#127C38", "#005824", "#00441B"], "jjg_cbcont_seq_cbcGreys": ["#FFFFFF", "#F8F8F8", "#E4E4E4", "#CBCBCB", "#AAAAAA", "#848484", "#626262", "#3C3C3C", "#121212", "#000000"], "jjg_cbcont_seq_cbcOranges": ["#FFF5EB", "#FEEEDC", "#FEDBB8", "#FDBF86", "#FD9E54", "#F77B28", "#E5580A", "#C03F02", "#922F04", "#7F2704"], "jjg_cbcont_seq_cbcOrRd": ["#FFF7EC", "#FEF0DA", "#FEDEB3", "#FDC891", "#FCA46E", "#F67950", "#E34A34", "#C51810", "#990000", "#7F0000"], "jjg_cbcont_seq_cbcPuBu": ["#FFF7FB", "#F6EFF6", "#DEDCEC", "#BBC7E0", "#8DB3D5", "#559CC8", "#1E80B8", "#04659E", "#034972", "#023858"], "jjg_cbcont_seq_cbcPuBuGn": ["#FFF7FB", "#F6ECF5", "#DEDAEB", "#BBC7E0", "#86B3D5", "#4E9CC8", "#1C88A5", "#027672", "#015948", "#014636"], "jjg_cbcont_seq_cbcPuRd": ["#F7F4F9", "#EFEBF4", "#DECDE4", "#CEA6D0", "#D47DBC", "#E3479D", "#DB1E70", "#B3094D", "#800031", "#67001F"], "jjg_cbcont_seq_cbcPurples": ["#FCFBFD", "#F6F4F9", "#E4E3F0", "#CBCCE3", "#ADACD2", "#8F8BC1", "#7567AE", "#5F3C99", "#4A1486", "#3F007D"], "jjg_cbcont_seq_cbcRdPu": ["#FFF7F3", "#FEECE8", "#FCD2CE", "#FBB2BB", "#F884AB", "#EA4E9C", "#C61A8B", "#94017A", "#620070", "#49006A"], "jjg_cbcont_seq_cbcReds": ["#FFF5F0", "#FEEBE1", "#FDCEBA", "#FCA68A", "#FC7E5E", "#F5523B", "#DD2A24", "#B81419", "#860811", "#67000D"], "jjg_cbcont_seq_cbcYlGn": ["#FFFFE5", "#FBFECF", "#E8F6AE", "#C3E698", "#92D284", "#5CB86B", "#329850", "#12763D", "#005630", "#004529"], "jjg_cbcont_seq_cbcYlGnBu": ["#FFFFD9", "#F6FCC5", "#DAF0B2", "#A3DBB8", "#60C2C0", "#2FA3C2", "#2078B4", "#24499E", "#162876", "#081D58"], "jjg_cbcont_seq_cbcYlOrBr": ["#FFFFE5", "#FFFBD0", "#FEEDA6", "#FED370", "#FEAE3C", "#F5841E", "#DC5E0B", "#B24003", "#802C05", "#662506"], "jjg_cbcont_seq_cbcYlOrRd": ["#FFFFCC", "#FFF6B6", "#FEE38B", "#FEC561", "#FEA044", "#FC6E33", "#F03423", "#D00D21", "#9E0026", "#800026"], "jjg_ccolo_adgrapho_500_LOVERS_ThankYou": ["#F23D3D", "#F23D3D", "#F8664E", "#FF8F5E", "#FCB270", "#FAD682", "#EEE695", "#E1F5A9", "#AFE8B8", "#7DDBC7", "#7DDBC7"], "jjg_ccolo_adgrapho_Asleep": ["#8D9996", "#8D9996", "#8FA6A0", "#91B3AA", "#9CC6AC", "#A7D9AE", "#BCE3A6", "#D2ED9F", "#E8F0A5", "#FFF4AB", "#FFF4AB"], "jjg_ccolo_adgrapho_Autumn_Harmony": ["#AB505E", "#AB505E", "#C27868", "#D9A071", "#D4B480", "#CFC88F", "#BABC90", "#A5B090", "#829482", "#607873", "#607873"], "jjg_ccolo_adgrapho_Canzone_Per_Te": ["#E9F0C5", "#E9F0C5", "#D6E2BC", "#C4D4B4", "#AEC7AC", "#99BAA3", "#A0A395", "#A88C87", "#B27679", "#BD606B", "#BD606B"], "jjg_ccolo_adgrapho_Latent": ["#D4D3A3", "#D4D3A3", "#EABC9A", "#FFA491", "#FF8E8E", "#FF788C", "#F8607A", "#F04869", "#AE4466", "#6B4063", "#6B4063"], "jjg_ccolo_adgrapho_Never_See_The_Sun": ["#F2DCC2", "#F2DCC2", "#EACBA5", "#E3B988", "#DC9D79", "#D4816A", "#C4626E", "#B54371", "#8E3C6D", "#683569", "#683569"], "jjg_ccolo_adgrapho_Oct": ["#733043", "#733043", "#8C4248", "#A6554E", "#BD7450", "#D49353", "#E0B272", "#EBD091", "#C6C299", "#A1B3A1", "#A1B3A1"], "jjg_ccolo_adgrapho_Oktober_Silentium": ["#6B1233", "#6B1233", "#742830", "#7D3F2E", "#8B5E3B", "#997E48", "#A09862", "#A6B37B", "#A4C498", "#A3D6B4", "#A3D6B4"], "jjg_ccolo_adgrapho_Road": ["#FF8229", "#FF8229", "#F8A456", "#F0C684", "#F0D4A3", "#F0E2C2", "#EEE6D0", "#EDEADD", "#D3DAC3", "#B9C9A9", "#B9C9A9"], "jjg_ccolo_alpen_friday_sunset": ["#FE2129", "#FE2129", "#E21A31", "#C61439", "#B01640", "#991848", "#811E46", "#692345", "#4A2436", "#2C2527", "#2C2527"], "jjg_ccolo_alpen_mango_mystery": ["#4C4F4B", "#4C4F4B", "#836247", "#BA7443", "#DB8237", "#FC902B", "#FEC516", "#FFFA01", "#BACE26", "#74A14A", "#74A14A"], "jjg_ccolo_alpen_natural_light": ["#FC683E", "#FC683E", "#DE4C51", "#BF3064", "#8B2668", "#571B6B", "#301266", "#090962", "#0D0D52", "#111143", "#111143"], "jjg_ccolo_alpen_road_spray": ["#F7F7E1", "#F7F7E1", "#EBFBE0", "#DFFFDE", "#C5F6CB", "#ABEDB8", "#99E0BD", "#87D4C2", "#84B9AC", "#809E97", "#809E97"], "jjg_ccolo_alpen_zone_out": ["#2C4561", "#2C4561", "#4F5670", "#726780", "#6D7E87", "#68948E", "#92AB92", "#BDC297", "#BCB683", "#BAAA6F", "#BAAA6F"], "jjg_ccolo_angelafaye_Coloured_sky_in": ["#181427", "#181427", "#743E24", "#CF6720", "#D88022", "#E29A24", "#CCA356", "#B6AC89", "#B2BC9B", "#ADCCAD", "#ADCCAD"], "jjg_ccolo_angelafaye_Mt_Fuji_Sumie": ["#E8D19B", "#E8D19B", "#D2C196", "#BCB191", "#AFA688", "#A29C7E", "#929079", "#828474", "#727566", "#616559", "#616559"], "jjg_ccolo_angelafaye_scent_of_spring": ["#F7D18F", "#F7D18F", "#FBC399", "#FEB6A3", "#FEA387", "#FF916B", "#F57C68", "#EB6766", "#C3585F", "#9C4858", "#9C4858"], "jjg_ccolo_angelafaye_soothe_my_mind": ["#F2D19C", "#F2D19C", "#D8C593", "#BFBA8B", "#BAAE90", "#B5A294", "#A3887A", "#916F61", "#795450", "#613A3E", "#613A3E"], "jjg_ccolo_angelafaye_The_Calanques": ["#062F52", "#062F52", "#0A5074", "#0D7195", "#1B818E", "#299187", "#3C9A80", "#4FA379", "#7EB893", "#ADCCAD", "#ADCCAD"], "jjg_ccolo_Bionic_Blender_Aphalara_Itadori": ["#FAE095", "#FAE095", "#F1C670", "#E8AC4A", "#CC8837", "#B06323", "#745223", "#374222", "#383012", "#381D03", "#381D03"], "jjg_ccolo_Bionic_Blender_Bad_Kitten": ["#261C21", "#261C21", "#4A1D42", "#6E1E62", "#8F2258", "#B0254F", "#C7333B", "#DE4126", "#E46C16", "#EB9605", "#EB9605"], "jjg_ccolo_Bionic_Blender_Death_Top_Work_Shop": ["#F7E099", "#F7E099", "#E9CE7C", "#DBBD60", "#C59E50", "#B07E41", "#6A7254", "#246666", "#274D4D", "#293333", "#293333"], "jjg_ccolo_Bionic_Blender_Drunken_Cow_Woman": ["#F2EFE1", "#F2EFE1", "#CADBD0", "#A3C7BE", "#BAA3A3", "#D18088", "#95605F", "#593F36", "#382B26", "#171615", "#171615"], "jjg_ccolo_Bionic_Blender_IE_h_a_v_e_f_u_n": ["#FCE4A6", "#FCE4A6", "#FACC9D", "#F7B594", "#EE9E95", "#E68796", "#CC65A4", "#B142B3", "#763D74", "#3B3836", "#3B3836"], "jjg_ccolo_drumma_Asura": ["#D7F0B6", "#D7F0B6", "#B8DCAF", "#99C7A8", "#7FAA94", "#658C80", "#597072", "#4D5563", "#483C5E", "#432359", "#432359"], "jjg_ccolo_drumma_Buddha": ["#FFA578", "#FFA578", "#FFD2A0", "#FFFFC9", "#EEECC0", "#DED9B6", "#C0BBA1", "#A39C8C", "#827A70", "#615753", "#615753"], "jjg_ccolo_drumma_Debdebe": ["#FBFF8C", "#FBFF8C", "#D8E492", "#B4C997", "#7C9A88", "#446B78", "#404E5D", "#3C3242", "#3C2537", "#3B182C", "#3B182C"], "jjg_ccolo_drumma_Disap_Pointedly": ["#33181E", "#33181E", "#3C2425", "#45312C", "#5D503F", "#756F52", "#8C9C72", "#A4C991", "#CEE4A2", "#F7FFB3", "#F7FFB3"], "jjg_ccolo_drumma_Karantina": ["#F0CA9E", "#F0CA9E", "#D3B693", "#B6A388", "#99907E", "#7C7C73", "#5E6868", "#41545D", "#234255", "#05304D", "#05304D"], "jjg_ccolo_drumma_MOS_6581": ["#8C0F2D", "#8C0F2D", "#942D3F", "#9D4B50", "#A56E61", "#AD9072", "#B6A984", "#BEC295", "#DBCE9A", "#F7DA9E", "#F7DA9E"], "jjg_ccolo_drumma_Opaque": ["#E5E6B8", "#E5E6B8", "#D6DDB8", "#C6D4B8", "#99BDAE", "#6CA6A3", "#788886", "#856A6A", "#904E63", "#9C325C", "#9C325C"], "jjg_ccolo_drumma_Photosynthesis": ["#FFDD99", "#FFDD99", "#E2D091", "#C4C389", "#A0AA7A", "#7D916A", "#5D7861", "#3D5E58", "#2F4047", "#212236", "#212236"], "jjg_ccolo_drumma_Totoro": ["#FFA96B", "#FFA96B", "#F8C893", "#F2E6BB", "#E2D1A3", "#D1BC8C", "#A69C7A", "#7A7D68", "#5E5F52", "#42413D", "#42413D"], "jjg_ccolo_electroluv_Beat_Around_The_Bush": ["#494A3D", "#494A3D", "#405546", "#376050", "#507353", "#6A8656", "#8AA255", "#AABF54", "#CAD37B", "#EBE7A3", "#EBE7A3"], "jjg_ccolo_electroluv_Everglowing_Wonder": ["#D9FAA8", "#D9FAA8", "#C3EA88", "#ADDB67", "#A2BC5D", "#989C52", "#8E7350", "#854A4E", "#7E3B48", "#762C43", "#762C43"], "jjg_ccolo_electroluv_Hypothetical_Spite": ["#040423", "#040423", "#0D0D2C", "#161634", "#1F1F3A", "#282841", "#3C4253", "#4F5C65", "#8E9DA6", "#CCDEE8", "#CCDEE8"], "jjg_ccolo_electroluv_iCreate": ["#ED9761", "#ED9761", "#F6775C", "#FF5757", "#EC385B", "#D9185F", "#AF1850", "#851941", "#6A1A39", "#4F1C32", "#4F1C32"], "jjg_ccolo_electroluv_Justified_Reasons": ["#FFDA6C", "#FFDA6C", "#DAB851", "#B59536", "#965038", "#780C3B", "#6A0E3A", "#5C1138", "#4C1431", "#3B172A", "#3B172A"], "jjg_ccolo_electroluv_My_Resolute_Heart": ["#779196", "#779196", "#7E8086", "#857076", "#8C5F65", "#924E53", "#8C3C4C", "#852A44", "#762D42", "#66303F", "#66303F"], "jjg_ccolo_electroluv_Run_Away_Tonight": ["#DF9B78", "#DF9B78", "#C98E78", "#B38178", "#917274", "#6F6270", "#544E5D", "#3A394A", "#2B283A", "#1C1629", "#1C1629"], "jjg_ccolo_electroluv_s_e_a_s_h_e_l_l_s": ["#218695", "#218695", "#70A0A5", "#C0BBB5", "#AAA59D", "#949085", "#807A70", "#6C635A", "#5D544C", "#4E453E", "#4E453E"], "jjg_ccolo_electroluv_s_o_l_a_r_i_s": ["#F7B39E", "#F7B39E", "#E6A898", "#D69C91", "#C08D89", "#AB7E81", "#966676", "#814F6A", "#6C3F58", "#562E46", "#562E46"], "jjg_ccolo_hana_A_m_i_k_k_a": ["#DCEADB", "#DCEADB", "#D5DEC2", "#CED2AA", "#CBBFA0", "#C8AC96", "#B28684", "#9C6071", "#764E54", "#513C37", "#513C37"], "jjg_ccolo_hana_d_a_m_m_a_r": ["#F9E7C8", "#F9E7C8", "#F8DCC0", "#F6D0B7", "#C2C4AB", "#8FB89F", "#7DA69D", "#6A949B", "#627F82", "#5B6A69", "#5B6A69"], "jjg_ccolo_hana_H_a_i_k_u": ["#2D1C2E", "#2D1C2E", "#2F3A48", "#315761", "#386868", "#3E7A6F", "#4E8B70", "#5D9C70", "#7E9C72", "#9E9C73", "#9E9C73"], "jjg_ccolo_hana_M_a_i_k_o": ["#E06376", "#E06376", "#D25276", "#C44175", "#B13D6B", "#9E3961", "#842E50", "#69233F", "#46182A", "#240C15", "#240C15"], "jjg_ccolo_hana_n_a_t_u_r_a_l_l_y": ["#3B3039", "#3B3039", "#5A4950", "#786267", "#8A6D73", "#9C787F", "#AF9391", "#C2AFA3", "#C2B8A3", "#C1C2A3", "#C1C2A3"], "jjg_ccolo_hana_r_a_i_n_y": ["#460E8A", "#460E8A", "#2E3A96", "#1566A3", "#2880A2", "#3B9AA1", "#6CA69F", "#9DB39D", "#ADB898", "#BDBC93", "#BDBC93"], "jjg_ccolo_hana_S_e_a": ["#C6C7A9", "#C6C7A9", "#B1C0A9", "#9CB8A9", "#89ACAF", "#769FB5", "#4F92B5", "#2884B5", "#3C73C0", "#5062CC", "#5062CC"], "jjg_ccolo_hana_S_e_p_t_e_m_b_e_r": ["#3B6E69", "#3B6E69", "#427A6A", "#48876A", "#6E9974", "#94AB7E", "#B4C082", "#D4D687", "#C9C378", "#BDB168", "#BDB168"], "jjg_ccolo_hana_S_u_g_a_r": ["#CF8C76", "#CF8C76", "#CF9C86", "#CFAC97", "#CFBBA6", "#CFC9B4", "#C6CCB5", "#BCCFB6", "#B3CFBC", "#ABCFC3", "#ABCFC3"], "jjg_ccolo_phill_bad_moon_rising": ["#2F4C73", "#2F4C73", "#223D62", "#142E52", "#5B6567", "#A39C7C", "#C0B78E", "#DED2A0", "#EAE0B5", "#F5EDCB", "#F5EDCB"], "jjg_ccolo_phill_blueberry_pancakes": ["#D9D096", "#D9D096", "#CAC086", "#BAB175", "#87A08B", "#548FA1", "#498293", "#3E7485", "#2A6678", "#15576B", "#15576B"], "jjg_ccolo_phill_moldy_bread": ["#74AB86", "#74AB86", "#75B68B", "#76C28F", "#98CE76", "#B9DB5C", "#CDE05E", "#E1E660", "#EDF17D", "#F9FC9A", "#F9FC9A"], "jjg_ccolo_Skyblue2u_Adrift_in_Dreams": ["#CFF09E", "#CFF09E", "#BCE5A3", "#A8DBA8", "#90CCA1", "#79BD9A", "#5AA290", "#3B8686", "#236778", "#0B486B", "#0B486B"], "jjg_ccolo_Skyblue2u_Deep_Skyblues": ["#107FC9", "#107FC9", "#0F66BB", "#0E4EAD", "#0C2F9C", "#0B108C", "#0C1079", "#0C0F66", "#0A0C52", "#07093D", "#07093D"], "jjg_ccolo_Skyblue2u_Gentle_Waves": ["#D3E2B6", "#D3E2B6", "#CBDEB5", "#C3DBB4", "#B6D3B2", "#AACCB1", "#98C4B1", "#87BDB1", "#78B8B0", "#68B3AF", "#68B3AF"], "jjg_ccolo_Skyblue2u_mellon_ball_surprise": ["#D1F2A5", "#D1F2A5", "#E0F6AC", "#EFFAB4", "#F7DFA0", "#FFC48C", "#FFB286", "#FF9F80", "#FA8488", "#F56991", "#F56991"], "jjg_ccolo_vredeling_After_Eight": ["#BAEC95", "#BAEC95", "#AAD488", "#99BC7A", "#88A36C", "#778B5E", "#667250", "#555A43", "#444235", "#332927", "#332927"], "jjg_ccolo_vredeling_Another_Earth": ["#9ECC14", "#9ECC14", "#8CC62E", "#7AC149", "#68BB63", "#55B57D", "#42AF98", "#30A9B2", "#1EA3CC", "#0B9DE6", "#0B9DE6"], "jjg_ccolo_vredeling_Black_Hole_Sun": ["#FFEE99", "#FFEE99", "#E6D78C", "#CCC080", "#B2A873", "#999166", "#807A5A", "#66624D", "#4D4A40", "#333333", "#333333"], "jjg_ccolo_vredeling_British_Cheer": ["#704DA1", "#704DA1", "#856EB4", "#9B8EC8", "#C5C6C1", "#F0FFBA", "#C6D084", "#9CA14D", "#908A2B", "#857409", "#857409"], "jjg_ccolo_vredeling_Cafe_88_Cafe": ["#CAFE88", "#CAFE88", "#C2F897", "#BAF1A6", "#B2EBB4", "#A9E4C3", "#A1DED2", "#99D7E1", "#90D0F0", "#88CAFE", "#88CAFE"], "jjg_ccolo_vredeling_CHIC_Painted_Skies": ["#A19889", "#A19889", "#ACA38B", "#B6AE8D", "#C8C6A2", "#DBDDB8", "#B2BAAA", "#89969C", "#788C96", "#678190", "#678190"], "jjg_ccolo_vredeling_Dulled": ["#DBFFF1", "#DBFFF1", "#D2ECDE", "#C8D9CC", "#BEC6B9", "#B4B3A6", "#AAA093", "#A08D81", "#967A6E", "#8C675B", "#8C675B"], "jjg_ccolo_vredeling_Grand_Boucle": ["#F8B61A", "#F8B61A", "#F5C81C", "#F2D91D", "#F8EC8E", "#FFFFFF", "#E4DFE0", "#C9BFC0", "#A4969A", "#806C73", "#806C73"], "jjg_ccolo_vredeling_Lucy_in_the_Sky": ["#DD1B7F", "#DD1B7F", "#E2307A", "#E64574", "#EA5A6E", "#EE6E69", "#F28264", "#F7975E", "#FBAC58", "#FFC053", "#FFC053"], "jjg_ccolo_vredeling_Mare_Nostrum": ["#638B77", "#638B77", "#759078", "#869479", "#97997A", "#A89D7B", "#B9A27C", "#CAA67D", "#DBAB7E", "#ECAF7E", "#ECAF7E"], "jjg_ccolo_vredeling_Misty_Morning": ["#DDDDD3", "#DDDDD3", "#CCCEC2", "#BCC0B1", "#ACB1A0", "#9BA28E", "#8A937D", "#7A856B", "#6A765A", "#596748", "#596748"], "jjg_ccolo_vredeling_Ninja_Wardrobe": ["#0D060D", "#0D060D", "#160C1A", "#1E1326", "#221A33", "#252040", "#262846", "#26304D", "#2A3D53", "#2D4A59", "#2D4A59"], "jjg_ccolo_vredeling_Office_Space": ["#948F92", "#948F92", "#9A9392", "#9F9792", "#A49B92", "#AA9E91", "#B0A290", "#B5A590", "#BAA990", "#BFAC8F", "#BFAC8F"], "jjg_ccolo_vredeling_OK_Computer": ["#FCFFFF", "#FCFFFF", "#DFF3F8", "#C2E7F2", "#ADD3E5", "#98BFD9", "#7EA0C0", "#6380A6", "#4A5A6D", "#303333", "#303333"], "jjg_ccolo_vredeling_Optimus_Prime": ["#3A4959", "#3A4959", "#405A79", "#456C99", "#96A6B4", "#E6DFCF", "#E0887D", "#D9312B", "#B2221C", "#8C120E", "#8C120E"], "jjg_ccolo_vredeling_Rationality": ["#0A6666", "#0A6666", "#058888", "#00AAAA", "#80D4D4", "#FFFFFF", "#CCC8D5", "#9A91AB", "#827895", "#6A6080", "#6A6080"], "jjg_ccolo_vredeling_Schindlers_List": ["#222223", "#222223", "#333333", "#444443", "#666663", "#888883", "#B2B2AB", "#DDDDD3", "#D66E6A", "#D00000", "#D00000"], "jjg_ccolo_vredeling_Sleep_Deprevation": ["#62238C", "#62238C", "#6F3BAC", "#7C52CC", "#7E65D2", "#8177D9", "#9191E0", "#A1ABE6", "#B8C3EC", "#CEDCF2", "#CEDCF2"], "jjg_ccolo_vredeling_Super_Gran": ["#A2E8F5", "#A2E8F5", "#8ECBD6", "#79AEB8", "#607678", "#473D38", "#706159", "#9A847A", "#C4A99C", "#EFCDBE", "#EFCDBE"], "jjg_ccolo_vredeling_Tubular_Bells": ["#1F2620", "#1F2620", "#3A403C", "#555959", "#A6AAA8", "#F7FAF8", "#BED1E2", "#85A8CC", "#5E85AC", "#38628C", "#38628C"], "jjg_misc_rainfall": ["#E5B42C", "#E5B42C", "#F2B464", "#F2B464", "#F3E977", "#F3E977", "#91CE7E", "#91CE7E", "#43BE87", "#43BE87", "#34B485", "#34B485", "#069B42", "#069B42"], "jjg_misc_seminf_haxby": ["#FFFFFF", "#FFFFFF", "#D0D8FB", "#D0D8FB", "#BAC5F7", "#BAC5F7", "#8FA1F1", "#8FA1F1", "#617AEC", "#617AEC", "#0027E0", "#0027E0", "#1965F0", "#1965F0", "#0C81F8", "#0C81F8", "#18AFFF", "#18AFFF", "#31BEFF", "#31BEFF", "#43CAFF", "#43CAFF", "#60E1F0", "#60E1F0", "#69EBE1", "#69EBE1", "#7BEBC8", "#7BEBC8", "#8AECAE", "#8AECAE", "#ACF5A8", "#ACF5A8", "#CDFFA2", "#CDFFA2", "#DFF58D", "#DFF58D", "#F0EC78", "#F0EC78", "#F7D767", "#F7D767", "#FFBD56", "#FFBD56", "#FFA044", "#FFA044", "#F4744A", "#F4744A", "#EE4F4D", "#EE4F4D"], "jjg_misc_subtle": ["#0075E2", "#06ACF1", "#0CE3FF", "#51F0E8", "#95FED0", "#BBEE9E", "#E0DE6D", "#F0C17F", "#FFA391", "#E78166", "#CF5F3B"], "jjg_misc_temperature": ["#1316B4", "#1316B4", "#2331C7", "#2331C7", "#2D42C9", "#2D42C9", "#3755CB", "#3755CB", "#365FC6", "#365FC6", "#466FCF", "#466FCF", "#507DD2", "#507DD2", "#598DD6", "#598DD6", "#629BD9", "#629BD9", "#7EB9E9", "#7EB9E9", "#A5D7FF", "#A5D7FF", "#C4E5B7", "#C4E5B7", "#B4DFA8", "#B4DFA8", "#B0D793", "#B0D793", "#C7CF74", "#C7CF74", "#DBC85B", "#DBC85B", "#DEBD50", "#DEBD50", "#D9A449", "#D9A449", "#D39242", "#D39242", "#D1853E", "#D1853E", "#CC7139", "#CC7139", "#CA6232", "#CA6232", "#C74528", "#C74528"], "jjg_misc_virus": ["#000006", "#000D4B", "#006464", "#00942A", "#706700", "#CF2300", "#E07000", "#EFB300", "#FEFA00"], "jjg_misc_voxpop": ["#9CCDDC", "#9CCDDC", "#AED6E3", "#AED6E3", "#C0DFE9", "#C0DFE9", "#D2E8F0", "#D2E8F0", "#E4F1F6", "#E4F1F6", "#F6FAFC", "#F6FAFC", "#FEF8F8", "#FEF8F8", "#FCEAEA", "#FCEAEA", "#FADCDC", "#FADCDC", "#F9CECE", "#F9CECE", "#F7C0C0", "#F7C0C0"], "jjg_physics_bbrad": ["#FF0100", "#FF0E00", "#FF1A00", "#FF2500", "#FF3000", "#FF3B02", "#FF4707", "#FF530D", "#FF5E15", "#FF691D", "#FF7426", "#FF7E30", "#FF883B", "#FF9146", "#FF9A52", "#FFA25E", "#FFAA6B", "#FFB277", "#FFB984", "#FFC091", "#FFC79E", "#FFCDAB", "#FFD3B8", "#FFD9C5", "#FFDED2", "#FFE3DE", "#FFE8EA", "#FFEDF6", "#FDEFFF", "#F2E9FF", "#E8E3FF", "#DFDEFF", "#D7D9FF", "#D0D4FF", "#C9D0FF", "#C3CCFF", "#BDC9FF", "#B8C5FF", "#B3C2FF", "#AFBFFF", "#AABCFF", "#A7BAFF", "#A3B7FF", "#A0B5FF", "#9DB3FF", "#9AB1FF"], "jjg_physics_visspec": ["#640065", "#67006A", "#6A006E", "#6C0073", "#6F0077", "#71007B", "#73007F", "#750084", "#770088", "#79008C", "#7B0090", "#7C0094", "#7D0098", "#7E009C", "#7F00A0", "#8000A4", "#8100A8", "#8100AC", "#8200B0", "#8200B4", "#8200B8", "#8200BC", "#8200C0", "#8200C4", "#8100C7", "#8100CB", "#8000CF", "#7F00D3", "#7E00D6", "#7D00DA", "#7C00DE", "#7A00E2", "#7900E5", "#7700E9", "#7500EC", "#7300F0", "#7100F4", "#6F00F7", "#6C00FB", "#6900FF", "#6500FF", "#6100FF", "#5C00FF", "#5800FF", "#5400FF", "#4F00FF", "#4B00FF", "#4600FF", "#4100FF", "#3C00FF", "#3700FF", "#3200FF", "#2D00FF", "#2800FF", "#2200FF", "#1D00FF", "#1700FF", "#1000FF", "#0900FF", "#0000FF", "#000BFF", "#0013FF", "#001AFF", "#0021FF", "#0028FF", "#002EFF", "#0034FF", "#003AFF", "#0040FF", "#0046FF", "#004BFF", "#0051FF", "#0056FF", "#005CFF", "#0061FF", "#0066FF", "#006BFF", "#0070FF", "#0075FF", "#007AFF", "#007FFF", "#0084FF", "#0089FF", "#008DFF", "#0092FF", "#0097FF", "#009BFF", "#00A0FF", "#00A4FF", "#00A9FF", "#00ADFF", "#00B2FF", "#00B6FF", "#00BBFF", "#00BFFF", "#00C4FF", "#00C8FF", "#00CCFF", "#00D1FF", "#00D5FF", "#00D9FF", "#00DDFF", "#00E2FF", "#00E6FF", "#00EAFF", "#00EEFF", "#00F2FF", "#00F6FF", "#00FAFF", "#00FFFF", "#00FFF4", "#00FFEA", "#00FFDF", "#00FFD5", "#00FFCA", "#00FFBF", "#00FFB4", "#00FFA9", "#00FF9E", "#00FF92", "#00FF86", "#00FF7A", "#00FF6E", "#00FF61", "#00FF54", "#00FF46", "#00FF37", "#00FF28", "#00FF17", "#00FF00", "#08FF00", "#0EFF00", "#14FF00", "#19FF00", "#1EFF00", "#23FF00", "#28FF00", "#2CFF00", "#31FF00", "#35FF00", "#3AFF00", "#3EFF00", "#42FF00", "#46FF00", "#4AFF00", "#4EFF00", "#52FF00", "#56FF00", "#59FF00", "#5DFF00", "#61FF00", "#65FF00", "#68FF00", "#6CFF00", "#6FFF00", "#73FF00", "#77FF00", "#7AFF00", "#7EFF00", "#81FF00", "#84FF00", "#88FF00", "#8BFF00", "#8FFF00", "#92FF00", "#95FF00", "#99FF00", "#9CFF00", "#9FFF00", "#A2FF00", "#A6FF00", "#A9FF00", "#ACFF00", "#AFFF00", "#B3FF00", "#B6FF00", "#B9FF00", "#BCFF00", "#BFFF00", "#C2FF00", "#C5FF00", "#C9FF00", "#CCFF00", "#CFFF00", "#D2FF00", "#D5FF00", "#D8FF00", "#DBFF00", "#DEFF00", "#E1FF00", "#E4FF00", "#E7FF00", "#EAFF00", "#EDFF00", "#F0FF00", "#F3FF00", "#F6FF00", "#F9FF00", "#FCFF00", "#FFFF00", "#FFFB00", "#FFF800", "#FFF500", "#FFF200", "#FFEF00", "#FFEB00", "#FFE800", "#FFE500", "#FFE200", "#FFDF00", "#FFDB00", "#FFD800", "#FFD500", "#FFD200", "#FFCE00", "#FFCB00", "#FFC800", "#FFC400", "#FFC100", "#FFBE00", "#FFBA00", "#FFB700", "#FFB300", "#FFB000", "#FFAC00", "#FFA900", "#FFA500", "#FFA200", "#FF9E00", "#FF9B00", "#FF9700", "#FF9400", "#FF9000", "#FF8D00", "#FF8900", "#FF8500", "#FF8100", "#FF7E00", "#FF7A00", "#FF7600", "#FF7200", "#FF6F00", "#FF6B00", "#FF6700", "#FF6300", "#FF5F00", "#FF5B00", "#FF5700", "#FF5300", "#FF4E00", "#FF4A00", "#FF4600", "#FF4200", "#FF3D00", "#FF3900", "#FF3400", "#FF2F00", "#FF2A00", "#FF2500", "#FF2000", "#FF1B00", "#FF1500", "#FF0F00", "#FF0900", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FD0000", "#FB0000", "#F90000", "#F70000", "#F60000", "#F40000", "#F20000", "#F00000", "#EE0000", "#EC0000", "#EB0000", "#E90000", "#E70000", "#E50000", "#E30000", "#E20000", "#E00000", "#DE0000", "#DC0000", "#DA0000", "#D80000", "#D60000", "#D50000", "#D30000", "#D10000", "#CF0000", "#CD0000", "#CB0000", "#C90000", "#C70000", "#C50000", "#C40000", "#C20000", "#C00000", "#BE0000", "#BC0000", "#BA0000", "#B80000", "#B60000", "#B40000", "#B20000", "#B00000", "#AE0000", "#AC0000", "#AA0000", "#A80000", "#A60000", "#A40000", "#A20000", "#A00000", "#9E0000", "#9C0000", "#9A0000", "#980000", "#960000", "#940000", "#920000", "#900000", "#8E0000", "#8C0000", "#8A0000", "#880000", "#860000", "#840000", "#820000", "#7F0000", "#7D0000", "#7B0000", "#790000", "#770000", "#750000", "#730000", "#700000", "#6E0000", "#6C0000", "#6A0000", "#680000", "#650000", "#630000", "#610000"], "jm_sd_sd_a": ["#54E597", "#54E597", "#61F082", "#61F082", "#73F775", "#73F775", "#94FE85", "#94FE85", "#9EFE87", "#9EFE87", "#ADFD88", "#ADFD88", "#B4FE8B", "#B4FE8B", "#BDFE8C", "#BDFE8C", "#C5FD8D", "#C5FD8D", "#CFFE90", "#CFFE90", "#D7FE92", "#D7FE92", "#DFFE93", "#DFFE93", "#E7FE95", "#E7FE95", "#EEFD97", "#EEFD97", "#F7FE9A", "#F7FE9A", "#FEFE9B", "#FEFE9B", "#FDFC97", "#FDFC97", "#FEF895", "#FEF895", "#FDF292", "#FDF292", "#FEEE92", "#FEEE92", "#FDE98C", "#FDE98C", "#FEE187", "#FEE187", "#FDDB7F", "#FDDB7F", "#FED779", "#FED779", "#FDCE7D", "#FDCE7D", "#FACB80", "#FACB80", "#F8C583", "#F8C583", "#F6C586", "#F6C586", "#F4C588", "#F4C588", "#F2BE8B", "#F2BE8B", "#F0BC8F", "#F0BC8F", "#EEBB91", "#EEBB91", "#EBBC99", "#EBBC99", "#EBC2A4", "#EBC2A4", "#E8C5AC", "#E8C5AC", "#E6C8B1", "#E6C8B1", "#DFC6B3", "#DFC6B3", "#DDC7B7", "#DDC7B7", "#E0CFC2", "#E0CFC2", "#E4D6CB", "#E4D6CB", "#E8DDD4", "#E8DDD4", "#EBE2DB", "#EBE2DB", "#EFE7E1", "#EFE7E1", "#F3EEEA", "#F3EEEA", "#F6F0EC", "#F6F0EC", "#FAF9F8", "#FAF9F8", "#FFFFFF", "#FFFFFF"], "ma_gray_grayscale02": ["#AAAAAA", "#CCCCCC", "#EEEEEE"], "mby_mby": ["#000050", "#001E64", "#003266", "#136CA0", "#188CCD", "#87CEFA", "#B0E2FF", "#006147", "#107B30", "#E8D67D", "#A34400", "#821E1E", "#A1A1A1", "#CECECE", "#FFFFFF"], "inferno": ["#000004", "#010005", "#010106", "#010108", "#02010A", "#02020C", "#02020E", "#030210", "#040312", "#040314", "#050417", "#060419", "#07051B", "#08051D", "#09061F", "#0A0722", "#0B0724", "#0C0826", "#0D0829", "#0E092B", "#10092D", "#110A30", "#120A32", "#140B34", "#150B37", "#160B39", "#180C3C", "#190C3E", "#1B0C41", "#1C0C43", "#1E0C45", "#1F0C48", "#210C4A", "#230C4C", "#240C4F", "#260C51", "#280B53", "#290B55", "#2B0B57", "#2D0B59", "#2F0A5B", "#310A5C", "#320A5E", "#340A5F", "#360961", "#380962", "#390963", "#3B0964", "#3D0965", "#3E0966", "#400A67", "#420A68", "#440A68", "#450A69", "#470B6A", "#490B6A", "#4A0C6B", "#4C0C6B", "#4D0D6C", "#4F0D6C", "#510E6C", "#520E6D", "#540F6D", "#550F6D", "#57106E", "#59106E", "#5A116E", "#5C126E", "#5D126E", "#5F136E", "#61136E", "#62146E", "#64156E", "#65156E", "#67166E", "#69166E", "#6A176E", "#6C186E", "#6D186E", "#6F196E", "#71196E", "#721A6E", "#741A6E", "#751B6E", "#771C6D", "#781C6D", "#7A1D6D", "#7C1D6D", "#7D1E6D", "#7F1E6C", "#801F6C", "#82206C", "#84206B", "#85216B", "#87216B", "#88226A", "#8A226A", "#8C2369", "#8D2369", "#8F2469", "#902568", "#922568", "#932667", "#952667", "#972766", "#982766", "#9A2865", "#9B2964", "#9D2964", "#9F2A63", "#A02A63", "#A22B62", "#A32C61", "#A52C60", "#A62D60", "#A82E5F", "#A92E5E", "#AB2F5E", "#AD305D", "#AE305C", "#B0315B", "#B1325A", "#B3325A", "#B43359", "#B63458", "#B73557", "#B93556", "#BA3655", "#BC3754", "#BD3853", "#BF3952", "#C03A51", "#C13A50", "#C33B4F", "#C43C4E", "#C63D4D", "#C73E4C", "#C83F4B", "#CA404A", "#CB4149", "#CC4248", "#CE4347", "#CF4446", "#D04545", "#D24644", "#D34743", "#D44842", "#D54A41", "#D74B3F", "#D84C3E", "#D94D3D", "#DA4E3C", "#DB503B", "#DD513A", "#DE5238", "#DF5337", "#E05536", "#E15635", "#E25734", "#E35933", "#E45A31", "#E55C30", "#E65D2F", "#E75E2E", "#E8602D", "#E9612B", "#EA632A", "#EB6429", "#EB6628", "#EC6726", "#ED6925", "#EE6A24", "#EF6C23", "#EF6E21", "#F06F20", "#F1711F", "#F1731D", "#F2741C", "#F3761B", "#F37819", "#F47918", "#F57B17", "#F57D15", "#F67E14", "#F68013", "#F78212", "#F78410", "#F8850F", "#F8870E", "#F8890C", "#F98B0B", "#F98C0A", "#F98E09", "#FA9008", "#FA9207", "#FA9407", "#FB9606", "#FB9706", "#FB9906", "#FB9B06", "#FB9D07", "#FC9F07", "#FCA108", "#FCA309", "#FCA50A", "#FCA60C", "#FCA80D", "#FCAA0F", "#FCAC11", "#FCAE12", "#FCB014", "#FCB216", "#FCB418", "#FBB61A", "#FBB81D", "#FBBA1F", "#FBBC21", "#FBBE23", "#FAC026", "#FAC228", "#FAC42A", "#FAC62D", "#F9C72F", "#F9C932", "#F9CB35", "#F8CD37", "#F8CF3A", "#F7D13D", "#F7D340", "#F6D543", "#F6D746", "#F5D949", "#F5DB4C", "#F4DD4F", "#F4DF53", "#F4E156", "#F3E35A", "#F3E55D", "#F2E661", "#F2E865", "#F2EA69", "#F1EC6D", "#F1ED71", "#F1EF75", "#F1F179", "#F2F27D", "#F2F482", "#F3F586", "#F3F68A", "#F4F88E", "#F5F992", "#F6FA96", "#F8FB9A", "#F9FC9D", "#FAFDA1", "#FCFFA4"], "magma": ["#000004", "#010005", "#010106", "#010108", "#020109", "#02020B", "#02020D", "#03030F", "#030312", "#040414", "#050416", "#060518", "#06051A", "#07061C", "#08071E", "#090720", "#0A0822", "#0B0924", "#0C0926", "#0D0A29", "#0E0B2B", "#100B2D", "#110C2F", "#120D31", "#130D34", "#140E36", "#150E38", "#160F3B", "#180F3D", "#19103F", "#1A1042", "#1C1044", "#1D1147", "#1E1149", "#20114B", "#21114E", "#221150", "#241253", "#251255", "#271258", "#29115A", "#2A115C", "#2C115F", "#2D1161", "#2F1163", "#311165", "#331067", "#341069", "#36106B", "#38106C", "#390F6E", "#3B0F70", "#3D0F71", "#3F0F72", "#400F74", "#420F75", "#440F76", "#451077", "#471078", "#491078", "#4A1079", "#4C117A", "#4E117B", "#4F127B", "#51127C", "#52137C", "#54137D", "#56147D", "#57157E", "#59157E", "#5A167E", "#5C167F", "#5D177F", "#5F187F", "#601880", "#621980", "#641A80", "#651A80", "#671B80", "#681C81", "#6A1C81", "#6B1D81", "#6D1D81", "#6E1E81", "#701F81", "#721F81", "#732081", "#752181", "#762181", "#782281", "#792282", "#7B2382", "#7C2382", "#7E2482", "#802582", "#812581", "#832681", "#842681", "#862781", "#882781", "#892881", "#8B2981", "#8C2981", "#8E2A81", "#902A81", "#912B81", "#932B80", "#942C80", "#962C80", "#982D80", "#992D80", "#9B2E7F", "#9C2E7F", "#9E2F7F", "#A02F7F", "#A1307E", "#A3307E", "#A5317E", "#A6317D", "#A8327D", "#AA337D", "#AB337C", "#AD347C", "#AE347B", "#B0357B", "#B2357B", "#B3367A", "#B5367A", "#B73779", "#B83779", "#BA3878", "#BC3978", "#BD3977", "#BF3A77", "#C03A76", "#C23B75", "#C43C75", "#C53C74", "#C73D73", "#C83E73", "#CA3E72", "#CC3F71", "#CD4071", "#CF4070", "#D0416F", "#D2426F", "#D3436E", "#D5446D", "#D6456C", "#D8456C", "#D9466B", "#DB476A", "#DC4869", "#DE4968", "#DF4A68", "#E04C67", "#E24D66", "#E34E65", "#E44F64", "#E55064", "#E75263", "#E85362", "#E95462", "#EA5661", "#EB5760", "#EC5860", "#ED5A5F", "#EE5B5E", "#EF5D5E", "#F05F5E", "#F1605D", "#F2625D", "#F2645C", "#F3655C", "#F4675C", "#F4695C", "#F56B5C", "#F66C5C", "#F66E5C", "#F7705C", "#F7725C", "#F8745C", "#F8765C", "#F9785D", "#F9795D", "#F97B5D", "#FA7D5E", "#FA7F5E", "#FA815F", "#FB835F", "#FB8560", "#FB8761", "#FC8961", "#FC8A62", "#FC8C63", "#FC8E64", "#FC9065", "#FD9266", "#FD9467", "#FD9668", "#FD9869", "#FD9A6A", "#FD9B6B", "#FE9D6C", "#FE9F6D", "#FEA16E", "#FEA36F", "#FEA571", "#FEA772", "#FEA973", "#FEAA74", "#FEAC76", "#FEAE77", "#FEB078", "#FEB27A", "#FEB47B", "#FEB67C", "#FEB77E", "#FEB97F", "#FEBB81", "#FEBD82", "#FEBF84", "#FEC185", "#FEC287", "#FEC488", "#FEC68A", "#FEC88C", "#FECA8D", "#FECC8F", "#FECD90", "#FECF92", "#FED194", "#FED395", "#FED597", "#FED799", "#FED89A", "#FDDA9C", "#FDDC9E", "#FDDEA0", "#FDE0A1", "#FDE2A3", "#FDE3A5", "#FDE5A7", "#FDE7A9", "#FDE9AA", "#FDEBAC", "#FCECAE", "#FCEEB0", "#FCF0B2", "#FCF2B4", "#FCF4B6", "#FCF6B8", "#FCF7B9", "#FCF9BB", "#FCFBBD", "#FCFDBF"], "plasma": ["#0D0887", "#100788", "#130789", "#16078A", "#19068C", "#1B068D", "#1D068E", "#20068F", "#220690", "#240691", "#260591", "#280592", "#2A0593", "#2C0594", "#2E0595", "#2F0596", "#310597", "#330597", "#350498", "#370499", "#38049A", "#3A049A", "#3C049B", "#3E049C", "#3F049C", "#41049D", "#43039E", "#44039E", "#46039F", "#48039F", "#4903A0", "#4B03A1", "#4C02A1", "#4E02A2", "#5002A2", "#5102A3", "#5302A3", "#5502A4", "#5601A4", "#5801A4", "#5901A5", "#5B01A5", "#5C01A6", "#5E01A6", "#6001A6", "#6100A7", "#6300A7", "#6400A7", "#6600A7", "#6700A8", "#6900A8", "#6A00A8", "#6C00A8", "#6E00A8", "#6F00A8", "#7100A8", "#7201A8", "#7401A8", "#7501A8", "#7701A8", "#7801A8", "#7A02A8", "#7B02A8", "#7D03A8", "#7E03A8", "#8004A8", "#8104A7", "#8305A7", "#8405A7", "#8606A6", "#8707A6", "#8808A6", "#8A09A5", "#8B0AA5", "#8D0BA5", "#8E0CA4", "#8F0DA4", "#910EA3", "#920FA3", "#9410A2", "#9511A1", "#9613A1", "#9814A0", "#99159F", "#9A169F", "#9C179E", "#9D189D", "#9E199D", "#A01A9C", "#A11B9B", "#A21D9A", "#A31E9A", "#A51F99", "#A62098", "#A72197", "#A82296", "#AA2395", "#AB2494", "#AC2694", "#AD2793", "#AE2892", "#B02991", "#B12A90", "#B22B8F", "#B32C8E", "#B42E8D", "#B52F8C", "#B6308B", "#B7318A", "#B83289", "#BA3388", "#BB3488", "#BC3587", "#BD3786", "#BE3885", "#BF3984", "#C03A83", "#C13B82", "#C23C81", "#C33D80", "#C43E7F", "#C5407E", "#C6417D", "#C7427C", "#C8437B", "#C9447A", "#CA457A", "#CB4679", "#CC4778", "#CC4977", "#CD4A76", "#CE4B75", "#CF4C74", "#D04D73", "#D14E72", "#D24F71", "#D35171", "#D45270", "#D5536F", "#D5546E", "#D6556D", "#D7566C", "#D8576B", "#D9586A", "#DA5A6A", "#DA5B69", "#DB5C68", "#DC5D67", "#DD5E66", "#DE5F65", "#DE6164", "#DF6263", "#E06363", "#E16462", "#E26561", "#E26660", "#E3685F", "#E4695E", "#E56A5D", "#E56B5D", "#E66C5C", "#E76E5B", "#E76F5A", "#E87059", "#E97158", "#E97257", "#EA7457", "#EB7556", "#EB7655", "#EC7754", "#ED7953", "#ED7A52", "#EE7B51", "#EF7C51", "#EF7E50", "#F07F4F", "#F0804E", "#F1814D", "#F1834C", "#F2844B", "#F3854B", "#F3874A", "#F48849", "#F48948", "#F58B47", "#F58C46", "#F68D45", "#F68F44", "#F79044", "#F79143", "#F79342", "#F89441", "#F89540", "#F9973F", "#F9983E", "#F99A3E", "#FA9B3D", "#FA9C3C", "#FA9E3B", "#FB9F3A", "#FBA139", "#FBA238", "#FCA338", "#FCA537", "#FCA636", "#FCA835", "#FCA934", "#FDAB33", "#FDAC33", "#FDAE32", "#FDAF31", "#FDB130", "#FDB22F", "#FDB42F", "#FDB52E", "#FEB72D", "#FEB82C", "#FEBA2C", "#FEBB2B", "#FEBD2A", "#FEBE2A", "#FEC029", "#FDC229", "#FDC328", "#FDC527", "#FDC627", "#FDC827", "#FDCA26", "#FDCB26", "#FCCD25", "#FCCE25", "#FCD025", "#FCD225", "#FBD324", "#FBD524", "#FBD724", "#FAD824", "#FADA24", "#F9DC24", "#F9DD25", "#F8DF25", "#F8E125", "#F7E225", "#F7E425", "#F6E626", "#F6E826", "#F5E926", "#F5EB27", "#F4ED27", "#F3EE27", "#F3F027", "#F2F227", "#F1F426", "#F1F525", "#F0F724", "#F0F921"], "viridis": ["#440154", "#440256", "#450457", "#450559", "#46075A", "#46085C", "#460A5D", "#460B5E", "#470D60", "#470E61", "#471063", "#471164", "#471365", "#481467", "#481668", "#481769", "#48186A", "#481A6C", "#481B6D", "#481C6E", "#481D6F", "#481F70", "#482071", "#482173", "#482374", "#482475", "#482576", "#482677", "#482878", "#482979", "#472A7A", "#472C7A", "#472D7B", "#472E7C", "#472F7D", "#46307E", "#46327E", "#46337F", "#463480", "#453581", "#453781", "#453882", "#443983", "#443A83", "#443B84", "#433D84", "#433E85", "#423F85", "#424086", "#424186", "#414287", "#414487", "#404588", "#404688", "#3F4788", "#3F4889", "#3E4989", "#3E4A89", "#3E4C8A", "#3D4D8A", "#3D4E8A", "#3C4F8A", "#3C508B", "#3B518B", "#3B528B", "#3A538B", "#3A548C", "#39558C", "#39568C", "#38588C", "#38598C", "#375A8C", "#375B8D", "#365C8D", "#365D8D", "#355E8D", "#355F8D", "#34608D", "#34618D", "#33628D", "#33638D", "#32648E", "#32658E", "#31668E", "#31678E", "#31688E", "#30698E", "#306A8E", "#2F6B8E", "#2F6C8E", "#2E6D8E", "#2E6E8E", "#2E6F8E", "#2D708E", "#2D718E", "#2C718E", "#2C728E", "#2C738E", "#2B748E", "#2B758E", "#2A768E", "#2A778E", "#2A788E", "#29798E", "#297A8E", "#297B8E", "#287C8E", "#287D8E", "#277E8E", "#277F8E", "#27808E", "#26818E", "#26828E", "#26828E", "#25838E", "#25848E", "#25858E", "#24868E", "#24878E", "#23888E", "#23898E", "#238A8D", "#228B8D", "#228C8D", "#228D8D", "#218E8D", "#218F8D", "#21908D", "#21918C", "#20928C", "#20928C", "#20938C", "#1F948C", "#1F958B", "#1F968B", "#1F978B", "#1F988B", "#1F998A", "#1F9A8A", "#1E9B8A", "#1E9C89", "#1E9D89", "#1F9E89", "#1F9F88", "#1FA088", "#1FA188", "#1FA187", "#1FA287", "#20A386", "#20A486", "#21A585", "#21A685", "#22A785", "#22A884", "#23A983", "#24AA83", "#25AB82", "#25AC82", "#26AD81", "#27AD81", "#28AE80", "#29AF7F", "#2AB07F", "#2CB17E", "#2DB27D", "#2EB37C", "#2FB47C", "#31B57B", "#32B67A", "#34B679", "#35B779", "#37B878", "#38B977", "#3ABA76", "#3BBB75", "#3DBC74", "#3FBC73", "#40BD72", "#42BE71", "#44BF70", "#46C06F", "#48C16E", "#4AC16D", "#4CC26C", "#4EC36B", "#50C46A", "#52C569", "#54C568", "#56C667", "#58C765", "#5AC864", "#5CC863", "#5EC962", "#60CA60", "#63CB5F", "#65CB5E", "#67CC5C", "#69CD5B", "#6CCD5A", "#6ECE58", "#70CF57", "#73D056", "#75D054", "#77D153", "#7AD151", "#7CD250", "#7FD34E", "#81D34D", "#84D44B", "#86D549", "#89D548", "#8BD646", "#8ED645", "#90D743", "#93D741", "#95D840", "#98D83E", "#9BD93C", "#9DD93B", "#A0DA39", "#A2DA37", "#A5DB36", "#A8DB34", "#AADC32", "#ADDC30", "#B0DD2F", "#B2DD2D", "#B5DE2B", "#B8DE29", "#BADE28", "#BDDF26", "#C0DF25", "#C2DF23", "#C5E021", "#C8E020", "#CAE11F", "#CDE11D", "#D0E11C", "#D2E21B", "#D5E21A", "#D8E219", "#DAE319", "#DDE318", "#DFE318", "#E2E418", "#E5E419", "#E7E419", "#EAE51A", "#ECE51B", "#EFE51C", "#F1E51D", "#F4E61E", "#F6E620", "#F8E621", "#FBE723", "#FDE725"], "ncl_amwg": ["#9370DB", "#9370DB", "#0000C8", "#0000C8", "#3C64E6", "#3C64E6", "#789BF2", "#789BF2", "#B0E0E6", "#B0E0E6", "#20B2AA", "#20B2AA", "#9ACD32", "#9ACD32", "#2E8B57", "#2E8B57", "#F5E6BE", "#F5E6BE", "#DEB887", "#DEB887", "#FFE100", "#FFE100", "#FFA500", "#FFA500", "#FF4500", "#FF4500", "#B22222", "#B22222", "#FFB6C1", "#FFB6C1", "#FF1493", "#FF1493"], "ncl_Cat12": ["#FFBF7F", "#FFBF7F", "#FF7F00", "#FF7F00", "#FFFF99", "#FFFF99", "#FFFF32", "#FFFF32", "#B2FF8C", "#B2FF8C", "#32FF00", "#32FF00", "#A5EDFF", "#A5EDFF", "#19B2FF", "#19B2FF", "#CCBFFF", "#CCBFFF", "#654CFF", "#654CFF", "#FF99BF", "#FF99BF", "#E51932", "#E51932"], "ncl_cosam": ["#780088", "#780088", "#5A00B8", "#5A00B8", "#4600F5", "#4600F5", "#00AAE1", "#00AAE1", "#00C8C8", "#00C8C8", "#00C87D", "#00C87D", "#C3FF00", "#C3FF00", "#FFFF00", "#FFFF00", "#FF9B00", "#FF9B00", "#FF0000", "#FF0000"], "ncl_cosam12": ["#640074", "#640074", "#780088", "#780088", "#5A00B8", "#5A00B8", "#4600F5", "#4600F5", "#00AAE1", "#00AAE1", "#00C8C8", "#00C8C8", "#00C87D", "#00C87D", "#C3FF00", "#C3FF00", "#FFFF00", "#FFFF00", "#FF6400", "#FF6400", "#FF9B00", "#FF9B00", "#FF0000", "#FF0000"], "ncl_hotcold_18lev": ["#181870", "#181870", "#104E8B", "#104E8B", "#1774CD", "#1774CD", "#4876FF", "#4876FF", "#5BACED", "#5BACED", "#ADD7E6", "#ADD7E6", "#D1EDED", "#D1EDED", "#E5EFF9", "#E5EFF9", "#F2FFFF", "#F2FFFF", "#FFFFFF", "#FFFFFF", "#FDF5E6", "#FDF5E6", "#FFE4B4", "#FFE4B4", "#F3A460", "#F3A460", "#ED7600", "#ED7600", "#CD661D", "#CD661D", "#E0310F", "#E0310F", "#ED0000", "#ED0000", "#CD0000", "#CD0000", "#8B0000", "#8B0000"], "ncl_hotcolr_19lev": ["#000032", "#000032", "#181870", "#181870", "#104E8B", "#104E8B", "#1774CD", "#1774CD", "#4876FF", "#4876FF", "#5BACED", "#5BACED", "#ADD7E6", "#ADD7E6", "#D1EDED", "#D1EDED", "#E5EFF9", "#E5EFF9", "#F2FFFF", "#F2FFFF", "#FDF5E6", "#FDF5E6", "#FFE4B4", "#FFE4B4", "#F3A460", "#F3A460", "#ED7600", "#ED7600", "#CD661D", "#CD661D", "#E0310F", "#E0310F", "#ED0000", "#ED0000", "#CD0000", "#CD0000", "#8B0000", "#8B0000", "#320000", "#320000"], "ncl_mch_default": ["#FFFFFF", "#FFFFFF", "#000000", "#000000", "#202020", "#202020", "#404040", "#404040", "#606060", "#606060", "#808080", "#808080", "#A0A0A0", "#A0A0A0", "#C0C0C0", "#C0C0C0", "#E0E0E0", "#E0E0E0", "#FF0000", "#FF0000", "#00FF00", "#00FF00", "#0000FF", "#0000FF", "#FFFF00", "#FFFF00", "#00FFFF", "#00FFFF", "#FF00FF", "#FF00FF"], "ncl_nrl_sirkes_nowhite": ["#006180", "#006180", "#0080A1", "#0080A1", "#00A1BF", "#00A1BF", "#00BFE0", "#00BFE0", "#00E0FF", "#00E0FF", "#00FFFF", "#00FFFF", "#33FCFC", "#33FCFC", "#66FCFC", "#66FCFC", "#99FCFC", "#99FCFC", "#FCFC00", "#FCFC00", "#FCE000", "#FCE000", "#FCBF00", "#FCBF00", "#FCA100", "#FCA100", "#FC8000", "#FC8000", "#FC6100", "#FC6100", "#FC4000", "#FC4000", "#FC2100", "#FC2100", "#BF0000", "#BF0000", "#800000", "#800000"], "ncl_nrl_sirkes": ["#006180", "#006180", "#0080A1", "#0080A1", "#00A1BF", "#00A1BF", "#00BFE0", "#00BFE0", "#00E0FF", "#00E0FF", "#00FFFF", "#00FFFF", "#33FCFC", "#33FCFC", "#66FCFC", "#66FCFC", "#99FCFC", "#99FCFC", "#CCFCFC", "#CCFCFC", "#FFFFFF", "#FFFFFF", "#FCFC00", "#FCFC00", "#FCE000", "#FCE000", "#FCBF00", "#FCBF00", "#FCA100", "#FCA100", "#FC8000", "#FC8000", "#FC6100", "#FC6100", "#FC4000", "#FC4000", "#FC2100", "#FC2100", "#BF0000", "#BF0000", "#800000", "#800000"], "ncl_OceanLakeLandSnow": ["#1874CD", "#1874CD", "#87CEFF", "#87CEFF", "#266728", "#266728", "#2A6B28", "#2A6B28", "#2E6E29", "#2E6E29", "#327229", "#327229", "#367529", "#367529", "#3A792A", "#3A792A", "#3E7C2A", "#3E7C2A", "#42802A", "#42802A", "#46832B", "#46832B", "#4A872B", "#4A872B", "#4E8A2B", "#4E8A2B", "#528E2C", "#528E2C", "#56912C", "#56912C", "#5A952C", "#5A952C", "#5E982D", "#5E982D", "#629C2D", "#629C2D", "#669F2E", "#669F2E", "#6AA32E", "#6AA32E", "#6EA62E", "#6EA62E", "#72AA2F", "#72AA2F", "#76AD2F", "#76AD2F", "#7AB12F", "#7AB12F", "#7EB430", "#7EB430", "#82B830", "#82B830", "#86BB30", "#86BB30", "#8ABF31", "#8ABF31", "#8EC231", "#8EC231", "#92C631", "#92C631", "#9ACD32", "#9ACD32", "#9BCE34", "#9BCE34", "#9CCF36", "#9CCF36", "#9ED038", "#9ED038", "#9FD239", "#9FD239", "#A0D33B", "#A0D33B", "#A1D43D", "#A1D43D", "#A2D53F", "#A2D53F", "#A3D641", "#A3D641", "#A5D743", "#A5D743", "#A6D845", "#A6D845", "#A7DA46", "#A7DA46", "#A8DB48", "#A8DB48", "#A9DC4A", "#A9DC4A", "#AADD4C", "#AADD4C", "#ACDE4E", "#ACDE4E", "#ADDF50", "#ADDF50", "#AEE052", "#AEE052", "#AFE154", "#AFE154", "#B0E355", "#B0E355", "#B1E457", "#B1E457", "#B3E559", "#B3E559", "#B4E65B", "#B4E65B", "#B5E75D", "#B5E75D", "#B6E85F", "#B6E85F", "#B7E961", "#B7E961", "#B8EB62", "#B8EB62", "#BAEC64", "#BAEC64", "#BCEE68", "#BCEE68", "#BEEE6B", "#BEEE6B", "#C0EE6F", "#C0EE6F", "#C2EF72", "#C2EF72", "#C5EF75", "#C5EF75", "#C7EF79", "#C7EF79", "#C9EF7C", "#C9EF7C", "#CBF07F", "#CBF07F", "#CDF082", "#CDF082", "#CFF086", "#CFF086", "#D1F089", "#D1F089", "#D4F18C", "#D4F18C", "#D6F190", "#D6F190", "#D8F193", "#D8F193", "#DAF196", "#DAF196", "#DCF29A", "#DCF29A", "#DEF29D", "#DEF29D", "#E0F2A0", "#E0F2A0", "#E2F2A4", "#E2F2A4", "#E5F3A7", "#E5F3A7", "#E7F3AA", "#E7F3AA", "#E9F3AE", "#E9F3AE", "#EBF3B1", "#EBF3B1", "#EDF4B4", "#EDF4B4", "#EFF4B7", "#EFF4B7", "#F1F4BB", "#F1F4BB", "#F4F4BE", "#F4F4BE", "#F6F5C1", "#F6F5C1", "#FAF5C8", "#FAF5C8", "#FAF4C7", "#FAF4C7", "#F9F4C5", "#F9F4C5", "#F9F3C4", "#F9F3C4", "#F9F3C2", "#F9F3C2", "#F8F2C1", "#F8F2C1", "#F8F2BF", "#F8F2BF", "#F8F1BE", "#F8F1BE", "#F7F1BC", "#F7F1BC", "#F7F0BB", "#F7F0BB", "#F7EFBA", "#F7EFBA", "#F6EFB8", "#F6EFB8", "#F6EEB7", "#F6EEB7", "#F6EEB5", "#F6EEB5", "#F5EDB4", "#F5EDB4", "#F5EDB2", "#F5EDB2", "#F4ECB1", "#F4ECB1", "#F4ECAF", "#F4ECAF", "#F4EBAE", "#F4EBAE", "#F3EBAC", "#F3EBAC", "#F3EAAB", "#F3EAAB", "#F3E9AA", "#F3E9AA", "#F2E9A8", "#F2E9A8", "#F2E8A7", "#F2E8A7", "#F2E8A5", "#F2E8A5", "#F1E7A4", "#F1E7A4", "#F1E7A2", "#F1E7A2", "#F1E6A1", "#F1E6A1", "#F0E59E", "#F0E59E", "#EFE49B", "#EFE49B", "#EEE299", "#EEE299", "#EDE196", "#EDE196", "#ECE094", "#ECE094", "#EBDE91", "#EBDE91", "#EADD8E", "#EADD8E", "#E9DC8C", "#E9DC8C", "#E9DB89", "#E9DB89", "#E8D987", "#E8D987", "#E7D884", "#E7D884", "#E6D782", "#E6D782", "#E5D57F", "#E5D57F", "#E4D47C", "#E4D47C", "#E3D37A", "#E3D37A", "#E2D177", "#E2D177", "#E1D075", "#E1D075", "#E0CF72", "#E0CF72", "#DFCD6F", "#DFCD6F", "#DECC6D", "#DECC6D", "#DDCB6A", "#DDCB6A", "#DCC968", "#DCC968", "#DCC865", "#DCC865", "#DBC763", "#DBC763", "#DAC660", "#DAC660", "#D9C45D", "#D9C45D", "#D8C35B", "#D8C35B", "#D5BF53", "#D5BF53", "#D5BE51", "#D5BE51", "#D4BD4F", "#D4BD4F", "#D4BB4D", "#D4BB4D", "#D4BA4C", "#D4BA4C", "#D4B94A", "#D4B94A", "#D3B848", "#D3B848", "#D3B646", "#D3B646", "#D3B544", "#D3B544", "#D3B442", "#D3B442", "#D2B340", "#D2B340", "#D2B13F", "#D2B13F", "#D2B03D", "#D2B03D", "#D1AF3B", "#D1AF3B", "#D1AE39", "#D1AE39", "#D1AC37", "#D1AC37", "#D1AB35", "#D1AB35", "#D0AA33", "#D0AA33", "#D0A931", "#D0A931", "#D0A730", "#D0A730", "#CFA62E", "#CFA62E", "#CFA52C", "#CFA52C", "#CFA42A", "#CFA42A", "#CFA228", "#CFA228", "#CEA126", "#CEA126", "#CEA024", "#CEA024", "#CE9F23", "#CE9F23", "#CE9D21", "#CE9D21", "#CD9B1D", "#CD9B1D", "#CB991D", "#CB991D", "#C8971E", "#C8971E", "#C6941E", "#C6941E", "#C4921F", "#C4921F", "#C2901F", "#C2901F", "#BF8E20", "#BF8E20", "#BD8B20", "#BD8B20", "#BB8921", "#BB8921", "#B98721", "#B98721", "#B68522", "#B68522", "#B48222", "#B48222", "#B28023", "#B28023", "#AF7E23", "#AF7E23", "#AD7C24", "#AD7C24", "#AB7924", "#AB7924", "#A97725", "#A97725", "#A67525", "#A67525", "#A47326", "#A47326", "#A27026", "#A27026", "#9F6E27", "#9F6E27", "#9D6C27", "#9D6C27", "#9B6A28", "#9B6A28", "#996728", "#996728", "#966529", "#966529", "#946329", "#946329", "#92612A", "#92612A", "#905E2A", "#905E2A", "#8B5A2B", "#8B5A2B", "#89592A", "#89592A", "#87582A", "#87582A", "#855629", "#855629", "#835529", "#835529", "#815428", "#815428", "#7F5327", "#7F5327", "#7D5127", "#7D5127", "#7C5026", "#7C5026", "#7A4F26", "#7A4F26", "#784E25", "#784E25", "#764C25", "#764C25", "#744B24", "#744B24", "#724A23", "#724A23", "#704923", "#704923", "#6E4722", "#6E4722", "#6C4622", "#6C4622", "#6A4521", "#6A4521", "#684420", "#684420", "#664220", "#664220", "#64411F", "#64411F", "#62401F", "#62401F", "#613F1E", "#613F1E", "#5F3D1E", "#5F3D1E", "#5D3C1D", "#5D3C1D", "#5B3B1C", "#5B3B1C", "#593A1C", "#593A1C", "#57381B", "#57381B", "#53361A", "#53361A", "#593D22", "#593D22", "#5E432A", "#5E432A", "#644A32", "#644A32", "#6A513A", "#6A513A", "#6F5741", "#6F5741", "#755E49", "#755E49", "#7B6551", "#7B6551", "#816C59", "#816C59", "#867261", "#867261", "#8C7969", "#8C7969", "#928071", "#928071", "#978679", "#978679", "#9D8D81", "#9D8D81", "#A39489", "#A39489", "#A89A90", "#A89A90", "#AEA198", "#AEA198", "#B4A8A0", "#B4A8A0", "#B9AEA8", "#B9AEA8", "#BFB5B0", "#BFB5B0", "#C5BCB8", "#C5BCB8", "#CAC2C0", "#CAC2C0", "#D0C9C8", "#D0C9C8", "#D6D0D0", "#D6D0D0", "#DCD7D8", "#DCD7D8", "#E1DDDF", "#E1DDDF", "#E7E4E7", "#E7E4E7", "#EDEBEF", "#EDEBEF", "#F8F8FF", "#F8F8FF"], "ncl_perc2_9lev": ["#D7E3EE", "#D7E3EE", "#B5CAFF", "#B5CAFF", "#8FB3FF", "#8FB3FF", "#7F97FF", "#7F97FF", "#ABCF63", "#ABCF63", "#E8F59E", "#E8F59E", "#FFFA14", "#FFFA14", "#FFD121", "#FFD121", "#FFA30A", "#FFA30A", "#FF4C00", "#FF4C00"], "ncl_percent_11lev": ["#640096", "#640096", "#2730D7", "#2730D7", "#598DFC", "#598DFC", "#8BEFD9", "#8BEFD9", "#60CF91", "#60CF91", "#1A9850", "#1A9850", "#91CF60", "#91CF60", "#D9EF8B", "#D9EF8B", "#FEE08B", "#FEE08B", "#FC8D59", "#FC8D59", "#D73027", "#D73027", "#960064", "#960064"], "ncl_posneg_1": ["#FFFFFF", "#FFFFFF", "#000000", "#000000", "#000000", "#181870", "#181870", "#104E8B", "#104E8B", "#1774CD", "#1774CD", "#4876FF", "#4876FF", "#5BACED", "#5BACED", "#ADD7E6", "#ADD7E6", "#D1EDED", "#D1EDED", "#E6E6FA", "#E6E6FA", "#FFE4B4", "#FFE4B4", "#F3A460", "#F3A460", "#ED7600", "#ED7600", "#D2691E", "#D2691E", "#FF0000", "#FF0000", "#ED0000", "#ED0000", "#CD0000", "#CD0000", "#8B0000", "#8B0000"], "ncl_posneg_2": ["#FFFFFF", "#FFFFFF", "#000000", "#000000", "#181870", "#181870", "#104E8B", "#104E8B", "#1774CD", "#1774CD", "#4876FF", "#4876FF", "#5BACED", "#5BACED", "#ADD7E6", "#ADD7E6", "#D1EDED", "#D1EDED", "#E5EFF9", "#E5EFF9", "#F2FFFF", "#F2FFFF", "#FDF5E6", "#FDF5E6", "#FFE4B4", "#FFE4B4", "#F3A460", "#F3A460", "#ED7600", "#ED7600", "#CD661D", "#CD661D", "#E0310F", "#E0310F", "#ED0000", "#ED0000", "#CD0000", "#CD0000", "#8B0000", "#8B0000"], "ncl_prcp_1": ["#FFFFFF", "#FFFFFF", "#AAFFFF", "#AAFFFF", "#55A0FF", "#55A0FF", "#1D00FF", "#1D00FF", "#7EE55B", "#7EE55B", "#4ECC43", "#4ECC43", "#2EB239", "#2EB239", "#1E993D", "#1E993D", "#FFFF66", "#FFFF66", "#FFCC66", "#FFCC66", "#FF884C", "#FF884C", "#FF1919", "#FF1919", "#CC3D3D", "#CC3D3D", "#A53131", "#A53131", "#ED00ED", "#ED00ED", "#8967CD", "#8967CD", "#FAF0E6", "#FAF0E6"], "ncl_prcp_2": ["#F5F5F5", "#F5F5F5", "#AFEDED", "#AFEDED", "#98FB98", "#98FB98", "#43CD80", "#43CD80", "#3BB371", "#3BB371", "#FAFAD2", "#FAFAD2", "#FFFF00", "#FFFF00", "#FFA400", "#FFA400", "#FF0000", "#FF0000", "#CD3700", "#CD3700", "#C71485", "#C71485", "#ED82ED", "#ED82ED"], "ncl_prcp_3": ["#FFFFFF", "#FFFFFF", "#000000", "#000000", "#FFFFFF", "#FFFFFF", "#E9CCF9", "#E9CCF9", "#CF80DF", "#CF80DF", "#833393", "#833393", "#3A00B0", "#3A00B0", "#1D00D7", "#1D00D7", "#0000FF", "#0000FF", "#033CAF", "#033CAF", "#05775F", "#05775F", "#08B30F", "#08B30F", "#84D908", "#84D908", "#FFFF00", "#FFFF00", "#FFAA00", "#FFAA00", "#FF5500", "#FF5500", "#FF0000", "#FF0000", "#B30000", "#B30000", "#660000", "#660000", "#330000", "#330000", "#000000", "#000000", "#FAC5FA", "#FAC5FA", "#FFFFFF", "#FFFFFF"], "ncl_precip_11lev": ["#FFFFFF", "#FFFFFF", "#EDFAC2", "#EDFAC2", "#CDFFCD", "#CDFFCD", "#99F0B2", "#99F0B2", "#53BD9F", "#53BD9F", "#32A696", "#32A696", "#3296B4", "#3296B4", "#0570B0", "#0570B0", "#05508C", "#05508C", "#0A1F96", "#0A1F96", "#2C0246", "#2C0246", "#6A2C5A", "#6A2C5A"], "ncl_precip_diff_12lev": ["#B66A28", "#B66A28", "#CD853F", "#CD853F", "#E1A564", "#E1A564", "#F5CD84", "#F5CD84", "#F5E09E", "#F5E09E", "#FFF5BA", "#FFF5BA", "#FFFFFF", "#FFFFFF", "#CDFFCD", "#CDFFCD", "#99F0B2", "#99F0B2", "#53BD9F", "#53BD9F", "#6EAAC8", "#6EAAC8", "#0570B0", "#0570B0", "#023858", "#023858"], "ncl_precip2_15lev": ["#FFFFFF", "#FFFFFF", "#640064", "#640064", "#AF00AF", "#AF00AF", "#DC00DC", "#DC00DC", "#3232C8", "#3232C8", "#0064FF", "#0064FF", "#009696", "#009696", "#00C832", "#00C832", "#64FF00", "#64FF00", "#96FF00", "#96FF00", "#C8FF32", "#C8FF32", "#FFFF00", "#FFFF00", "#FFC800", "#FFC800", "#FFA000", "#FFA000", "#FF7D00", "#FF7D00", "#E11900", "#E11900"], "ncl_precip2_17lev": ["#FFFFFF", "#FFFFFF", "#EBF6FF", "#EBF6FF", "#D6E2FF", "#D6E2FF", "#B5C9FF", "#B5C9FF", "#8EB2FF", "#8EB2FF", "#7F96FF", "#7F96FF", "#7285F8", "#7285F8", "#6370F8", "#6370F8", "#009E1E", "#009E1E", "#3CBC3D", "#3CBC3D", "#B3D16E", "#B3D16E", "#B9F96E", "#B9F96E", "#FFF913", "#FFF913", "#FFA309", "#FFA309", "#E50000", "#E50000", "#BD0000", "#BD0000", "#810000", "#810000", "#000000", "#000000"], "ncl_precip3_16lev": ["#FFFFFF", "#FFFFFF", "#D6E2FF", "#D6E2FF", "#B5C9FF", "#B5C9FF", "#8EB2FF", "#8EB2FF", "#7F96FF", "#7F96FF", "#6370F7", "#6370F7", "#0063FF", "#0063FF", "#009696", "#009696", "#00C633", "#00C633", "#63FF00", "#63FF00", "#96FF00", "#96FF00", "#C6FF33", "#C6FF33", "#FFFF00", "#FFFF00", "#FFC600", "#FFC600", "#FFA000", "#FFA000", "#FF7C00", "#FF7C00", "#FF1900", "#FF1900"], "ncl_precip4_11lev": ["#FEFEFE", "#FEFEFE", "#DFFFF9", "#DFFFF9", "#9AD9CA", "#9AD9CA", "#67C2A3", "#67C2A3", "#40AD75", "#40AD75", "#32A696", "#32A696", "#5AA0CD", "#5AA0CD", "#4292C7", "#4292C7", "#4C8DC4", "#4C8DC4", "#072F6B", "#072F6B", "#071E46", "#071E46", "#4C0073", "#4C0073"], "ncl_precip4_diff_19lev": ["#6B2107", "#6B2107", "#B53B21", "#B53B21", "#C75542", "#C75542", "#CD695A", "#CD695A", "#A63237", "#A63237", "#AD4058", "#AD4058", "#C26772", "#C26772", "#D99A9F", "#D99A9F", "#FFDFE0", "#FFDFE0", "#FEFEFE", "#FEFEFE", "#FEFEFE", "#DFFFF9", "#DFFFF9", "#9AD9CA", "#9AD9CA", "#67C2A3", "#67C2A3", "#40AD75", "#40AD75", "#32A696", "#32A696", "#5AA0CD", "#5AA0CD", "#4292C7", "#4292C7", "#4C8DC4", "#4C8DC4", "#072F6B", "#072F6B"], "ncl_radar": ["#00FFFF", "#00FFFF", "#009DFF", "#009DFF", "#0000FF", "#0000FF", "#0982AF", "#0982AF", "#00FF00", "#00FF00", "#08AF14", "#08AF14", "#FFD600", "#FFD600", "#FF9800", "#FF9800", "#FF0000", "#FF0000", "#DD001B", "#DD001B", "#BC0036", "#BC0036", "#79006D", "#79006D", "#7933A0", "#7933A0", "#C3A3D4", "#C3A3D4", "#FFFFFF", "#FFFFFF"], "ncl_rh_19lev": ["#FEFEFE", "#FEFEFE", "#FEFEA0", "#FEFEA0", "#FEFE63", "#FEFE63", "#F4F46E", "#F4F46E", "#FFD223", "#FFD223", "#FFA319", "#FFA319", "#FF5919", "#FF5919", "#E67A65", "#E67A65", "#ED917C", "#ED917C", "#EFB292", "#EFB292", "#F7C7B2", "#F7C7B2", "#FFE6E6", "#FFE6E6", "#D7E1FF", "#D7E1FF", "#96D2FF", "#96D2FF", "#1EBDFF", "#1EBDFF", "#149FFF", "#149FFF", "#0A6CF0", "#0A6CF0", "#0B74FF", "#0B74FF", "#0A68C8", "#0A68C8", "#00599F", "#00599F"], "ncl_spread_15lev": ["#FFFFFF", "#FFFFFF", "#FFE1E1", "#FFE1E1", "#FFD2D2", "#FFD2D2", "#FFA5A5", "#FFA5A5", "#FF7878", "#FF7878", "#FF4B4B", "#FF4B4B", "#FF0000", "#FF0000", "#FF6400", "#FF6400", "#FF9600", "#FF9600", "#FFC800", "#FFC800", "#FFFF00", "#FFFF00", "#8CFF00", "#8CFF00", "#00FF00", "#00FF00", "#00CD5F", "#00CD5F", "#0091C8", "#0091C8", "#0000FF", "#0000FF"], "ncl_StepSeq25": ["#990F0F", "#990F0F", "#B22C2C", "#B22C2C", "#CC5151", "#CC5151", "#E57E7E", "#E57E7E", "#FFB2B2", "#FFB2B2", "#99540F", "#99540F", "#B26F2C", "#B26F2C", "#CC8E51", "#CC8E51", "#E5B17E", "#E5B17E", "#FFD8B2", "#FFD8B2", "#6B990F", "#6B990F", "#85B22C", "#85B22C", "#A3CC51", "#A3CC51", "#C3E57E", "#C3E57E", "#E5FFB2", "#E5FFB2", "#0F6B99", "#0F6B99", "#2C85B2", "#2C85B2", "#51A3CC", "#51A3CC", "#7EC3E5", "#7EC3E5", "#B2E5FF", "#B2E5FF", "#260F99", "#260F99", "#422CB2", "#422CB2", "#6551CC", "#6551CC", "#8F7EE5", "#8F7EE5", "#BFB2FF", "#BFB2FF"], "ncl_sunshine_9lev": ["#FFFFFF", "#FFFFFF", "#FFF5CC", "#FFF5CC", "#FFE670", "#FFE670", "#FFCC33", "#FFCC33", "#FFAF33", "#FFAF33", "#FF9933", "#FF9933", "#FF6F33", "#FF6F33", "#FF5500", "#FF5500", "#E6281E", "#E6281E", "#C81E14", "#C81E14"], "ncl_sunshine_diff_12lev": ["#510979", "#510979", "#950FDF", "#950FDF", "#B74BF3", "#B74BF3", "#CB7EF6", "#CB7EF6", "#E1B4FA", "#E1B4FA", "#ECD0FC", "#ECD0FC", "#FFFFFF", "#FFFFFF", "#FFF5CC", "#FFF5CC", "#FFE670", "#FFE670", "#FFCC33", "#FFCC33", "#FFAF33", "#FFAF33", "#FF6F00", "#FF6F00", "#E6281E", "#E6281E"], "ncl_t2m_29lev": ["#6DE3FF", "#6DE3FF", "#AFF0FF", "#AFF0FF", "#FFC4E2", "#FFC4E2", "#FF99CC", "#FF99CC", "#FF00FF", "#FF00FF", "#800080", "#800080", "#000080", "#000080", "#4646FF", "#4646FF", "#3366FF", "#3366FF", "#85A2FF", "#85A2FF", "#FFFFFF", "#FFFFFF", "#CCCCCC", "#CCCCCC", "#B3B3B3", "#B3B3B3", "#999999", "#999999", "#606060", "#606060", "#808000", "#808000", "#005C00", "#005C00", "#008000", "#008000", "#339966", "#339966", "#9DD500", "#9DD500", "#D4FF5B", "#D4FF5B", "#FFFF00", "#FFFF00", "#FFB870", "#FFB870", "#FF9900", "#FF9900", "#FF6600", "#FF6600", "#FF0000", "#FF0000", "#BC4B00", "#BC4B00", "#AB0038", "#AB0038", "#800000", "#800000", "#A370FF", "#A370FF"], "ncl_tbr_240_300": ["#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#0A000F", "#0A000F", "#13001E", "#13001E", "#1D002D", "#1D002D", "#27003C", "#27003C", "#30004C", "#30004C", "#3A005B", "#3A005B", "#44006A", "#44006A", "#4D0079", "#4D0079", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#550585", "#550585", "#530A81", "#530A81", "#500F7E", "#500F7E", "#4E147B", "#4E147B", "#4C1977", "#4C1977", "#4A1E74", "#4A1E74", "#482370", "#482370", "#45286D", "#45286D", "#432D6A", "#432D6A", "#413266", "#413266", "#3F3763", "#3F3763", "#3D3C60", "#3D3C60", "#3A415C", "#3A415C", "#384659", "#384659", "#364B56", "#364B56", "#345052", "#345052", "#32554F", "#32554F", "#305A4C", "#305A4C", "#2D5E48", "#2D5E48", "#2B6345", "#2B6345", "#296841", "#296841", "#276D3E", "#276D3E", "#25723B", "#25723B", "#227737", "#227737", "#207C34", "#207C34", "#1E8131", "#1E8131", "#1C862D", "#1C862D", "#1A8B2A", "#1A8B2A", "#179027", "#179027", "#159523", "#159523", "#139A20", "#139A20", "#119F1C", "#119F1C", "#0FA419", "#0FA419", "#0CA916", "#0CA916", "#0AAE12", "#0AAE12", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#0FB50F", "#0FB50F", "#16B70E", "#16B70E", "#1DB90E", "#1DB90E", "#23BB0D", "#23BB0D", "#2ABE0D", "#2ABE0D", "#31C00D", "#31C00D", "#38C20C", "#38C20C", "#3FC40C", "#3FC40C", "#46C60B", "#46C60B", "#4DC80B", "#4DC80B", "#53CA0A", "#53CA0A", "#5ACC0A", "#5ACC0A", "#61CE0A", "#61CE0A", "#68D109", "#68D109", "#6FD309", "#6FD309", "#76D508", "#76D508", "#7DD708", "#7DD708", "#84D908", "#84D908", "#8ADB07", "#8ADB07", "#91DD07", "#91DD07", "#98DF06", "#98DF06", "#9FE106", "#9FE106", "#A6E405", "#A6E405", "#ADE605", "#ADE605", "#B4E805", "#B4E805", "#BAEA04", "#BAEA04", "#C1EC04", "#C1EC04", "#C8EE03", "#C8EE03", "#CFF003", "#CFF003", "#D6F203", "#D6F203", "#DDF402", "#DDF402", "#E4F702", "#E4F702", "#EAF901", "#EAF901", "#F1FB01", "#F1FB01", "#F8FD00", "#F8FD00", "#FFFF00", "#FFFF00", "#FFFF00", "#FFFF00", "#FFF600", "#FFF600", "#FFED00", "#FFED00", "#FFE500", "#FFE500", "#FFDC00", "#FFDC00", "#FFD300", "#FFD300", "#FFCA00", "#FFCA00", "#FFC100", "#FFC100", "#FFB900", "#FFB900", "#FFB000", "#FFB000", "#FFA700", "#FFA700", "#FF9E00", "#FF9E00", "#FF9500", "#FF9500", "#FF8D00", "#FF8D00", "#FF8400", "#FF8400", "#FF7B00", "#FF7B00", "#FF7200", "#FF7200", "#FF6A00", "#FF6A00", "#FF6100", "#FF6100", "#FF5800", "#FF5800", "#FF4F00", "#FF4F00", "#FF4600", "#FF4600", "#FF3E00", "#FF3E00", "#FF3500", "#FF3500", "#FF2C00", "#FF2C00", "#FF2300", "#FF2300", "#FF1A00", "#FF1A00", "#FF1200", "#FF1200", "#FF0900", "#FF0900", "#FF0000", "#FF0000", "#FE030A", "#FE030A", "#FE0715", "#FE0715", "#FD0A1F", "#FD0A1F", "#FC0E2A", "#FC0E2A", "#FC1134", "#FC1134", "#FB153F", "#FB153F", "#FA1849", "#FA1849", "#FA1C53", "#FA1C53", "#F91F5E", "#F91F5E", "#F82368", "#F82368", "#F82673", "#F82673", "#F72A7D", "#F72A7D", "#F72D88", "#F72D88", "#F63192", "#F63192", "#F5349D", "#F5349D", "#F538A7", "#F538A7", "#F43BB1", "#F43BB1", "#F33FBC", "#F33FBC", "#F342C6", "#F342C6", "#F246D1", "#F246D1", "#F149DB", "#F149DB", "#F14DE6", "#F14DE6", "#F050F0", "#F050F0", "#F15AF1", "#F15AF1", "#F265F2", "#F265F2", "#F36FF3", "#F36FF3", "#F479F4", "#F479F4", "#F483F4", "#F483F4", "#F58EF5", "#F58EF5", "#F698F6", "#F698F6", "#F7A2F7", "#F7A2F7", "#F8ADF8", "#F8ADF8", "#F9B7F9", "#F9B7F9", "#FAC1FA", "#FAC1FA", "#FBCCFB", "#FBCCFB", "#FBD6FB", "#FBD6FB", "#FCE0FC", "#FCE0FC", "#FDEAFD", "#FDEAFD", "#FEF5FE", "#FEF5FE", "#FFFFFF", "#FFFFFF"], "ncl_tbr_stdev_0_30": ["#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#050007", "#050007", "#09000E", "#09000E", "#0E0015", "#0E0015", "#12001D", "#12001D", "#170024", "#170024", "#1B002B", "#1B002B", "#200032", "#200032", "#250039", "#250039", "#290040", "#290040", "#2E0048", "#2E0048", "#32004F", "#32004F", "#370056", "#370056", "#3C005D", "#3C005D", "#400064", "#400064", "#45006B", "#45006B", "#490073", "#490073", "#4E007A", "#4E007A", "#520081", "#520081", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#540684", "#540684", "#520C80", "#520C80", "#4F117C", "#4F117C", "#4D1778", "#4D1778", "#4A1D74", "#4A1D74", "#482371", "#482371", "#45286D", "#45286D", "#432E69", "#432E69", "#403465", "#403465", "#3E3A61", "#3E3A61", "#3B405D", "#3B405D", "#384559", "#384559", "#364B55", "#364B55", "#335151", "#335151", "#31574D", "#31574D", "#2E5C4A", "#2E5C4A", "#2C6246", "#2C6246", "#296842", "#296842", "#276E3E", "#276E3E", "#24733A", "#24733A", "#217936", "#217936", "#1F7F32", "#1F7F32", "#1C852E", "#1C852E", "#1A8B2A", "#1A8B2A", "#179026", "#179026", "#159623", "#159623", "#129C1F", "#129C1F", "#10A21B", "#10A21B", "#0DA717", "#0DA717", "#0BAD13", "#0BAD13", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#14B70E", "#14B70E", "#20BA0E", "#20BA0E", "#2BBE0D", "#2BBE0D", "#37C10C", "#37C10C", "#43C50B", "#43C50B", "#4FC90B", "#4FC90B", "#5ACC0A", "#5ACC0A", "#66D009", "#66D009", "#72D409", "#72D409", "#7ED708", "#7ED708", "#89DB07", "#89DB07", "#95DE06", "#95DE06", "#A1E206", "#A1E206", "#ADE605", "#ADE605", "#B8E904", "#B8E904", "#C4ED04", "#C4ED04", "#D0F103", "#D0F103", "#DCF402", "#DCF402", "#E7F801", "#E7F801", "#F3FB01", "#F3FB01", "#FFFF00", "#FFFF00", "#FFF600", "#FFF600", "#FFED00", "#FFED00", "#FFE400", "#FFE400", "#FFDB00", "#FFDB00", "#FFD100", "#FFD100", "#FFC800", "#FFC800", "#FFBF00", "#FFBF00", "#FFB600", "#FFB600", "#FFAD00", "#FFAD00", "#FFA400", "#FFA400", "#FF9B00", "#FF9B00", "#FF9200", "#FF9200", "#FF8900", "#FF8900", "#FF8000", "#FF8000", "#FF7600", "#FF7600", "#FF6D00", "#FF6D00", "#FF6400", "#FF6400", "#FF5B00", "#FF5B00", "#FF5200", "#FF5200", "#FF4900", "#FF4900", "#FF4000", "#FF4000", "#FF3700", "#FF3700", "#FF2E00", "#FF2E00", "#FF2400", "#FF2400", "#FF1B00", "#FF1B00", "#FF1200", "#FF1200", "#FF0900", "#FF0900", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FD0D28", "#FD0D28", "#FA1B50", "#FA1B50", "#F82878", "#F82878", "#F535A0", "#F535A0", "#F343C8", "#F343C8", "#F050F0", "#F050F0", "#F266F2", "#F266F2", "#F47CF4", "#F47CF4", "#F692F6", "#F692F6", "#F8A8F8", "#F8A8F8", "#F9BDF9", "#F9BDF9", "#FBD3FB", "#FBD3FB", "#FDE9FD", "#FDE9FD", "#FFFFFF", "#FFFFFF", "#FFFFFF", "#FFFFFF", "#FFFFFF", "#FFFFFF", "#FFFFFF"], "ncl_tbr_var_0_500": ["#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#09000E", "#09000E", "#11001B", "#11001B", "#1A0029", "#1A0029", "#230036", "#230036", "#2C0044", "#2C0044", "#340052", "#340052", "#3D005F", "#3D005F", "#46006D", "#46006D", "#4E007A", "#4E007A", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#530982", "#530982", "#4F117C", "#4F117C", "#4C1A77", "#4C1A77", "#482271", "#482271", "#442B6B", "#442B6B", "#403365", "#403365", "#3D3C60", "#3D3C60", "#39445A", "#39445A", "#354D54", "#354D54", "#31554E", "#31554E", "#2E5E49", "#2E5E49", "#2A6643", "#2A6643", "#266F3D", "#266F3D", "#227737", "#227737", "#1F8032", "#1F8032", "#1B882C", "#1B882C", "#179126", "#179126", "#139920", "#139920", "#10A21B", "#10A21B", "#0CAA15", "#0CAA15", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#15B70E", "#15B70E", "#22BB0D", "#22BB0D", "#2FBF0D", "#2FBF0D", "#3CC30C", "#3CC30C", "#49C70B", "#49C70B", "#56CB0A", "#56CB0A", "#63CF09", "#63CF09", "#70D309", "#70D309", "#7DD708", "#7DD708", "#8ADB07", "#8ADB07", "#97DF06", "#97DF06", "#A4E306", "#A4E306", "#B1E705", "#B1E705", "#BEEB04", "#BEEB04", "#CBEF03", "#CBEF03", "#D8F302", "#D8F302", "#E5F702", "#E5F702", "#F2FB01", "#F2FB01", "#FFFF00", "#FFFF00", "#FFFF00", "#FFFF00", "#FFFF00", "#FFFF00", "#FFFF00", "#FFFF00", "#FFFF00", "#FFFF00", "#FFF900", "#FFF900", "#FFF300", "#FFF300", "#FFED00", "#FFED00", "#FFE700", "#FFE700", "#FFE100", "#FFE100", "#FFDB00", "#FFDB00", "#FFD500", "#FFD500", "#FFCE00", "#FFCE00", "#FFC800", "#FFC800", "#FFC200", "#FFC200", "#FFBC00", "#FFBC00", "#FFB600", "#FFB600", "#FFB000", "#FFB000", "#FFAA00", "#FFAA00", "#FFA400", "#FFA400", "#FF9E00", "#FF9E00", "#FF9800", "#FF9800", "#FF9200", "#FF9200", "#FF8C00", "#FF8C00", "#FF8600", "#FF8600", "#FF8000", "#FF8000", "#FF7900", "#FF7900", "#FF7300", "#FF7300", "#FF6D00", "#FF6D00", "#FF6700", "#FF6700", "#FF6100", "#FF6100", "#FF5B00", "#FF5B00", "#FF5500", "#FF5500", "#FF4F00", "#FF4F00", "#FF4900", "#FF4900", "#FF4300", "#FF4300", "#FF3D00", "#FF3D00", "#FF3700", "#FF3700", "#FF3100", "#FF3100", "#FF2B00", "#FF2B00", "#FF2400", "#FF2400", "#FF1E00", "#FF1E00", "#FF1800", "#FF1800", "#FF1200", "#FF1200", "#FF0C00", "#FF0C00", "#FF0600", "#FF0600", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FE0818", "#FE0818", "#FC1030", "#FC1030", "#FB1848", "#FB1848", "#F92060", "#F92060", "#F82878", "#F82878", "#F63090", "#F63090", "#F538A8", "#F538A8", "#F340C0", "#F340C0", "#F248D8", "#F248D8", "#F050F0", "#F050F0", "#F050F0", "#F050F0", "#F050F0", "#F050F0", "#F050F0", "#F050F0", "#F050F0", "#F050F0", "#F050F0", "#F157F1", "#F157F1", "#F15FF1", "#F15FF1", "#F266F2", "#F266F2", "#F36DF3", "#F36DF3", "#F374F3", "#F374F3", "#F47CF4", "#F47CF4", "#F483F4", "#F483F4", "#F58AF5", "#F58AF5", "#F692F6", "#F692F6", "#F699F6", "#F699F6", "#F7A0F7", "#F7A0F7", "#F8A8F8", "#F8A8F8", "#F8AFF8", "#F8AFF8", "#F9B6F9", "#F9B6F9", "#F9BDF9", "#F9BDF9", "#FAC5FA", "#FAC5FA", "#FBCCFB", "#FBCCFB", "#FBD3FB", "#FBD3FB", "#FCDBFC", "#FCDBFC", "#FDE2FD", "#FDE2FD", "#FDE9FD", "#FDE9FD", "#FEF0FE", "#FEF0FE", "#FEF8FE", "#FEF8FE", "#FFFFFF", "#FFFFFF"], "ncl_tbrAvg1": ["#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#11001B", "#11001B", "#230036", "#230036", "#340052", "#340052", "#46006D", "#46006D", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#530A81", "#530A81", "#4E147B", "#4E147B", "#4A1E74", "#4A1E74", "#45286D", "#45286D", "#413266", "#413266", "#3D3C60", "#3D3C60", "#384659", "#384659", "#345052", "#345052", "#305A4C", "#305A4C", "#2B6345", "#2B6345", "#276D3E", "#276D3E", "#227737", "#227737", "#1E8131", "#1E8131", "#1A8B2A", "#1A8B2A", "#159523", "#159523", "#119F1C", "#119F1C", "#0CA916", "#0CA916", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#16B70E", "#16B70E", "#23BB0D", "#23BB0D", "#31C00D", "#31C00D", "#3FC40C", "#3FC40C", "#4DC80B", "#4DC80B", "#5ACC0A", "#5ACC0A", "#68D109", "#68D109", "#76D508", "#76D508", "#84D908", "#84D908", "#91DD07", "#91DD07", "#9FE106", "#9FE106", "#ADE605", "#ADE605", "#BAEA04", "#BAEA04", "#C8EE03", "#C8EE03", "#D6F203", "#D6F203", "#E4F702", "#E4F702", "#F1FB01", "#F1FB01", "#FFFF00", "#FFFF00", "#FFFF00", "#FFED00", "#FFED00", "#FFDB00", "#FFDB00", "#FFC800", "#FFC800", "#FFB600", "#FFB600", "#FFA400", "#FFA400", "#FF9200", "#FF9200", "#FF8000", "#FF8000", "#FF6D00", "#FF6D00", "#FF5B00", "#FF5B00", "#FF4900", "#FF4900", "#FF3700", "#FF3700", "#FF2400", "#FF2400", "#FF1200", "#FF1200", "#FF0000", "#FF0000", "#FE0714", "#FE0714", "#FD0D28", "#FD0D28", "#FB143C", "#FB143C", "#FA1B50", "#FA1B50", "#F92164", "#F92164", "#F82878", "#F82878", "#F62F8C", "#F62F8C", "#F535A0", "#F535A0", "#F43CB4", "#F43CB4", "#F343C8", "#F343C8", "#F149DC", "#F149DC", "#F050F0", "#F050F0", "#F266F2", "#F266F2", "#F47CF4", "#F47CF4", "#F692F6", "#F692F6", "#F8A8F8", "#F8A8F8", "#F9BDF9", "#F9BDF9", "#FBD3FB", "#FBD3FB", "#FDE9FD", "#FDE9FD", "#FFFFFF", "#FFFFFF"], "ncl_tbrStd1": ["#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#0A000F", "#0A000F", "#13001E", "#13001E", "#1D002D", "#1D002D", "#27003C", "#27003C", "#30004C", "#30004C", "#3A005B", "#3A005B", "#44006A", "#44006A", "#4D0079", "#4D0079", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#520C80", "#520C80", "#4C1878", "#4C1878", "#472470", "#472470", "#423068", "#423068", "#3D3C60", "#3D3C60", "#374858", "#374858", "#325450", "#325450", "#2D5F47", "#2D5F47", "#286B3F", "#286B3F", "#227737", "#227737", "#1D832F", "#1D832F", "#188F27", "#188F27", "#139B1F", "#139B1F", "#0DA717", "#0DA717", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#1EBA0E", "#1EBA0E", "#35C10C", "#35C10C", "#4BC80B", "#4BC80B", "#62CF0A", "#62CF0A", "#78D608", "#78D608", "#8FDC07", "#8FDC07", "#A5E305", "#A5E305", "#BCEA04", "#BCEA04", "#D2F103", "#D2F103", "#E9F801", "#E9F801", "#FFFF00", "#FFFF00", "#FFED00", "#FFED00", "#FFDB00", "#FFDB00", "#FFC800", "#FFC800", "#FFB600", "#FFB600", "#FFA400", "#FFA400", "#FF9200", "#FF9200", "#FF8000", "#FF8000", "#FF6D00", "#FF6D00", "#FF5B00", "#FF5B00", "#FF4900", "#FF4900", "#FF3700", "#FF3700", "#FF2400", "#FF2400", "#FF1200", "#FF1200", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FA1B50", "#FA1B50", "#F535A0", "#F535A0", "#F050F0", "#F050F0", "#F373F3", "#F373F3", "#F696F6", "#F696F6", "#F9B9F9", "#F9B9F9", "#FCDCFC", "#FCDCFC", "#FFFFFF", "#FFFFFF", "#FFFFFF", "#FFFFFF"], "ncl_tbrVar1": ["#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#11001B", "#11001B", "#230036", "#230036", "#340052", "#340052", "#46006D", "#46006D", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#570088", "#50107D", "#50107D", "#492172", "#492172", "#413167", "#413167", "#3A415C", "#3A415C", "#335151", "#335151", "#2C6246", "#2C6246", "#25723B", "#25723B", "#1E8230", "#1E8230", "#169225", "#169225", "#0FA31A", "#0FA31A", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#08B30F", "#23BB0D", "#23BB0D", "#3FC40C", "#3FC40C", "#5ACC0A", "#5ACC0A", "#76D508", "#76D508", "#91DD07", "#91DD07", "#ADE605", "#ADE605", "#C8EE03", "#C8EE03", "#E4F702", "#E4F702", "#FFFF00", "#FFFF00", "#FFFF00", "#FFFF00", "#FFFF00", "#FFFF00", "#FFF300", "#FFF300", "#FFE700", "#FFE700", "#FFDB00", "#FFDB00", "#FFCE00", "#FFCE00", "#FFC200", "#FFC200", "#FFB600", "#FFB600", "#FFAA00", "#FFAA00", "#FF9E00", "#FF9E00", "#FF9200", "#FF9200", "#FF8600", "#FF8600", "#FF7900", "#FF7900", "#FF6D00", "#FF6D00", "#FF6100", "#FF6100", "#FF5500", "#FF5500", "#FF4900", "#FF4900", "#FF3D00", "#FF3D00", "#FF3100", "#FF3100", "#FF2400", "#FF2400", "#FF1800", "#FF1800", "#FF0C00", "#FF0C00", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FF0000", "#FB143C", "#FB143C", "#F82878", "#F82878", "#F43CB4", "#F43CB4", "#F050F0", "#F050F0", "#F050F0", "#F050F0", "#F050F0", "#F050F0", "#F050F0", "#F15FF1", "#F15FF1", "#F36DF3", "#F36DF3", "#F47CF4", "#F47CF4", "#F58AF5", "#F58AF5", "#F699F6", "#F699F6", "#F8A8F8", "#F8A8F8", "#F9B6F9", "#F9B6F9", "#FAC5FA", "#FAC5FA", "#FBD3FB", "#FBD3FB", "#FDE2FD", "#FDE2FD", "#FEF0FE", "#FEF0FE", "#FFFFFF", "#FFFFFF"], "ncl_temp_19lev": ["#071E46", "#071E46", "#072F6B", "#072F6B", "#08529C", "#08529C", "#2171B5", "#2171B5", "#4292C7", "#4292C7", "#5AA0CD", "#5AA0CD", "#78BFD6", "#78BFD6", "#AADCE6", "#AADCE6", "#DBF5FF", "#DBF5FF", "#F0FCFF", "#F0FCFF", "#FFF0F5", "#FFF0F5", "#FFE0E0", "#FFE0E0", "#FCBBAA", "#FCBBAA", "#FC9272", "#FC9272", "#FB6A4A", "#FB6A4A", "#F03C2B", "#F03C2B", "#CC181E", "#CC181E", "#A60F14", "#A60F14", "#780A0F", "#780A0F", "#5F0000", "#5F0000"], "ncl_temp_diff_18lev": ["#071E46", "#071E46", "#072F6B", "#072F6B", "#08579C", "#08579C", "#2171B5", "#2171B5", "#4292C7", "#4292C7", "#5AA0CD", "#5AA0CD", "#78BFD6", "#78BFD6", "#AADCE6", "#AADCE6", "#DBF5FF", "#DBF5FF", "#FFFFFF", "#FFFFFF", "#FFE0E0", "#FFE0E0", "#FCBBAA", "#FCBBAA", "#FC9272", "#FC9272", "#FB6A4A", "#FB6A4A", "#F03C2B", "#F03C2B", "#CC181E", "#CC181E", "#A60F14", "#A60F14", "#780A0F", "#780A0F", "#5F0000", "#5F0000"], "ncl_temp_diff_1lev": ["#F03C2B", "#F03C2B", "#2171B5", "#2171B5"], "ncl_topo_15lev": ["#28369A", "#28369A", "#00C932", "#00C932", "#1ED368", "#1ED368", "#5EE074", "#5EE074", "#A2EB82", "#A2EB82", "#DFF892", "#DFF892", "#F6E595", "#F6E595", "#C8B276", "#C8B276", "#A27E5E", "#A27E5E", "#8F6154", "#8F6154", "#A27D74", "#A27D74", "#B2968B", "#B2968B", "#C7B0AA", "#C7B0AA", "#DBCDCA", "#DBCDCA", "#ECE4E2", "#ECE4E2", "#FFFFFF", "#FFFFFF"], "ncl_wgne15": ["#A020F0", "#A020F0", "#0000B4", "#0000B4", "#3C64E6", "#3C64E6", "#789BF2", "#789BF2", "#B0E0E6", "#B0E0E6", "#2E8B57", "#2E8B57", "#64E100", "#64E100", "#D2FF2F", "#D2FF2F", "#F5E6BE", "#F5E6BE", "#DEB887", "#DEB887", "#FFE100", "#FFE100", "#FFA500", "#FFA500", "#FF4500", "#FF4500", "#962222", "#962222", "#FF69B4", "#FF69B4"], "ncl_wind_17lev": ["#FFFFFF", "#FFFFFF", "#EFF4D1", "#EFF4D1", "#E8F49E", "#E8F49E", "#AACE63", "#AACE63", "#E2ED16", "#E2ED16", "#FFED00", "#FFED00", "#FFED82", "#FFED82", "#F4D17F", "#F4D17F", "#EDA549", "#EDA549", "#E58C3D", "#E58C3D", "#DB7C3D", "#DB7C3D", "#EF073D", "#EF073D", "#E856A3", "#E856A3", "#9B70A8", "#9B70A8", "#6370F7", "#6370F7", "#7F96FF", "#7F96FF", "#8EB2FF", "#8EB2FF", "#B5C9FF", "#B5C9FF"], "ngdc_ETOPO1_Reed": ["#1006B4", "#1006B4", "#000ECB", "#000ECB", "#0C44E7", "#0C44E7", "#159EFC", "#159EFC", "#41C8FF", "#41C8FF", "#5EDFFF", "#5EDFFF", "#8AE3FF", "#8AE3FF", "#336600", "#003366", "#33CC66", "#33CC66", "#FFDCB9", "#FFDCB9", "#F3CA89", "#F3CA89", "#D9A627", "#D9A627", "#9F7B0D", "#9F7B0D", "#B27676", "#B27676"], "ngdc_ETOPO1": ["#0A0079", "#1A0089", "#260098", "#1B03A6", "#1006B4", "#0509C1", "#000ECB", "#0016D2", "#001ED8", "#0027DF", "#0C44E7", "#1A66F0", "#1375F4", "#0E85F9", "#159EFC", "#1EB2FF", "#2BBAFF", "#37C1FF", "#41C8FF", "#4FD2FF", "#5EDFFF", "#8AE3FF", "#BCE6FF", "#336600", "#33CC66", "#BBE492", "#FFDCB9", "#F3CA89", "#E6B858", "#D9A627", "#A89A1F", "#A49019", "#A28613", "#9F7B0D", "#9C7107", "#996600", "#A25959", "#B27676", "#B79393", "#C2B0B0", "#CCCCCC", "#E5E5E5", "#FFFFFF"], "oc_ndvi": ["#EBEBEB", "#EBEBEB", "#EBEBEB", "#EBEBEB", "#EBEBEB", "#EBEBEB", "#EBEBEB", "#EBEBEB", "#EBEBEB", "#EBEBEB", "#EBEBEB", "#EBEBEB", "#EBEBEB", "#EBEBEB", "#EBEBEB", "#CA6C20", "#CB6E22", "#CC7124", "#CE7326", "#CF7627", "#D17829", "#D27B2B", "#D37D2D", "#D5802F", "#D68231", "#D78532", "#D98734", "#DA8936", "#DB8C38", "#DD8E3A", "#DE903B", "#DF933D", "#E0953F", "#E29740", "#E39A42", "#E49C43", "#E59E45", "#E6A047", "#E7A248", "#E9A54A", "#EAA74B", "#EBA94C", "#ECAB4E", "#EDAD4F", "#EEAF51", "#EFB152", "#F0B353", "#F1B555", "#F2B756", "#F2B957", "#F3BB58", "#F4BD59", "#F5BF5A", "#F6C05B", "#F6C25C", "#F7C45D", "#F8C65E", "#F8C75F", "#F9C960", "#FACB61", "#FACC62", "#FBCE63", "#FBD063", "#FCD164", "#FCD265", "#FDD465", "#FDD566", "#FDD766", "#FED867", "#FED967", "#FEDB67", "#FFDC68", "#FFDD68", "#FFDE68", "#7E9C2C", "#7E9C2C", "#7E9C2C", "#7E9C2C", "#7E9C2C", "#7E9C2C", "#7E9C2C", "#7E9C2C", "#7E9C2C", "#7E9C2C", "#7E9C2C", "#7E9C2C", "#7E9C2C", "#7E9C2C", "#7E9C2C", "#96B613", "#96B613", "#96B613", "#96B613", "#96B613", "#96B613", "#96B613", "#96B613", "#96B613", "#96B613", "#96B613", "#96B613", "#96B613", "#96B613", "#96B613", "#75AA00", "#75AA00", "#75AA00", "#75AA00", "#75AA00", "#75AA00", "#75AA00", "#75AA00", "#75AA00", "#75AA00", "#75AA00", "#75AA00", "#75AA00", "#75AA00", "#75AA00", "#67A100", "#67A100", "#67A100", "#67A100", "#67A100", "#67A100", "#67A100", "#67A100", "#67A100", "#67A100", "#67A100", "#67A100", "#67A100", "#67A100", "#67A100", "#529400", "#529400", "#529400", "#529400", "#529400", "#529400", "#529400", "#529400", "#529400", "#529400", "#529400", "#529400", "#529400", "#529400", "#529400", "#3D8601", "#3D8601", "#3D8601", "#3D8601", "#3D8601", "#3D8601", "#3D8601", "#3D8601", "#3D8601", "#3D8601", "#3D8601", "#3D8601", "#3D8601", "#3D8601", "#3D8601", "#1C7301", "#1C7301", "#1C7301", "#1C7301", "#1C7301", "#1C7301", "#1C7301", "#1C7301", "#1C7301", "#1C7301", "#1C7301", "#1C7301", "#1C7301", "#1C7301", "#1C7301", "#005F01", "#005F01", "#005F01", "#005F01", "#005F01", "#005F01", "#005F01", "#005F01", "#005F01", "#005F01", "#005F01", "#005F01", "#005F01", "#005F01", "#005F01", "#004800", "#004800", "#004800", "#004800", "#004800", "#004800", "#004800", "#004800", "#004800", "#004800", "#004800", "#004800", "#004800", "#004800", "#004800", "#023701", "#023701", "#023701", "#023701", "#023701", "#023701", "#023701", "#023701", "#023701", "#023701", "#023701", "#023701", "#023701", "#023701", "#023701", "#002901", "#002901", "#002901", "#002901", "#002901", "#002901", "#002901", "#002901", "#002901", "#002901", "#002901", "#002901", "#002901", "#002901", "#002901", "#011301", "#011301", "#011301", "#011301", "#011301", "#011301", "#011301", "#011301", "#011301", "#011301", "#011301", "#011301", "#011301", "#011301"], "oc_rainbow": ["#90006F", "#8D0072", "#8A0075", "#870078", "#84007B", "#81007E", "#7E0081", "#7B0084", "#780087", "#75008A", "#72008D", "#6F0090", "#6C0093", "#690096", "#660099", "#63009C", "#60009F", "#5D00A2", "#5A00A5", "#5700A8", "#5400AB", "#5100AE", "#4E00B1", "#4B00B4", "#4800B7", "#4500BA", "#4200BD", "#3F00C0", "#3C00C3", "#3900C6", "#3600C9", "#3300CC", "#3000CF", "#2D00D2", "#2A00D5", "#2700D8", "#2400DB", "#2100DE", "#1E00E1", "#1B00E4", "#1800E7", "#1500EA", "#1200ED", "#0F00F0", "#0C00F3", "#0900F6", "#0600F9", "#0000FC", "#0000FF", "#0005FF", "#000AFF", "#0010FF", "#0015FF", "#001AFF", "#0020FF", "#0025FF", "#002AFF", "#0030FF", "#0035FF", "#003AFF", "#0040FF", "#0045FF", "#004AFF", "#0050FF", "#0055FF", "#005AFF", "#0060FF", "#0065FF", "#006AFF", "#0070FF", "#0075FF", "#007AFF", "#0080FF", "#0085FF", "#008AFF", "#0090FF", "#0095FF", "#009AFF", "#00A0FF", "#00A5FF", "#00AAFF", "#00B0FF", "#00B5FF", "#00BAFF", "#00C0FF", "#00C5FF", "#00CAFF", "#00D0FF", "#00D5FF", "#00DAFF", "#00E0FF", "#00E5FF", "#00EAFF", "#00F0FF", "#00F5FF", "#00FAFF", "#00FFFF", "#00FFF7", "#00FFEF", "#00FFE7", "#00FFDF", "#00FFD7", "#00FFCF", "#00FFC7", "#00FFBF", "#00FFB7", "#00FFAF", "#00FFA7", "#00FF9F", "#00FF97", "#00FF8F", "#00FF87", "#00FF7F", "#00FF77", "#00FF6F", "#00FF67", "#00FF5F", "#00FF57", "#00FF4F", "#00FF47", "#00FF3F", "#00FF37", "#00FF2F", "#00FF27", "#00FF1F", "#00FF17", "#00FF0F", "#00FF00", "#08FF00", "#10FF00", "#18FF00", "#20FF00", "#28FF00", "#30FF00", "#38FF00", "#40FF00", "#48FF00", "#50FF00", "#58FF00", "#60FF00", "#68FF00", "#70FF00", "#78FF00", "#80FF00", "#88FF00", "#90FF00", "#98FF00", "#A0FF00", "#A8FF00", "#B0FF00", "#B8FF00", "#C0FF00", "#C8FF00", "#D0FF00", "#D8FF00", "#E0FF00", "#E8FF00", "#F0FF00", "#F8FF00", "#FFFF00", "#FFFB00", "#FFF700", "#FFF300", "#FFEF00", "#FFEB00", "#FFE700", "#FFE300", "#FFDF00", "#FFDB00", "#FFD700", "#FFD300", "#FFCF00", "#FFCB00", "#FFC700", "#FFC300", "#FFBF00", "#FFBB00", "#FFB700", "#FFB300", "#FFAF00", "#FFAB00", "#FFA700", "#FFA300", "#FF9F00", "#FF9B00", "#FF9700", "#FF9300", "#FF8F00", "#FF8B00", "#FF8700", "#FF8300", "#FF7F00", "#FF7B00", "#FF7700", "#FF7300", "#FF6F00", "#FF6B00", "#FF6700", "#FF6300", "#FF5F00", "#FF5B00", "#FF5700", "#FF5300", "#FF4F00", "#FF4B00", "#FF4700", "#FF4300", "#FF3F00", "#FF3B00", "#FF3700", "#FF3300", "#FF2F00", "#FF2B00", "#FF2700", "#FF2300", "#FF1F00", "#FF1B00", "#FF1700", "#FF1300", "#FF0F00", "#FF0B00", "#FF0700", "#FF0300", "#FF0000", "#FA0000", "#F50000", "#F00000", "#EB0000", "#E60000", "#E10000", "#DC0000", "#D70000", "#D20000", "#CD0000", "#C80000", "#C30000", "#BE0000", "#B90000", "#B40000", "#AF0000", "#AA0000", "#A50000", "#A00000", "#9B0000", "#960000", "#910000", "#8C0000", "#870000", "#820000", "#7D0000", "#780000", "#730000", "#6E0000", "#690000"], "oc_sst": ["#63098B", "#7007AB", "#7C07CA", "#8207DF", "#8007EA", "#7807EE", "#6E07EE", "#6407EF", "#5807EF", "#4907EF", "#3607EF", "#2208EE", "#1208EC", "#0B08E9", "#0808E4", "#0808E0", "#0808DD", "#0808D9", "#0808D4", "#0808CF", "#0808C9", "#0808C4", "#0808BF", "#0808B9", "#0808B3", "#0808AD", "#0808A6", "#08089F", "#080899", "#080B93", "#08108B", "#081782", "#081E79", "#082672", "#082E6D", "#08366A", "#083E68", "#084668", "#084E68", "#08566A", "#085D6B", "#08626D", "#086470", "#086372", "#086275", "#08617A", "#086282", "#08658B", "#086893", "#086C98", "#08719B", "#08769D", "#087B9E", "#08809F", "#08859F", "#0888A0", "#088CA2", "#0891A3", "#0896A5", "#089CA6", "#08A1A7", "#08A6A9", "#08ACAC", "#08B1B1", "#08B6B6", "#08BBBB", "#08C0C0", "#08C5C5", "#08C8C8", "#08CCCC", "#08D1D1", "#08D5D5", "#08D8D8", "#08DBDB", "#08DEDE", "#08E1E1", "#08E3E3", "#08E6E6", "#08E9E9", "#08EBEB", "#08EDEC", "#08EEEA", "#08EEE5", "#08EEDF", "#08EDD8", "#08EBD1", "#08EACA", "#08E8C0", "#08E7B2", "#08E6A2", "#08E593", "#08E385", "#08E27B", "#08E074", "#08DD72", "#08DB72", "#08D873", "#08D575", "#08D176", "#08CC76", "#08C775", "#08C173", "#08BC70", "#08B86B", "#08B563", "#08B25B", "#08AF54", "#08AC51", "#08A950", "#08A450", "#089F50", "#089950", "#08944F", "#088F4F", "#088A4F", "#08864E", "#08844B", "#088646", "#08893F", "#088C38", "#088C30", "#088B25", "#098A18", "#0E8B0E", "#188D09", "#259208", "#2F9708", "#349C08", "#37A108", "#39A608", "#3CAC08", "#41B108", "#46B608", "#4BBB08", "#50C008", "#55C408", "#59C708", "#5FC908", "#67CC08", "#6ECE08", "#76D108", "#7ED308", "#86D608", "#8ED908", "#97DB08", "#A0DE08", "#A9E108", "#B3E308", "#BBE508", "#C3E608", "#CDE608", "#D7E608", "#DFE508", "#E2E308", "#E1E008", "#E0DD08", "#E0D908", "#E0D308", "#E0CD08", "#E0C608", "#E0BF08", "#E0B908", "#E0B408", "#E0AE08", "#E0A608", "#E09F08", "#E09708", "#E08F08", "#E08708", "#E07F08", "#E07708", "#E06F08", "#E06708", "#E05F08", "#E05908", "#E05408", "#E04E08", "#DF4608", "#DF3F08", "#DF3708", "#DE2E08", "#DD2508", "#DB1C08", "#D81308", "#D50C08", "#D10908", "#CC0808", "#C80808", "#C40808", "#BE0808", "#B60808", "#AF0808", "#A70808", "#9F0808", "#970808", "#8F0808", "#870808", "#7F0808", "#780808", "#730808", "#6E0808", "#680808", "#6C0D0D", "#701313", "#721616", "#731A1A", "#761E1E", "#772221", "#792626", "#7B2929", "#7D2D2D", "#7F3131", "#803435", "#823838", "#843C3C", "#86403F", "#884343", "#8A4746", "#8C4B4A", "#8E4F4E", "#8F5252", "#915555", "#93595A", "#955D5D", "#966161", "#986464", "#9A6868", "#9C6B6C", "#9E706F", "#A07373", "#A27777", "#A47B7B", "#A57E7E", "#A88282", "#A98686", "#AA8A89", "#AD8D8D", "#AF9191", "#B09595", "#B29999", "#B59C9C", "#B69F9F", "#B7A3A3", "#B9A7A7", "#BCAAAB", "#BEAEAE", "#BFB2B2", "#C1B6B6", "#C3B9B9", "#C5BDBD", "#C7C0C1", "#C8C5C5", "#CAC8C9", "#CCCCCC"], "oc_zeu": ["#6F3B01", "#713F02", "#744203", "#764604", "#794A04", "#7B4E06", "#7E5106", "#815507", "#845907", "#865D09", "#896109", "#8B650A", "#8E690B", "#906D0C", "#92700D", "#95740D", "#98780E", "#9A7B0F", "#9C7F10", "#A08310", "#A38811", "#A58B12", "#A78F13", "#AA9314", "#AD9714", "#AF9A16", "#B19E16", "#B4A217", "#B6A618", "#B9AA18", "#BBAE1A", "#BEB21A", "#C1B61B", "#C4B91B", "#C6BD1D", "#C9C01D", "#CBC51E", "#CEC81F", "#D0CC20", "#D3D021", "#D0D121", "#CBCE20", "#C7CC1F", "#C2CA1E", "#BCC81E", "#B8C51D", "#B3C31C", "#AEC11B", "#A8BF1A", "#A3BD1A", "#9EBB18", "#99B918", "#94B617", "#8EB416", "#89B215", "#84B015", "#7FAD14", "#7AAA13", "#74A913", "#6FA711", "#6AA411", "#65A110", "#609F0F", "#5A9E0E", "#559B0D", "#50990D", "#4B970C", "#46950B", "#40920A", "#3B9009", "#368E09", "#328C07", "#2D8907", "#268706", "#218506", "#1D8304", "#188004", "#117E03", "#0C7C02", "#087A01", "#037700", "#007905", "#007C0A", "#007F10", "#008216", "#00851C", "#008922", "#008C28", "#008F2E", "#009234", "#00963B", "#009941", "#009C47", "#00A04E", "#00A454", "#00A65A", "#00AA60", "#00AD67", "#00B16D", "#00B473", "#00B779", "#00BB80", "#00BE86", "#00C18C", "#00C492", "#00C899", "#00CC9F", "#00CEA5", "#00D2AB", "#00D6B1", "#00D9B8", "#00DCBE", "#00DFC4", "#00E3CA", "#00E6D1", "#00E9D7", "#00EDDD", "#00F0E3", "#00F4EA", "#00F7F0", "#00FAF6", "#00FDFC", "#00FAFF", "#00F5FF", "#00EFFF", "#00E9FF", "#00E4FF", "#00DDFF", "#00D7FF", "#00D1FF", "#00CBFF", "#00C4FF", "#00BEFF", "#00B8FF", "#00B2FF", "#00ACFF", "#00A6FF", "#00A0FF", "#0098FF", "#0092FF", "#008CFF", "#0086FF", "#007FFF", "#0079FF", "#0073FF", "#006DFF", "#0066FF", "#0060FF", "#005AFF", "#0054FF", "#004EFF", "#0047FF", "#0041FF", "#003BFF", "#0035FF", "#002EFF", "#0028FF", "#0022FF", "#001CFF", "#0015FF", "#000FFF", "#0009FF", "#0003FF", "#0202FF", "#0403FF", "#0705FF", "#0A08FF", "#0C0AFF", "#0F0CFF", "#120EFF", "#1410FF", "#1712FF", "#1A14FF", "#1D17FF", "#1F19FF", "#221BFF", "#251DFF", "#271FFF", "#2A21FF", "#2D23FF", "#3025FF", "#3228FF", "#352AFF", "#382CFF", "#3A2EFF", "#3D30FF", "#4032FF", "#4234FF", "#4537FF", "#4839FF", "#4B3BFF", "#4D3DFF", "#503FFF", "#5341FF", "#5543FF", "#5845FF", "#5B48FF", "#5D4AFF", "#604CFF", "#634EFF", "#6650FF", "#6852FF", "#6B54FF", "#6E57FF", "#7059FF", "#735BFF", "#765DFF", "#795FFF", "#7A60FE", "#795FFA", "#785DF6", "#765BF1", "#7558ED", "#7356E8", "#7154E4", "#7052E0", "#6E50DB", "#6D4ED7", "#6B4CD2", "#6A49CE", "#6847C9", "#6645C5", "#6543C0", "#6341BC", "#623FB7", "#603DB3", "#5E3BAE", "#5D38AA", "#5B36A5", "#5A34A1", "#58329C", "#573098", "#552E93", "#532C8F", "#52298A", "#502786", "#4F2581", "#4D237D", "#4B2178", "#4A1F74", "#481D6F", "#471B6B", "#451866", "#441662", "#42145D", "#401259", "#3F1054", "#3D0E50", "#3C0C4C", "#3A0A47", "#380742", "#37053E", "#35033A", "#340135"], "pn_moon": ["#8CA6CC", "#8DA7CD", "#90A9CE", "#92ABCF", "#96ADCF", "#98AFD0", "#9AB1D1", "#9DB2D2", "#9FB4D2", "#A2B6D3", "#A5B8D3", "#A7BAD4", "#AABCD4", "#ACBED5", "#AEC0D5", "#B0C1D6", "#B2C3D6", "#B5C5D7", "#B7C7D7", "#BAC8D8", "#BCCAD8", "#BFCCD9", "#C1CEDA", "#C4D0DB", "#C7D3DB", "#CAD5DC", "#CCD7DD", "#CED9DE", "#D0DBDF", "#D2DDE0", "#D5DEE0", "#D7E1E1", "#DAE2E1", "#DCE4E2", "#DFE6E2", "#E2E8E3", "#E4EAE3", "#E7EDE4", "#EAEFE4", "#EDF1E5", "#EFF3E6", "#F2F5E6", "#F4F7E7", "#F6F8E8", "#F8F9E9", "#FAFBEA", "#FBFCEA"], "rc_aquamarinemermaid": ["#662A70", "#B16388", "#F3C164", "#4180D6", "#662A70"], "rc_autumnrose": ["#9C2224", "#C42D25", "#E23F30", "#EF5D41", "#F38D4E", "#F59A3A", "#FABF58", "#FCCFA0"], "rc_blackhorse": ["#45610D", "#6FA6F8", "#121751", "#632D5E", "#042D25", "#45610D"], "rc_bluefly": ["#000000", "#006D93", "#DDECF7", "#000000"], "rc_butterflyfairy": ["#A74D26", "#D7A769", "#85CBCE", "#13588A", "#010609"], "rc_butterflytalker": ["#060D39", "#3E3E88", "#B7ACE4", "#B3CFE4", "#B7ACE4", "#3E3E88", "#000000"], "rc_carousel": ["#2D3077", "#2D3077", "#DEB644", "#F0C825", "#DEB644", "#A74375", "#A74375"], "rc_celticsun": ["#BF4F42", "#FFA537"], "rc_cloud": ["#FCC8A9", "#EC6499", "#8096E2"], "rc_daisyfae": ["#343600", "#9FA015", "#D6D77B", "#F8C200"], "rc_desertjewel": ["#8C8F74", "#9B924F", "#946F29", "#B95852", "#C79A9D", "#D7A487"], "rc_faecat": ["#704D6F", "#A276A2", "#77723C", "#3C402B", "#782E1A", "#E4B742", "#A7C6F9", "#B78193", "#704D6F"], "rc_fairygarden": ["#8E50B2", "#AF64C5", "#D973D5", "#C2DBF8", "#A7BAEB", "#5F6FB9"], "rc_fireandice": ["#A41D0A", "#EB470F", "#FA671D", "#588BC2", "#2A5298", "#151F34"], "rc_girlcat": ["#DCF386", "#CAE480", "#84D877", "#409E35", "#005800"], "rc_halloween": ["#DC7D02", "#000000", "#DC7D02", "#DC7D02"], "rc_hangonfatboy": ["#EF923A", "#9F5589", "#5D2F68", "#3B6AA5", "#06356D", "#06356D", "#3B6AA5", "#5D2F68", "#9F5589", "#EF923A"], "rc_healingangel": ["#AECCDB", "#98ABD7", "#BDB3E4", "#DCB8D2", "#ECADB4", "#E7B59B", "#EDEFBF"], "rc_hopegoddess": ["#F59B06", "#792570"], "rc_ildwinds": ["#5B3132", "#8A504F", "#DEC1BD", "#7188B1", "#2B3A63"], "rc_impatientfairy": ["#792E1D", "#9F4E29", "#975412", "#B45747", "#BF6464", "#C36988", "#B65D83", "#6C284F"], "rc_jeweleddragon": ["#2A1A2A", "#4D324F", "#81517A", "#AC88AC", "#CA9EAC", "#CBA0A6", "#E1AAC1", "#EFA4A3", "#F6A58E", "#EC9568", "#E07146", "#D05A30", "#792E1D"], "rc_lailah1": ["#521533", "#762E5C", "#14192D", "#171B9D", "#724733", "#A4723D", "#157569", "#96FEEA", "#605625", "#F7FEA8", "#462039", "#DD8EA7"], "rc_leo": ["#3F2E20", "#69452F", "#824C34", "#955635", "#955635", "#BB693A", "#CF7D58", "#E07B64", "#DF8262", "#F6AD87", "#F2D1A3", "#F6AD87", "#DF8262", "#E07B64", "#CF7D58", "#BB693A", "#955635", "#955635", "#824C34", "#69452F", "#3F2E20"], "rc_liahlah2": ["#7B91CC", "#414F86", "#9E6FF5", "#8E79DF", "#56BFFD", "#C2B7ED", "#5280F4", "#C189F4", "#414F86", "#7B91CC"], "rc_mistressnight": ["#272C6C", "#793D63", "#BEA057", "#793D63", "#252A6A"], "rc_otis": ["#6A1CA8", "#5AE100", "#0067AE", "#0067AE"], "rc_parrot": ["#C30021", "#E7D355", "#E7D355", "#001D70", "#001D70"], "rc_patriot": ["#FF0000", "#FF0000", "#004AFF", "#004AFF"], "rc_praire": ["#98793C", "#FFCC66"], "rc_purplefly": ["#000000", "#F900BE", "#FEFF9F", "#000000"], "rc_quagga": ["#263AA4", "#80589A", "#3E832B", "#AAD464", "#80589A", "#263AA4"], "rc_rainbow": ["#C308CA", "#DB0967", "#F33813", "#F8C11A", "#8BD608", "#14E509", "#0EEA8A", "#08B8D8", "#0837CE", "#4F09CF", "#4F09CF", "#DB09E3"], "rc_renmaiden": ["#329934", "#474255", "#E194B3", "#E9EBD2", "#F29ED9", "#E48833", "#329934"], "rc_scarletdragon": ["#1F130C", "#591E1E", "#912E1C", "#B24927", "#BF6543", "#C6724E", "#D4966A", "#F4A16C"], "rc_scoutie": ["#FFCC00", "#00E25A", "#1A0079", "#1A0079"], "rc_serendil": ["#008000", "#949844", "#C69C48", "#EFEF7D", "#F8B0E0", "#E54F5B"], "rc_shyviolet": ["#4A3970", "#7F6AA0", "#B4ACE2", "#CCCBE5", "#91A1DC", "#5F7BD3", "#3A58B2"], "rc_snodraegon": ["#6990D1", "#78A3DA", "#FFFDFD", "#766497", "#6C5A8E"], "rc_spellbound": ["#F6F67A", "#D4FC81", "#B2FB86", "#8CFD71", "#5DF789", "#4DEAD5", "#5DC7EE", "#81B8F8", "#8893FC", "#8893FC", "#ADACFC", "#BFBAFD", "#C5C1FE", "#CDBDFE", "#CFB0FE", "#CD6BDC", "#BB4DA6", "#D76589", "#FFA89F", "#F5F681", "#F5F681"], "rc_springangel": ["#AFC9C9", "#78A8D9", "#9FA9B7", "#A1A5B7", "#D8C4C4", "#E2C4C2", "#E0B8AD", "#E3A38D", "#F19E6A", "#AD9C7B", "#AD9C7B"], "rc_springbird": ["#4A74CD", "#4A74CD", "#E5B6D5", "#E5B6D5"], "rc_sunlitwave": ["#3B39A4", "#7A58B7", "#592D8E", "#681C5D", "#76172B", "#DD6A3E", "#ECAA56", "#F9EAD3"], "rc_tashangel": ["#C78CE6", "#2E1571", "#8968C3", "#E8F1F8", "#7FDEF4", "#C78CE6"], "rc_titannightfall": ["#DC90B6", "#BA6697", "#9D5096", "#2E1A71", "#9D5096", "#BA6697", "#DC90B6"], "rc_trove": ["#51574A", "#447C69", "#74C493", "#8E8C6D", "#E4BF80", "#E9D78E", "#E2975D", "#F19670", "#E16552", "#C94A53", "#BE5168", "#A34974", "#993767", "#65387D", "#4E2472", "#9163B6", "#E279A3", "#E0598B", "#7C9FB0", "#5698C4", "#9ABF88"], "rc_tubepreview": ["#BBA663", "#FFFFFF", "#FFFFFF", "#000000", "#000000", "#FFFFFF", "#FFFFFF", "#BBA663"], "rc_wildwinds": ["#5B3132", "#8A504F", "#DEC1BD", "#7188B1", "#2B3A63"], "td_DEM_poster": ["#006147", "#107A2F", "#E8D77D", "#A14300", "#9E0000", "#6E6E6E", "#FFFFFF", "#FFFFFF"], "td_DEM_print": ["#336600", "#81C31F", "#FFFFCC", "#F4BD45", "#66330C", "#663300", "#FFFFFF"], "td_DEM_screen": ["#008435", "#33CC00", "#F4F071", "#F4BD45", "#99642B", "#FFFFFF"], "ukmo_wow_humidity": ["#31007E", "#31007E", "#000081", "#000081", "#0032B3", "#0032B3", "#0000FF", "#0000FF", "#007DFF", "#007DFF", "#00BDFF", "#00BDFF", "#17D78B", "#17D78B", "#39AD73", "#39AD73", "#2AA92A", "#2AA92A", "#2AC82A", "#2AC82A", "#00FF31", "#00FF31", "#53FF00", "#53FF00", "#9FFF00", "#9FFF00", "#FFFF00", "#FFFF00", "#FFCC00", "#FFCC00", "#FF9800", "#FF9800", "#FF6500", "#FF6500", "#FF5400", "#FF5400", "#FF0000", "#FF0000", "#FF007F", "#FF007F", "#FF2290", "#FF2290", "#FF5EB1", "#FF5EB1", "#FF86C2", "#FF86C2", "#FFAED7", "#FFAED7", "#FFD7EB", "#FFD7EB"], "ukmo_wow_rain_mmh": ["#0000CC", "#0000CC", "#3265FF", "#3265FF", "#989800", "#989800", "#FFCC00", "#FFCC00", "#FF9800", "#FF9800", "#FF0000", "#FF0000", "#FF00FF", "#FF00FF", "#CCFFFF", "#CCFFFF"], "ukmo_wow_temp_c": ["#4A001D", "#4A001D", "#31007E", "#31007E", "#000081", "#000081", "#0032B3", "#0032B3", "#0000FF", "#0000FF", "#007DFF", "#007DFF", "#00BDFF", "#00BDFF", "#17D78B", "#17D78B", "#39AD73", "#39AD73", "#2AA92A", "#2AA92A", "#2AC82A", "#2AC82A", "#00FF31", "#00FF31", "#53FF00", "#53FF00", "#9FFF00", "#9FFF00", "#FFFF00", "#FFFF00", "#FFCC00", "#FFCC00", "#FF9800", "#FF9800", "#FF6500", "#FF6500", "#FF5400", "#FF5400", "#FF0000", "#FF0000", "#FF007F", "#FF007F", "#FF2290", "#FF2290", "#FF5EB1", "#FF5EB1", "#FF86C2", "#FF86C2", "#FFAED7", "#FFAED7", "#FFD7EB", "#FFD7EB", "#FFFFFF", "#FFFFFF"], "usgs_gswa2": ["#7F9F65", "#82AE6A", "#A0C27A", "#BAD68C", "#CFE29C", "#E0E9A6", "#EDECA6", "#F2E49F", "#F0D290", "#E6BC88", "#D8A585", "#C5958A", "#D9A592", "#E3B599", "#E9C4A0", "#EAD0AA", "#E6D6B6", "#E4DAC2", "#E6DBCE", "#F0DCDC", "#FAE6ED", "#FFFFFF"], "usgs": ["#7F9F65", "#82B070", "#A0C27C", "#B9D67C", "#CFE09C", "#DFE9A8", "#F1EEA6", "#EDDF9F", "#F0D28D", "#E6BC8A", "#D8A585", "#C59587", "#D9A59C", "#E3B7B1", "#DFC0BF", "#EFCDD9", "#F4D7E1", "#F3DFE9", "#F8E3E8", "#F8E9EE", "#F6F0F5", "#FFFFFF"], "vh_Caribbean": ["#00007E", "#002DA5", "#003CB4", "#0A55C3", "#0A64CD", "#0A82C8", "#0A96C8", "#0AA0CD", "#32AAD2", "#50AAD7", "#5AB4DC", "#5AB4C8", "#78B4DC", "#96B4DC", "#A5BED2", "#AAC8E1", "#AFD7EB", "#B9DCF5", "#DCE6FA", "#EBEBFA", "#757D50", "#828750", "#848750", "#918C5A", "#A09164", "#AF9669", "#B9A069", "#C3A56E", "#CDAF69", "#D7B468", "#E1B967", "#E1B968", "#EBC366", "#F5C865", "#FAD264", "#FAF0E6"], "wkp_mars_wiki_mars": ["#784114", "#784114", "#8D542B", "#8D542B", "#A47242", "#A47242", "#BC9059", "#BC9059", "#D3AE70", "#D3AE70", "#EBCD88", "#EBCD88", "#DBB978", "#DBB978", "#CCA569", "#CCA569", "#BD915A", "#BD915A", "#AE7D4B", "#AE7D4B", "#9F6E46", "#9F6E46", "#A07850", "#A07850", "#AE8664", "#AE8664", "#BDA38C", "#BDA38C", "#CCBFB4", "#CCBFB4", "#DCD4CD", "#DCD4CD", "#F0E8E1", "#F0E8E1", "#FFFFFF", "#FFFFFF"], "wkp_plumbago_wiki_plumbago": ["#9700B0", "#9700B0", "#7000A4", "#7000A4", "#4A0097", "#4A0097", "#170097", "#170097", "#27139D", "#27139D", "#382AA1", "#382AA1", "#483FA7", "#483FA7", "#5A56AD", "#5A56AD", "#6A6BB2", "#6A6BB2", "#7A81B7", "#7A81B7", "#8B97BE", "#8B97BE", "#97A4CB", "#97A4CB", "#A8C1DC", "#A8C1DC", "#B9DFED", "#B9DFED", "#CBFEFE", "#CBFEFE", "#00A800", "#00A800", "#42B417", "#42B417", "#86BE30", "#86BE30", "#CBCB4A", "#CBCB4A", "#FEFE7E", "#FEFE7E", "#E6DE70", "#E6DE70", "#CEBF65", "#CEBF65", "#B6A057", "#B6A057", "#9E814A", "#9E814A", "#86623E", "#86623E", "#6E4332", "#6E4332", "#572424", "#572424", "#CB65CB", "#CB65CB", "#D690D6", "#D690D6", "#E4BEE4", "#E4BEE4"], "wkp_precip_wiki_precip_in": ["#FFFFFF", "#B5F5B6", "#85EE85", "#53E754", "#1AE01F", "#05D18B", "#07C4CD", "#03BAC8", "#03B1C4", "#09A7C0", "#049DBB", "#0694B9", "#0089B5", "#0280B1", "#0575AD", "#056BA9", "#0162A7", "#0058A2", "#004E9F", "#00449B", "#013A96", "#013093", "#032690", "#021D8C", "#041186", "#090882", "#020283", "#000082", "#000082"], "wkp_precip_wiki_precip_mm": ["#FFFFFF", "#BFF6C0", "#98F198", "#71EB71", "#49E54A", "#1AE01F", "#04D475", "#07C8CF", "#08C0CA", "#01B8C7", "#03B1C4", "#0AA9C1", "#05A1BD", "#0399BA", "#0792B8", "#0089B5", "#0282B2", "#027AAF", "#0871AB", "#0469A9", "#0162A7", "#005AA3", "#0052A0", "#004A9D", "#00429A", "#013A96", "#013294", "#022A91", "#05228E", "#011B8B", "#041186", "#0A0982", "#040483", "#000082", "#000082", "#000082"], "wkp_schwarzwald_wiki_schwarzwald_cont": ["#AEEFD5", "#AFF0D3", "#B0F2D0", "#B0F2CA", "#B1F2C4", "#B0F3BE", "#B0F4BA", "#B2F6B5", "#B5F6B2", "#BAF7B2", "#C0F7B2", "#C6F8B2", "#CCF9B2", "#D2FAB1", "#D9FAB2", "#E0FBB2", "#E7FCB2", "#EEFCB3", "#F5FCB3", "#FAFCB2", "#F8F9AC", "#EEF4A2", "#E2F097", "#D5EB8C", "#C6E480", "#B8DE76", "#AAD86C", "#9AD362", "#8CCD59", "#7DC752", "#6EC24A", "#5EBC42", "#4DB639", "#3EB032", "#31AB2C", "#27A52A", "#1EA02B", "#189A2E", "#129431", "#0E8E34", "#098938", "#07843C", "#0C823F", "#18823F", "#28843D", "#34883C", "#408C3B", "#4C8E3B", "#579238", "#639436", "#6E9634", "#789A32", "#809C30", "#89A02E", "#93A22B", "#9CA429", "#A6A627", "#B0AA24", "#BBAD22", "#C5B01E", "#CFB11C", "#DAB318", "#E4B414", "#EEB60E", "#F6B608", "#F8B004", "#F4A602", "#EE9B02", "#E89002", "#E28402", "#DC7A02", "#D86F02", "#D36602", "#CE5C02", "#C85402", "#C04A02", "#BA4202", "#B43A02", "#AE3102", "#A92A02", "#A32402", "#9D1E02", "#971702", "#921201", "#8D0E01", "#870800", "#820500", "#7D0400", "#7A0802", "#770D02", "#761002", "#751204", "#751404", "#751504", "#741604", "#741805", "#721A06", "#721D06", "#701F07", "#6F2108", "#6E2308", "#6E2408", "#6D2609", "#6C280A", "#6C280A", "#6C2A0A", "#6B2C0B", "#6A2C0C", "#6A2E0C", "#6B300E", "#6E3412", "#713917", "#743E1C", "#764220", "#794625", "#7D4A2B", "#804F32", "#835538", "#875A3F", "#8A6045", "#8C654C", "#906A54", "#936F5A", "#967460", "#987A68", "#9C8170", "#9E8778", "#A08D82", "#A3938B", "#A69A93", "#A7A09C", "#AAA7A4", "#ACACAB", "#AEAEAE", "#B2B2B2", "#B5B5B5", "#B8B8B8", "#BCBCBC", "#C0C0C0", "#C4C4C4", "#C8C8C8", "#CCCCCC", "#D0CED0", "#D4D2D4", "#D8D6D8", "#DAD8DA", "#DDDBDD", "#E1DFE1", "#E5E3E5", "#E9E7E9", "#EBE9EB"], "wkp_shadowxfox_colombia": ["#001E50", "#001E50", "#003366", "#003366", "#006699", "#006699", "#0099CD", "#0099CD", "#64C8FF", "#64C8FF", "#C6ECFF", "#C6ECFF", "#94AB84", "#94AB84", "#ACBF8B", "#ACBF8B", "#BDCC96", "#BDCC96", "#E4DFAF", "#E4DFAF", "#E6CA94", "#E6CA94", "#CDAB83", "#CDAB83", "#B59880", "#B59880", "#9B7B62", "#9B7B62"], "wkp_template_wiki_1.02": ["#7FA8CB", "#7FA8CB", "#92B5D5", "#92B5D5", "#A0C2DE", "#A0C2DE", "#ADCBE6", "#ADCBE6", "#B9D5ED", "#B9D5ED", "#C4DFF4", "#C4DFF4", "#CEE7F9", "#CEE7F9", "#DAF0FD", "#DAF0FD", "#ACD0A5", "#ACD0A5", "#94BF8B", "#94BF8B", "#A8C68F", "#A8C68F", "#BDCC96", "#BDCC96", "#D1D7AB", "#D1D7AB", "#E1E4B5", "#E1E4B5", "#EFEBC0", "#EFEBC0", "#E8E1B6", "#E8E1B6", "#DED6A3", "#DED6A3", "#D3CA9D", "#D3CA9D", "#CAB982", "#CAB982", "#C3A76B", "#C3A76B"], "wkp_template_wiki_2.0": ["#71ABD8", "#71ABD8", "#79B2DE", "#79B2DE", "#84B9E3", "#84B9E3", "#8DC1EA", "#8DC1EA", "#96C9F0", "#96C9F0", "#A1D2F7", "#A1D2F7", "#ACDBFB", "#ACDBFB", "#B9E3FF", "#B9E3FF", "#C6ECFF", "#C6ECFF", "#D8F2FE", "#D8F2FE", "#ACD0A5", "#ACD0A5", "#94BF8B", "#94BF8B", "#A8C68F", "#A8C68F", "#BDCC96", "#BDCC96", "#D1D7AB", "#D1D7AB", "#E1E4B5", "#E1E4B5", "#EFEBC0", "#EFEBC0", "#E8E1B6", "#E8E1B6", "#DED6A3", "#DED6A3", "#D3CA9D", "#D3CA9D", "#CAB982", "#CAB982", "#C3A76B", "#C3A76B", "#B9985A", "#B9985A", "#AA8753", "#AA8753", "#AC9A7C", "#AC9A7C", "#BAAE9A", "#BAAE9A", "#CAC3B8", "#CAC3B8", "#E0DED8", "#E0DED8", "#F5F4F2", "#F5F4F2"], "wkp_tubs_nrwc": ["#050603", "#373724", "#183E29", "#346945", "#3E8A59", "#6CA363", "#A5BA6F", "#E7D57A", "#C7A75C", "#B0783A", "#D77F3F"], "wkp_tubs_nrwd": ["#050603", "#050603", "#373724", "#373724", "#183E29", "#183E29", "#346945", "#346945", "#3E8A59", "#3E8A59", "#6CA363", "#6CA363", "#A5BA6F", "#A5BA6F", "#E7D57A", "#E7D57A", "#C7A75C", "#C7A75C", "#B0783A", "#B0783A"], "mako": ["#0B0405", "#0D0406", "#0E0508", "#0F0609", "#10060A", "#11070C", "#12080D", "#13090F", "#140910", "#150A12", "#160B13", "#170C15", "#180D16", "#190E18", "#1A0E19", "#1B0F1A", "#1C101C", "#1D111D", "#1E111F", "#1F1220", "#201322", "#211423", "#221425", "#231526", "#241628", "#251729", "#26172B", "#27182D", "#28192E", "#291930", "#291A31", "#2A1B33", "#2B1C35", "#2C1C36", "#2D1D38", "#2E1E39", "#2E1E3B", "#2F1F3D", "#30203E", "#312140", "#312142", "#322243", "#332345", "#342447", "#342548", "#35254A", "#35264C", "#36274D", "#37284F", "#372851", "#382953", "#382A54", "#392B56", "#3A2C58", "#3A2C59", "#3B2D5B", "#3B2E5D", "#3B2F5F", "#3C3060", "#3C3162", "#3D3164", "#3D3266", "#3E3367", "#3E3469", "#3E356B", "#3F366D", "#3F366F", "#3F3770", "#403872", "#403974", "#403A76", "#403B78", "#403C79", "#413D7B", "#413E7D", "#413E7F", "#413F80", "#414082", "#414184", "#414285", "#414387", "#414488", "#40468A", "#40478B", "#40488D", "#40498E", "#3F4A8F", "#3F4B90", "#3F4C92", "#3E4D93", "#3E4F94", "#3E5095", "#3D5195", "#3D5296", "#3C5397", "#3C5598", "#3B5698", "#3B5799", "#3B589A", "#3A599A", "#3A5B9B", "#3A5C9B", "#395D9C", "#395E9C", "#385F9C", "#38619D", "#38629D", "#38639D", "#37649E", "#37659E", "#37669E", "#37689F", "#36699F", "#366A9F", "#366B9F", "#366CA0", "#366DA0", "#366FA0", "#3670A0", "#3671A0", "#3572A1", "#3573A1", "#3574A1", "#3575A1", "#3576A2", "#3578A2", "#3579A2", "#357AA2", "#357BA3", "#357CA3", "#357DA3", "#357EA4", "#347FA4", "#3480A4", "#3482A4", "#3483A5", "#3484A5", "#3485A5", "#3486A5", "#3487A6", "#3488A6", "#3489A6", "#348BA6", "#348CA7", "#348DA7", "#348EA7", "#348FA7", "#3490A8", "#3491A8", "#3492A8", "#3493A8", "#3495A9", "#3496A9", "#3497A9", "#3498A9", "#3499AA", "#349AAA", "#359BAA", "#359CAA", "#359EAA", "#359FAB", "#35A0AB", "#35A1AB", "#36A2AB", "#36A3AB", "#36A4AB", "#37A5AC", "#37A6AC", "#37A8AC", "#38A9AC", "#38AAAC", "#39ABAC", "#39ACAC", "#3AADAC", "#3AAEAD", "#3BAFAD", "#3CB1AD", "#3CB2AD", "#3DB3AD", "#3EB4AD", "#3FB5AD", "#3FB6AD", "#40B7AD", "#41B8AD", "#42B9AD", "#43BAAD", "#44BCAD", "#45BDAD", "#46BEAD", "#47BFAD", "#48C0AD", "#49C1AD", "#4BC2AD", "#4CC3AD", "#4DC4AD", "#4FC5AD", "#50C6AD", "#52C7AD", "#53C9AD", "#55CAAD", "#57CBAD", "#59CCAD", "#5BCDAD", "#5ECDAD", "#60CEAC", "#62CFAC", "#65D0AD", "#68D1AD", "#6AD2AD", "#6DD3AD", "#70D4AD", "#73D4AD", "#76D5AE", "#79D6AE", "#7CD6AF", "#7FD7AF", "#82D8B0", "#85D9B1", "#88D9B1", "#8BDAB2", "#8EDBB3", "#91DBB4", "#94DCB5", "#96DDB5", "#99DDB6", "#9CDEB7", "#9EDFB8", "#A1DFB9", "#A4E0BB", "#A6E1BC", "#A9E1BD", "#ABE2BE", "#AEE3C0", "#B0E4C1", "#B2E4C2", "#B5E5C4", "#B7E6C5", "#B9E6C7", "#BBE7C8", "#BEE8CA", "#C0E9CC", "#C2E9CD", "#C4EACF", "#C6EBD1", "#C8ECD2", "#CAEDD4", "#CCEDD6", "#CEEED7", "#D0EFD9", "#D2F0DB", "#D4F1DC", "#D6F1DE", "#D8F2E0", "#DAF3E1", "#DCF4E3", "#DEF5E5"], "rocket": ["#03051A", "#04051A", "#05061B", "#06071C", "#07071D", "#08081E", "#0A091F", "#0B0920", "#0D0A21", "#0E0B22", "#100B23", "#110C24", "#130D25", "#140E26", "#160E27", "#170F28", "#180F29", "#1A102A", "#1B112B", "#1D112C", "#1E122D", "#20122E", "#211330", "#221331", "#241432", "#251433", "#271534", "#281535", "#2A1636", "#2B1637", "#2D1738", "#2E1739", "#30173A", "#31183B", "#33183C", "#34193D", "#35193E", "#37193F", "#381A40", "#3A1A41", "#3C1A42", "#3D1A42", "#3F1B43", "#401B44", "#421B45", "#431C46", "#451C47", "#461C48", "#481C48", "#491D49", "#4B1D4A", "#4C1D4B", "#4E1D4B", "#501D4C", "#511E4D", "#531E4D", "#541E4E", "#561E4F", "#581E4F", "#591E50", "#5B1E51", "#5C1E51", "#5E1F52", "#601F52", "#611F53", "#631F53", "#641F54", "#661F54", "#681F55", "#691F55", "#6B1F56", "#6D1F56", "#6E1F57", "#701F57", "#711F57", "#731F58", "#751F58", "#761F58", "#781F59", "#7A1F59", "#7B1F59", "#7D1F5A", "#7F1E5A", "#811E5A", "#821E5A", "#841E5A", "#861E5B", "#871E5B", "#891E5B", "#8B1D5B", "#8C1D5B", "#8E1D5B", "#901D5B", "#921C5B", "#931C5B", "#951C5B", "#971C5B", "#981B5B", "#9A1B5B", "#9C1B5B", "#9E1A5B", "#9F1A5B", "#A11A5B", "#A3195B", "#A4195B", "#A6195A", "#A8185A", "#AA185A", "#AB185A", "#AD1759", "#AF1759", "#B01759", "#B21758", "#B41658", "#B51657", "#B71657", "#B91657", "#BA1656", "#BC1656", "#BD1655", "#BF1654", "#C11754", "#C21753", "#C41753", "#C51852", "#C71951", "#C81951", "#CA1A50", "#CB1B4F", "#CD1C4E", "#CE1D4E", "#CF1E4D", "#D11F4C", "#D2204C", "#D3214B", "#D5224A", "#D62449", "#D72549", "#D82748", "#D92847", "#DB2946", "#DC2B46", "#DD2C45", "#DE2E44", "#DF2F44", "#E03143", "#E13342", "#E23442", "#E33641", "#E43841", "#E53940", "#E63B40", "#E73D3F", "#E83F3F", "#E8403E", "#E9423E", "#EA443E", "#EB463E", "#EB483E", "#EC4A3E", "#EC4C3E", "#ED4E3E", "#ED503E", "#EE523F", "#EE543F", "#EF5640", "#EF5840", "#EF5A41", "#F05C42", "#F05E42", "#F06043", "#F16244", "#F16445", "#F16646", "#F26747", "#F26948", "#F26B49", "#F26D4B", "#F26F4C", "#F3714D", "#F3734E", "#F37450", "#F37651", "#F37852", "#F47A54", "#F47C55", "#F47D57", "#F47F58", "#F4815A", "#F4835B", "#F4845D", "#F4865E", "#F58860", "#F58A61", "#F58B63", "#F58D64", "#F58F66", "#F59067", "#F59269", "#F5946B", "#F5966C", "#F5976E", "#F59970", "#F69B71", "#F69C73", "#F69E75", "#F6A077", "#F6A178", "#F6A37A", "#F6A47C", "#F6A67E", "#F6A880", "#F6A981", "#F6AB83", "#F6AD85", "#F6AE87", "#F6B089", "#F6B18B", "#F6B38D", "#F6B48F", "#F6B691", "#F6B893", "#F6B995", "#F6BB97", "#F6BC99", "#F6BE9B", "#F6BF9D", "#F6C19F", "#F7C2A2", "#F7C4A4", "#F7C6A6", "#F7C7A8", "#F7C9AA", "#F7CAAC", "#F7CCAF", "#F7CDB1", "#F7CFB3", "#F7D0B5", "#F8D1B8", "#F8D3BA", "#F8D4BC", "#F8D6BE", "#F8D7C0", "#F8D9C3", "#F8DAC5", "#F8DCC7", "#F9DDC9", "#F9DFCB", "#F9E0CD", "#F9E2D0", "#F9E3D2", "#F9E5D4", "#FAE6D6", "#FAE8D8", "#FAE9DA", "#FAEBDD"], "turbo": ["#30123B", "#321543", "#33184A", "#341B51", "#351E58", "#36215F", "#372466", "#38276D", "#392A73", "#3A2D79", "#3B2F80", "#3C3286", "#3D358B", "#3E3891", "#3F3B97", "#3F3E9C", "#4040A2", "#4143A7", "#4146AC", "#4249B1", "#424BB5", "#434EBA", "#4451BF", "#4454C3", "#4456C7", "#4559CB", "#455CCF", "#455ED3", "#4661D6", "#4664DA", "#4666DD", "#4669E0", "#466BE3", "#476EE6", "#4771E9", "#4773EB", "#4776EE", "#4778F0", "#477BF2", "#467DF4", "#4680F6", "#4682F8", "#4685FA", "#4687FB", "#458AFC", "#458CFD", "#448FFE", "#4391FE", "#4294FF", "#4196FF", "#4099FF", "#3E9BFE", "#3D9EFE", "#3BA0FD", "#3AA3FC", "#38A5FB", "#37A8FA", "#35ABF8", "#33ADF7", "#31AFF5", "#2FB2F4", "#2EB4F2", "#2CB7F0", "#2AB9EE", "#28BCEB", "#27BEE9", "#25C0E7", "#23C3E4", "#22C5E2", "#20C7DF", "#1FC9DD", "#1ECBDA", "#1CCDD8", "#1BD0D5", "#1AD2D2", "#1AD4D0", "#19D5CD", "#18D7CA", "#18D9C8", "#18DBC5", "#18DDC2", "#18DEC0", "#18E0BD", "#19E2BB", "#19E3B9", "#1AE4B6", "#1CE6B4", "#1DE7B2", "#1FE9AF", "#20EAAC", "#22EBAA", "#25ECA7", "#27EEA4", "#2AEFA1", "#2CF09E", "#2FF19B", "#32F298", "#35F394", "#38F491", "#3CF58E", "#3FF68A", "#43F787", "#46F884", "#4AF880", "#4EF97D", "#52FA7A", "#55FA76", "#59FB73", "#5DFC6F", "#61FC6C", "#65FD69", "#69FD66", "#6DFE62", "#71FE5F", "#75FE5C", "#79FE59", "#7DFF56", "#80FF53", "#84FF51", "#88FF4E", "#8BFF4B", "#8FFF49", "#92FF47", "#96FE44", "#99FE42", "#9CFE40", "#9FFD3F", "#A1FD3D", "#A4FC3C", "#A7FC3A", "#A9FB39", "#ACFB38", "#AFFA37", "#B1F936", "#B4F836", "#B7F735", "#B9F635", "#BCF534", "#BEF434", "#C1F334", "#C3F134", "#C6F034", "#C8EF34", "#CBED34", "#CDEC34", "#D0EA34", "#D2E935", "#D4E735", "#D7E535", "#D9E436", "#DBE236", "#DDE037", "#DFDF37", "#E1DD37", "#E3DB38", "#E5D938", "#E7D739", "#E9D539", "#EBD339", "#ECD13A", "#EECF3A", "#EFCD3A", "#F1CB3A", "#F2C93A", "#F4C73A", "#F5C53A", "#F6C33A", "#F7C13A", "#F8BE39", "#F9BC39", "#FABA39", "#FBB838", "#FBB637", "#FCB336", "#FCB136", "#FDAE35", "#FDAC34", "#FEA933", "#FEA732", "#FEA431", "#FEA130", "#FE9E2F", "#FE9B2D", "#FE992C", "#FE962B", "#FE932A", "#FE9029", "#FD8D27", "#FD8A26", "#FC8725", "#FC8423", "#FB8122", "#FB7E21", "#FA7B1F", "#F9781E", "#F9751D", "#F8721C", "#F76F1A", "#F66C19", "#F56918", "#F46617", "#F36315", "#F26014", "#F15D13", "#F05B12", "#EF5811", "#ED5510", "#EC530F", "#EB500E", "#EA4E0D", "#E84B0C", "#E7490C", "#E5470B", "#E4450A", "#E2430A", "#E14109", "#DF3F08", "#DD3D08", "#DC3B07", "#DA3907", "#D83706", "#D63506", "#D43305", "#D23105", "#D02F05", "#CE2D04", "#CC2B04", "#CA2A04", "#C82803", "#C52603", "#C32503", "#C12302", "#BE2102", "#BC2002", "#B91E02", "#B71D02", "#B41B01", "#B21A01", "#AF1801", "#AC1701", "#A91601", "#A71401", "#A41301", "#A11201", "#9E1001", "#9B0F01", "#980E01", "#950D01", "#920B01", "#8E0A01", "#8B0902", "#880802", "#850702", "#810602", "#7E0502", "#7A0403"] };